Index: libgomp/ChangeLog
===================================================================
--- libgomp/ChangeLog	(.../tags/gcc_8_1_0_release)
+++ libgomp/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,13 @@
+2018-05-02  Tom de Vries  <tom@codesourcery.com>
+
+	backport from trunk:
+	2018-04-26  Tom de Vries  <tom@codesourcery.com>
+
+	PR target/85519
+	* testsuite/libgomp.fortran/examples-4/declare_target-1.f90: Reduce
+	recursion depth from 25 to 23.
+	* testsuite/libgomp.fortran/examples-4/declare_target-2.f90: Same.
+
 2018-05-02  Release Manager
 
 	* GCC 8.1.0 released.
Index: libgomp/testsuite/libgomp.fortran/examples-4/declare_target-1.f90
===================================================================
--- libgomp/testsuite/libgomp.fortran/examples-4/declare_target-1.f90	(.../tags/gcc_8_1_0_release)
+++ libgomp/testsuite/libgomp.fortran/examples-4/declare_target-1.f90	(.../branches/gcc-8-branch)
@@ -27,5 +27,7 @@
 program e_53_1
   use e_53_1_mod, only : fib, fib_wrapper
   if (fib (15) /= fib_wrapper (15)) STOP 1
-  if (fib (25) /= fib_wrapper (25)) STOP 2
+  ! Reduced from 25 to 23, otherwise execution runs out of thread stack on
+  ! Nvidia Titan V.
+  if (fib (23) /= fib_wrapper (23)) STOP 2
 end program
Index: libgomp/testsuite/libgomp.fortran/examples-4/declare_target-2.f90
===================================================================
--- libgomp/testsuite/libgomp.fortran/examples-4/declare_target-2.f90	(.../tags/gcc_8_1_0_release)
+++ libgomp/testsuite/libgomp.fortran/examples-4/declare_target-2.f90	(.../branches/gcc-8-branch)
@@ -4,9 +4,11 @@
   !$omp declare target (fib)
   integer :: x, fib
   !$omp target map(from: x)
-    x = fib (25)
+    ! Reduced from 25 to 23, otherwise execution runs out of thread stack on
+    ! Nvidia Titan V.
+    x = fib (23)
   !$omp end target
-  if (x /= fib (25)) STOP 1
+  if (x /= fib (23)) STOP 1
 end program
 
 integer recursive function fib (n) result (f)
Index: libstdc++-v3/src/filesystem/ops.cc
===================================================================
--- libstdc++-v3/src/filesystem/ops.cc	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/src/filesystem/ops.cc	(.../branches/gcc-8-branch)
@@ -1132,10 +1132,11 @@
       ec.assign(errno, std::generic_category());
   else
     {
+      uintmax_t fragment_size = f.f_frsize;
       info = space_info{
-	f.f_blocks * f.f_frsize,
-	f.f_bfree * f.f_frsize,
-	f.f_bavail * f.f_frsize
+	f.f_blocks * fragment_size,
+	f.f_bfree * fragment_size,
+	f.f_bavail * fragment_size
       };
       ec.clear();
     }
Index: libstdc++-v3/src/filesystem/std-ops.cc
===================================================================
--- libstdc++-v3/src/filesystem/std-ops.cc	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/src/filesystem/std-ops.cc	(.../branches/gcc-8-branch)
@@ -1378,10 +1378,11 @@
       ec.assign(errno, std::generic_category());
   else
     {
+      uintmax_t fragment_size = f.f_frsize;
       info = space_info{
-	f.f_blocks * f.f_frsize,
-	f.f_bfree * f.f_frsize,
-	f.f_bavail * f.f_frsize
+	f.f_blocks * fragment_size,
+	f.f_bfree * fragment_size,
+	f.f_bavail * fragment_size
       };
       ec.clear();
     }
Index: libstdc++-v3/include/std/optional
===================================================================
--- libstdc++-v3/include/std/optional	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/include/std/optional	(.../branches/gcc-8-branch)
@@ -82,8 +82,9 @@
   {
   public:
     bad_optional_access() { }
+
     virtual const char* what() const noexcept override
-    {return "bad optional access";}
+    { return "bad optional access"; }
 
     virtual ~bad_optional_access() noexcept = default;
   };
@@ -108,36 +109,40 @@
 	      is_trivially_move_assignable<_Tp>::value>
     struct _Optional_payload
     {
-      constexpr _Optional_payload()
-	: _M_empty() {}
+      constexpr _Optional_payload() noexcept : _M_empty() { }
 
       template <typename... _Args>
-      constexpr _Optional_payload(in_place_t, _Args&&... __args)
-	: _M_payload(std::forward<_Args>(__args)...),
-	  _M_engaged(true) {}
+	constexpr
+	_Optional_payload(in_place_t, _Args&&... __args)
+	: _M_payload(std::forward<_Args>(__args)...), _M_engaged(true) { }
 
       template<typename _Up, typename... _Args>
-      constexpr _Optional_payload(std::initializer_list<_Up> __il,
-				  _Args&&... __args)
+	constexpr
+	_Optional_payload(std::initializer_list<_Up> __il,
+			  _Args&&... __args)
 	: _M_payload(__il, std::forward<_Args>(__args)...),
-	  _M_engaged(true) {}
+	  _M_engaged(true)
+	{ }
+
       constexpr
       _Optional_payload(bool __engaged, const _Optional_payload& __other)
-	: _Optional_payload(__other)
-      {}
+      : _Optional_payload(__other)
+      { }
 
       constexpr
       _Optional_payload(bool __engaged, _Optional_payload&& __other)
-	: _Optional_payload(std::move(__other))
-      {}
+      : _Optional_payload(std::move(__other))
+      { }
 
-      constexpr _Optional_payload(const _Optional_payload& __other)
+      constexpr
+      _Optional_payload(const _Optional_payload& __other)
       {
 	if (__other._M_engaged)
 	  this->_M_construct(__other._M_payload);
       }
 
-      constexpr _Optional_payload(_Optional_payload&& __other)
+      constexpr
+      _Optional_payload(_Optional_payload&& __other)
       {
 	if (__other._M_engaged)
 	  this->_M_construct(std::move(__other._M_payload));
@@ -176,7 +181,9 @@
       }
 
       using _Stored_type = remove_const_t<_Tp>;
+
       struct _Empty_byte { };
+
       union {
           _Empty_byte _M_empty;
           _Stored_type _M_payload;
@@ -201,16 +208,12 @@
 
       // The _M_get operations have _M_engaged as a precondition.
       constexpr _Tp&
-	_M_get() noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() noexcept
+      { return this->_M_payload; }
 
       constexpr const _Tp&
-	_M_get() const noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() const noexcept
+      { return this->_M_payload; }
 
       // _M_reset is a 'safe' operation with no precondition.
       void
@@ -224,62 +227,64 @@
       }
     };
 
-  // Payload for constexpr optionals.
+  // Payload for potentially-constexpr optionals.
   template <typename _Tp>
     struct _Optional_payload<_Tp, true, true, true>
     {
-      constexpr _Optional_payload()
-	: _M_empty(), _M_engaged(false) {}
+      constexpr _Optional_payload() noexcept
+      : _M_empty(), _M_engaged(false) { }
 
       template<typename... _Args>
-      constexpr _Optional_payload(in_place_t, _Args&&... __args)
-	: _M_payload(std::forward<_Args>(__args)...),
-	  _M_engaged(true)
-      {}
+	constexpr
+	_Optional_payload(in_place_t, _Args&&... __args)
+	: _M_payload(std::forward<_Args>(__args)...), _M_engaged(true)
+	{ }
 
       template<typename _Up, typename... _Args>
-      constexpr _Optional_payload(std::initializer_list<_Up> __il,
-				  _Args&&... __args)
+	constexpr
+	_Optional_payload(std::initializer_list<_Up> __il,
+			  _Args&&... __args)
 	: _M_payload(__il, std::forward<_Args>(__args)...),
-	  _M_engaged(true) {}
+	  _M_engaged(true)
+	{ }
 
       template <class _Up> struct __ctor_tag {};
 
-      constexpr _Optional_payload(__ctor_tag<bool>,
-				  const _Tp& __other)
-	: _M_payload(__other),
-	  _M_engaged(true)
-      {}
+      constexpr
+      _Optional_payload(__ctor_tag<bool>, const _Tp& __other)
+      : _M_payload(__other), _M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(__ctor_tag<void>)
-	: _M_empty(), _M_engaged(false)
-      {}
+      constexpr _Optional_payload(__ctor_tag<void>) noexcept
+      : _M_empty(), _M_engaged(false)
+      { }
 
       constexpr _Optional_payload(__ctor_tag<bool>, _Tp&& __other)
-	: _M_payload(std::move(__other)),
-	  _M_engaged(true)
-      {}
+      : _M_payload(std::move(__other)), _M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  const _Optional_payload& __other)
-	: _Optional_payload(__engaged ?
-			    _Optional_payload(__ctor_tag<bool>{},
-					      __other._M_payload) :
-			    _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, const _Optional_payload& __other)
+      : _Optional_payload(__engaged ?
+			  _Optional_payload(__ctor_tag<bool>{},
+					    __other._M_payload) :
+			  _Optional_payload(__ctor_tag<void>{}))
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  _Optional_payload&& __other)
-	: _Optional_payload(__engaged
-			    ? _Optional_payload(__ctor_tag<bool>{},
-						std::move(__other._M_payload))
-			    : _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, _Optional_payload&& __other)
+      : _Optional_payload(__engaged
+			  ? _Optional_payload(__ctor_tag<bool>{},
+					      std::move(__other._M_payload))
+			  : _Optional_payload(__ctor_tag<void>{}))
+      { }
 
       using _Stored_type = remove_const_t<_Tp>;
+
       struct _Empty_byte { };
+
       union {
-          _Empty_byte _M_empty;
+	  _Empty_byte _M_empty;
           _Stored_type _M_payload;
       };
       bool _M_engaged;
@@ -289,53 +294,54 @@
   template <typename _Tp>
     struct _Optional_payload<_Tp, true, false, true>
     {
-      constexpr _Optional_payload()
-	: _M_empty(), _M_engaged(false) {}
+      constexpr _Optional_payload() noexcept
+      : _M_empty(), _M_engaged(false) { }
 
       template<typename... _Args>
-      constexpr _Optional_payload(in_place_t, _Args&&... __args)
-	: _M_payload(std::forward<_Args>(__args)...),
-	  _M_engaged(true)
-      {}
+	constexpr
+	_Optional_payload(in_place_t, _Args&&... __args)
+	: _M_payload(std::forward<_Args>(__args)...), _M_engaged(true)
+	{ }
 
       template<typename _Up, typename... _Args>
-      constexpr _Optional_payload(std::initializer_list<_Up> __il,
-				  _Args&&... __args)
+	constexpr
+	_Optional_payload(std::initializer_list<_Up> __il,
+			  _Args&&... __args)
 	: _M_payload(__il, std::forward<_Args>(__args)...),
-	  _M_engaged(true) {}
+	  _M_engaged(true)
+	{ }
 
       template <class _Up> struct __ctor_tag {};
 
-      constexpr _Optional_payload(__ctor_tag<bool>,
-				  const _Tp& __other)
-	: _M_payload(__other),
-	  _M_engaged(true)
-      {}
+      constexpr _Optional_payload(__ctor_tag<bool>, const _Tp& __other)
+      : _M_payload(__other),
+	_M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(__ctor_tag<void>)
-	: _M_empty(), _M_engaged(false)
-      {}
+      constexpr _Optional_payload(__ctor_tag<void>) noexcept
+      : _M_empty(), _M_engaged(false)
+      { }
 
       constexpr _Optional_payload(__ctor_tag<bool>, _Tp&& __other)
-	: _M_payload(std::move(__other)),
-	  _M_engaged(true)
-      {}
+      : _M_payload(std::move(__other)),
+	_M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  const _Optional_payload& __other)
-	: _Optional_payload(__engaged ?
-			    _Optional_payload(__ctor_tag<bool>{},
-					      __other._M_payload) :
-			    _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, const _Optional_payload& __other)
+      : _Optional_payload(__engaged ?
+			  _Optional_payload(__ctor_tag<bool>{},
+					    __other._M_payload) :
+			  _Optional_payload(__ctor_tag<void>{}))
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  _Optional_payload&& __other)
-	: _Optional_payload(__engaged
-			    ? _Optional_payload(__ctor_tag<bool>{},
-						std::move(__other._M_payload))
-			    : _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, _Optional_payload&& __other)
+      : _Optional_payload(__engaged
+			  ? _Optional_payload(__ctor_tag<bool>{},
+					      std::move(__other._M_payload))
+			  : _Optional_payload(__ctor_tag<void>{}))
+      { }
 
       _Optional_payload(const _Optional_payload&) = default;
       _Optional_payload(_Optional_payload&&) = default;
@@ -359,7 +365,9 @@
       operator=(_Optional_payload&& __other) = default;
 
       using _Stored_type = remove_const_t<_Tp>;
+
       struct _Empty_byte { };
+
       union {
           _Empty_byte _M_empty;
           _Stored_type _M_payload;
@@ -378,16 +386,12 @@
 
       // The _M_get operations have _M_engaged as a precondition.
       constexpr _Tp&
-	_M_get() noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() noexcept
+      { return this->_M_payload; }
 
       constexpr const _Tp&
-	_M_get() const noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() const noexcept
+      { return this->_M_payload; }
 
       // _M_reset is a 'safe' operation with no precondition.
       void
@@ -405,53 +409,56 @@
   template <typename _Tp>
     struct _Optional_payload<_Tp, true, true, false>
     {
-      constexpr _Optional_payload()
-	: _M_empty(), _M_engaged(false) {}
+      constexpr _Optional_payload() noexcept
+      : _M_empty(), _M_engaged(false) { }
 
       template<typename... _Args>
-      constexpr _Optional_payload(in_place_t, _Args&&... __args)
+	constexpr
+	_Optional_payload(in_place_t, _Args&&... __args)
 	: _M_payload(std::forward<_Args>(__args)...),
 	  _M_engaged(true)
-      {}
+	{ }
 
       template<typename _Up, typename... _Args>
-      constexpr _Optional_payload(std::initializer_list<_Up> __il,
-				  _Args&&... __args)
+	constexpr
+	_Optional_payload(std::initializer_list<_Up> __il,
+			  _Args&&... __args)
 	: _M_payload(__il, std::forward<_Args>(__args)...),
-	  _M_engaged(true) {}
+	  _M_engaged(true)
+	{ }
 
       template <class _Up> struct __ctor_tag {};
 
-      constexpr _Optional_payload(__ctor_tag<bool>,
-				  const _Tp& __other)
-	: _M_payload(__other),
-	  _M_engaged(true)
-      {}
+      constexpr
+      _Optional_payload(__ctor_tag<bool>, const _Tp& __other)
+      : _M_payload(__other),
+	_M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(__ctor_tag<void>)
-	: _M_empty(), _M_engaged(false)
-      {}
+      constexpr _Optional_payload(__ctor_tag<void>) noexcept
+      : _M_empty(), _M_engaged(false)
+      { }
 
       constexpr _Optional_payload(__ctor_tag<bool>, _Tp&& __other)
-	: _M_payload(std::move(__other)),
-	  _M_engaged(true)
-      {}
+      : _M_payload(std::move(__other)),
+	_M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  const _Optional_payload& __other)
-	: _Optional_payload(__engaged ?
-			    _Optional_payload(__ctor_tag<bool>{},
-					      __other._M_payload) :
-			    _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, const _Optional_payload& __other)
+      : _Optional_payload(__engaged ?
+			  _Optional_payload(__ctor_tag<bool>{},
+					    __other._M_payload) :
+			  _Optional_payload(__ctor_tag<void>{}))
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  _Optional_payload&& __other)
-	: _Optional_payload(__engaged
-			    ? _Optional_payload(__ctor_tag<bool>{},
-						std::move(__other._M_payload))
-			    : _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, _Optional_payload&& __other)
+      : _Optional_payload(__engaged
+			  ? _Optional_payload(__ctor_tag<bool>{},
+					      std::move(__other._M_payload))
+			  : _Optional_payload(__ctor_tag<void>{}))
+      { }
 
       _Optional_payload(const _Optional_payload&) = default;
       _Optional_payload(_Optional_payload&&) = default;
@@ -477,7 +484,9 @@
       }
 
       using _Stored_type = remove_const_t<_Tp>;
+
       struct _Empty_byte { };
+
       union {
           _Empty_byte _M_empty;
           _Stored_type _M_payload;
@@ -496,16 +505,12 @@
 
       // The _M_get operations have _M_engaged as a precondition.
       constexpr _Tp&
-	_M_get() noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() noexcept
+      { return this->_M_payload; }
 
       constexpr const _Tp&
-	_M_get() const noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() const noexcept
+      { return this->_M_payload; }
 
       // _M_reset is a 'safe' operation with no precondition.
       void
@@ -523,53 +528,55 @@
   template <typename _Tp>
     struct _Optional_payload<_Tp, true, false, false>
     {
-      constexpr _Optional_payload()
-	: _M_empty(), _M_engaged(false) {}
+      constexpr _Optional_payload() noexcept
+      : _M_empty(), _M_engaged(false) {}
 
       template<typename... _Args>
-      constexpr _Optional_payload(in_place_t, _Args&&... __args)
+	constexpr
+	_Optional_payload(in_place_t, _Args&&... __args)
 	: _M_payload(std::forward<_Args>(__args)...),
 	  _M_engaged(true)
-      {}
+	{ }
 
       template<typename _Up, typename... _Args>
-      constexpr _Optional_payload(std::initializer_list<_Up> __il,
-				  _Args&&... __args)
+	constexpr
+	_Optional_payload(std::initializer_list<_Up> __il,
+			  _Args&&... __args)
 	: _M_payload(__il, std::forward<_Args>(__args)...),
-	  _M_engaged(true) {}
+	  _M_engaged(true)
+	{ }
 
       template <class _Up> struct __ctor_tag {};
 
-      constexpr _Optional_payload(__ctor_tag<bool>,
-				  const _Tp& __other)
-	: _M_payload(__other),
-	  _M_engaged(true)
-      {}
+      constexpr _Optional_payload(__ctor_tag<bool>, const _Tp& __other)
+      : _M_payload(__other),
+	    _M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(__ctor_tag<void>)
-	: _M_empty(), _M_engaged(false)
-      {}
+      constexpr _Optional_payload(__ctor_tag<void>) noexcept
+      : _M_empty(), _M_engaged(false)
+      { }
 
       constexpr _Optional_payload(__ctor_tag<bool>, _Tp&& __other)
-	: _M_payload(std::move(__other)),
-	  _M_engaged(true)
-      {}
+      : _M_payload(std::move(__other)),
+	_M_engaged(true)
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  const _Optional_payload& __other)
-	: _Optional_payload(__engaged ?
-			    _Optional_payload(__ctor_tag<bool>{},
-					      __other._M_payload) :
-			    _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, const _Optional_payload& __other)
+      : _Optional_payload(__engaged ?
+			  _Optional_payload(__ctor_tag<bool>{},
+					    __other._M_payload) :
+			  _Optional_payload(__ctor_tag<void>{}))
+      { }
 
-      constexpr _Optional_payload(bool __engaged,
-				  _Optional_payload&& __other)
-	: _Optional_payload(__engaged
-			    ? _Optional_payload(__ctor_tag<bool>{},
-						std::move(__other._M_payload))
-			    : _Optional_payload(__ctor_tag<void>{}))
-      {}
+      constexpr
+      _Optional_payload(bool __engaged, _Optional_payload&& __other)
+      : _Optional_payload(__engaged
+			  ? _Optional_payload(__ctor_tag<bool>{},
+					      std::move(__other._M_payload))
+			  : _Optional_payload(__ctor_tag<void>{}))
+      { }
 
       _Optional_payload(const _Optional_payload&) = default;
       _Optional_payload(_Optional_payload&&) = default;
@@ -607,7 +614,9 @@
       }
 
       using _Stored_type = remove_const_t<_Tp>;
+
       struct _Empty_byte { };
+
       union {
           _Empty_byte _M_empty;
           _Stored_type _M_payload;
@@ -626,16 +635,12 @@
 
       // The _M_get operations have _M_engaged as a precondition.
       constexpr _Tp&
-	_M_get() noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() noexcept
+      { return this->_M_payload; }
 
       constexpr const _Tp&
-	_M_get() const noexcept
-      {
-	return this->_M_payload;
-      }
+      _M_get() const noexcept
+      { return this->_M_payload; }
 
       // _M_reset is a 'safe' operation with no precondition.
       void
@@ -658,15 +663,15 @@
       // The _M_construct operation has !_M_engaged as a precondition
       // while _M_destruct has _M_engaged as a precondition.
       template<typename... _Args>
-      void
-      _M_construct(_Args&&... __args)
+	void
+	_M_construct(_Args&&... __args)
 	noexcept(is_nothrow_constructible<_Stored_type, _Args...>())
-      {
-	::new
-	  (std::__addressof(static_cast<_Dp*>(this)->_M_payload._M_payload))
-	  _Stored_type(std::forward<_Args>(__args)...);
-	static_cast<_Dp*>(this)->_M_payload._M_engaged = true;
-      }
+	{
+	  ::new
+	    (std::__addressof(static_cast<_Dp*>(this)->_M_payload._M_payload))
+	    _Stored_type(std::forward<_Args>(__args)...);
+	  static_cast<_Dp*>(this)->_M_payload._M_engaged = true;
+	}
       
       void
       _M_destruct() noexcept
@@ -700,8 +705,8 @@
       : protected _Optional_base_impl<_Tp, _Optional_base<_Tp>>
     {
       friend class _Optional_base_impl<_Tp, _Optional_base<_Tp>>;
+
     public:
-
       // Constructors for disengaged optionals.
       constexpr _Optional_base() = default;
 
Index: libstdc++-v3/include/std/variant
===================================================================
--- libstdc++-v3/include/std/variant	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/include/std/variant	(.../branches/gcc-8-branch)
@@ -1389,7 +1389,7 @@
 
       using _Result_type =
 	decltype(std::forward<_Visitor>(__visitor)(
-	    get<0>(std::forward<_Variants>(__variants))...));
+	    std::get<0>(std::forward<_Variants>(__variants))...));
 
       constexpr auto& __vtable = __detail::__variant::__gen_vtable<
 	_Result_type, _Visitor&&, _Variants&&...>::_S_vtable;
Index: libstdc++-v3/ChangeLog
===================================================================
--- libstdc++-v3/ChangeLog	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,31 @@
+2018-05-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/85642 fix is_nothrow_default_constructible<optional<T>>
+	* include/std/optional (_Optional_payload): Add noexcept to default
+	constructor. Re-indent.
+	(_Optional_payload<_Tp, true, true, true>): Likewise. Add noexcept to
+	constructor for copying disengaged payloads.
+	(_Optional_payload<_Tp, true, false, true>): Likewise.
+	(_Optional_payload<_Tp, true, true, false>): Likewise.
+	(_Optional_payload<_Tp, true, false, false>): Likewise.
+	* testsuite/20_util/optional/cons/85642.cc: New.
+	* testsuite/20_util/optional/cons/value_neg.cc: Adjust dg-error lines.
+
+2018-05-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/84769
+	* include/std/variant (visit): Qualify std::get call.
+
+2018-05-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/85632 use uintmax_t for arithmetic
+	* src/filesystem/ops.cc (experimental::filesystem::space): Perform
+	arithmetic in result type.
+	* src/filesystem/std-ops.cc (filesystem::space): Likewise.
+	* testsuite/27_io/filesystem/operations/space.cc: Check total capacity
+	is greater than free space.
+	* testsuite/experimental/filesystem/operations/space.cc: New.
+
 2018-05-02  Release Manager
 
 	* GCC 8.1.0 released.
Index: libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/testsuite/27_io/filesystem/operations/space.cc	(.../branches/gcc-8-branch)
@@ -32,6 +32,7 @@
   std::error_code ec = make_error_code(std::errc::invalid_argument);
   s = std::filesystem::space("/", ec);
   VERIFY( !ec );
+
   s = std::filesystem::space(__gnu_test::nonexistent_path(), ec);
   VERIFY( ec );
   VERIFY( s.capacity ==  static_cast<uintmax_t>(-1) );
@@ -39,8 +40,16 @@
   VERIFY( s.available ==  static_cast<uintmax_t>(-1) );
 }
 
+void
+test02()
+{
+  std::filesystem::space_info s = std::filesystem::space(".");
+  VERIFY( s.capacity >= s.free );
+}
+
 int
 main()
 {
   test01();
+  test02();
 }
Index: libstdc++-v3/testsuite/experimental/filesystem/operations/space.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/operations/space.cc	(.../tags/gcc_8_1_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/experimental/filesystem/operations/space.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,57 @@
+// Copyright (C) 2017-2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-DUSE_FILESYSTEM_TS -lstdc++fs" }
+// { dg-do run { target c++11 } }
+// { dg-require-filesystem-ts "" }
+
+// 30.10.14.3 Permissions [fs.op.space]
+
+#include <experimental/filesystem>
+#include <testsuite_fs.h>
+#include <testsuite_hooks.h>
+
+namespace fs = std::experimental::filesystem;
+
+void
+test01()
+{
+  fs::space_info s = fs::space("/");
+  std::error_code ec = make_error_code(std::errc::invalid_argument);
+  s = fs::space("/", ec);
+  VERIFY( !ec );
+
+  s = fs::space(__gnu_test::nonexistent_path(), ec);
+  VERIFY( ec );
+  VERIFY( s.capacity ==  static_cast<uintmax_t>(-1) );
+  VERIFY( s.free ==  static_cast<uintmax_t>(-1) );
+  VERIFY( s.available ==  static_cast<uintmax_t>(-1) );
+}
+
+void
+test02()
+{
+  fs::space_info s = fs::space(".");
+  VERIFY( s.capacity >= s.free );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc	(.../tags/gcc_8_1_0_release)
+++ libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc	(.../branches/gcc-8-branch)
@@ -37,8 +37,8 @@
     std::optional<std::unique_ptr<int>> oup2 = new int;  // { dg-error "conversion" }
     struct U { explicit U(std::in_place_t); };
     std::optional<U> ou(std::in_place); // { dg-error "no matching" }
-    // { dg-error "no type" "" { target { *-*-* } } 1015 }
-    // { dg-error "no type" "" { target { *-*-* } } 1025 }
-    // { dg-error "no type" "" { target { *-*-* } } 1082 }
+    // { dg-error "no type" "" { target { *-*-* } } 1020 }
+    // { dg-error "no type" "" { target { *-*-* } } 1030 }
+    // { dg-error "no type" "" { target { *-*-* } } 1087 }
   }
 }
Index: libstdc++-v3/testsuite/20_util/optional/cons/85642.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/optional/cons/85642.cc	(.../tags/gcc_8_1_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/20_util/optional/cons/85642.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,63 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++17 } }
+
+#include <optional>
+
+struct NonTrivialDtor {
+  ~NonTrivialDtor() { }
+};
+
+struct NonTrivialCopyAssign {
+  NonTrivialCopyAssign& operator=(const NonTrivialCopyAssign&) { return *this; }
+  NonTrivialCopyAssign& operator=(NonTrivialCopyAssign&&) = default;
+};
+
+struct NonTrivialMoveAssign {
+  NonTrivialMoveAssign& operator=(const NonTrivialMoveAssign&) = default;
+  NonTrivialMoveAssign& operator=(NonTrivialMoveAssign&&) { return *this; }
+};
+
+struct NonTrivialAssign {
+  NonTrivialAssign& operator=(const NonTrivialAssign&) { return *this; }
+  NonTrivialAssign& operator=(NonTrivialAssign&&) { return *this; }
+};
+
+struct NonTrivialAll {
+  ~NonTrivialAll() { }
+  NonTrivialAll& operator=(const NonTrivialAll&) { return *this; }
+  NonTrivialAll& operator=(NonTrivialAll&&) { return *this; }
+};
+
+struct ConstExpr { int i = 0; };
+
+struct Trivial { int i; };
+
+template<typename T>
+  constexpr bool check
+    = std::is_nothrow_default_constructible_v<std::optional<T>>;
+
+// PR libstdc++/85642
+static_assert(check<NonTrivialDtor>);
+static_assert(check<NonTrivialCopyAssign>);
+static_assert(check<NonTrivialMoveAssign>);
+static_assert(check<NonTrivialAssign>);
+static_assert(check<NonTrivialAll>);
+static_assert(check<ConstExpr>);
+static_assert(check<Trivial>);
Index: gcc/DATESTAMP
===================================================================
--- gcc/DATESTAMP	(.../tags/gcc_8_1_0_release)
+++ gcc/DATESTAMP	(.../branches/gcc-8-branch)
@@ -1 +1 @@
-20180502
+20180504
Index: gcc/ChangeLog
===================================================================
--- gcc/ChangeLog	(.../tags/gcc_8_1_0_release)
+++ gcc/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,7 @@
+2018-05-02  Jakub Jelinek  <jakub@redhat.com>
+
+	* BASE-VER: Set to 8.1.1.
+
 2018-05-02  Release Manager
 
 	* GCC 8.1.0 released.
Index: gcc/ada/init.c
===================================================================
--- gcc/ada/init.c	(.../tags/gcc_8_1_0_release)
+++ gcc/ada/init.c	(.../branches/gcc-8-branch)
@@ -1279,7 +1279,7 @@
 
   /* If it was a DEC Ada specific condtiion, make it GNAT otherwise
      keep the old facility.  */
-  if (sigargs [1] & FAC_MASK == DECADA_M_FACILITY)
+  if ((sigargs [1] & FAC_MASK) == DECADA_M_FACILITY)
     SYS$PUTMSG (sigargs, copy_msg, &gnat_facility,
 	        (unsigned long long ) message);
   else
Index: gcc/ada/ChangeLog
===================================================================
--- gcc/ada/ChangeLog	(.../tags/gcc_8_1_0_release)
+++ gcc/ada/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,13 @@
+2018-05-04  John Marino  <gnugcc@marino.st>
+
+	PR ada/85635
+	* link.c (BSD platforms): Add missing backslash.
+
+2018-05-04  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR ada/85540
+	* init.c (__gnat_handle_vms_condition): Add missing parentheses.
+
 2018-05-02  Release Manager
 
 	* GCC 8.1.0 released.
Index: gcc/ada/link.c
===================================================================
--- gcc/ada/link.c	(.../tags/gcc_8_1_0_release)
+++ gcc/ada/link.c	(.../branches/gcc-8-branch)
@@ -104,7 +104,7 @@
 const char *__gnat_default_libgcc_subdir = "lib";
 
 #elif defined (__FreeBSD__) || defined (__DragonFly__) \
-   || defined (__NetBSD__) || defined (__OpenBSD__)
+   || defined (__NetBSD__) || defined (__OpenBSD__) \
    || defined (__QNX__)
 const char *__gnat_object_file_option = "-Wl,@";
 const char *__gnat_run_path_option = "-Wl,-rpath,";
Index: gcc/BASE-VER
===================================================================
--- gcc/BASE-VER	(.../tags/gcc_8_1_0_release)
+++ gcc/BASE-VER	(.../branches/gcc-8-branch)
@@ -1 +1 @@
-8.1.0
+8.1.1
Index: gcc/po/es.po
===================================================================
--- gcc/po/es.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/es.po	(.../branches/gcc-8-branch)
@@ -41,8 +41,8 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1-b20180401\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
-"PO-Revision-Date: 2018-04-07 11:09+0200\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"PO-Revision-Date: 2018-05-02 18:50+0200\n"
 "Last-Translator: Antonio Ceballos Roa <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
 "Language: es\n"
@@ -185,40 +185,40 @@
 msgid "negative insn length"
 msgstr "longitud de insn negativa"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "no se puede dividir insn"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "'asm' no válido: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "alternativas de dialecto ensamblador anidadas"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "alternativa de dialecto ensamblador sin terminar"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "falta un número operando después de %%-letra"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "número operando fuera de rango"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "%%-código no válido"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "el operando '%%l' no es una etiqueta"
@@ -229,13 +229,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "constante de coma flotante mal usada"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1199,25 +1199,25 @@
 msgid "At top level:"
 msgstr "En el nivel principal:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "En la función miembro %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "En la función %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    incluido en línea de %qs en %r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    incluido en línea de %qs en %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    incluido en línea de %qs"
@@ -2967,9 +2967,9 @@
 msgid "invalid address mode"
 msgstr "modo de direccionamiento no válido"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
@@ -2985,7 +2985,7 @@
 msgstr "valor %%r no válido"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2992,13 +2992,13 @@
 msgstr "valor %%R no válido"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
@@ -3029,7 +3029,7 @@
 msgstr "valor %%U no válido"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
@@ -3040,7 +3040,7 @@
 msgstr "valor %%C no válido"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
@@ -3051,7 +3051,7 @@
 msgstr "reubicación unspec desconocida"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3062,57 +3062,57 @@
 msgid "invalid operand address"
 msgstr "dirección de operando no válida"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "operando no válido para el código %%Z"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "operando no válido para el código %%z"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "operandos no válidos para el código %%c"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "operando no válido para el código %%M"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "operador no válido para el código %%p"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "operando no válido para el código %%s"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "operando no válido para el código %%R"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "operando no válido para el código %%H%%L"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "operando no válido para el código %%U"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "operando no válido para el código %%V"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "operando no válido para el código %%O"
@@ -3119,18 +3119,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "operando no válido en el código de salida"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC no válido como operando: %d"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "no se reconoce la constante supuesta"
 
@@ -3165,7 +3165,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
@@ -3288,8 +3288,8 @@
 msgstr "operando const_double no válido"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3506,98 +3506,98 @@
 msgid "bad output_condmove_single operand"
 msgstr "operando output_condmove_single erróneo"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC no válido como operando"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "uso no válido del registro '%s'"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "tipo no válido de la salida del indicador asm"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "tamaño de operando no válido para el código de operando 'O'"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "tamaño de operando no válido para el código de operando 'z'"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "se usó un tipo de operando no válido con el código de operando 'Z'"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "tamaño de operando no válido para el código de operando 'Z'"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "el operando no es un código de condición, código de operando 'Y' no válido"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "el operando no es un código de condición, código de operando 'D' no válido"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "el operando no es un código de condición, código de operando '%c' no válido"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "el operando no es una referencia de memoria desplazable, código de operando 'H' no válido"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "el operando no es un entero, código de operando 'K' no válido"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "el operando no es un entero concreto, código de operando 'r' no válido"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "el operando no es un entero, código de operando 'R' no válido"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "el operando no es un entero concreto, código de operando 'R' no válido"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "código de operando '%c' no válido"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "restricciones no válidas para el operando"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid vector constant"
 msgid "invalid vector immediate"
 msgstr "constante de vector no válida"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "modo insn desconocido"
 
@@ -3635,7 +3635,7 @@
 msgstr "operando %%P no válido"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -3689,7 +3689,7 @@
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -3852,141 +3852,141 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion requiere modelo de código medio/grande"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 y __ibm128 no pueden utilizarse en la misma expresión"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, reg #1 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, reg #2 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load no MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, reg #1 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, reg #2 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store no MEM"
 
@@ -4112,43 +4112,43 @@
 msgid "created and used with different endianness"
 msgstr "creado y usado con diferente orden de bits"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "operando %%Y no válido"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "operando %%A no válido"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "operando %%B no válido"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "operando %%C no válido"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "operando %%D no válido"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "operando %%f no válido"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "operando %%s no válido"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "la constante de coma flotante no es un operando inmediato válido"
@@ -4363,14 +4363,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -4385,7 +4385,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -4393,7 +4393,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -4407,7 +4407,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
@@ -4414,7 +4414,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -4424,13 +4424,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
@@ -4439,18 +4439,18 @@
 msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
@@ -4458,23 +4458,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
@@ -4483,7 +4483,7 @@
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -4494,39 +4494,39 @@
 msgid "expected label"
 msgstr "se esperaba etiqueta"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "candidato 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "candidato 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "salto a la etiqueta %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "salto a la etiqueta case"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr "entra en el bloque try"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr "entra en el bloque catch"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr "entra en el bloque estructurado OpenMP"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr "entra en la sentencia sincronizada o atómica"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -4617,7 +4617,7 @@
 msgid "<statement>"
 msgstr "<sentencia>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<desconocido>"
@@ -4636,114 +4636,114 @@
 msgid "<unparsed>"
 msgstr "<sidecodificar>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr "<lambda>"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<error de expresión>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<operador desconocido>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "En el ámbito global:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "En la función miembro static %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "En el constructor copia %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "En el constructor %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "En el destructor %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "En la función lambda"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: En la sustitución de %qS:\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: En la instanciación de %q#D:\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr "%r%s:%d:%d:%R   "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr "%r%s:%d:%R   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "se requiere recursivamente para la sustitución de %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr "se requiere para la sustitución de %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr "se requiere recursivamente desde %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr "se requiere desde %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr "se requiere recursivamente desde aquí\n"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr "se requiere desde aquí\n"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%d:%R   [ se saltan %d contextos de instanciación; utilice -ftemplate-backtrace-limit=0 para desactivarlo ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%R   [ se saltan %d contextos de instanciación; utilice -ftemplate-backtrace-limit=0 para desactivarlo ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%d:%R   en la expansión de la %<constexpr%> de %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   en la expansión de la %<constexpr%> de %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "los candidatos son:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
@@ -4789,48 +4789,48 @@
 msgid "source type is not polymorphic"
 msgstr "el tipo fuente no es polimórfico"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argumento de tipo erróneo para el decremento unario"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argumento de tipo erróneo para el incremento unario"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argumento de tipo erróneo para complemento de bits"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argumento de tipo erróneo para abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argumento de tipo erróneo para la conjugación"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "en el argumento para el ! unario"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "no hay operador de pre-incremento para el tipo"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "no hay operador de post-incremento para el tipo"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "no hay operador de pre-decremento para el tipo"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "no hay operador de post-decremento para el tipo"
 
@@ -5101,11 +5101,11 @@
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
@@ -5260,47 +5260,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangos inconsistentes para el operador en %%L y %%L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -5342,12 +5342,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Longitudes de caracteres desiguales (%ld/%ld) en %s"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es negativo (su valor es %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es demasiado grande"
 
@@ -5581,6 +5581,7 @@
 msgstr "-Xbind-now y -Xbind-lazy son incompatibles"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "considere usar `-pg' en lugar de `-p' con gprof (1)"
 
@@ -8244,7 +8245,7 @@
 msgstr "Alinea las variables en límites de 32-bit."
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr "Especifica el nombre de la arquitectura destino."
 
@@ -8690,7 +8691,7 @@
 msgstr "Especifica el rango de registros a convertir en fijos."
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr "Especifica el tamaño de bit para los desplazamientos TLS inmediatos."
 
@@ -9349,7 +9350,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Genera código que cumpla con la ABI dada."
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "ABIs conocidas (para usar con la opción -mabi=):"
 
@@ -9755,7 +9756,7 @@
 msgstr "Admite funciones internas y generación de código PKU."
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr "USa la guarda de protección de la pila dada."
 
@@ -9764,12 +9765,12 @@
 msgstr "Guarda de protección de pila conocida (para usar con la opción -mstack-protector-guard=):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Usa el registro base dado para direccionar la guarda de protección de la pila."
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Usa el desplazamiento dado para direccionar la guarda de protección de la pila."
 
@@ -9782,45 +9783,47 @@
 msgstr "Trata de evitar que se generen secuencias de instrucciones que contengan ret bytes."
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation."
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Admite funciones internas y generación de código MMX y SSE."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
 msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr "Activa la instrumentación CET para sentencias switch que usan tabla de saltos y salto indirecto."
 
-#: config/i386/i386.opt:1031
+#: config/i386/i386.opt:1021
 msgid "Make all function calls indirect."
 msgstr "Hace indirectas todas las llamadas a función."
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "el tipo de devolución de función no puede ser función"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Opciones conocidas para ramificación indirecta (para usar con las opciones -mindirect-branch=/-mfunction-return=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Admite funciones internas y generación de código BMI."
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Admite funciones internas y generación de código BMI."
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr "Asume que el código se enlazará mediante ld de GNU."
@@ -10196,7 +10199,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Opción obsoleta.  Use en su lugar -mvrsave."
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr "Especifica cúantos bytes se debe mover en inclusión en línea antes de llamar a memcpy/memmove."
 
@@ -10204,7 +10207,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10288,7 +10291,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\tCódigo de planificador para la CPU dada."
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr "-mtraceback=\tSelecciona la tabla full, part, ó sin traceback."
 
@@ -10316,7 +10319,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Argumentos válidos para -mfloat-gprs:"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr "-mlong-double-<n>\tEspecifica el tamaño de long double (64 ó 128 bits)."
 
@@ -10392,23 +10395,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Usa instrucciones ISA 2.07 Category:Vector.AES y Category:Vector.SHA2."
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr "Usa movimiento directo de ISA 2.07 entre las instrucciones de registro GPR & VSX."
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Usa instrucciones de memoria transaccionales (HTM) de ISA 2.07."
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Genera instrucciones de memoria quad word (lq/stq)."
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr "Genera instrucciones atómicas de memoria quad word (lqarx/stqcx)."
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr "Genera parámetros agregados pasando código con alineamiento de 64 bits a lo sumo."
 
@@ -10428,19 +10431,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr "Permite variables enteras de 64 bits en los registros superiores con -mcpu=power7 o -mvsx."
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr "Analiza y elimina intercambios de palabra doble en cómputos VSX."
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr "Fusiona ciertas operaciones para un mejor rendimiento en power9."
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Usa ciertas instrucciones escalares añadidas en ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr "Usa instrucciones vectoriales añadidas en ISA 3.0."
 
@@ -10456,15 +10459,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr "Usa instrucciones de memoria registro+desplazamiento añadidas en ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Usa las nuevas instrucciones min/max definidas en ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr "fusiona referencias toc de modelo código mediano/grande con la instrucción de memoria."
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr "Genera las instrucciones módulo de enteros."
 
@@ -10472,15 +10475,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr "Permite los tipos de 128 bits de IEEE sin necesidad de la palabra clave __float128."
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "Activa coma flotante de 128 bits IEEE mediante la palabra clave __float128."
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Activa el uso de instrucciones de coma flotante de 128 bits IEEE."
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr "Activa las conversiones predefinidas entre __float128 y long double."
 
@@ -10488,7 +10491,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Permite enteros pequeños en registros VSX."
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Argumentos válidos para -mstack-protector-guard=:"
 
@@ -10517,12 +10520,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Llama a mcount para análisis de perfil antes del prólogo de una función."
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr "Selecciona el convenio de llamadas ABI."
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr "Selecciona el método para el manejo de sdata."
 
@@ -11178,7 +11180,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Evita el traslape en registros de destino y dirección en las instrucciones LDRD que pueden disparar errores Cortex-M3."
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "Activa los accesos word sin alinear y halfword para los datos packed."
 
@@ -11369,14 +11371,30 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mvrsave=yes%> es obsoleto; utilice en su lugar %<-mvrsave%>"
 
+#: config/rs6000/rs6000.opt:334
+#, fuzzy
+#| msgid "Max. count of debug markers to expand or inline."
+msgid "Max number of bytes to move inline."
+msgstr "Máx. número de marcadores de depuración para expandir o poner en línea."
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare without loops."
+msgstr "El número máximo de insns en un bucle sin switch."
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare with loops."
+msgstr "El número máximo de insns en un bucle sin switch."
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop."
+msgid "Max number of pairs of load insns for compare."
+msgstr "El número máximo de pelados en un solo bucle."
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr "%<-misel=no%> es obsoleto; utilice en su lugar %<-mno-isel%>"
@@ -11385,10 +11403,48 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-misel=yes%> es obsoleto; utilice en su lugar %<-misel%>"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table."
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tSelecciona la tabla full, part, ó sin traceback."
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\tEspecifica el tamaño de long double (64 ó 128 bits)."
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs es obsoleto"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention."
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Selecciona el convenio de llamadas ABI."
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling."
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Selecciona el método para el manejo de sdata."
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr "Permite datos de solo lectura en sdata."
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets."
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Especifica el tamaño de bit para los desplazamientos TLS inmediatos."
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr "Usa registros fp."
@@ -12481,88 +12537,154 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Permite a gcc generar las instrucciones SETLB y Lcc."
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "Genera código en modo big endian."
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "Genera código en modo little endian."
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr "Usa un juego reducido de registros para asignación de registros."
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr "Usa el juego completo de registros para asignación de registros."
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+#, fuzzy
+#| msgid "Use alternate leaf function entries"
+msgid "Align function entry to 4 byte."
+msgstr "Usar entradas de función hojas alternadas"
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr "Genera instrucciones move condicionales."
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr "Genera instrucciones de extensión del rendimiento."
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr "Genera instrucciones de la versión 2 de la extensión del rendimiento."
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 msgid "Generate string extension instructions."
 msgstr "Genera instrucciones de extensión de cadenas."
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Genera instrucciones v3 push25/pop25."
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr "Genera instrucciones de 16 bits."
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr "Activa el soporte de alojamiento virtual."
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr "Especifica el tamaño de cada vector de interrupciones, que ha de ser 4 o 16."
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr "Especifica el tamaño de cada bloque de caché, que ha de ser potencia de 2 entre 4 y 512."
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr "Tipos de arquitectura conocidos (para usar con la opción -march=):"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr "Especifica la estrategia de generación de direcciones para modelo de código."
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "Tipos de modelos de código conocidos (para uso con la opción -mcmodel=):"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the code model."
 msgid "Specify the cpu for pipeline model."
 msgstr "Especifica el modelo de código."
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Tipos de cpu conocidos (para usar con la opción -mcpu=):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+#, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "ABIs de coma flotante conocidas (para usar con la opción -mfloat-abi):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr "Activa la opción constructor/destructor."
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr "Guía al enlazador para que relaje las instrucciones."
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set."
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Genera matemáticas de coma flotante usando el conjunto de instrucciones dado."
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions."
+msgid "Generate single-precision floating-point instructions."
+msgstr "Usa instrucciones apareadas-sencillas de coma flotante."
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Genera código que use las instrucciones de coma flotante del 68881."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr "Especifica la CPU para propósitos de generación de código."
@@ -13385,13 +13507,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Genera instrucciones mul64 y mulu64."
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs es obsoleto"
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr "No generar instrucciones mpy para ARC700."
@@ -15628,8 +15743,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr "Usa registro de guarda de invocador entre llamadas si es posible."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "no se usa el valor calculado"
@@ -15655,7 +15770,7 @@
 msgstr "se esperaba un tipo booleano"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "se esperaba un entero"
@@ -16072,7 +16187,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atributo %qs"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16098,12 +16213,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "se descarta el atributo"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
@@ -16152,9 +16267,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16167,8 +16282,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "falta el atributo %<target%> para %qD multiversionado"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "declaración previa de %qD"
@@ -16298,82 +16413,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: el tamaño especificado entre %E y %E excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir %E bytes o más en una región de tamaño %E desborda el destino"
 
-#: builtins.c:3177
-#, gcc-internal-format
+#: builtins.c:3176
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr "%K%qD: escribir %E byte en una región de tamaño %E desborda el destino"
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] "%K%qD: escribir %E byte en una región de tamaño %E desborda el destino"
+msgstr[1] "%K%qD: escribir %E byte en una región de tamaño %E desborda el destino"
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr "%K%qD: escribir %E bytes en una región de tamaño %E desborda el destino"
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: escribir entre %E y %E bytes en una región de tamaño %E desborda el destino"
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: el límite especificado entre %E y %E excede el tamaño de objeto máximo %E"
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr "%K%qD: el límite especificado entre %E y %E excede el tamaño del destino %E"
 
-#: builtins.c:3278
-#, gcc-internal-format
+#: builtins.c:3276
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD reading %E byte from a region of size %E"
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr "%K%qD leyendo %E byte en una región de tamaño %E"
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] "%K%qD leyendo %E byte en una región de tamaño %E"
+msgstr[1] "%K%qD leyendo %E byte en una región de tamaño %E"
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD leyendo %E o más bytes en una región de tamaño %E"
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD leyendo entre %E y %E bytes en una región de tamaño %E"
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "el límite de %K%qD %E especificado es igual al tamaño del destino"
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "faltan argumentos para la función %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "argumento no válido para %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "no se admite el argumento para %qD"
@@ -16380,72 +16491,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "llamar a %qD con un argumento distinto de cero es arriesgado"
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "ambos argumentos de %<__builtin_clear_cache%> deben ser punteros"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "se generó un trampolín para la función anidada %qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD cambió su semántica en GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "argumento de modelo de memoria no válido para la función interna"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "la falla de modelo de memoria no puede ser más fuerte que el modelo de memoria exitoso para %<__atomic_compare_exchange%>"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "falla de modelo de memoria no válido para %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "modelo de memoria no válido para %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "modelo de memoria no válido para %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "el argumento 1 para __atomic_always_lock_free no es una constante"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "el argumento 1 para __atomic_is_lock_free no es un entero"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "no se admite __builtin_thread_pointer en este objetivo"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "no se admite __builtin_set_thread_pointer en este objetivo"
@@ -16452,7 +16563,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack ()%>"
@@ -16459,12 +16570,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "el segundo argumento de %<__builtin_longjump%> debe ser 1"
@@ -16471,62 +16582,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Su plataforma objetivo no soporta -fcheck-pointer-bounds"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "el formato objetivo no soporta infinito"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "se usó %<va_start%> en una función con argumentos fijos"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "número erróneo argumentos para la función %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "se llamó a %<__builtin_next_arg%> sin un argumento"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "número erróneo de argumentos para la función %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "el segundo parámetro de %<va_start%> no es el último argumento nombrado"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "la conducta es indefinida cuando el segundo parámetro de %<va_start%> se declara con almacenamiento %<register%>"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kel primer argumento de %qD debe ser un puntero, el segundo una constante entera"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kel último argumento de %qD no es una constante entera entre 0 y 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kse intenta liberar un objeto %qD que no es de pila"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kse intenta liberar un objeto que no es de pila"
@@ -17699,37 +17810,37 @@
 msgid "conversion to incomplete type"
 msgstr "conversión a tipo de dato incompleto"
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "no se puede convertir un vector de tipo %qT en el tipo %qT con tamaño diferente"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "se usó un valor agregado donde se esperaba un entero"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "se usó un valor de puntero donde se esperaba un complejo"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "se usó un valor agregado donde se esperaba un complejo"
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "no se puede convertir un valor de tipo %qT en un vector de tipo %qT con tamaño diferente"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "no se puede convertir el valor a un vector"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "se usó un valor agregado donde se esperaba uno de coma fija"
@@ -17884,12 +17995,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "sólo se admiten múltiples personalidades EH con ensambladores que admiten la directiva cfi.personality"
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "se encontró UNSPEC %s (%d) que no está delegitimado la ubicación de variable"
@@ -17999,12 +18110,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kla llamada a %qs se redeclaró con error de atributo: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kla llamada a %qs se redecló con aviso de atributo: %s"
@@ -18019,12 +18130,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "el tamaño de marco de %wd bytes es mayor que %wd bytes"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "no se puede abrir el fichero de volcado de insn final %qs: %m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "no se puede cerrar el fichero de volcado de insn final %qs: %m"
@@ -18034,42 +18145,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "se truncó la constante de coma fija grande implícitamente al tipo de coma fija"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "la comparación siempre es %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de pruebas no equivalentes sin coincidencia siempre es 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de pruebas equivalentes mutuamente exclusivas siempre es 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se reduce la constante en comparación"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se combinan constantes alrededor de una comparación"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold check: el árbol original cambió por un pliegue"
@@ -18606,32 +18717,32 @@
 msgid "can%'t write PCH file"
 msgstr "no se puede escribir el fichero PCH"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr "el argumento origen %qD es el mismo que el destino"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr "destino %G%qD intacto tras no copiar ningún byte de una cadena de longitud %E"
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "destino %G%qD intacto tras no copiar ningún byte"
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 #, fuzzy
 #| msgid "specified bound %wu equals the size of the destination"
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "el límite %wu especificado es igual al tamaño del destino"
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 #, fuzzy
 #| msgid "%K%qD: specified bound %wu exceeds maximum object size %wu"
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr "%K%qD: el límite %wu especificado excede el tamaño de objeto máximo %wu"
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 #, fuzzy
 #| msgid "specified bound %wu equals the size of the destination"
 msgid "%G%qD specified bound %E equals source length"
@@ -18647,12 +18758,13 @@
 msgid "null pointer dereference"
 msgstr "desreferencia a puntero nulo"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "se declara aquí"
@@ -19043,113 +19155,105 @@
 
 #: gimple-ssa-warn-restrict.c:1402
 msgid "%G%qD accessing %wu byte at offsets %s and %s overlaps %wu byte at offset %s"
-msgstr "%G%qD al acceder %wu byte en los desplazamientos %s y %s solapa %wu byte en el desplazamiento %s"
+msgstr "%G%qD accediendo %wu byte en los desplazamientos %s y %s solapa %wu byte en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1404
 msgid "%G%qD accessing %wu byte at offsets %s and %s overlaps %wu bytes at offset %s"
-msgstr "%G%qD al acceder %wu byte en los desplazamientos %s y %s solapa %wu bytes en el desplazamiento %s"
+msgstr "%G%qD accediendo %wu byte en los desplazamientos %s y %s solapa %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1408
 msgid "%G%qD accessing %wu bytes at offsets %s and %s overlaps %wu byte at offset %s"
-msgstr "%G%qD al acceder %wu bytes en los desplazamientos %s y %s solapa %wu byte en el desplazamiento %s"
+msgstr "%G%qD accediendo %wu bytes en los desplazamientos %s y %s solapa %wu byte en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1410
 msgid "%G%qD accessing %wu bytes at offsets %s and %s overlaps %wu bytes at offset %s"
-msgstr "%G%qD al acceder %wu bytes en los desplazamientos %s y %s solapa %wu bytes en el desplazamiento %s"
+msgstr "%G%qD accediendo %wu bytes en los desplazamientos %s y %s solapa %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1417
 msgid "%G%qD accessing %wu byte at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
 msgid_plural "%G%qD accessing %wu bytes at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
-msgstr[0] "%G%qD al acceder %wu byte en los desplazamientos %s y %s solapa entre %wu y %wu bytes en el desplazamiento %s"
-msgstr[1] "%G%qD al acceder %wu bytes en los desplazamientos %s y %s solapa entre %wu y %wu bytes en el desplazamiento %s"
+msgstr[0] "%G%qD accediendo %wu byte en los desplazamientos %s y %s solapa entre %wu y %wu bytes en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo %wu bytes en los desplazamientos %s y %s solapa entre %wu y %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1427
 msgid "%G%qD accessing %wu byte at offsets %s and %s overlaps %wu or more bytes at offset %s"
 msgid_plural "%G%qD accessing %wu bytes at offsets %s and %s overlaps %wu or more bytes at offset %s"
-msgstr[0] "%G%qD al acceder %wu byte en los desplazamientos %s y %s solapa %wu o más bytes en el desplazamiento %s"
-msgstr[1] "%G%qD al acceder %wu bytes en los desplazamientos %s y %s solapa %wu o más bytes en el desplazamiento %s"
+msgstr[0] "%G%qD accediendo %wu byte en los desplazamientos %s y %s solapa %wu o más bytes en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo %wu bytes en los desplazamientos %s y %s solapa %wu o más bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1440
-#, fuzzy
-#| msgid "%K%qD: writing between %wu and %wu bytes into a region of size %wu overflows the destination"
 msgid "%G%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps %wu byte at offset %s"
 msgid_plural "%G%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps %wu bytes at offset %s"
-msgstr[0] "%K%qD: escribir entre %wu y %wu bytes en una región de tamaño %wu desborda el destino"
-msgstr[1] "%K%qD: escribir entre %wu y %wu bytes en una región de tamaño %wu desborda el destino"
+msgstr[0] "%G%qD accediendo entre %wu y %wu bytes en los desplazamientos %s y %s solapa %wu byte en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo entre %wu y %wu bytes en los desplazamientos %s y %s solapa %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1450
-#, fuzzy
-#| msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgid "%G%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
-msgstr "directiva %<%.*s%> escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
+msgstr "%G%qD accediendo entre %wu y %wu bytes en los desplazamientos %s y %s solapa entre %wu y %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1458
 msgid "%G%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps %wu or more bytes at offset %s"
-msgstr ""
+msgstr "%G%qD accediendo entre %wu y %wu bytes en los desplazamientos %s y %s solapa %wu o más bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1471
 msgid "%G%qD accessing %wu or more bytes at offsets %s and %s overlaps %wu byte at offset %s"
 msgid_plural "%G%qD accessing %wu or more bytes at offsets %s and %s overlaps %wu bytes at offset %s"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "%G%qD accediendo %wu o más bytes en los desplazamientos %s y %s solapa %wu byte en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo %wu o más bytes en los desplazamientos %s y %s solapa %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1479
 msgid "%G%qD accessing %wu or more bytes at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
-msgstr ""
+msgstr "%G%qD accediendo %wu o más bytes en los desplazamientos %s y %s solapa entre %wu y %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1486
 msgid "%G%qD accessing %wu or more bytes at offsets %s and %s overlaps %wu or more bytes at offset %s"
-msgstr ""
+msgstr "%G%qD accediendo %wu o más bytes en los desplazamientos %s y %s solapa %wu o más bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1514
 msgid "%G%qD accessing %wu byte may overlap %wu byte"
 msgid_plural "%G%qD accessing %wu bytes may overlap %wu byte"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "%G%qD accediendo %wu byte puede solapar %wu byte"
+msgstr[1] "%G%qD accediendo %wu bytes puede solapar %wu byte"
 
 #: gimple-ssa-warn-restrict.c:1521
 msgid "%G%qD accessing %wu byte at offsets %s and %s may overlap %wu byte at offset %s"
 msgid_plural "%G%qD accessing %wu bytes at offsets %s and %s may overlap %wu byte at offset %s"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "%G%qD accediendo %wu byte en los desplazamientos %s y %s puede solapar %wu byte en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo %wu bytes en los desplazamientos %s y %s puede solapar %wu byte en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1532
 msgid "%G%qD accessing %wu byte may overlap up to %wu bytes"
 msgid_plural "%G%qD accessing %wu bytes may overlap up to %wu bytes"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "%G%qD accediendo %wu byte puede solapar hasta %wu bytes"
+msgstr[1] "%G%qD accediendo %wu bytes puede solapar hasta %wu bytes"
 
 #: gimple-ssa-warn-restrict.c:1539
 msgid "%G%qD accessing %wu byte at offsets %s and %s may overlap up to %wu bytes at offset %s"
 msgid_plural "%G%qD accessing %wu bytes at offsets %s and %s may overlap up to %wu bytes at offset %s"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "%G%qD accediendo %wu byte en los desplazamientos %s y %s puede solapar hasta %wu bytes en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo %wu bytes en los desplazamientos %s y %s puede solapar hasta %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1552
-#, fuzzy
-#| msgid "%K%qD: specified size between %wu and %wu exceeds maximum object size %wu"
 msgid "%G%qD accessing between %wu and %wu bytes may overlap %wu byte"
 msgid_plural "%G%qD accessing between %wu and %wu bytes may overlap up to %wu bytes"
-msgstr[0] "%K%qD: el tamaño especificado entre %wu y %wu excede el tamaño de objeto máximo %wu"
-msgstr[1] "%K%qD: el tamaño especificado entre %wu y %wu excede el tamaño de objeto máximo %wu"
+msgstr[0] "%G%qD accediendo entre %wu y %wu bytes puede solapar %wu byte"
+msgstr[1] "%G%qD accediendo entre %wu y %wu bytes puede solapar %wu bytes"
 
 #: gimple-ssa-warn-restrict.c:1559
-#, fuzzy
-#| msgid "%K%qD: writing between %wu and %wu bytes into a region of size %wu overflows the destination"
 msgid "%G%qD accessing between %wu and %wu bytes at offsets %s and %s may overlap %wu byte at offset %s"
 msgid_plural "%G%qD accessing between %wu and %wu bytes at offsets %s and %s may overlap up to %wu bytes at offset %s"
-msgstr[0] "%K%qD: escribir entre %wu y %wu bytes en una región de tamaño %wu desborda el destino"
-msgstr[1] "%K%qD: escribir entre %wu y %wu bytes en una región de tamaño %wu desborda el destino"
+msgstr[0] "%G%qD accediendo entre %wu y %wu bytes en los desplazamientos %s y %s puede solapar %wu byte en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo entre %wu y %wu bytes en los desplazamientos %s y %s puede solapar hasta %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1571
 msgid "%G%qD accessing %wu or more bytes at offsets %s and %s may overlap %wu byte at offset %s"
 msgid_plural "%G%qD accessing %wu or more bytes at offsets %s and %s may overlap up to %wu bytes at offset %s"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "%G%qD accediendo %wu o más bytes en los desplazamientos %s y %s puede solapar %wu byte en el desplazamiento %s"
+msgstr[1] "%G%qD accediendo %wu o más bytes en los desplazamientos %s y %s puede solapar hasta %wu bytes en el desplazamiento %s"
 
 #: gimple-ssa-warn-restrict.c:1631
 msgid "%G%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
-msgstr ""
+msgstr "%G%qD desborda puntero entre el desplazamiento %s y el tamaño %s accediendo al array %qD con el tipo %qT"
 
 #: gimple-ssa-warn-restrict.c:1635
 #, gcc-internal-format
@@ -19179,10 +19283,10 @@
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -19215,7 +19319,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 #, fuzzy
 #| msgid "%qE argument is not a function"
 msgid "%G%qD source argument is the same as destination"
@@ -19556,252 +19660,257 @@
 msgid "function cannot be instrumented"
 msgstr "no se puede instrumentar la función"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr "la tabla virtual de tipo %qD viola la regla de definición única"
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr "variable del mismo nombre de ensamblador que la tabla virtual está definida en otra unidad de traducción"
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr "la tabla virtual de tipo %qD contiene información RTTI"
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr "RTTI no funcionará en este tipo"
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr "la tabla virtual de tipo %qD viola la regla de definición única "
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr "el tipo conflictivo definido en otra unidad de traducción tiene una tabla virtual de tamaño diferente"
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr "el tipo conflictivo definido en otra unidad de traducción tiene una información RTTI diferente"
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr "el tipo conflictivo definido en otra unidad de traducción"
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "contiene el método virtual adicional %qD"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr "el tipo conflictivo definido en otra unidad de traducción tiene una una tabla virtual con más entradas"
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "método virtual %qD"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr "debería concordar con el método virtual %qD pero no concuerda"
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr "el tipo conflictivo definido en otra unidad de traducción tiene una una tabla virtual con diferente contenido"
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "el tipo %qT viola la regla de definición única de C++"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "hay definido un tipo diferente en otra unidad de traducción"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr "la primera diferencia de las definiciones correspondientes es el campo %qD"
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr "la primera diferencia de las definiciones correspondientes es el método %qD"
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr "el tipo %qT definido en el espacio de nombres anónimo no puede coincidir con el tipo %qT a través del contorno de la unidad de traducción"
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr "el tipo %qT definido en el espacio de nombres anónimo no puede coincidir a través del contorno de la unidad de traducción"
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "el tipo incompatible definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr "el nombre de tipo %qs debería concordar con el nombre de tipo %qs"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "el tipo incompatible está definido aquí"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr "Los tipos de array tienen límites diferentes"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "no coincide el tipo del valor de retorno"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "no coincide el tipo del puntero this implícito"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "los tipos no coinciden en el parámetro %i"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "tipos con número de parámetros diferentes"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "el propio tipo %qT viola la regla de una sola definición de C++"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "el tipo %qT debería coincidir con el tipo %T"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr "hay un tipo con cualificadores distintos definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "hay un tipo con atributos distintos definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr "hay un enum con nombre de valor distinto definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr "hay un enum con valores distintos definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr "hay un enum con distinto número de valores definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr "hay un tipo con distinta precisión definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr "hay un tipo con diferente tipo de signo definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr "está definido como puntero en un espacio de direcciones diferente en otra unidad de traducción"
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr "está definido como puntero a un tipo diferente en otra unidad de traducción"
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr "hay un array de distinto tamaño definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "tiene distinto valor de retorno en otra unidad de translación"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "tiene parámetros distintos en otra unidad de translación"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr "un tipo definido en otra unidad de traducción no es polimórfico"
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr "un tipo definido en otra unidad de traducción es polimórfico"
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr "hay un tipo con punteros de tabla virtual distinta definidos en otra unidad de traducción"
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr "hay un tipo con bases distintas definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "hay un campo con un nombre distinto definido en otra unidad de translación"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr "hay un campo con el mismo nombre pero distinto tipo definido en otra unidad de traducción"
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "los campos tienen distinta disposición en otra unidad de translación"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -19822,7 +19931,7 @@
 msgid "the extra base is defined here"
 msgstr "la base extra se define aquí"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -19829,7 +19938,7 @@
 msgstr[0] "Declarar el tipo %qD final permitiría desvirtualizar %i llamada"
 msgstr[1] "Declarar el tipo %qD final permitiría desvirtualizar %i llamadas"
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19836,7 +19945,7 @@
 msgstr[0] "Declarar el tipo %qD final permitiría desvirtualizar %i llamada ejecutada %lli veces"
 msgstr[1] "Declarar el tipo %qD final permitiría desvirtualizar %i llamadas ejecutadas %lli veces"
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -19843,7 +19952,7 @@
 msgstr[0] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamada"
 msgstr[1] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamadas"
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -19850,7 +19959,7 @@
 msgstr[0] "Declarar el método %qD final permitiría desvirtualizar %i llamada"
 msgstr[1] "Declarar el método %qD final permitiría desvirtualizar %i llamadas"
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19857,7 +19966,7 @@
 msgstr[0] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamada ejecutada %lli veces"
 msgstr[1] "Declarar el destructor virtual de %qD final permitiría desvirtualizar %i llamadas ejecutadas %lli veces"
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20131,32 +20240,38 @@
 msgstr "el objetivo no admite despachador de versión de función"
 
 #: multiple_target.c:91
-#, gcc-internal-format
-msgid "default target_clones attribute was not set"
+#, fuzzy, gcc-internal-format
+#| msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "no se ha especificado el atributo target_clones predefinido"
 
-#: multiple_target.c:324
-#, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+#: multiple_target.c:343
+#, fuzzy, gcc-internal-format
+#| msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "se descarta el atributo sencillo target_clones"
 
-#: multiple_target.c:332
-#, fuzzy, gcc-internal-format
-#| msgid "default target_clones attribute was not set"
+#: multiple_target.c:351
+#, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
-msgstr "no se ha especificado el atributo target_clones predefinido"
+msgstr "no se pueden crear los clones para el atributo %<target_clones%>"
 
-#: multiple_target.c:335
-#, fuzzy, gcc-internal-format
-#| msgid "function %q+F can never be copied because it uses variable sized variables"
+#: multiple_target.c:354
+#, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
-msgstr "la función %q+F nunca se puede copiar porque usa variables de tamaño variable"
+msgstr "la función %q+F nunca se puede copiar porque tiene atributo %<noclone%>"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr "no se ha especificado el objetivo predefinido"
 
+#: multiple_target.c:379
+#, fuzzy, gcc-internal-format
+#| msgid "missing value in %<target()%> pragma or attribute"
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr "falta el valor en el pragma o atributo %<target()%>"
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20469,12 +20584,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "no se reconoce el argumento en la opción %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para %qs son: %s; ¿quiso decir %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "los argumentos válidos para %qs son: %s"
@@ -20631,28 +20746,24 @@
 msgstr "la memoria transaccional no se admite con %<-fsanitize=kernel-address%>"
 
 #: opts.c:1048
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-loops=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-loops=%d is not between 0 and %d"
-msgstr "-malign-loops=%d no está entre 0 y %d"
+msgstr "-falign-loops=%d no está entre 0 y %d"
 
 #: opts.c:1052
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-jumps=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-jumps=%d is not between 0 and %d"
-msgstr "-malign-jumps=%d no está entre 0 y %d"
+msgstr "-falign-jumps=%d no está entre 0 y %d"
 
 #: opts.c:1056
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-functions=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-functions=%d is not between 0 and %d"
-msgstr "-malign-functions=%d no está entre 0 y %d"
+msgstr "-falign-functions=%d no está entre 0 y %d"
 
 #: opts.c:1060
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-loops=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-labels=%d is not between 0 and %d"
-msgstr "-malign-loops=%d no está entre 0 y %d"
+msgstr "-falign-labels=%d no está entre 0 y %d"
 
 #: opts.c:1471
 #, gcc-internal-format
@@ -20695,8 +20806,7 @@
 msgstr "HSA no se activó durante la configuración"
 
 #: opts.c:2226
-#, fuzzy, gcc-internal-format
-#| msgid "-foffload-abi option can be specified only for offload compiler"
+#, gcc-internal-format
 msgid "%<-foffload-abi%> option can be specified only for offload compiler"
 msgstr "la opción %<-foffload-abi%> solo puede especificarse para compilador de descarga"
 
@@ -21074,22 +21184,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "el operando de salida %d debe usar la restricción %<&%>"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] next_regno erróneo para la cadena vacía (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Ciclo en la cadena regno (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] oldest_regno erróneo (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Registro no vacío en la cadena (%s %u %i)"
@@ -21133,7 +21243,7 @@
 msgstr "se usó el registro de %qD para múltiples variables de registro globales"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "genera un conflicto con %qD"
@@ -21373,158 +21483,158 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "se renombró %qD después de ser referenciado en el ensamblado"
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "el símbolo de función no es una función"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "el símbolo de variable no es una variable"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "el nodo tiene un tipo desconocido"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nodo no encontrado node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "el nodo difiere de node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "lista hash de nombres del ensamblador corrupta"
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "no se encontró un nodo en cgraph_hash"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "lista doblemente enlazada de nombres del ensamblador corrrupta"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "el nodo tiene body_removed y sin embargo es una definición"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "el nodo está analizado pero no es una definición"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "el nodo es un alias pero no un alias implícito"
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "el nodo es un alias pero no una definición"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "el nodo es una weakref pero no un transparent_alias"
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "el nodo es un transparent_alias pero no un alias"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "el nodo está en la lista same_comdat_group no tiene comdat_group"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "list same_comdat_group con grupos diferentes"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "no se permite mezclar diferentes símbolos de tipos en los mismos grupos comdat"
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "el nodo está solo en un grupo comdat"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group no es una lista circular"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "el símbolo comdat-local referenciado en %s fuera de su comdat"
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "el indicador implicit_section está puesto pero la sección on lo es"
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Tanto la sección como el grupo comdat están puestos"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Alias y sección del objetivo difieren"
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "El alias y los grupos comdat del objetivo difieren"
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "El alias transparente y los nombres de ensamblador del objetivo difieren"
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Alias transparentes encadenados"
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::falló verify"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Hay dos símbolos con el mismo comdat_group que no están vinculados a la lista same_comdat_group."
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "la función %q+D es parte de un ciclo de alias"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "la variable %q+D es parte de un ciclo de alias"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "la sección del alias %q+D debe cuadrar con la sección de su objetivo"
@@ -22690,12 +22800,12 @@
 msgid "control reaches end of non-void function"
 msgstr "el control alcanza el final de una función que no es void"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "se descarta el valor de devolución de la función declarada con atributo warn_unused_result"
@@ -22969,32 +23079,24 @@
 msgstr[1] ""
 
 #: tree-ssa-strlen.c:1989
-#, fuzzy
-#| msgid "%qD output truncated copying %E byte from a string of length %wu"
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
-msgstr[0] "salida de %qD truncada copiando %E byte desde una cadena de longitud %wu"
-msgstr[1] "salida de %qD truncada copiando %E byte desde una cadena de longitud %wu"
+msgstr[0] "salida de %G%qD truncada copiando %E byte desde una cadena de longitud %wu"
+msgstr[1] "salida de %G%qD truncada copiando %E bytes desde una cadena de longitud %wu"
 
 #: tree-ssa-strlen.c:1996
-#, fuzzy
-#| msgid "%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
-msgstr "salida de %qD truncada copiando entre %wu y %wu bytes desde una cadena de longitud %wu"
+msgstr "salida de %G%qD truncada copiando entre %wu y %wu bytes desde una cadena de longitud %wu"
 
 #: tree-ssa-strlen.c:2008
-#, fuzzy
-#| msgid "%qD output may be truncated copying %E byte from a string of length %wu"
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
-msgstr[0] "la salida de %qD puede ser truncada copiando %E byte desde una cadena de longitud %wu"
-msgstr[1] "la salida de %qD puede ser truncada copiando %E byte desde una cadena de longitud %wu"
+msgstr[0] "la salida de %G%qD puede truncarse copiando %E byte desde una cadena de longitud %wu"
+msgstr[1] "la salida de %G%qD puede truncarse copiando %E bytes desde una cadena de longitud %wu"
 
 #: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
-#, fuzzy
-#| msgid "%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
-msgstr "salida de %qD puede ser truncada copiando entre %wu y %wu bytes desde una cadena de longitud %wu"
+msgstr "la salida de %G%qD puede truncarse copiando entre %wu y %wu bytes desde una cadena de longitud %wu"
 
 #: tree-ssa-strlen.c:2150
 #, fuzzy
@@ -23003,10 +23105,8 @@
 msgstr "la salida %qE podría truncarse antes del último carácter de formato"
 
 #: tree-ssa-strlen.c:2156
-#, fuzzy
-#| msgid "%K%qD: specified bound %wu exceeds the size %wu of the destination"
 msgid "%G%qD specified bound depends on the length of the source argument"
-msgstr "%K%qD: el límite %wu especificado excede el tamaño %wu del destino"
+msgstr "%G%qD: el límite especificado depende de la longitud del argumento origen"
 
 #: tree-ssa-strlen.c:2163
 #, gcc-internal-format
@@ -23213,7 +23313,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "la operación de ordenamiento vectorial se expandirá por piezas"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "no se ha producido vectorización para un bucle simd"
@@ -23253,92 +23353,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "elemento con efectos colaterales en CONSTRUCTOR sin efectos colaterales"
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "las matrices de funciones no tienen significado"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "el tipo de devolución de función no puede ser función"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: %s, se tiene %s en %s, en %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: no se esperaba ninguno de %s, se tiene %s en %s, en %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba la clase %qs, se tiene %qs (%s) en %s, en %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "revisión de árbol: no se esperaba la clase %qs, se tiene %qs (%s) en %s, en %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba omp_clause %s, se tiene %s en %s, en %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba un árbol que contenga la estructura %qs, se tiene %qs en %s, en %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "revisión de árbol: acceso de elt %d de tree_int_cst con %d elts en %s, en %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "revisión de árbol: acceso de elt %d de tree_vec con %d elts en %s, en %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de %s con %d operandos en %s, en %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de omp_clause %s con %d operandos en %s, en %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD es obsoleto: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD es obsoleto"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE es obsoleto: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE es obsoleto"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "el tipo es obsoleto: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "el tipo es obsoleto"
@@ -23363,242 +23463,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "type variant differs by "
+msgid "type variant differs by %s"
 msgstr "tipo variante difiere en "
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "tipos variantes difieren en TYPE_SIZE_UNIT"
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT del tipo variante"
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT del tipo"
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "tipo variante con TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "tipo variante con diferente TYPE_VFIELD"
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "tipo variante con diferente TYPE_BINFO"
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "TYPE_BINFO del tipo variante"
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "TYPE_BINFO del tipo"
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "tipo variante con diferente TYPE_FIELDS"
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "el primer descuadre es campo"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr "y campo"
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "tipo variante con diferente TREE_TYPE"
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "TREE_TYPE del tipo variante"
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "TREE_TYPE del tipo"
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "el tipo no es compatible con su variante"
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "La variante principal no está definida"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT tiene diferente TYPE_MAIN_VARIANT"
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL tiene diferente TYPE_CANONICAL"
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL no es compatible"
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "TYPE_MODE de TYPE_CANONICAL no es compatible"
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD no es FIELD_DECL ni TREE_LIST"
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO no es POINTER_TYPE"
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO no es REFERENCE_TYPE"
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO no es TREE_BINFO"
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "El tipo TYPE_BINFO no es TYPE_MAIN_VARIANT"
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE no es registro ni unión"
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE no es registro ni unión"
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE no es INTEGER_CST"
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW no NULL"
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "El campo TYPE_LANG_SLOT_1 (binfo) es no NULL"
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "El valor enumerado no es CONST_DECL ni INTEGER_CST"
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "El tipo de valor enumerado no es INTEGER_TYPE ni puede convertirse al enumerado"
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "El nombre de valor enumerado no es IDENTIFIER_NODE"
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "El array TYPE_DOMAIN no es de un tipo entero"
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS definidos en un tipo incompleto"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Árbol incorrecto en una lista TYPE_FIELDS"
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P es %i mientras que TYPE_CACHED_VALUES es %p"
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES no es TREE_VEC"
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "entrada TYPE_CACHED_VALUES incorrecta"
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE es no NULL en una lista TYPE_ARG_TYPES"
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Entrada incorrecta en una lista TYPE_ARG_TYPES"
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "El campo TYPE_VALUES_RAW es no NULL"
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "TYPE_CACHED_VALUES_P está activado y no debería"
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG está activado en un código de tipo incorrecto"
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE no es una variante de main"
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "falló verify_type"
@@ -23623,12 +23724,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "valor de perfil corrupto: la cuenta del perfilador %s (%d de %d) es inconsistente con la cuenta bloque-básico (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "se excedió el límite de tamaño de rastreo de variable con -fvar-tracking-assignments, se reintenta sin esa opción"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "se excedió el límite de tamaño de rastreo de variable"
@@ -23918,10 +24019,9 @@
 msgstr "el atributo %qE solamente afecta a objetos de alto nivel"
 
 #: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
-#, fuzzy, gcc-internal-format
-#| msgid "using result of function returning %<void%>"
+#, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
-msgstr "se usa el resultado de una función que devuelve %<void%>"
+msgstr "atributo %qE en una función que devuelve %<void%>"
 
 #: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
 #, gcc-internal-format
@@ -24287,14 +24387,12 @@
 msgstr "un argumento que no es nulo hace referencia a un operando que no es puntero (argumento %lu, operando %lu)"
 
 #: c-family/c-attribs.c:3208
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for field of type %qT"
+#, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
-msgstr "se descarta el atributo %qE para el campo de tipo %qT"
+msgstr "se descarta el atributo %qE en objetos de tipo %qT"
 
 #: c-family/c-attribs.c:3216
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute doesn't apply to functions"
+#, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "el atributo %qE no se aplica a funciones"
 
@@ -24513,7 +24611,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "el compilador puede asumir que la dirección de %qD siempre se evaluará como %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "se sugieren paréntesis alrededor de la asignación usada como valor verdadero"
@@ -24764,7 +24862,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "el índice %E denota un desplazamiento mayor que el tamaño de %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "el tamaño de la matriz es demasiado grande"
@@ -25376,7 +25474,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos variables diferentes para la memoria"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo no válido para la variable de iteración %qE"
@@ -25391,22 +25489,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador no válido"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento no válida"
@@ -25951,8 +26049,8 @@
 msgid "wrong type argument to %s"
 msgstr "argumento de tipo erróneo para %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "desbordamiento en la expresión constante"
@@ -26590,7 +26688,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparación entre los tipos %qT y %qT"
@@ -26669,7 +26767,7 @@
 msgstr[0] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 msgstr[1] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "esta condición tiene bifurcaciones idénticas"
@@ -26798,47 +26896,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s tiene una versión de silicio no válida"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops es obsoleto, use -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps es obsoleto, use -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions es obsoleto, use -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d no está entre 0 y %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d no está entre 0 y 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "sólo se admite %<-fsplit-stack%> en GNU/Linux"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> requiere soporte del ensamblador para las directivas CFI"
@@ -26864,31 +26962,31 @@
 msgstr "para la opción -mcache-block-size=X, las X válidas son: 4, 8, 16, 32, 64, 128, 256, o 512"
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "interruptor -mdebug-%s desconocido"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "opción -mlong-double-%s desconocida"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "la opción -msingle-float es equivalente a -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "se descarta la opción -msimple-fpu"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "sólo se admite %<-fsplit-stack%> en PowerPC64 GNU/Linux con glibc-2.18 o superior"
@@ -27368,8 +27466,8 @@
 msgstr "el pragma o atributo %<target(\"%s=%s\")%> no es válido"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %<target%> no es una cadena"
@@ -27449,8 +27547,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "valor %qs erróneo para -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27559,11 +27657,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27573,147 +27671,137 @@
 msgid "%qE attribute only applies to functions"
 msgstr "el atributo %qE se aplica solamente a funciones"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "__builtin_arc_aligned con alineamiento no constante"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "valor de argumento no válido para __builtin_arc_aligned"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr "el operando interno debería ser un valor de 6 bits sin signo"
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "el operando 1 debería ser un inmediato de 3 bits sin signo"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "el operando 2 debería ser un valor de 3 bits sin signo (10-17)"
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "el operando 1 debería ser un valor de 3 bits sin signo (10-17)"
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "el operando 2 debería ser un valor de 8 bits sin signo"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "el operando 3 debería ser un valor de 8 bits sin signo"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "el operando 4 debería ser un valor de 8 bits sin signo (0-255)"
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "el operando 3 debería ser un valor de 3 bits sin signo (10-17)"
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "el operando 2 debería ser un valor de 3 bits sin signo (0-7)"
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "el operando 2 debería ser un valor de 3 bits par (subreg 0,2,4,6)"
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "el interno requiere un inmediato para el operando %d"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "el operando %d debería ser un inmediato sin signo de 6 bits"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "el operando %d debería ser un inmediato sin signo de 8 bits"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "el operando %d debería ser un inmediato sin signo de 3 bits"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "el número de registro debe ser una constante en tiempo de compilación. Pruebe a poner niveles de optimización más altos"
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr "el operando para la instrucción sleep debe ser una constante en tiempo de compilación sin signo de 6 bits"
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "Direcciones de insn no establecidas después de shorten_branches"
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "direcciones de insn no liberadas"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "el atributo %qE solamente es válido para la arquitectura ARCv2"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "falta el argumento del atributo %qE"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "el atributo %qE sólo permite una constante entera como argumento"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "el atributo %qE solo es válido para la arquitectura ARC EM"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "el atributo %qE se aplica solamente a tipos de funciones"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is missing"
 msgid "argument of %qE attribute ignored"
 msgstr "falta el argumento del atributo %qE"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "el atributo %qE solamente se aplica a variables"
@@ -27739,153 +27827,153 @@
 msgstr "Debe activar las instrucciones crypto (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) para usar estos intrínsecos."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "el selector debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "el rango del selector debe estar entre 0 y 7"
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "el rango del selector debe estar entre 0 y 3"
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "el rango del selector debe estar entre 0 y 1"
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "la máscara debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "el rango de la máscara debe estar entre 0 y 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -28688,12 +28776,12 @@
 msgid "invalid IACC argument"
 msgstr "argumento IACC no válido"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs espera una constante como argumento"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "el argumento constante está fuera de rango para %qs"
@@ -28793,570 +28881,552 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "no se puede establecer la posición en el fichero PCH: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argumento %qs incorrecto para la opción %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "los rangos de tamaño de la opción %qs deberían ser crecientes"
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "se especificó un nombre de estrategia %qs incorrecto para la opción %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "no se admite el nombre de estrategia %qs especificado para la opción %qs para código de 32 bits"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "se especificó una alineación %qs desconocida para la opción %qs"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "el valor máximo para el último rango de tamaños debería ser -1 para la opción %qs"
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "se especificaron demasiados rangos de tamaños en la opción %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "parámetro desconocido para la opción -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "no se admite Intel MCU psABI en el modo %s"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> es obsoleto; use en su lugar %<-mtune=k8%> o %<-mtune=generic%> como sea adecuado"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> es obsoleto; use %<target(\"tune=k8\")%> o %<target(\"tune=generic\")%> en su lugar como convenga"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "el modelo de direcciones %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "no se admite -mabi=ms con X32 ABI"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "no se admite -masm=intel en esta configuración"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "no está compilado el modo bit-%i"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<generic%> solo se puede usar para el ajuste %<-tune=%>"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<generic%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<intal%> solo se puede usar para el ajuste %<-mtune=%>"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<intel%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "el CPU que seleccionó no admite el conjunto de instrucciones x86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX no tiene soporte para x32"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-march=%>"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"arch=\")%>"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s; ¿qiuso decir %qs?"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-mtune=%>"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "se descarta -mregparm en modo de 64-bit"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "se descarta -mregparm para Intel MCU psABI"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d no está entre 0 y %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "se descarta %<-mrtd%> en el modo de 64bit"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "se descarta %<target(\"rtd\")%> en el modo de 64bit"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount no está implementada para -fPIC"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "se usó %<-msseregparm%> sin SSE activado"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "se usó %<target(\"ssseregparm\")%> sin SSE activado"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "la prueba de pila requiere %<-maccumulate-outgoing-args%> para ser correcta"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "la prueba de pila requiere %<target(\"accumulate-outgoing-args\"%> para ser correcta"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "el registro ebp fijo requiere %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "el registro ebp fijo requiere %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs no es un número válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs no es un desplazamiento válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs no es un registro base válido en -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:4942
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fcf-protection=branch%> requires CET support on this target. Use -mcet or one of -mibt, -mshstk options to enable CET"
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "%<-fcf-protection=branch%> requiere suporte CET en este objetivo. Utilice las opciones -mcet o una de entre -mibt y -mshstk para activar CET."
-
-#: config/i386/i386.c:4951
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fcf-protection=return%> requires CET support on this target. Use -mcet or one of -mibt, -mshstk options to enable CET"
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "%<-fcf-protection=return%> requiere suporte CET en este objetivo. Utilice las opciones -mcet o una de entre -mibt y -mshstk para activar CET."
-
-#: config/i386/i386.c:4961
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fcf-protection=full%> requires CET support on this target. Use -mcet or one of -mibt, -mshstk options to enable CET"
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "%<-fcf-protection=full%> requiere suporte CET en este objetivo. Utilice las opciones -mcet o una de entre -mibt y -mshstk para activar CET."
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "ya se había especificado option(\"%s\")"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "interrupción y atributos desnudos no es compatible"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Solo se admite el formato de depuración DWARF para la rutina de servicio de interrupciones."
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qT con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 no admite el atributo ms_abi"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue no es compatible con la función anidada"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "el argumento de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "el retorno de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "el retorno de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "el argumento de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "la devolución de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "el argumento de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "la devolución de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "la ABI para pasar un struct con un miembro de matriz flexible cambió en GCC 4.4"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "la ABI para pasar un union con long double cambió en GCC 4.4"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "se devuelve el registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumento de registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "se devuelve el registro x87 con x87 desactivado"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el convenio de llamadas SSE sin activar SSE/SSE2"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "esto es un error de GCC que se puede sortear añadiendo el atributo usado a la función llamada"
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues no es compatible con %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "el atributo ms_hook_prologue no es compatible con -mfentry para 32-bit"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "No se admite Puntero de Argumento de Realineamiento Dinámico (DRAP) en la rutina de servicio de interrupciones.  Esto puede sortearse evitando funciones con retorno agregado."
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack no admite fastcall con funciones anidadas"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack no admite 2 parámetros de registro para una función anidada"
@@ -29363,312 +29433,312 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack no admite 3 parámetros de registro"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "modificador 'V' en registro no entero"
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "no se admite el tamaño para registro de enteros"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "los registros extendidos no tiene mitades superiores"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "no se admite el tamaño de operando para el registro extendido"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "se usó un operando que no es entero con el código de operando 'z'"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "no se puede llamar directamente a la rutina de servicio de interrupciones"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "No se ha encontrado despachador para los atributos de versión"
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "No se encontró despachador para %s"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "No se encontró despachador para los atributos de versión : %s"
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Las versiones de funciones no pueden marcarse como gnu_inline; hay que generar cuerpos"
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "El parámetro para la función interna debe ser una cadena constante o literal"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "El parámetro para la función interna no es válido: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 2-bit"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "el quinto argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 3-bit"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "el tercer argumento debe ser una constante de comparación"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "modo de comparación incorrecto"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "operando de redondeo incorrecto"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE necesita la opción isa desconocida"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE necesita la opción isa %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "el último argumento debe ser un inmediato"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "el último argumento debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "el argumento delantero debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "operando de pista incorrecto"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "el argumento de xabort debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "el argumento del atributo %qE no es \"ilink\""
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "la rutina de atención de interrupciones debería tener como segundo argumento un unsigned %sint"
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "ls rutina de servicio de interrupción no puede tener valor de retorno que no sea void"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "no se permiten alternativas en la salida del indicador asm"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "salida del indicador asm %qs desconocida"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "tipo no válido para la salida del indicador asm"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modelo de memoria específico de la arquitectura desconocido"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE no se usa con ACQUIRE o modelos de memoria más fuertes"
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE no se usa con RELEASE o modelos de memoria más fuertes"
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d no admitido"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "El Comprobador de Punteros requiere suporte MPX en este objetivo. Utilice las opciones -mmpx para activar MPX."
@@ -29889,7 +29959,7 @@
 msgstr "interrupt_thread sólo está disponible en fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "no se admite la expresión del límite de la pila"
@@ -30418,9 +30488,39 @@
 msgid "constant argument out of range for %s"
 msgstr "el argumento constante está fuera de rango para %qs"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "esta función interna sólo está disponible en el fr450"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "esta función interna sólo está disponible en el fr450"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin is not supported for this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "no se admite este interno para este objetivo"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
 #| msgid "Generate string extension instructions."
+msgid "don't support performance extension instructions"
+msgstr "Genera instrucciones de extensión de cadenas."
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate performance extension version 2 instructions."
+msgid "don't support performance extension version 2 instructions"
+msgstr "Genera instrucciones de la versión 2 de la extensión del rendimiento."
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
+#| msgid "Generate string extension instructions."
 msgid "don't support string extension instructions"
 msgstr "Genera instrucciones de extensión de cadenas."
 
@@ -30441,43 +30541,61 @@
 msgstr "atributos interrupt múltiples para la función %qD"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "no se admiten funciones anidadas para registros reducidos"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "el índice de registro intrínseco está fuera de rango"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
+#, fuzzy, gcc-internal-format
+#| msgid "intrinsic register index is out of range"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "el índice de registro intrínseco está fuera de rango"
+
+#: config/nds32/nds32.c:3508
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "valor de id no válido para atributo de interrupción/excepción"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "valor de id no válido atributo reset"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "función nmi no válida para atributo reset"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "función warm no válida para atributo reset"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
 #, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
+#, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "no se admite código independiente de posición"
 
@@ -30687,37 +30805,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr "no se admite la inicialización estática de la variable %q+D en memoria %<.shared%>"
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr "no se pueden emitir punteros desalineados en ensamblador ptx"
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX no admite declaraciones débiles (solamente definiciones débiles)"
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "el atributo %qE requiere tipo de retorno void"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "no se permite el atributo %qE con una clase de auto almacenamiento"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "se usa vector_length (%d); se hace caso omiso de %d"
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "se usa vector_length (%d); se hace caso omiso de la configuración de tiempo de ejecución"
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "se usa num_workers (%d); se hace caso omiso de %d"
@@ -30811,12 +30929,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "basura al final de #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
@@ -30866,7 +30984,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert sólo acepta 3 argumentos"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta los calificadores del tipo del destino del puntero"
@@ -31168,7 +31286,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "la disposición de los agregados que contienen vectores con alineamiento de %d bytes cambió en GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "Se devolvió un vector GCC por referencia: extensión de ABI no estándar sin garantía de compatibilidad"
@@ -31178,7 +31296,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "la ABI para pasar agregados con alineación de %d bytes cambió en GCC 5"
@@ -31188,12 +31306,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "la ABI para pasar agregados flotantes homogéneos cambió en GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vector GCC pasado por referencia: extensión ABI que no es estándar sin garantía de compatibilidad"
@@ -31203,28 +31321,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "error interno: la función interna %s ya se procesó"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "el argumento 1 debe ser un valor de un campo de 8 bits"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "el argumento 1 debe ser un literal con signo de 5 bits"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 5 bits"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "el argumento 1 debe ser un literal sin signo de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 7 bits"
@@ -31244,12 +31362,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "el interno %s solo es válido en modo de 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "el argumento %d debe ser un literal sin signo"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "el argumento %d es un literal sin signo fuera de rango"
@@ -31271,53 +31389,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "la hwcap %s es un argumento no válido para el interno %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 4-bit"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 2-bit"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "el argumento 1 debe ser 0 o 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "el argumento 1 debe ser un literal sin signo de 1 bit"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "el argumento 2 debe ser 0 ó 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "el argumento d de debe estar dentro del rango 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "el argumento para %qs debe ser una literal sin signo de 2-bit"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "sobrecarga sin resolver para el interno Altivec %qF"
@@ -31443,7 +31561,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "error interno: función interna %s, el argumento %d tiene el tipo de argumento inesperado %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "marco de pila demasiado grande"
@@ -31453,13 +31571,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack utiliza el registro r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "No se admite #pragma GCC target en este objetivo"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
@@ -31469,22 +31587,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "No se puede tomar la dirección de una función anindada si se usa la opción -mno-pointers-to-nested-functions."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
@@ -31494,7 +31612,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "el uso de %<long%> en tipos AltiVec es no válido para código de 64 bit sin -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
@@ -31958,22 +32076,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "cpu %qs desconocida para -mtune"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr "-mdiv requiere -march para subsumir la extensión %<M%>"
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr "la ABI solicitada requiere -march para subsumir la extensión %qc"
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr "ABI requiere -march=rv%d"
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d debe estar entre %d y %d"
@@ -32036,30 +32154,36 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "el interno %qs sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "el interno %qs solo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "el interno %qs solo acepta 1 argumento"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, fuzzy, gcc-internal-format
+#| msgid "builtin function %qs requires the %qs option"
+msgid "builtin %qs requires builtin %qs"
+msgstr "la función interna %qs requiere la opción %qs"
+
+#: config/rs6000/rs6000-c.c:7058
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "no se admite la función interna %s en esta configuración del compilador"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinación de parámetros no válida para el intrínseco AltiVec %qs"
@@ -32184,170 +32308,170 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs está obsoleto y no tiene ningún efecto"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use %qs para activarlas"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use %qs para activarlas"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "error interno: la función interna %qs ya se procesó"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 1 bit"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "el argumento 1 de %qs debe ser constante"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "el argumento 1 de %qs está fuera de rango"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "el interno %qs solo es válido en el modo de 64 bits"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "el interno %qs sólo acepta un argumento de cadena"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "la cpu %qs es un argumento no válido para el interno %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs es un argumento no válido para el interno %qs"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "el segundo argumento de %qs debe estar en 0..12"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "el tercer argumento de %qs debe estar en 0..12"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "el argumento 1 de %s debe ser una constante"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "la función interna %qs solo es válida para el procesador cell"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "la función interna %qs requiere las opciones %qs y %qs"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "la función interna %qs requiere requiere coma flotante de 128 bits del IEEE de ISA 3.0"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs and %qs options"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "la función interna %qs requiere las opciones %qs y %qs"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "la función interna %qs no se admite con las opciones actuales"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "error interno: la función interna %qs tiene un tipo de devolución inesperado %qs"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "error interno: función interna %qs, el argumento %d tiene el tipo de argumento inesperado %qs"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs usa el registro r29"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "no se puede tomar la dirección de una función anindada si se usa la opción %qs"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "el uso de %<long%> en tipos AltiVec no es válido para código de 64 bits sin %qs"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<long long%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<double%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "cpu %qs no válida para %s%qs%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s no es válido"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno=%s%> anula %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33165,7 +33289,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "no se descarta el valor void como debería de ser"
@@ -33418,7 +33542,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la declaración de %qD oscurece a una declaración global"
@@ -33428,7 +33552,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "la declaración de %qD oscurece a una declaración local previa"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "aquí está la declaración oscurecida"
@@ -33492,7 +33616,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "cada identificador sin declarar se reporta sólo una vez para cada función en el que aparece"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "la etiqueta %qE es referenciada fuera de cualquier función"
@@ -33522,7 +33646,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "declaración duplicada de la etiqueta %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "etiqueta %qD duplicada"
@@ -33641,7 +33765,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "no se permite %<[*]%> en otro lugar que no sea el ámbido de prototipo de función"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -33899,7 +34023,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "se especificó una clase de almacenamiento para un parámetro sin nombre"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
@@ -34064,7 +34188,7 @@
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
@@ -34194,7 +34318,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un miembro de una estructura o union no puede tener un tipo modificado variablemente"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "se declaró la variable o campo %qE como void"
@@ -34374,7 +34498,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "la definición de tipo en %qs es no válida en C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
@@ -34424,7 +34548,7 @@
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
@@ -34462,7 +34586,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeclaración de %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "el modo especificado es demasiado pequeño para valores enumerados"
@@ -34492,7 +34616,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "se le dió a la función incluida en línea %qD un atributo noinline"
@@ -34523,7 +34647,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
@@ -34638,12 +34762,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
@@ -34709,7 +34833,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
@@ -34863,38 +34987,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del tipo"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del tipo"
@@ -34927,7 +35051,7 @@
 msgid "to match this %qs"
 msgstr "%J  otro tipo aquí"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -34969,7 +35093,7 @@
 msgstr "nombre de tipo %qE desconocido"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -34985,7 +35109,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -35000,8 +35124,8 @@
 msgid "unexpected attribute"
 msgstr "atributo inesperado"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -35044,7 +35168,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "se esperaba %<,%> o %<;%>"
@@ -35072,7 +35196,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 no admite %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "se esperaba una cadena literal"
@@ -35140,13 +35264,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "coma al final de la lista de enumeradores"
@@ -35276,7 +35400,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "se esperaba %<}%> antes de %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sin un %<if%> previo"
@@ -35311,22 +35435,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "se esperaba una declaración"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<else%>"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "se sugieren llaves explícitas para evitar un %<else%> ambiguo"
@@ -35346,12 +35470,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable de iteración no válida en la enumeración rápida"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -35379,12 +35503,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -35693,7 +35817,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "los operandos de %<__builtin_complex%> son de tipos diferentes"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
@@ -35754,79 +35878,79 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "el atributo %<setter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "el atributo %<getter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC option%> no es una cadena"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -35843,59 +35967,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "se esperaba %<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -35918,95 +36042,95 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%<priority%> value must be non-negative"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "se esperaba %<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
 msgstr "se esperaba %<class%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "demasiados argumentos"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute"
 msgid "unexpected argument"
 msgstr "atributo inesperado"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "el argumento del atributo %qE no es una constante entera"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "se usaron al mismo tiempo %<long%> y %<void%> en los especificadores de declaración"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de planificador no válido"
@@ -36017,13 +36141,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
@@ -36047,19 +36171,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "género de planificador no válido"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "máscara no válida"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -36071,76 +36195,76 @@
 msgid "invalid proc_bind kind"
 msgstr "género de planificador no válido"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs se debe usar con %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Sección de matriz en la llamada '%s' en %L"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "uso no válido de %<--%> en la variable booleana %qD"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "invalid OpenACC clause at file scope"
 msgstr "tipo no válido en la declaración"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de %<--%> en la variable booleana %qD"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "La variable %qs se usa más de una vez en la lista de argumentos del método %qs"
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "se esperaba una cadena después de %<#pragma message%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -36157,7 +36281,7 @@
 msgid "expected function name"
 msgstr "se esperaba función"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -36169,46 +36293,46 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "no se puede usar el especificador %<constexpr%> en una declaración de función que no es una definición"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 #| msgid "the %<constexpr%> specifier cannot be used in a function declaration that is not a definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "no se puede usar el especificador %<constexpr%> en una declaración de función que no es una definición"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador no válido para %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
@@ -36219,22 +36343,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
@@ -36244,76 +36368,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "no se puede calificar %<void%> si es el único parámetro"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<operator%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "se esperaba %<using%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36334,34 +36458,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "se esperaba %<try%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "se esperaba %<decltype%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -36422,48 +36546,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
@@ -36480,7 +36604,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD tiene un tipo de dato incompleto"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "uso no válido de la expresión void"
@@ -36607,7 +36731,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "el valor del subíndice no es ni matriz ni puntero ni vector"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "el subíndice de la matriz no es un entero"
@@ -36632,7 +36756,7 @@
 msgid "enum constant defined here"
 msgstr "se definió la constante enum aquí"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -36738,18 +36862,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "la comparación con una literal de cadena resulta en una conducta no especificada"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "comparación entre puntero y entero"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot dereference, not a pointer"
 msgid "did you mean to dereference the pointer?"
@@ -36775,7 +36899,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -37020,7 +37144,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "conversión a puntero desde un entero de tamaño diferente"
@@ -37177,7 +37301,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
@@ -37250,7 +37374,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "uso no válido de matriz no-lvaluada"
@@ -37326,12 +37450,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "C tradicional rechaza la inicialización automática de agregados"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "matriz de tipo char inicializada con una cadena ancha"
@@ -37377,7 +37501,7 @@
 msgid "invalid initializer"
 msgstr "inicializador no válido"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
@@ -37392,7 +37516,7 @@
 msgid "braces around scalar initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inicialización de un miembro de matriz flexible en un contexto anidado"
@@ -37523,7 +37647,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C prohíbe %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
@@ -37564,7 +37688,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "la etiqueta de case no es una expresion constante entera"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "la etiqueta case no se encuentra dentro de una declaración switch"
@@ -37574,17 +37698,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "la etiqueta %<default%> no está dentro de una declaración switch"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "la declaración continue no está dentro de un bucle"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "se usó la declaración break en un bucle for de OpenMP"
@@ -37611,23 +37735,23 @@
 msgid "expression statement has incomplete type"
 msgstr "la declaración de la expresión tiene tipo de dato incompleto"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "se comparan vectores con tipos de elemento diferentes"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "se comparan vectores con números de elementos diferentes"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "could not find interface for class %qE"
 msgid "could not find an integer type of the same size as %qT"
 msgstr "no se puede encontrar la interfaz para la clase %qE"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "no es segura la comparacion de coma flotante con == o !="
@@ -37678,7 +37802,7 @@
 msgstr "comparación ordenada de puntero con un puntero nulo"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparación ordenada de puntero con el entero cero"
@@ -37708,12 +37832,12 @@
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -37724,27 +37848,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hdemasiadas cláusulas %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD no es una función plantilla miembro"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -37757,19 +37881,19 @@
 msgstr "%Hdemasiadas cláusulas %qs"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -37776,58 +37900,58 @@
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "zero length array section in %qs clause"
 msgstr "Sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Copia las secciones de matriz en un bloque contiguo en la entrada de procedimiento"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qE does not have pointer or array type"
@@ -37849,7 +37973,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE tiene tipo no válido para %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
@@ -37861,17 +37985,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -37886,18 +38010,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -37910,33 +38034,33 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE no es una variable en la cláusula %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE no es una variable en la cláusula %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -37960,64 +38084,64 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -38029,32 +38153,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -38206,7 +38330,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  no hay una conversión conocida para el argumento %d de %qT a %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38292,28 +38416,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "la conversión de %qT a %qT es ambigua"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "la llamada del %<%D(%A)%> sobrecargado es ambigua"
@@ -38320,681 +38444,681 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "la función puntero-a-miembro %E no se puede llamar dentro de un objeto; considere utilizar .* o ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "no hay coincidencia para la llamada a %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "la llamada de %<(%T) (%A)%> es ambigua"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "sobrecarga ambigua para %qs en %<%s %E%>"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "no hay coincidencia para %qs en %<%s %E%>"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "operandos no válidos para el binario %s (se tiene %qT y %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "operandos no válidos para el binario %s (se tiene %qT y %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "el operando es r0"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "no hay coincidencia para el %<operator?:%> terniario en %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "no hay coincidencia para %<operator%s%> en %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "no hay coincidencia para el %<operador[]%> en %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "no hay coincidencia para %qs en %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "no hay coincidencia para %<operator%s%> en %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "no hay coincidencia para %<operador%s%> en %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ prohíbe la omisión del término medio de una expresión ?:"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 #, fuzzy
 #| msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "la conversión del escalar %qT al vector %qT implica truncado"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "no coincide el enumeral en la expresión condicional: %qT vs %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "el segundo operando del operador condicional es del tipo %<void%>, pero el tercer operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "el tercer operando del operador condicional es del tipo %<void%>, pero el segundo operando no es una expresión throw ni del tipo %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "los operandos de ?: tienen tipos diferentes %qT y %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, fuzzy, gcc-internal-format
 #| msgid "methods cannot be converted to function pointers"
 msgid "  and each type can be converted to the other"
 msgstr "los métodos no pueden ser convertidos a apuntadores a funciones"
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro resultado del condicional"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "no coincide el enumeral en la expresión condicional: %qT vs %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "tipos enumeral y no enumeral en la expresión condicional"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo, intentando en su lugar el operador prefijo"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparación entre %q#T y %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "no existe una función de desalojo correspondiente para %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "no hay un %<operator %s%> adecuado para %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "se declara aquí"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "se declara aquí"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D es inaccesible"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "se pasó NULL al argumento %P de %qD que no es puntero"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "se convierte al tipo %qT que no es puntero desde NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "se convierte %<false%> a tipo puntero para el argumento %P de %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "se convierte %<false%> al tipo puntero %qT"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "demasiadas llaves alrededor del inicializador para %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid user-defined conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "conversión definida por el usuario no válida de %qT a %qT"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  argumento de inicialización %P de %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversión no válida de %qT a %qT"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversión a %qT desde la lista del inicializador usaría el constructor explícito %qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "no se puede unir el campo de bits %qE a %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "no se unir el campo packed %qE a %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "no se puede unir el r-valor %qE a %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "no se puede pasar objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluación recursiva del argumento por defecto para %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "la llamada a %qD usa el argumento por defecto para el parámetro %P, el cual no se ha definido aún"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "el argumento de la llamada a función puede ser un candidato para un atributo de formato"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted function %q+D with default argument"
 msgid "use of multiversioned function without a default"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT no es una base inaccesible de %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "se deduce %qT como %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (puede desactivar esto con -fno-deduce-init-list)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "; use value-initialization instead"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Extensión: reinicialización de '%s' en %L"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "la constante se refiere a sí misma"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  para una conversión de estilo de función, borre el %<::%D%> redundante"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "la llamada del %<%s(%A)%> sobrecargado es ambigua"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "virtual abstracto `%#D' llamado desde un constructor"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "virtual abstracto `%#D' llamado desde un destructor"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "no se puede llamar a la función miembro %qD sin un objeto"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "al pasar %qT se escoge %qT sobre %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "se escoge %qD sobre %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  porque la secuencia de conversión para el argumento es mejor"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "no coincide el argumento por defecto en la resolución de sobrecarga"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " candidato 1: %q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " candidato 2: %q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "no se puede convertir %qE de %qT a %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "un enlace temporal a %qD sólo persiste hasta que el constructor termina"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -39042,8 +39166,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %q#D"
@@ -39089,7 +39213,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qT declared here"
@@ -39177,7 +39301,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D no válido; un union anónimo sólo puede tener miembros con datos no estáticos"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
@@ -39482,7 +39606,7 @@
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
@@ -39554,7 +39678,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "no hay suficiente información de tipo"
@@ -39660,371 +39784,371 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D no se puede usar como una función constexpr porque:"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "Avisa en las llamadas a estas funciones"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E no es una expresión constante"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "función interna"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE does not designate a constexpr function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "la expresión %qE no designa una función constexpr"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-constexpr function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "llamada a la función %qD que no es constexpr"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD called in a constant expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "se usó %qD antes de su definición"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "la llamada tiene una dependencia circular"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "el operador del lado izquierdo de la expresión coma no tiene efecto"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD mutable no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "se accede al miembro %qD  en lugar del miembro inicializado %qD en la expresión constante"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "se accede al valor de %qE a través de glvalue %qT en una expresión constante"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "se usó %qD en su propio inicializador"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D no es const"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D es volatile"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD no se inicializó con una expresion constante"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "la expresión %qE tiene efectos colaterales"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast no válido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40073,7 +40197,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversión de %qT a %qT descarta los calificadores"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "la conversión de %qT a %qT no dereferencía a los punteros"
@@ -40084,313 +40208,313 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "no se puede convertir el tipo %qT al tipo %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "conversión de %q#T a %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "el resultado de la conversión no está especificado porque %qE está fuera del rango del tipo %qT"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "se usó %q#T donde se esperaba un %qT"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "no se puede convertir %qE de %qT a %qT"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "se usó %q#T donde se esperaba un valor de coma flotante"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "se solicitó la conversión desde %qT al tipo no escalar %qT"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "no se llamó al seudo-destructor"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo incompleto %qT"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "la indirección no accederá a un objeto de tipo incompleto %qT en la declaración"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "la indirección no accederá al objeto de tipo incompleto %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo %qT"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en la declaración"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "la deferencia implícita no accederá al objeto de tipo %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el operando derecho del operador coma"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en la declaración"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "la indirección no accederá al objeto de tipo no-copiable-trivialmente %qT en la expresión de incremento for"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "la conversión a void no accederá al objeto %qE de tipo incompleto %qT"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el segundo operando de la expresión condicional"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el tercer operando de la expresión condicional"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el operando derecho del operador coma"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en el operando izquierdo del operador coma"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en la declaración"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "la variable %qE de tipo incompleto %qT no se accederá en la expresión de incremento for"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "la conversión a void no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "el segundo operando de la expresión condicional no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "el tercer operando de la expresión condicional no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "el operando derecho del operador coma no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "el operador izquierdo del operador coma no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "la declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "la expresión de incremento for no puede resolver la dirección de la función sobrecargada"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "el segundo operando de la expresión condicional es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "el tercer operando de la expresión condicional es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "el operando derecho del operador coma es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "el operando izquierdo del operador coma es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "la declaración es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "la expresión de incremento for es una referencia, no una llamada, a la función %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "el segundo operando de la expresión condicional no tiene efecto"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "el operando derecho del operador coma no tiene efecto"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "el operando izquierdo del operador coma no tiene efecto"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "la declaración no tiene efecto"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "se convierte NULL a un tipo que no es puntero"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "conversión de tipo por defecto ambigua desde %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  las conversiones candidatas incluyen %qD y %qD"
@@ -40434,226 +40558,226 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD se declaró %<extern%> y después %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "la declaración de %qF tiene un especificador de excepción diferente"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "de la declaración previa de %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
 msgstr "declaración previa de %q+#D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of friend %q#D may not have default template arguments"
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "la redeclaración de friend %q#D no puede tener argumentos de plantilla por defecto"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "la plantilla de operador literal %q+D tiene conflictos con el operador literal raw %qD"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "el operador literal raw %q+D tiene conflictos con la plantilla de operador literal %qD"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "la definición previa de %q+D estaba aquí"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "la declaración previa de %q+D estaba aquí"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "la función interna %q+D no se declara como función"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "se oscurece la función interna %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "se oscurece la función de biblioteca %q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "se redeclara la función de biblioteca %q#D como %q#D que no es función"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "genera un conflicto con la declaración interna %q#D"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "la declaración de %qD oscurece a una declaración global"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration %q+#D"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "la declaración previa %q+#D que no es función"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "genera un conflicto con la declaración interna %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "hace ambigua la declaración interna %q#D"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "hace ambigua la declaración interna %q#D"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "semicolon missing after %s declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "falta punto y coma después de la declaración %s"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D redeclarado como un tipo diferente de símbolo"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "redeclaración de la plantilla %q#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "hace ambigua la declaración antigua %q+#D"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "old declaration %q#D"
 msgstr "la declaración global %q+#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "hace ambigua la declaración antigua %q+#D"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration as %q#D"
 msgstr "declaración previa de %q+#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "se define %q+#D previamente aquí"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
 msgstr "se declaró %q+#D previamente aquí"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "el prototipo para %q+#D"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "non-prototype definition here"
 msgid "previous non-prototype definition here"
 msgstr "la definición del no prototipo aquí"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "declaración previa de %q+#D con el enlace %qL"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "previous declaration with %qL linkage"
 msgstr "declaración previa de %q+#D con el enlace %qL"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in %q+#D"
 msgid "previous specification in %q#D here"
 msgstr "después de la especificación previa en %q+#D"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "declaración redundante de %qD en el mismo ámbito"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %q+D"
@@ -40667,12 +40791,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "'setter' attribute of property %qD conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -40679,28 +40803,28 @@
 msgstr "el atributo 'setter' de la propiedad %qD genera un conflicto con la declaración previa"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redefinición de %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD genera un conflicto con la función utilizada"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D no se declaró en la clase"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea con el atributo %<gnu_inline%>"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea sin el atributo %<gnu_inline%>"
@@ -40708,672 +40832,672 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redeclaración de friend %q#D no puede tener argumentos de plantilla por defecto"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "declaración thread-local de %q#D después de una declaración que no es thread-local"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "declaración que no es thread-local de %q#D después de una declaración thread-local"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redeclaración de %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "declaración redundante de `%s' en el mismo ámbito"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "un local previo"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  desde aquí"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sale del bloque estructurado OpenMP"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  cruza la inicialización de %q+#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  entra al ámbito de %q+#D el cual tiene un destructor que no es trivial"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  entra al bloque catch"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  salta la inicialización de %q+#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  entra al ámbito de %q+#D el cual tiene un destructor que no es trivial"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  entra al bloque try"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr%> if statement"
 msgstr "se esperaba una declaración"
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entra al bloque estructurado OpenMP"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "salida no válida de un bloque estructurado OpenMP"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD no es un tipo"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "se usa %qD sin parámetros de plantilla"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T no es una clase"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "no hay una plantilla de clase llamada %q#T en %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la búsqueda de %qT en %qT es ambigua"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es una plantilla de clase"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es un tipo"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mpcommit%> was deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<-mpcommit%> se ha hecho obsoleto"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mpcommit%> was deprecated"
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "%<-mpcommit%> se ha hecho obsoleto"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "no se admite -falign-labels=%d"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con constructor en un agregado anónimo"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con destructor en un agregado anónimo"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en un agregado anónimo"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "el atributo para %q#T debe estar a continuación de la palabra clave %qs"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "tipos múltiples en una declaración"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeclaración del tipo interno de C++ %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "falta el nombre del tipo en la declaración typedef"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ prohíbe structs anónimos"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sólo se puede especificar para constructores"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "se descartó %<typedef%> en esta declaración"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "se descartan los atributos aplicados al tipo de clase %qT fuera de la definición"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "se descartan los atributos aplicados al tipo dependiente %qT sin una declaración asociada"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD está inicializado (utilice decltype en su lugar)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la declaración de %q#D tiene %<extern%> y está inicializada"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la definición de %q#D se marca como %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ no permite que %<%T::%D%> se defina como %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "inicialización duplicada de %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D tiene inicializador pero de tipo de dato incompleto"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementos de la matriz %q#D con tipo de dato incompleto"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "el agregado %q#D tiene un tipo incompleto y no se puede definir"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD declarado como referencia pero no se inicializa"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "se usó un nombre en un inicializador designado de estilo GNU para una matriz"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "el nombre %qD se utiliza en un inicializador designado en estilo GNU para una matriz"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "no se admiten los inicializadores designados como no triviales"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "el inicializador no puede determinar el tamaño de %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "falta el tamaño de la matriz en %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "matriz %qD de tamaño cero"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %qD"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "el tamaño de almacenamiento de %qD no es constante"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  puede evitar esto eliminando el inicializador"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T no tiene constructor por defecto proporcionado por el usuario"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "el constructor no es proporcionado por el usuario porque está marcado explícitamente por defecto en el cuerpo de la clase"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, fuzzy, gcc-internal-format
 #| msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "y el constructor implícitamente definido no inicializa %q+#D"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipo %qT no válido como inicializador para un vector de tipo %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "el inicializador para %qT debe estar encerrado entre llaves"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "se usa %<[%E] =%> en un inicializador designado en estilo GNU para la clase %qT"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT no tiene un dato miembro que no es static llamado %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementos de la matriz %q#T tienen tipo de dato incompleto"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "literal compuesta de tamaño variable"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "el objeto escalar %qD requiere un elemento en el inicializador"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98 %qD debe ser inicializado por un constructor, no por %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "matriz %qD inicializada con una constante de cadena entre paréntesis %qE"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "inicializador no válido para el miembro static con constructor"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant in-class initialization invalid for static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(se requiere una inicialización fuera de la clase)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "uso no válido de la función miembro (¿Olvidó el %<&%>?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "se oscurece la declaración de tipo previa de %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -41381,7 +41505,7 @@
 msgstr[0] "se especificó %qs para el campo de estructura"
 msgstr[1] "se especificó %qs para el campo de estructura"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "only %u name provided for structured binding"
@@ -41389,7 +41513,7 @@
 msgstr[0] "inicializador no válido para la cadena de bits"
 msgstr[1] "inicializador no válido para la cadena de bits"
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -41396,258 +41520,264 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "tipo no válido para la variable de iteración %qE"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "dereferencing pointer to incomplete type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "puntero deferenciado a tipo de dato incompleto"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de variable"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de parámetro"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de tipo"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de campo"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "el método Java %qD tiene un tipo de devolución %qT que no es de Java"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definiendo la especialización explícita %qD en la declaración friend"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "uso no válido del id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "no se permiten los argumentos por defecto en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
@@ -41654,667 +41784,672 @@
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "operador literal con enlace C"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD tien una lista de argumentos no válida"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, fuzzy, gcc-internal-format
 #| msgid "integer suffix %<%s%> shadowed by implementation"
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo entero %<%s%> por la implementación"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %<%s%> shadowed by implementation"
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo de coma flotante %<%s%> por la implementación"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> debe devolver %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "la definición de %qD declarado implícitamente"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "la definición de %qD explícitamente por defecto"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D explicitly defaulted here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D explícitamente por defecto aquí"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "no hay una función miembro %q#D declarada en la clase %qT"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo incompleto"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "se necesita %<constexpr%> para la inicialización en la clase no válida del miembro de datos static %q#D de tipo que no es integral"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo que no es literal"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "inicialización en la clase no válida para el miembro de datos static de tipo %qT que no es integral"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ prohíbe la inicialización en la clase del miembro static %qD que no es constante"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ prohíbe la inicialización de la constante miembro %qD del tipo %qT que no es entero"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "el tamaño de la matriz %qD tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "el tamaño de la matriz %qD es negativo"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "el tamaño de la matriz es negativo"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de tamaño cero"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ prohíbe matrices de tamaño cero"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de longitud variable"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ prohíbe las matrices de longitud variable"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "se usa la matriz de longitud variable %qD"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "desbordamiento en la dimensión de la matriz"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "la declaración de %qD como una matriz de voids"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "se crea la matriz de voids"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "la declaración de %qD como una matriz de funciones"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "se crea la matriz de funciones"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "la declaración de %qD como una matriz de referencias"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "se crea la matriz de referencias"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "la declaración de %qD como una matriz de miembros de función"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "se crea la matriz de miembros de función"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qD como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "una matriz multidimensional debe tener límites para todas las dimensiones excepto para la primera"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la especificación del tipo de devolución para el constructor es no válida"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "se especificó un tipo de devolución para %<operator %T%>"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "se declaró la variable o campo sin nombre como void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "se declaró la variable o campo como void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "uso no válido del nombre calificado %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "uso no válido del nombre calificado %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "uso no válido del nombre calificado %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T no es una clase o un espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
 #  FIXME traducción
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "declaración de %qD como algo que no es miembro"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "falta el id del declarador; se utiliza la palabra reservada %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "declaración de %qD como %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "la declaración de %qD como parámetro"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dos o más tipos de datos en la declaración de %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ prohíbe la declaración de %qs sin tipo"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "no se admite %<__int128%> en este objetivo"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> o %<unsigned%> no válido para %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> y %<unsigned%> se especificaron juntos para %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> no válido para %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> no válido para %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> no válido para %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> o %<short%> no válidos para %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%>, o %<char%> no válido para %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "se especificó %<long%> o %<short%> con char para %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> y %<short%>  se especificaron juntos para %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> o %<long%> no válidos para %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "uso no válido de long, short, signed ó unsigned para %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex no válido para %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "declaración typedef no válida en la declaración de parámetros"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro de plantilla %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de parámetros"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "la definición de la función se declaró como %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "la definición de la función se declaró como %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "la función anidada %qs se declaró %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la declaración del nivel superior de %qs especifica %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "el ámbito de la función %qs es implícitamente auto y declarado %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de funciones friend"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
+#| msgid "type qualifiers ignored on function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
+
+#: cp/decl.c:11156
+#, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:11099
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
-msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
-
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42321,59 +42456,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -42380,257 +42515,257 @@
 msgstr "los constructores no se pueden declarar virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores no válidos en el tipo de función que no es miembro"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -42637,170 +42772,170 @@
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso no válido de %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto no válido"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es no válida para la función %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es no válida para la función %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
@@ -42807,80 +42942,80 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
@@ -42900,126 +43035,126 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor no válido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "la conversión a una referencia a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
@@ -43026,53 +43161,53 @@
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -43084,54 +43219,54 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT no válida"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
@@ -43139,42 +43274,42 @@
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT no válido"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -43184,82 +43319,82 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "declaración de función no válida"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "declaración de la función miembro no válida"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -43301,7 +43436,7 @@
 msgid "deleting %qT is undefined"
 msgstr "el borrado de %qT está indefinido"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "declaración plantilla de %q#D"
@@ -43314,7 +43449,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "se declaró el destructor %qD como una plantilla miembro"
@@ -43431,46 +43566,46 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "la anchura del campo de bits %qD es del tipo %qT que no integral"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "struct anónimo no está dentro de un tipo nombrado"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D no válido; un union anónimo sólo puede tener miembros con datos no estáticos"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "miembro privado %q+#D en union anónima"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "los agregados anónimos de alcance de espacio de nombres deben ser static"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "union anónima sin miembros"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> debe devolver el tipo %qT"
@@ -43479,71 +43614,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "el primer parámetro de %<operator new%> no puede tener un argumento por defecto"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> toma el tipo %<size_t%> (%qT) como primer argumento"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> debe devolver el tipo %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> toma el tipo %qT como primer argumento"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT se declaró con mayor visibilidad que el tipo de su campo %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -43553,70 +43688,70 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la variable %q#D sin enlace"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D no se refiere al tipo sin calificar, así que no se usa para el enlace"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, declarada usando el tipo local %qT, se usa pero nunca se define"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la variable %q#D con enlace"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D genera un conflicto con una declaración previa"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous mangling %q#D"
 msgstr "declaración previa de %q+#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (o =0) evita este error con un cambio en la decodificación"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "se usa la función inline %q+D pero nunca se define"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "falta el argumento por defecto para el parámetro %P de %q+#D"
@@ -43623,18 +43758,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -43645,117 +43780,117 @@
 msgid "with"
 msgstr "con"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "sin argumentos"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "los operadores de conversión explícita sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "los enums con ámbito sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "los controles de anulación (override/final) sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "los inicializadores de datos miembro que no son static sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "las literales definidas por el usuario sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "los constructores delegadores sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "los constructores delegadores sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "las literales definidas por el usuario sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "se utilizó el tipo incompleto %qT en un especificador de nombre anidado"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "la referencia a %<%T::%D%> es ambigua"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD no es un miembro de %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> no se ha declarado"
@@ -43906,70 +44041,70 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(si esta no es su intención, asegúrese que la plantilla de la función ya ha sido declarada y agregue <> aquí después del nombre de la función) "
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "inicialización por valor del tipo de dato incompleto %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "no se puede inicializar por valor la matriz %qT de límite desconocido"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "inicialización por valor del tipo de referencia %qT"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "se definió union aquí"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD se debe inicializar en la lista de inicialización de miembros"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
@@ -43976,307 +44111,307 @@
 msgid "%q#D should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D se inicializará después de"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT se inicializará después de"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  base %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  cuando se inicializó aquí"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "se dieron inicializaciones múltiples para %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "se dieron inicializaciones múltiples para la base %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "inicializaciones para múltiples miembros de %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la clase base %q#T debe ser inicializada explícitamente en la copia del constructor"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D es un dato miembro static; sólo se puede inicializar en su definición"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "inicializador sin nombre para %qT, el cual no tiene clases base"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "inicializador sin nombre para %qT, el cual usa herencia múltiple"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD es tanto una base directa como una base virtual indirecta"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "el tipo incompleto %qT no tiene al miembro %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "puntero no válido al campo de bits %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "uso no válido del dato miembro no static %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "desbordamiento entero en la expresión"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "no se permite cadenas con comillas dobles en expresiones #if"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "tipo %<void%> no válido para new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const sin inicializar en %<new%> de %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "no se encontró un %qD adecuado en la clase %qT"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la petición para el miembro %qD es ambigua"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "inicializador entre paréntesis en la matriz new"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new no se puede aplicar a un tipo de referencia"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "el inicializador termina prematuramente"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "tamaño de matriz desconocida en delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase abstracta %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase polimórfica %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
@@ -44288,7 +44423,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -44373,71 +44508,71 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código, pero permitir el uso de un nombre sin declarar es obsoleto)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "se decodifica typeof, utilice decltype en su lugar"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "se decodifica __underlying_type"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "se decodifica el tipo de coma fija desconocido"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "decodificando %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "se omitió el operando de enmedio de %<?%>: no se puede revolver el operando"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "literal de cadena en la firma de plantilla de función"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
@@ -44569,46 +44704,46 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D genera un conflicto con una declaración previa"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D esconde el destructor para %q#T"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la declaración de %q#D oscurece un parámetro"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "la declaración global %q+#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -44617,63 +44752,63 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "la búsqueda de nombre de %qD cambió"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  coincide con este %q+D bajo las reglas de ISO estándar"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  coincide con este %q+D bajo las reglas antiguas"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "la búsqueda de nombre de %qD cambió por el nuevo alcance ISO de %<for%>"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "  se usa la asignación obsoleta en %q+D"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -44681,12 +44816,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "una declaración de uso no puede especificar un id de plantilla.  Intente %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "no se permite el espacio de nombres %qD en la declaración using"
@@ -44693,107 +44828,107 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT no es un espacio de nombres"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD ya se declaró en este ámbito"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "no se declaró %qD"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> nombra al destructor"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nombra al constructor en %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "no hay miembros que coincidan con %<%T::%D%> en %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la declaración de %qD no está en un espacio de nombres alrededor de %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "calificación explícita en la declaración de %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D se declaró como friend"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD se debería declarar dentro de %qD"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "el atributo %qD no tiene signifcado porque los miembros del espacio de nombres anónimo tiene símbolos locales"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qD"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "límite máximo de %d espacios de nombres buscados para %qE"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -44800,12 +44935,12 @@
 msgstr[0] "alternativa sugerida:"
 msgstr[1] "alternativas sugeridas:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -44812,77 +44947,83 @@
 msgid "suggested alternative: %qs"
 msgstr "alternativa sugerida:"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%s is not available for %s architecture"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%s no está disponible para la arquitectura %s"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D no se puede definir como %qE"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "se definió struct aquí"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "you may use an inline namespace instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "no se permite aquí el alias del espacio de nombres %qD, se asume que es %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "los atributos de método sólo se deben especificar al final"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entrando a pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX saliendo de pop_everything ()\n"
@@ -44902,7 +45043,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44927,7 +45068,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "solicitud por el miembro %qE en el tipo %qT que no es clase"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> no se ha declarado"
@@ -45009,7 +45150,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "una literal de coma flotante no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "una conversión a un tipo diferente de un tipo integral o de enumeración no puede aparecer en una expresión constante"
@@ -45242,7 +45383,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "no se puede encontrar un operador literal de cadena %qD con argumentos %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "se esperaba una declaración"
@@ -45328,7 +45469,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "el ámbito %qT antes de %<~%> no es un nombre-de-clase"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
@@ -45344,343 +45485,334 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "se usa el nombre-de-definición-de-tipo %qD como un declarador de destructor"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "se encontró %<:%> en un especificador de nombre anidado, se esperaba %<::%>"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "el tipo de declaración evalúa a %qT, el cual no es una clase o un tipo enumerado"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "se utilizó el tipo incompleto %qT en un especificador de nombre anidado"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD no es una plantilla"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "los tipos no se pueden definir en conversiones"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "número erróneo de argumentos para %<__builtin_complex%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ prohíbe las literales compuestas"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "uso no válido de %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> no es un miembro clase"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "tipo que no es escalar"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ no permite %<alignof%> con algo que no es tipo"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<noexcept%>"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "no se pueden definir tipos en una expresión new"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "se prohíbe el límite de matriz después del id-de-tipo entre paréntesis"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Se esperaba un tipo de expresión"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "la expresión en el declarador-new debe tener un tipo integral o de enumeración"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "uso de conversión de estilo antiguo"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "el operador %<>>%> se tratará como dos en llaves en ángulo derechas en C++11"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "se sugieren paréntesis alrededor de la expresión %<>>%>"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ no permite ?: con el operando medio omitido"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in conditions"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "no se pueden definir tipos en condiciones"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "expresión lambda en un contexto sin evaluar"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in unevaluated context"
 msgid "lambda-expression in template-argument"
 msgstr "expresión lambda en un contexto sin evaluar"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "se esperaba el fin de la lista-de-captura"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %<this%> es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "capture of non-variable %qD "
 msgid "capture of non-variable %qE"
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
 msgstr "%q+#D se declaró aquí"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "captura de la variable %qD con duración de almacenamiento que no es automática"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %qD es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la captura por referencia explícita de %qD es redundate con la captura por referencia por defecto"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "se especificó un argumento por defecto para el parámetro lambda"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> duplicado"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "se esperaba una declaración etiquetada"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "la etiqueta case %qE no está dentro de una declaración switch"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "se necesita %<typename%> antes de %qE porque %qT es un ámbito dependiente"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nombra el constructor, no el tipo"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "la expresión %<for%> basada en rango de tipo %qT es de tipo incompleto"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "la expresión %<for%> basada en rango de tipo %qT tiene un miembro %<end%> pero no tiene %<begin%>"
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "la expresión %<for%> basada en rango de tipo %qT tiene un miembro %<begin%> pero no tiene %<end%>"
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
@@ -45687,576 +45819,576 @@
 msgstr "declaración compuesta en una función constexpr"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "<;%> extra"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label%> no está al inicio de un bloque"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "se prohíbe mezclar declaraciones y definiciones-de-función"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in range-based for loops"
 msgid "initializer in range-based %<for%> loop"
 msgstr "no se pueden definir tipos en bucles for basados en rango"
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "declaraciones múltiples `%T' y `%T'"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "empty structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "se usó %<friend%> fuera de la clase"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> cambiará su significado en C++11; por favor bórrelo"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in %qT"
 msgid "%qD invalid in lambda"
 msgstr "%qD no válido en %qT"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la definición de clase no se puede declarar como friend"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "especificación de enlace no válida"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<decltype%>"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "solamente los constructores toman inicializadores miembro"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "inicializador de clase base de estilo antiguo anacrónico"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (un inicializador de miembro calificado es implícitamente un tipo)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "falta un espacio entre %<\"\"%> y el identificador sufijo"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "se esperaba un identificador sufijo"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "se esperaba una cadena vacía después de la palabra clave %<operator%>"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operandos no válidos en la operación terniaria"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operador inesperado"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "parámetro de captura no válido"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros plantilla %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "los paquetes de parámetro de plantilla no pueden tener argumentos por defecto"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> no puede iniciar una lista de argumentos de plantilla"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> es una forma alternativa para %<[%>. Inserte espacios en blanco entre %<<%> y %<::%>"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "error de decodificación en la lista de argumentos de plantilla"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "se esperaba un nombre de plantilla"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilice %<%T::template %D%> para indicar que es una plantilla"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<inline%>"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "especialización de plantilla con enlace C"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "se esperaba un specificador de tipo"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "se esperaba un id de plantilla para el tipo"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "se esperaba un nombre de tipo"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, fuzzy, gcc-internal-format
 #| msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "el especificador de tipo elaborado para un ámbito enumerado no debe usar la palabra clave %<%D%>"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la declaración %qD no declara nada"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "se descartan los atributos en un especificador de tipo elaborado que no es una declaración adelantada"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD es una plantilla de enumeración"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "se esperaba %<;%> o %<{%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "no se puede agregar una lista de enumerador a una instanciación de plantilla"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "la declaración de %qD en el espacio de nombres %qD el cual no incluye a %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "la declaración de %qD en %qD la cual no incluye a %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "no se permite la calificación extra"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "especificador enumerador opaco sin nombre"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "el especificador enumerador opaco debe usar un identificador simple"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD no es un nombre-de-espacio-de-nombres"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace name required"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "El enumerador no puede tener atributos %C"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "varargs function cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "la función varargs no puede ser inline"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace %qD entered"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id-de-plantilla no puede aparecer en una declaración-using"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "las declaraciones access son obsoletas en favor de las declaraciones using: sugerencia: use la palabra clave %<using%>"
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "no se pueden definir tipos en declaraciones de plantilla alias"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "una definición de función no se permite aquí"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "no se permite una especificación-asm en una definición-de-función"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "se esperaba un constructor, un destructor, o una conversión de tipo"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "se esperaba un inicializador"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "se proporcionó un inicializador para la función"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "se redeclara la función %q+D como inline"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "el límite de la matriz no es una constante entera"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "no se puede definir el miembro de la definición de tipo dependiente %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> no es un tipo"
@@ -46265,17 +46397,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "declarador no válido"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "uso no válido del constructor como una plantilla"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "use %<%T::%D%> en lugar de %<%T::%D%> para nombrar el constructor en un nombre calificado"
@@ -46282,409 +46414,409 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "tipo no válido en la declaración"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "se esperaba un declarador"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD es un espacio de nombres"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "se esperaba un operador puntero"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource requiere -o"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "uso no válido de %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "no se pueden definir tipos en argumentos de plantilla"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "se esperaba un especificador de tipo"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "se esperaba %<,%> o %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "los argumentos por defecto sólo se permiten para parámetros de función"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros plantilla no puede tener un argumento por defecto"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ no permite inicializadores designados de C99"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "se esperaba un nombre de clase"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "se esperaba %<;%> después de la definición de struct"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "se esperaba %<{%> o %<:%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "no se puede especificar %<override%> para una clase"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la calificación global del nombre de clase es no válida"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "el nombre calificado no nombra una clase"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nombre de clase no válido en la declaración de %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "una especialización explícita se debe preceder con %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "no se puede resolver el tipo typename"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "definición previa de %q+#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03 se debe usar una llave-clase cuando se declara un friend"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for unnamed bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "especificador-pure en la definición-de-función"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "especificador pure no válido (sólo se permite %<= 0%>)"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "un inicializador dentro de llaves no se permite aquí"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "se especificó %<virtual%> más de una vez en la base especificada"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, fuzzy, gcc-internal-format
 #| msgid "more than one access specifier in base-specified"
 msgid "more than one access specifier in base-specifier"
 msgstr "más de un especificador de acceso en la base especificada"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (la clase base es implícitamente un tipo)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "las especificaciones de excepción dinámicas son obsoletas en C++0x; utilice %<noexcept%> en su lugar"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD no es %<constexpr%>"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "El atributo %qE genera un conflicto con el atributo %s"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "se esperaba un identificador o %<(%>"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%> no está disponible en Objective-C 1.0"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 #| msgid "a transaction expression cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "una expresión de transacción no puede aparecer en una expresión constante"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración no válida de %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -46693,421 +46825,421 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Activa las instrucciones multiply"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración no válida de plantilla miembro en la clase local"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita no válida"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "la declaración no declara nada"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso no válido de %qD en la especificación de enlace"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ no válido"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo no válido para la variable de de instancia"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo no válido para la propiedad"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -47114,117 +47246,117 @@
 msgstr "%qD no es una función plantilla miembro"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "basura al final de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "el dato miembro %qD no puede ser una plantilla miembro"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "especialización explícita en el ámbito %qD que no es espacio de nombres"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "las plantillas de clase contenedoras no son explícitamente especializadas"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "especialización de %qD en un espacio de nombres diferente"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr " de la definición de %q+#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "el nombre de la clase oscurece la plantilla de parámetro de plantilla %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of alias template %qD"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "especialización de %qT después de la instanciación"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "se especializó %q#T en un espacio de nombres diferente"
@@ -47231,71 +47363,71 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "especialización de %qT después de la instanciación %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "no se permite la especialización de plantilla de %qD por ISO C++"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "especialización de %qD después de la instanciación"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD no es una plantilla de función"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD no es una variable"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "el id-de-plantilla %qD para %q+D no coincide con ninguna declaración de plantilla"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "se encontró %d %<template<>%>, se necesita %d para especializar una plantilla de función miembro"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "especialización de plantilla %qD ambigua para %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -47302,25 +47434,25 @@
 msgstr "especialización explícita de %qD después del primer uso"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing primary template attributes %s"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing primary template attribute %s"
@@ -47328,60 +47460,60 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "no se usan la plantilla de lista de parámetros en la instanciación explícita"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "se proporcionó una definición para la instanciación explícita"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "demasiadas listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "faltan listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la especialización explícita de %qD se debe preceder con %<template <>%>"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "se especificó un argumento por defecto en la especialización explícita"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD no es una función plantilla"
@@ -47394,154 +47526,154 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "especialización de la función miembro especial declarada implícitamente"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "la función no miembro %qD se declaró en %qT"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "shadowed declaration is here"
 msgid "friend declaration here"
 msgstr "aquí está la declaración oscurecida"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "El argumento de ACOS en %L debe estar entre -1 y 1"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "la expansión del inicializador base %<%T%> no contiene paquetes de parámetro"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "el patrón de expansión %<%T%> no contiene paquetes de argumento"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "el patrón de expansión %<%E%> no contiene paquetes de argumento"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "no se expanden los paquetes de parámetro con %<...%>"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anónimo>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "no se usan los parámetros de plantilla en la especialización parcial:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template %qD"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qE debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qT debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47548,19 +47680,19 @@
 msgstr[0] "el tipo %qT del argumento de plantilla %qE depende de un parámetro de plantilla"
 msgstr[1] "el tipo %qT del argumento de plantilla %qE depende de parámetros de plantilla"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "especialización parcial de %qT después de la instanciación %qT"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "no hay un argumento por defecto para %qD"
@@ -47568,50 +47700,50 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "el parámetro de paquete %qE debe estar al final de la lista de parámetros de plantilla"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en la re-declaración friend de la plantilla de función"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las declaraciones friend de la plantilla de función"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "los argumentos de plantilla por defecto no se pueden usar en las plantillas de función sin -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las especializaciones parciales"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "template %qD declared"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "clase de plantilla sin nombre"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -47622,58 +47754,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "declaración de la plantilla de %qD no válida"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definición de plantilla de %q#D que no es plantilla"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "se esperaban %d niveles de parámetros de plantilla para %q#D, se obtuvieron %d"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  pero se requieren %d"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "los argumentos de plantilla para %qD no coinciden con la plantilla original %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilice template<> para una especialización explícita"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT no es un tipo plantilla"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "no se especificaron los especificadores de plantilla en la declaración de %qD"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -47680,7 +47812,7 @@
 msgstr[0] "se redeclaró con %d parámetro de plantilla"
 msgstr[1] "se redeclaró con %d parámetros de plantilla"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -47689,12 +47821,12 @@
 msgstr[0] "la declaración previa de %q+#D usó %d parámetro de plantilla"
 msgstr[1] "la declaración previa de %q+#D usó %d parámetros de plantilla"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parámetro de plantilla %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
@@ -47703,121 +47835,121 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "debe ser un puntero-a-miembro de la forma %<&X::Y%>"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  los tipos %qT y %qT tiene calificadores-cv incompatibles"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  no coinciden los tipos %qT y %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  el parámetro de plantilla %qD no es un paquete de parámetro, pero el argumento %qD sí"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  el argumento de plantilla %qE no coincide con la constante puntero-a-miembro %qE"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE no es equivalente a %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  se deducen tipos en conflicto para el parámetro %qT (%qT y %qT)"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  se deducen valores en conflicto para el parámetro %qE que no es tipo (%qE y %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -47826,309 +47958,315 @@
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  no se puede convertir %qE (tipo %qT) al tipo %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT no es derivado de %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  los parámetros de plantilla de un argumento de plantilla plantilla son inconsistentes con otros argumentos de plantilla deducidos"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  no se puede deducir una plantilla para %qT del tipo %qT que no es plantilla"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match %qD"
 msgid "  template argument %qE does not match %qE"
 msgstr "  el argumento de plantilla %qE no coincide con %qD"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque las literales de cadena nunca se pueden usar en este contexto"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "in template argument for type %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qE no es una variable"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un objeto con enlace externo"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque el objeto %qD no tiene enlace externo"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso no válido del destructor %qE como un tipo"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es no válido"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "falla interna de consistencia"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "miembro de matriz flexible en union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -48147,285 +48285,285 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT no válido"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -48438,116 +48576,122 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of '%E' as a non-type template-argument"
+msgid "invalid use of %qT in template argument"
+msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -48764,7 +48908,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ámbito calificador no válido en el nombre del seudo-destructor"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificado %qT no coincide con el nombre del destructor ~%qT"
@@ -48815,7 +48959,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
@@ -48890,327 +49034,329 @@
 msgstr "%qT no es un tipo de enumeración"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Los paquetes de parámetros __bases sólo son válidos en la declaración de plantilla"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "no se puede aplicar %<offsetof%> al destructor %<~%T%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
-msgstr ""
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
+msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE tiene tipo no válido para %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD no es una variable en la cláusula %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "el final de la rebanada debe ser entero"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "demasiadas cláusulas %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "falló la aserción estática: %E"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -49353,12 +49499,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "cero como constante de puntero nulo"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "revisión lang_*: falló en %s, en %s:%d"
@@ -49420,773 +49566,767 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "el mismo nodo de tipo canónico para los tipos diferentes %T y %T"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplicación no válida de %qs a una función miembro"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplicación no válida de %<sizeof%> a un campo de bits"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<sizeof%> a una expresión de tipo de función"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplicación no válida de %<__alignof%> a un campo de bits"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<__alignof%> a una expresión de tipo de función"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "se toma la dirección de la matriz temporal"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "solicitud por el miembro %qD en %qE, el cual es de tipo puntero %qT (¿ Tal vez quiso utilizar %<->%> ?)"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "solicitud por el miembro %qD en %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "uso no válido del dato miembro no static %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "acceso no válido a datos del miembro que no es static %qD  del objeto NULL"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "el tipo de objeto %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "el tipo que se destruye es %qT, pero el destructor se refiere a %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> no es un miembro de %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT no es una base de %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD no es una función plantilla miembro"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT no es de tipo puntero-a-objeto"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uso no válido del índice de matriz en puntero a miembro"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uso no válido del unario %<*%> en puntero a miembro"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uso no válido de la conversión implícita en puntero a miembro"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "se declaró el subíndice de la matriz como %<register%>"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "el valor indicado por el subíndice no es ni matriz ni puntero"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "falta un objeto en el uso de %qE"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "no se puede desactivar la función interna %qs"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ prohíbe la llamada %<::main%> dentro del mismo programa"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "se debe usar %<.*%> o %<->*%> en la llamada a la función puntero-a-miembro en %<%E (...)%>, p.e. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "faltan argumentos para el constructor %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "demasiados argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "faltan argumentos para la función miembro %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "demasiados argumentos para la función %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "faltan argumentos para la función %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "demasiados argumentos para el método %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "faltan argumentos para el método %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "demasiados argumentos para la función"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "faltan argumentos para la función"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "el parámetro %P de %qD tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "el parámetro %P tiene el tipo incompleto %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "la dirección de %qD nunca debe ser NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "se asume la conversión al tipo %qT desde la función sobrecargada"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "se usó NULL en la aritmética"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "la cuenta de rotación izquierda es negativa"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "la cuenta de rotación derecha es negativa"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "la cuenta de rotación izquierda >= anchura del tipo"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "la cuenta de rotación derecha >= anchura del tipo"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ prohíbe la comparación entre puntero y entero"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "comparación sin orden en el argumento de coma no flotante"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operadores no válidos de tipos %qT y %qT para el binario %qO"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero de tipo %<void *%> en la sustracción"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a una función en la sustracción"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a un método en la sustracción"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "uso no válido de un puntero a un tipo incompleto en aritmética de punteros"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "se toma la dirección del constructor %qE"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "uso no válido de %qE para formar una función puntero a miembro"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  se requiere un id calificado"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "no se pueden usar paréntesis alrededor de %qE para formar una función-puntero-a-miembro"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro no estática sin calificar o entre paréntesis para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro limitada para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "se toma la dirección del temporal"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "se toma la dirección de xvalue (referencia rvalue)"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ prohíbe tomar la dirección de la función %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "no se puede crear un puntero al miembro referencia %qD"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "no se puede tomar la dirección del campo de bits %qD"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type bool"
 msgstr "se toma la dirección de la expresión de tipo %<id%>"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ prohíbe decrementar un enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "no se puede incrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "no se puede decrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe incrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe decrementar un puntero de tipo %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "no se puede tomar la dirección de %<this%> que es una expresión r-valuada"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "se solicitó la dirección de la variable register explícita %qD"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "se solicitó la dirección de %qD, la cual se declaró como %<register%>"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "el inicializador de lista para el tipo que no es clase no debe estar entre paréntesis"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en en inicializador"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en el inicializador de memoria"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "se trata la lista de expresiones como una expresión compuesta en la conversión funcional"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "se trata la lista de expresiones como una expresión compuesta %s"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "no hay contexto para resolver el tipo de %qE"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "la conversión del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT usa el tipo local %qT"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "static_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "se convierte de %qT a %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "la conversión de %qT a %qT pierde precisión"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "la comparación entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "la conversión de %qT a %qT incrementa la alineación requerida del tipo del destino"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ prohíbe la conversión entre puntero a función y puntero a objeto"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "conversión no válida del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "uso no válido de const_cast con tipo %qT, que no es puntero, referencia, ni un tipo puntero-a-datos-miembro"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "uso no válido de const_cast con tipo %qT, el cual es un puntero o referencia a un tipo de función"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "const_cast no válido de un valor-r de tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "const_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ prohíbe la conversión a un tipo de matriz %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "conversión no válida al tipo de función %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  en la evaluación de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "se asigna a una matriz desde una lista de inicializador"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipos incompatible en la asignación de %qT a %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "se usó una matriz como inicializador"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "asignación de matriz no válida"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   en la conversión del puntero a función miembro"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "puntero a la conversión miembro a través de la base virtual %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   en la conversión del puntero a miembro"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversión no válida del tipo %qT a partir del tipo %qT"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "no se puede convertir %qT a %qT para el argumento %qP para %qD"
+#| msgid "cannot convert %qT to %qT"
+msgid "cannot convert %qH to %qI"
+msgstr "no se puede convertir %qT a %qT"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "no se puede convertir %qT a %qT en el argumento por defecto"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "no se puede convertir %qT a %qT en el paso de argumentos"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-#| msgid "cannot convert %qT to %qT"
-msgid "cannot convert %qH to %qI"
-msgstr "no se puede convertir %qT a %qT"
-
-#: cp/typeck.c:8804
-#, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "no se puede convertir %qT a %qT en la devolución"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "no se puede convertir %qT a %qT en la asignación"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "el parámetro %qP de %qD puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "el parámetro puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "el objetivo de conversión puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "el objetivo de inicialización puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "al pasar el argumento %P de %q+D"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "se devolvió una referencia a un valor que no es l-valor"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "se devolvió una referencia a la variable local %q+D"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "se devuelve un valor de un destructor"
@@ -50193,58 +50333,58 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "no se puede regresar de un manejador de una función-intenta-bloque de un constructor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "se devuelve un valor de un constructor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<lista inicializador dentro de llaves>"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "se deducen los tipos inconsistentes %qT y %qT para el tipo de devolución lambda"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> no debe regresar NULL a menos que se declare %<throw()%> (o -fcheck-new esté en efecto)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "se usa el temporal como l-valor"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "se usa xvalue (referencia a r-valor) como l-valor"
@@ -50479,151 +50619,151 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "se usó la sintaxis de constructor, pero no se declaró un constructor para el tipo %qT"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "la conversión estrechadora de %qE desde %qT a %qT dentro de { } está mal formada en C++11"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "conversión estrechadora de %qE desde %qT a %qT dentro de { }"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "la expresión en la aserción static no es una expresión constante entera"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "matriz de enteros inicializada con una cadena que no es ancha"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "matriz de enteros inicializada con una cadena ancha incompatible"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "la cadena del inicializador para la matriz de caracteres es demasiado larga"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -51081,29 +51221,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Longitudes de CHARACTER diferentes (%d/%d) en el constructor de matriz en %L"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -51110,22 +51250,22 @@
 msgid "Simplification error"
 msgstr "falló la gimplificación"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -52261,7 +52401,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
@@ -52454,7 +52594,7 @@
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: parámetro de tipo diferido en %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -52738,12 +52878,12 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Aún sin implementar: LCOBOUND para una comatriz con colímites que no son constantes en %L"
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
@@ -52754,485 +52894,485 @@
 # como `apuntado'. cfuga
 # Referencia: http://gcc.gnu.org/onlinedocs/gfortran/Cray-pointers.html
 #
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Especificación de matriz duplicada para el apuntado Cray en %C"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Extensión: Inicialización de estilo antiguo en %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference type"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in pointer initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Error en la inicialización de puntero en %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "La inicialización en %C no es para una variable puntero"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "La inicialización de puntero en %C requiere '=>', no '='"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de una variable en %C en un procedimiento PURE"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "No se permite la inicialización del componente allocatable en %C"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "El componente puntero '%s' de '%s' en %L es de un tipo que no se ha declarado"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "No se admite la declaración de tipo de estilo antiguo %s*%d en %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Declaración de tipo %s*%d no estándar en %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Falta el paréntesis derecho en %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización escalar en %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "No se admite el género %d para el tipo %s en %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "El parámetro de tipo de género C es para el tipo %s, pero el tipo en %L es %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Falta el paréntesis derecho o una coma en %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "No se admite el género %d para CHARACTER en %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "El parámetro de tipo de género para la entidad en %L difiere del parámetro de tipo de género de la especificación de tipo"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "el primer parámetro de %<operator new%> no puede tener un argumento por defecto"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "La expresión en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "La matriz '%s' en %L es una variable, lo cual no se reduce a una expresión constante"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "argumento de tipo derivado parametrizado"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Extensión: tipo BYTE en %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "El tipo BYTE usado en %C no está disponible en la máquina objetivo"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "El argumento por valor en %L no se permite en este contexto"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: TYPE with intrinsic-type-spec at %C"
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008: TYPE con especificación de tipo intrínseco en %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: DOUBLE COMPLEX at %C"
 msgid "DOUBLE COMPLEX at %C"
 msgstr "Extensión: DOUBLE COMPLEX en %C"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "El nombre de tipo '%s' en %C es ambiguo"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: CLASS statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003: Declaración CLASS en %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "El nombre de tipo '%s' en %C tiene conflictos con la entidad declarada previamente en %L, la cual tiene el mismo nombre"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Declaración IMPLICIT NONE duplicada en %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Falta el rango de carácter en IMPLICIT en %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Las letras debe estar en orden alfabético en la declaración IMPLICIT en %C"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "No se puede IMPORTar '%s' desde la unidad de ámbito del anfitrión en %C - no existe."
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' ya se IMPORTó desde la unidad de ámbito del anfitrión en %C."
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Error sintáctico en la declaración IMPORT en %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Falta la especificación de codimensión en %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Falta la especificación de dimensión en %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Atributo %s duplicado en %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL Iteration variable at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "La variable de iteración FORALL en %L debe ser INTEGER"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL Iteration variable at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "La variable de iteración FORALL en %L debe ser INTEGER"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "No se permite el atributo %s en %L fuera de la parte de especificación de un módulo"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS attribute at %C"
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003: Atributo ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS attribute at %C"
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008: Atributo CONTIGUOUS en %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "Sólo se permite PROTECTED en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: Atributo PROTECTED en %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: Atributo VALUE en %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: Atributo VOLATILE en %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Se proveen múltiples identificadores con un sólo especificador NAME= en %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La función implícitamente declarada BIND(C) '%s' en %L no puede ser interoperable con C"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable '%s' en el bloque común '%s' en %L no puede ser un género interoperable con C ya que el bloque común '%s' es BIND(C)"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La declaración de tipo '%s' en %L no es interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable '%s' en %L no es de un género interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable '%s' en el bloque común '%s' en %L no se puede declarar con BIND(C) porque no es un global"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "El tipo de devolución de la función BIND(C) '%s' en %L no puede ser una matriz"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -53240,362 +53380,362 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "El símbolo '%s' en %L se marcó PRIVATE pero se le dio la etiqueta de asignación '%s'"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Se necesita una entidad o un nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Falta la entidad o el nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Falta el nombre"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "El tipo derivado en %C no se definió previamente y no puede aparecer en una definición de tipo derivado"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: IMPURE procedure at %C"
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008: Procedimiento IMPURE en %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "No deben aparecer PURE con IMPURE en %C"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Se esperaba la etiqueta de devolución alterna en %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A parameter name is required at %C"
 msgstr "Se requiere paréntesis izquierdo después de %<*%>"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "El nombre '%s' en %C es el nombre del procedimiento"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Se esperaba otra dimensión en la declaración de matriz %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Basura inesperada en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate name '%s' in association at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Nombre '%s' duplicado en la asociación en %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Símbolo '%s' duplicado en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT en %C debe ser diferente que el nombre de la función"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Basura inesperada después de la declaración de la función en %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: El atributo BIND(C) en %L no se puede especificar para un procedimiento internal"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "El atributo BIND(C) en %C requiere una interfaz con BIND(C)"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "El procedimiento BIND(C) con NAME no debe tener atributo POINTER en %C"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "El procedimiento dummy en %C no puede tener atributo BIND(C) con NAME"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "El procedimiento '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Error sintáctico en la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Se esperaba '::' después de los atributos de enlazado en %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer component at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003: Procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Error sintáctico en el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE en %C debe estar en una interfaz genérica"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008: dos puntos dobles en la declaración MODULE PROCEDURE en %L"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: Declaración PROCEDURE en %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Se esperaba una lista de argumentos formales en la definición de la función en %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "El atributo BIND(C) en %L sólo se puede usar para variables o bloques comunes"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un PROGRAM"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un BLOCK DATA"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DERIVED TYPE"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque IF-THEN"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DO"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque FORALL"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque WHERE"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un subprograma contenido"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Faltan los paréntesis requeridos antes de BIND(C) en %C"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nombre C no válido en el especificador NAME= en %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Error sintáctico en el especificador NAME= para la etiqueta de asignación %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Falta el paréntesis que cierra en la etiqueta de asignación en %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "No se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Para el procedimiento dummy %s, no se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "No se permite NAME en BIND(C) para ABSTRACT INTERFACE en %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: END statement instead of %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -53602,665 +53742,665 @@
 msgstr "Fortran 2008: Declaración END en lugar de una declaración %s en %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Se esperaba %s en la declaración en %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Se esperaba la declaración %s en %C"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Se esperaba el nombre de bloque de '%s' en la declaración %s en %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Se esperaba la etiqueta '%s' para la declaración %s en %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración DIMENSION"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Se especificarion dimensiones para %s en %L después de su inicialización"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración CODIMENSION"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La especificación de matriz se debe diferir en %L"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Carácter inesperado en la lista de variables en %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Se esperaba '(' en %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "se esperaba un nombre variable en %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "El puntero Cray en %C tiene %d bytes de precisión; las direcciones de memoria requieren %d bytes"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Se esperaba \")\" en %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Se esperaba \",\" o el final de la declaración en %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "No se permite INTENT dentro de BLOCK en %C"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "No se permite OPTIONAL dentro de BLOCK en %C"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "La declaración de punteros Cray en %C requiere la opción -fcray-pointer"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008: Declaración CONTIGUOUS en %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La especificación de acceso del operador %s en %C ya se había especificado"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La especificación de acceso del operador .%s. en %C ya se había especificado"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: Declaración PROTECTED en %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Se esperaba un nombre de variable en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Se esperaba un signo = en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Se esperaba una expresión en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Se inicializa una variable ya inicializada en %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caracteres inesperados en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Declaración SAVE incondicional en %C después de una declaración SAVE previa"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "No se permite VALUE dentro de BLOCK en %C"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: Declaración VALUE en %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Error sintáctico en la declaración VALUE en %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: Declaración VOLATILE en %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, fuzzy, gcc-internal-format
 #| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Se especifica VOLATILE para la variable de comatriz '%s' en %C, la cual es asociada a uso/anfitrión"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003: Declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Error sintáctico en la declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Basura después de la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE en %C debe estar en una interfaz genérica de módulo"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "El procedimiento intrínseco en %L no puede ser un MODULE PROCEDURE"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Símbolo ambiguo en la definición TYPE en %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' en la expresión EXTENDS en %C no es un tipo derivado"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' no se puede extender en %C porque es BIND(C)"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' no se puede extender en %C porque es un tipo SEQUENCE"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PRIVATE en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PUBLIC en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "El tipo ABSTRACT '%s' se usa en %L"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Etiqueta construct '%s' duplicada en %C"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing structure name for outer structure definition at %0"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Falta el nombre de la estructura para la definición de la estructura externa en %0"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Se esperaba :: en la definición TYPE en %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "El nombre de tipo derivado '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "El Apuntado Cray en %C no puede ser una matriz de forma asumida"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM y ENUMERATOR en %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "El enumerador excede el tipo entero de C en %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L no se inicializó con una expresión entera"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Se esperaba una declaración de definición ENUM antes de %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Error sintáctico en la definición ENUMERATOR en %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Especificador de acceso duplicado en %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, NOPASS ilegal en %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, PASS ilegal en %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Atributo POINTER duplicado en %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE duplicado en %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED duplicado en %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Se esperaba un especificador de acceso en %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Se esperaba un atributo de enlace en %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "No pueden aparecer NON_OVERRIDABLE y DEFERRED al mismo tiempo en %C"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Se requiere el atributo POINTER para el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "Se esperaba ')' en %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Se debe especificar una interfaz para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) en %C se debe declarar DEFERRED"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Se esperaba un nombre de enlace en %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: PROCEDURE list at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008: Lista PROCEDURE en %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "'=> objetivo' es no válido para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "Se necesita '::' en el enlace PROCEDURE con objetivo explícito en %C"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Se esperaba un objetivo de enlace después de '=>' en %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "El tipo '%s' que contiene el enlace DEFERRED en %C no es ABSTRACT"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, fuzzy, gcc-internal-format
 #| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento con nombre de enlazado '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC en %C debe estar dentro de un tipo derivado CONTAINS"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Se esperaba '::' en %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Se esperaba un nombre genérico o un descriptor de operador en %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Forma no válida de la declaración PROGRAM en %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Se esperaba '=>' en %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento que no es genérico con el nombre de enlace '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "El enlace en %C debe tener el mismo acceso que el enlace '%s' que ya está definido"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Se esperaba un nombre de enlace específico en %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Ya se definió '%s' como un enlace específico para el genérico '%s' en %C"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Basura después del enlace GENERIC en %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La declaración FINAL en %C debe estar dentro de una sección de tipo derivado CONTAINS"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La declaración de tipo derivado con FINAL en %C debe estar en la parte de especificación de un MODULE"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vacío en %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Se esperaba un nombre de procedimiento de módulo en %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nombre de procedimiento \"%s\" desconocido en %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "¡'%s' en %C ya se había definido como un procedimiento FINAL!"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Atributo desconocido en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Error sintáctico en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -54627,31 +54767,31 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Extensión: se usa la literal BOZ en %L para inicializar la variable '%s' que no es entera"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Extensión: la literal BOZ en %L está fuera de una declaración DATA y fuera de INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "La literal BOZ en %L se transfiere por bits al símbolo '%s' que no es entero"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Desborde aritmético por debajo del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Desborde aritmético del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -55009,7 +55149,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Se crea una matriz temporal en %L"
@@ -55020,71 +55160,71 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Se elimina la llamada a la función '%s' en %L"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "se esperaba una expresión"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "move erróneo"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "operandos no válidos en la comparación gimple"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "Interchanging loops at %L"
@@ -55212,12 +55352,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -56568,7 +56708,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -58121,12 +58261,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP FLUSH en %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -58394,8 +58534,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
@@ -58440,7 +58580,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
@@ -58819,201 +58959,201 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "Los bucles !$OMP DO colapsados no forman un espacio de iteración rectangular en %L"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "Los bucles !$OMP DO colapsados no están perfectamente anidados en %L"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "A format cannot be specified with a namelist"
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "No se puede especificar un formato con una lista de nombres"
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO no puede ser un DO WHILE ó DO sin control de bucle en %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "La variable de iteración !$OMP DO debe ser de tipo entero en %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "Los bucles !$OMP DO colapsados no forman un espacio de iteración rectangular en %L"
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "Los bucles !$OMP DO colapsados no están perfectamente anidados en %L"
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) genera un conflicto con INTENT(%s) en %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "TILE requires constant expression at %L"
 msgstr "%qE no es una expresión constante"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "action not allowed in SPEC MODULE"
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "no se pertite una acción en SPEC MODULE"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -60519,7 +60659,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
@@ -60645,7 +60785,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -61051,239 +61191,239 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "La variable errmsg en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -61292,248 +61432,248 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
@@ -61540,12 +61680,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -61553,114 +61693,114 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "La variable impura en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -61667,35 +61807,35 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero."
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
@@ -61702,40 +61842,40 @@
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -61743,7 +61883,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -61752,66 +61892,66 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: SAVE implícito para la variable de módulo '%s' en %L, se necesita por la inicialización por defecto"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -61819,1018 +61959,1018 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "El argumento de ICHAR en %L debe ser de longitud uno"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "El componente puntero '%s' de '%s' en %L es de un tipo que no se ha declarado"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Especificaciones de control de E/S en conflicto en %0 y %1"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -63289,7 +63429,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): tipo no válido: %s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -64001,20 +64141,20 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "No se reconoce la función intrínseca %s(%d)"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "el argumento 'dim' del intrínseco '%s' en %L no es un índice de dimensión válido"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deferred-length character component '%s' at %L is not yet supported"
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se admite"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "The event variable at %L shall not be coindexed"
@@ -64216,183 +64356,183 @@
 msgid "previously defined here as %s"
 msgstr "se definió previamente aquí"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "prevalecen definiciones múltiples para %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD ya se definió aquí"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "se definió previamente aquí"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T was previously declared here"
 msgid "%qD was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "la función %qD se redeclaró como variable"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "se declaró previamente aquí"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "flujo de bytecode: basura al final de la sección de símbolos"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "no se puede decodificar el número hexadecimal"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "nombre de fichero inesperado %s en el fichero de resolución de enlace. Se esperaba %s"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "no se puede abrir el fichero de desplazamiento"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "desplazamiento inesperado"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "línea no válida en el fichero de resolución"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "resolución no válida en el fichero de resolución"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, fuzzy, gcc-internal-format
 #| msgid "resolution sub id %x not in object file"
 msgid "resolution sub id %wx not in object file"
 msgstr "el sub id de resolución %x no está en el fichero objeto"
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "no se pueden leer las decls LTO de %s"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "No se puede abrir %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "No se puede mapear %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "No se puede leer %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "falló lto_obj_file_open()"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "atexit failed"
 msgid "waitpid failed"
 msgstr "falló atexit"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file: %m"
 msgid "streaming subprocess failed"
 msgstr "se renombra el fichero .rpo: %m"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "no se proporcionó el nombre de fichero de lista de salida TRANS"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "se abre la lista de salida LTRANS %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "se escribe a la lista de salida LTRANS %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "se cierra la lista de salida LTRANS %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "no se puede abrir el fichero de resolución de símbolos: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "errores durante la mezcla de unidades de traducción"
@@ -65336,6 +65476,49 @@
 msgstr "se crea un selector para el método %qE que no existe"
 
 #, fuzzy
+#~| msgid "Support MMX and SSE built-in functions and code generation."
+#~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+#~ msgstr "Admite funciones internas y generación de código MMX y SSE."
+
+#~ msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
+#~ msgstr "%K%qD: escribir %E bytes en una región de tamaño %E desborda el destino"
+
+#~ msgid "%K%qD reading %E bytes from a region of size %E"
+#~ msgstr "%K%qD leyendo %E bytes en una región de tamaño %E"
+
+#~ msgid "builtin operand should be an unsigned 6-bit value"
+#~ msgstr "el operando interno debería ser un valor de 6 bits sin signo"
+
+#~ msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
+#~ msgstr "el operando para la instrucción sleep debe ser una constante en tiempo de compilación sin signo de 6 bits"
+
+#, fuzzy
+#~| msgid "%<-fcf-protection=branch%> requires CET support on this target. Use -mcet or one of -mibt, -mshstk options to enable CET"
+#~ msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
+#~ msgstr "%<-fcf-protection=branch%> requiere suporte CET en este objetivo. Utilice las opciones -mcet o una de entre -mibt y -mshstk para activar CET."
+
+#, fuzzy
+#~| msgid "%<-fcf-protection=return%> requires CET support on this target. Use -mcet or one of -mibt, -mshstk options to enable CET"
+#~ msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
+#~ msgstr "%<-fcf-protection=return%> requiere suporte CET en este objetivo. Utilice las opciones -mcet o una de entre -mibt y -mshstk para activar CET."
+
+#, fuzzy
+#~| msgid "%<-fcf-protection=full%> requires CET support on this target. Use -mcet or one of -mibt, -mshstk options to enable CET"
+#~ msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
+#~ msgstr "%<-fcf-protection=full%> requiere suporte CET en este objetivo. Utilice las opciones -mcet o una de entre -mibt y -mshstk para activar CET."
+
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "la expresión %<for%> basada en rango de tipo %qT tiene un miembro %<end%> pero no tiene %<begin%>"
+
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "la expresión %<for%> basada en rango de tipo %qT tiene un miembro %<begin%> pero no tiene %<end%>"
+
+#, fuzzy
+#~| msgid "cannot convert %qT to %qT for argument %qP to %qD"
+#~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#~ msgstr "no se puede convertir %qT a %qT para el argumento %qP para %qD"
+
+#, fuzzy
 #~| msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 #~ msgid "%G%qD output truncated copying %E byte from a string of length %E"
 #~ msgstr "salida de la directiva %<%.*s%> truncada escribiendo %wu byte en una región de tamaño %wu"
Index: gcc/po/fr.po
===================================================================
--- gcc/po/fr.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/fr.po	(.../branches/gcc-8-branch)
@@ -134,7 +134,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1-b20180401\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2018-04-11 06:30+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
@@ -277,40 +277,40 @@
 msgid "negative insn length"
 msgstr "longueur insn négative"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "n'a pu séparer insn"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "« asm » invalide : "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "alternatives imbriquées de dialecte assembleur"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "alternative non terminée de dialecte assembleur"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "numéro d’opérande manquant après %%-lettre"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "numéro d’opérande hors limite"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "%%-code invalide"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "l'opérande « %%l » n'est pas une étiquette"
@@ -321,13 +321,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "constante flottante mal utilisée"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1293,26 +1293,26 @@
 msgid "At top level:"
 msgstr "Au plus haut niveau:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "Dans la fonction membre %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "Dans la fonction %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    mis en ligne depuis %qs à %r%s:%d:%d%R"
 
 # FRONT
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    mis en ligne depuis %qs à %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    mis en ligne depuis %qs"
@@ -3056,9 +3056,9 @@
 msgid "invalid address mode"
 msgstr "mode d'adresse invalide"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "« %%& » utilisé sans référence à un TLS dynamique local"
@@ -3074,7 +3074,7 @@
 msgstr "valeur %%r invalide"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3081,13 +3081,13 @@
 msgstr "valeur %%R invalide"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
@@ -3118,7 +3118,7 @@
 msgstr "valeur %%U invalide"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
@@ -3129,7 +3129,7 @@
 msgstr "valeur %%C invalide"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
@@ -3140,7 +3140,7 @@
 msgstr "relocalisation unspec inconnue"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3151,57 +3151,57 @@
 msgid "invalid operand address"
 msgstr "adresse d'opérande invalide"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "opérande invalide pour le code %%Z"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "opérande invalide pour le code %%z"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "opérandes invalides pour le code %%c"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "opérande invalide pour le code %%M"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "opérande invalide pour le code %%p"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "opérande invalide pour le code %%s"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "opérande invalide pour le code %%R"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "opérande invalide pour le code %%H/%%L"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "opérande invalide pour le code %%U"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "opérande invalide pour le code %%V"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "opérande invalide pour le code %%O"
@@ -3208,18 +3208,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "opérande invalide pour le code de sortie"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC invalide comme opérande : %d"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "constante supposée non reconnue"
 
@@ -3254,7 +3254,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
@@ -3377,8 +3377,8 @@
 msgstr "opérande const_double invalide"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3595,97 +3595,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "mauvais opérande output_condmove_single"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC invalide comme opérande"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "utilisation invalide du registre « %s »"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "utilisation invalide de la sortie du fanion asm"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "taille d'opérande invalide pour le code d'opérande « 0 »"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « z »"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "type opérande invalide utilisé avec le code d'opérande « Z »"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « Z »"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « Y » invalide"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « D » invalide"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « %c » invalide"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "l'opérande n'est pas une référence mémoire avec décalage, code d'opérande « H » invalide"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « K » invalide"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « r » invalide"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « R » invalide"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « R » invalide"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "contrainte invalide pour l'opérande"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, c-format
 msgid "invalid vector immediate"
 msgstr "immédiat vecteur invalide"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "mode insn inconnu"
 
@@ -3723,7 +3723,7 @@
 msgstr "opérande %%P invalide"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -3777,7 +3777,7 @@
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -3940,141 +3940,141 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion requiert le modèle de code moyen/large"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 et __ibm128 ne peuvent pas être utilisés dans la même expression"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, mauvais reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, mauvais reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load pas MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, mauvais reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, mauvais reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store pas MEM"
 
@@ -4200,43 +4200,43 @@
 msgid "created and used with different endianness"
 msgstr "créé et utilisé avec des boutismes différents"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "opérande %%Y invalide"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "opérande %%A invalide"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "opérande %%B invalide"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "opérande %%C invalide"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "opérande %%D invalide"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "opérande %%f invalide"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "opérande %%s invalide"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "la constante en virgule flottante n'est pas un opérande immédiat valide"
@@ -4451,14 +4451,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -4473,7 +4473,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -4481,7 +4481,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -4495,7 +4495,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
@@ -4502,7 +4502,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -4512,13 +4512,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
@@ -4527,18 +4527,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> ou %<)%> attendu"
@@ -4546,23 +4546,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> ou %<}%> attendu"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
@@ -4571,7 +4571,7 @@
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> attendu"
@@ -4582,39 +4582,39 @@
 msgid "expected label"
 msgstr "étiquette attendue"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "candidat 1 :"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "candidat 2 :"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "saut à l'étiquette %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "saut à l'étiquette du « case »"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr "entre dans le bloc « try »"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr "entre dans le bloc « catch »"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr "entre dans le bloc structuré OpenMP"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr "entre dans l'instruction synchronisée ou atomique"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr "entre dans l'instruction « if » « constexpr »"
 
@@ -4703,7 +4703,7 @@
 msgid "<statement>"
 msgstr "<déclaration>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<inconnu>"
@@ -4722,114 +4722,114 @@
 msgid "<unparsed>"
 msgstr "<non analysé>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr "<lambda>"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<erreur d'expression>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<opérateur inconnu>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "Au niveau global:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "Dans la fonction membre statique %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "Dans le constructeur de copie %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "Dans le constructeur %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "Dans le destructeur %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "Dans la fonction lambda"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: Dans la substitution de %qS :\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: Dans l'instanciation de %q#D :\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr "%r%s:%d:%d:%R   "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr "%r%s:%d:%R   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "requis récursivement par la substitution de %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr "requis par la substitution de %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr "requis récursivement par %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr "requis par %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr "requis récursivement depuis ici\n"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr "requis depuis ici\n"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%d:%R   [ passe outre %d contextes d'instanciation, utilisez -ftemplate-backtrace-limit=0 pour désactiver ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%R   [ passe outre %d contextes d'instanciation, utilisez -ftemplate-backtrace-limit=0 pour désactiver ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%d:%R   dans l'expansion %<constexpr%> de %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   dans l'expansion %<constexpr%> de %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "les candidats sont :"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
@@ -4875,48 +4875,48 @@
 msgid "source type is not polymorphic"
 msgstr "le type source n'est pas polymorphique"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "type d'argument erroné pour le moins unaire"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "type d'argument erroné pour le plus unaire"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "type d'argument erroné pour le complément de bit"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "type d'argument erroné pour abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "type d'argument erroné pour la conjugaison"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "dans l'argument d'un unaire !"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "pas d'opérateur de pré-incrémentation pour le type"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "pas d'opérateur de post-incrémentation pour le type"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "pas d'opérateur de pré-décrémentation pour le type"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "pas d'opérateur de post-décrémentation pour le type"
 
@@ -5187,11 +5187,11 @@
 msgid "implied END DO"
 msgstr "END DO implicite"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
@@ -5346,47 +5346,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangs inconsistant pour l'opérateur à %%L et %%L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr "variable d'itérateur"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "Expression de départ dans la boucle DO"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "Expression de fin dans la boucle DO"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "Expression de pas dans la boucle DO"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "objet ALLOCATE"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -5428,12 +5428,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Longueurs de caractères inégales (%ld/%ld) dans %s"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est négatif (sa valeur est %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est trop grand"
 
@@ -5667,6 +5667,7 @@
 msgstr "-Xbind-now et -Xbind-lazy sont incompatibles"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "envisagez d'utiliser « -pg » au lieu de « -p » avec gprof (1)"
 
@@ -8327,7 +8328,7 @@
 msgstr "Aligner les variables sur des frontières de 32 bits."
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr "Spécifier le nom de l'architecture cible."
 
@@ -8770,7 +8771,7 @@
 msgstr "Spécifier la plage des registres à rendre fixes."
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr "Spécifier la taille en bits des décalages TLS immédiats."
 
@@ -9429,7 +9430,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Générer du code conforme à l'ABI spécifiée."
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "ABI connues (à utiliser avec l'option -mabi=):"
 
@@ -9831,7 +9832,7 @@
 msgstr "Supporter les fonctions internes PKU et la génération de code."
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr "Utiliser la méthode donnée pour protéger la pile."
 
@@ -9840,12 +9841,12 @@
 msgstr "Méthodes connues pour protéger la pile (à utiliser avec l'option -mstack-protector-guard=):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Utiliser le registre de base donné pour adresser la protection de la pile."
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Utiliser le décalage donné pour adresser la protection de la pile."
 
@@ -9858,41 +9859,47 @@
 msgstr "Essayer d'éviter de générer des séquences d'instructions contenant des octets « ret »."
 
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Supporter les fonctions internes CET (Control-flow Enforcement Technology) et la génération de code."
+#, fuzzy
+#| msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr "Activer spécifiquement une fonctionnalité supportant la pile masquée de CET (Control-flow Enforcement Technology)."
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
-msgstr "Activer spécifiquement une fonctionnalité de suivi d'un branchement indirect de CET (Control-flow Enforcement Technology)."
-
-#: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr "Activer spécifiquement une fonctionnalité supportant la pile masquée de CET (Control-flow Enforcement Technology)."
-
-#: config/i386/i386.opt:1026
 msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr "Activer l'instrumentalisation CET pour les instructions switch qui utilisent une table de sauts et un saut indirect."
 
-#: config/i386/i386.opt:1031
+#: config/i386/i386.opt:1021
 msgid "Make all function calls indirect."
 msgstr "Rendre indirects tous les appels de fonctions."
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr "Convertir les appel et saut indirects en fragment d'appel et de saut"
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr "Convertir le retour de fonction en un fragment d'appel et de retour."
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Choix connus pour le branchement indirect (à utiliser avec les options -mindirect-branch=/-mfunction-return=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr "Forcer les appels indirects et les sauts via un registre."
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Supporter les fonctions internes BMI et la génération de code."
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Supporter les fonctions internes BMI et la génération de code."
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr "Supposer que le code sera lié par GNU ld."
@@ -10267,7 +10274,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Option obsolète. Utilisez -mvrsave à la place."
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr "Spécifier le nombre maximum d'octets qui peuvent être déplacés par du code en ligne. Au delà, memcpy et memmove sont utilisés."
 
@@ -10275,7 +10282,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr "Spécifier le nombre maximum de paires d'instructions de chargement qui doivent être générées en ligne pour la comparaison. Si le nombre requis dépasse la limite, un appel à memcmp est généré à la place."
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr "Spécifier le nombre maximum de paires d'instructions de chargement qui doivent être générées en ligne pour la comparaison. Si le nombre requis dépasse la limite, un appel à strncmp est généré à la place."
 
@@ -10360,7 +10367,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\tOrdonnancer le code pour le processeur donné."
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr "-mtraceback=\tSélectionner « full » (complète), « part » (partielle) ou « no » (aucune) pour la table de retraçage."
 
@@ -10389,7 +10396,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Arguments valides pour -mfloat-gprs=:"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr "-mlong-double-<n>\tSpécifier la taille des long double (64 ou 128 bits)."
 
@@ -10465,23 +10472,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Utiliser les instructions Category:Vector.AES et Category:Vector.SHA2 de l'ISA 2.07."
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr "Utiliser les instructions de déplacements directs entre les GPR et les registres VSX de l'ISA 2.07."
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Utiliser les instructions de mémoire transactionnelle (HTM) de l'ISA 2.07."
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Générer les instructions de mémoire quadruple mots (lq/stq)."
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr "Générer les instructions de mémoire atomique quadruple mots (lqarx/stqcx)."
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr "Générer du code de passage de paramètres agrégés avec, au plus, un alignement 64 bits."
 
@@ -10501,19 +10508,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr "Autoriser des variables entières 64 bits dans les registres supérieurs avec -mcpu=power7 ou -mvsx."
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr "Analyser et supprimer les échanges de doubles mots dans les calculs VSX."
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr "Fusionner certaines opérations pour une meilleure performance sur un power9."
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Utiliser certaines instructions scalaires ajoutées dans l'ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr "Utiliser les instructions vectorielles ajoutées dans l'ISA 3.0."
 
@@ -10529,15 +10536,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr "Utiliser les instructions mémoire de type registre+décalage ajoutées dans l'ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Utiliser les nouvelles instructions min/max définies dans l'ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr "Fusionner les références à la toc des modèles de code medium/large avec l'instruction mémoire."
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr "Générer les instructions avec modulo entier."
 
@@ -10545,15 +10552,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr "Autoriser les types IEEE 128 bits sans exiger le mot clé __float128."
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "Activer les virgules flottantes IEEE 128 bits via le mot clé __float128."
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Activer l'utilisation des instructions en virgule flottante IEEE 128 bits."
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr "Activer les conversions par défaut entre __float128 et long double."
 
@@ -10561,7 +10568,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Activer le placement de petits entiers dans les registres VSX."
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Arguments valides pour -mstack-protector-guard=:"
 
@@ -10590,12 +10597,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Appeler mcount pour le profilage avant le prologue d'une fonction."
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr "Sélectionner la convention d'appel de l'ABI."
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr "Sélectionner la méthode de traitement de sdata."
 
@@ -11254,7 +11260,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Éviter le chevauchement entre la destination et les registres d'adresses sur les instructions LDRD qui peuvent déclencher un errata du Cortex-M3."
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "Activer les accès sur des mots et demi-mots non alignés aux données compactées."
 
@@ -11443,14 +11449,30 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mvrsave=yes%> est dépréciée. Utilisez plutôt %<-mvrsave%>"
 
+#: config/rs6000/rs6000.opt:334
+#, fuzzy
+#| msgid "Max. count of debug markers to expand or inline."
+msgid "Max number of bytes to move inline."
+msgstr "Nombre max de marqueurs de débogage à étendre ou mettre en ligne."
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
-msgstr "Spécifier le nombre maximum d'octets à comparer en ligne avec le code qui ne participe pas à la boucle. Si cette valeur vaut 0, toutes les expansions en ligne (non boucle et boucle) de memcmp sont désactivées."
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare without loops."
+msgstr "Le nombre maximum d'insns d'une boucle qui est déplacée à l'intérieur de ses branchements."
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr "Spécifier le nombre maximum d'octets à comparer en ligne avec la génération de code de boucle. Si la longueur n'est pas connue au moment de la compilation, memcmp sera appelé après que ce nombre d'octets ait été comparé. Par défaut, la longueur est choisie sur base des paramètres de réglages."
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare with loops."
+msgstr "Le nombre maximum d'insns d'une boucle qui est déplacée à l'intérieur de ses branchements."
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop."
+msgid "Max number of pairs of load insns for compare."
+msgstr "Le nombre maximum de dépliages pour aplatir une boucle."
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr "%<-misel=no%> est déprécié; utilisez plutôt %<-mno-isel%>"
@@ -11459,10 +11481,48 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-misel=yes%> est déprécié; utilisez plutôt %<-misel%>"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table."
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tSélectionner « full » (complète), « part » (partielle) ou « no » (aucune) pour la table de retraçage."
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\tSpécifier la taille des long double (64 ou 128 bits)."
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs est obsolète"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention."
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Sélectionner la convention d'appel de l'ABI."
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling."
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Sélectionner la méthode de traitement de sdata."
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr "Autoriser des données en lecture seule dans sdata."
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets."
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Spécifier la taille en bits des décalages TLS immédiats."
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr "Utiliser les registres FP."
@@ -12557,86 +12617,152 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Autoriser gcc à générer les instruction SETLB et Lcc."
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "Générer du code en mode gros-boutiste."
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "Générer du code en mode petit-boutiste."
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr "Utiliser des registres réduits pour l'allocation de registres."
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr "Utiliser des registres complets pour l'allocation de registres."
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+#, fuzzy
+#| msgid "Patchable function entry > size"
+msgid "Align function entry to 4 byte."
+msgstr "Entrée de fonction patchable > taille"
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr "Générer des instructions de déplacements conditionnels."
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr "Générer des instructions de l'extension de performance."
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr "Générer des instructions de l'extension de performance version 2."
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 msgid "Generate string extension instructions."
 msgstr "Générer des instructions de l'extension de chaînes."
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Générer des instructions push25/pop25 v3."
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr "Générer des instructions 16 bits."
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr "Activer le support Virtual Hosting."
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr "Spécifier la taille de chaque vecteur d'interruption qui doit être 4 ou 16."
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr "Spécifier la taille de chaque bloc de cache qui doit être une puissance de 2 entre 4 et 512."
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr "Types d'architectures connues (à utiliser avec l'option -march=):"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr "Spécifier la stratégie de génération d'adresse pour le modèle de code."
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "Types de cmodel connus (à utiliser avec l'option -mcmodel=):"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr "Spécifier le processeur pour le modèle pipeline."
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Types de processeurs connus (à utiliser avec l'option -mcpu=):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+#, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "ABI en virgule flottante connues (à utiliser avec l'option -mfloat-abi=):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr "Activer la fonctionnalité constructeur/destructeur."
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr "Guider l'éditeur de liens pour relâcher les instructions."
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set."
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Générer les mathématiques en virgule flottante avec le jeu d'instructions donné."
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions."
+msgid "Generate single-precision floating-point instructions."
+msgstr "Utiliser les instructions en virgule flottante simple précision appariées (paired-single)."
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Générer du code qui utilise les instructions en virgules flottantes du 68881."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr "Spécifier le processeur pour les besoins de la génération de code."
@@ -13458,13 +13584,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Générer les instructions mul64 et mulu64."
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs est obsolète"
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr "Ne pas générer des instructions mpy sur un ARC700."
@@ -15699,8 +15818,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr "Faire sauvegarder les registres par l'appelant au travers des appels si possible."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "la valeur calculée n'est pas utilisée"
@@ -15726,7 +15845,7 @@
 msgstr "type booléen attendu"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "entier attendu"
@@ -16142,7 +16261,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "l'attribut %qE est ignoré car il est en conflit avec l'attribut %qs"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16168,12 +16287,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribut ignoré"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un attribut qui appartient à un spécificateur de type est ignoré"
@@ -16222,9 +16341,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16237,8 +16356,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "attribut %<target%> manquant pour %qD avec plusieurs versions"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "déclaration précédente de %qD"
@@ -16368,82 +16487,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: la taille spécifiée entre %E et %E excède la taille maximale %E de l'objet"
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: l'écriture de %E octets ou plus dans une région de taille %E déborde de la destination"
 
-#: builtins.c:3177
-#, gcc-internal-format
+#: builtins.c:3176
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr "%K%qD: l'écriture de %E octet dans une région de taille %E déborde de la destination"
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] "%K%qD: l'écriture de %E octet dans une région de taille %E déborde de la destination"
+msgstr[1] "%K%qD: l'écriture de %E octet dans une région de taille %E déborde de la destination"
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr "%K%qD: l'écriture de %E octets dans une région de taille %E déborde de la destination"
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: écrire entre %E et %E octets dans une région de taille %E déborde de la destination"
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD: la limite spécifiée (%E) excède la taille maximale de l'objet (%E)"
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: la limite spécifiée entre %E et %E excède la taille maximale de l'objet (%E)"
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD: la limite spécifiée (%E) excède la taille de la destination (%E)"
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr "%K%qD: la limite spécifiée entre %E et %E excède la taille de la destination (%E)"
 
-#: builtins.c:3278
-#, gcc-internal-format
+#: builtins.c:3276
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD reading %E byte from a region of size %E"
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr "%K%qD lecture de %E octet depuis une région de taille %E"
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] "%K%qD lecture de %E octet depuis une région de taille %E"
+msgstr[1] "%K%qD lecture de %E octet depuis une région de taille %E"
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr "%K%qD lecture de %E octets depuis une région de taille %E"
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD lecture de %E octets ou plus depuis une région de taille %E"
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD lecture entre %E et %E octets depuis une région de taille %E"
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%K%qD la limite %E spécifiée est égale à la taille de la destination"
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "trop peu d'arguments pour la fonction %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "argument invalide pour %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "argument non supporté par %qD"
@@ -16450,72 +16565,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "appeler %qD avec un argument non nul n'est pas sûr"
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "les deux arguments de %<__builtin___clear_cache%> doivent être des pointeurs"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "trampoline généré pour la fonction imbriquée %qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD a changé de sémantique dans GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "spécificateur d'architecture inconnu dans le modèle mémoire de la fonction interne"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "argument de modèle mémoire invalide dans la fonction interne"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "le modèle mémoire en cas d'échec ne peut pas être plus fort que le modèle mémoire en cas de succès pour %<__atomic_compare_exchange%>"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "modèle mémoire en cas d'échec invalide pour %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "modèle mémoire invalide pour %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "modèle mémoire invalide pour %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "argument 1 non constant pour __atomic_always_lock_free"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "argument 1 non entier pour __atomic_is_lock_free"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer n'est pas supporté sur cette cible"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer n'est pas supporté sur cette cible"
@@ -16522,7 +16637,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack ()%>"
@@ -16529,12 +16644,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "le deuxième argument de %<__builtin_longjmp%> doit être 1"
@@ -16541,62 +16656,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Votre plateforme cible ne supporte pas -fcheck-pointer-bounds"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "le format cible ne supporte pas l'infini"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> utilisé dans une fonction ayant des arguments fixes"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "nombre erroné d'arguments pour la fonction %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> appelé sans argument"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "nombre erroné d'arguments pour la fonction %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "le deuxième paramètre de %<va_start%> n'est pas le dernier argument nommé"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "le comportement est indéfini quand le second paramètre de %<va_start%> est déclaré avec le stockage %<register%>"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kle premier argument de %qD doit être un pointeur et le second une constante entière"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kle dernier argument de %qD n'est pas une constante entière entre 0 et 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Ktentative de libérer un objet %qD qui n'est pas sur le tas"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Ktentative de libérer un objet qui n'est pas sur le tas"
@@ -17764,37 +17879,37 @@
 msgid "conversion to incomplete type"
 msgstr "conversion vers un type incomplet"
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "ne peut convertir un vecteur de type %qT en un type %qT de taille différente"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "valeur d'agrégat utilisée là où un entier était attendu"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "valeur de pointeur utilisée là où un complexe était attendu"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "valeur d'agrégat utilisée là où un complexe était attendu"
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "ne peut convertir une valeur de type %qT vers le type vectoriel %qT qui a une taille différente"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "ne peut convertir une valeur en un vecteur"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "valeur d'agrégat utilisée là où une virgule flottante était attendue"
@@ -17950,12 +18065,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "les personnalités EH multiples sont uniquement supportées avec les assembleurs qui supportent la directive .cfi_personality"
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr "-gdwarf-6 est émis sous la version 5 avec des incompatibilités"
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "UNSPEC non délégitimisé %s (%d) trouvé à l'emplacement de la variable"
@@ -18065,12 +18180,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "écriture de %wu bits de données hors des limites de l'objet de destination, les données ont été tronquées dans %wu bits"
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kappel à %qs déclaré avec une erreur d'attribut: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kappel à %qs déclaré avec un avertissement d'attribut: %s"
@@ -18085,12 +18200,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "la taille de trame de %wd octets est plus grande que %wd octets"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "n'a pu ouvrir le fichier de vidange des insn finales %qs: %m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "n'a pu fermer le fichier de vidange des insn finales %qs: %m"
@@ -18100,42 +18215,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "la constante de grande taille en virgule fixe a été tronquée implicitement en un type en virgule fixe"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "comparaison est toujours %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de tests de non égalités non appariés est toujours 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de tests d'égalités mutuellement exclusifs est toujours 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque la constante dans la comparaison est réduite"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque des constantes sont combinées autour d'une comparaison"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vérification fold: arbre originale modifié par fold"
@@ -18674,28 +18789,28 @@
 msgid "can%'t write PCH file"
 msgstr "ne peut écrire dans le fichier PCH"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr "l'argument source %qD est le même que la destination"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr "la destination %G%qD n'a pas été changée après n'avoir copié aucun octet depuis une chaîne de longueur %E"
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "la destination %G%qD n'a pas été changée après n'avoir copié aucun octet"
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "la limite spécifiée par %G%qD (%E) est égale à la taille de la destination"
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr "la limite spécifiée par %G%qD (%E) excède la taille de la destination (%wu)"
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr "la limite spécifiée par %G%qD (%E) est égale la longueur de la destination"
 
@@ -18709,12 +18824,13 @@
 msgid "null pointer dereference"
 msgstr "déréférencement d'un pointeur null"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "déclaré ici"
@@ -19231,10 +19347,10 @@
 msgstr "%G%qD le décalage %s est hors des limites de l'objet %qD avec le type %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -19263,7 +19379,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr "%G%qD le décalage %s depuis l'objet à %qE est hors des limites du sous-objet référencé %qD avec le type %qT au décalage %wu"
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr "%G%qD l'argument source est le même que la destination"
 
@@ -19606,252 +19722,257 @@
 msgid "function cannot be instrumented"
 msgstr "la fonction ne peut pas être modifiée pour ajouter du code"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr "la table virtuelle de type %qD enfreint la règle de la définition unique"
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr "une variable avec le même nom assembleur que la table virtuelle est définie dans une autre unité de traduction"
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr "la table virtuelle de type %qD contient des informations RTTI"
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr "mais elle est remplacée par une autre qui n'en a pas dans une autre unité de traduction"
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr "RTTI ne fonctionnera pas sur ce type"
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr "la table virtuelle de type %qD enfreint la règle de la définition unique  "
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr "le type en conflit défini dans une autre unité de traduction a une table virtuelle d'une taille différente"
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr "le type en conflit défini dans une autre unité de traduction avec des informations RTTI différentes"
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr "le type en conflit défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "contient la méthode virtuelle additionnelle %qD"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr "le type en conflit défini dans une autre unité de traduction a une table virtuelle avec plus d'entrées"
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "méthode virtuelle %qD"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr "aurait dû correspondre à la méthode virtuelle %qD mais ce n'est pas le cas"
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr "le type en conflit défini dans une autre unité de traduction a une table virtuelle avec un contenu différent"
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "le type %qT enfreint la règle de la définition unique du C++"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "un type différent est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr "la première différence des définitions correspondantes est le champ %qD"
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr "la première différence des définitions correspondantes est la méthode %qD"
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr "le type %qT défini dans l'espace de noms anonyme ne peut pas correspondre au type %qT de l'autre côté de la frontière de l'unité de traduction"
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr "le type %qT défini dans l'espace de noms anonyme ne peut pas correspondre au type de même nom de l'autre côté de la frontière de l'unité de traduction"
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "le type incomplet défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr "le nom du type %qs devrait correspondre au nom du type %qs"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "le type incompatible est défini ici"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr "les types tableaux ont des limites différentes"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "désaccord dans le type de la valeur retournée"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "désaccord dans le type du pointeur implicite « this »"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "désaccord de type dans le paramètre %i"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "les types ont des nombres de paramètres différents"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "le type %qT enfreint lui-même la règle de la définition unique du C++"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "le type %qT devrait correspondre au type %qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr "un type avec des qualificatifs différents est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "un type avec des attributs différents est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr "un « enum » avec des noms de valeurs différents est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr "un « enum » avec des valeurs différentes est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr "un « enum » avec un nombre de valeurs différents est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr "un type avec une précision différente est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr "un type avec une plage signée différente est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr "il est défini comme un pointeur dans des espaces d'adresses différents dans une autre unité de traduction"
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr "il est défini comme un pointeur vers un type différent dans une autre unité de traduction"
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr "un tableau d'une taille différente est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "a une valeur de retour différente dans une autre unité de traduction"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "a des paramètres différents dans une autre unité de traduction"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr "un type défini dans une autre unité de traduction n'est pas polymorphique"
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr "un type défini dans une autre unité de traduction est polymorphique"
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr "un type avec des pointeurs de tables virtuelles différents est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr "un type avec une base différente est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "un champ avec un nom différent est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr "un champ avec le même nom mais un type différent est défini dans une autre unité de traduction"
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "les champs ont un agencement différent dans une autre unité de traduction"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -19872,7 +19993,7 @@
 msgid "the extra base is defined here"
 msgstr "la base supplémentaire est définie ici"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -19879,7 +20000,7 @@
 msgstr[0] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appel"
 msgstr[1] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appels"
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19886,7 +20007,7 @@
 msgstr[0] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appel exécuté %lli fois"
 msgstr[1] "La déclaration du type %qD comme étant final permettrait la dévirtualisation de %i appels exécutés %lli fois"
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -19893,7 +20014,7 @@
 msgstr[0] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appel"
 msgstr[1] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appels"
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -19900,7 +20021,7 @@
 msgstr[0] "La déclaration de la méthode %qD comme étant finale permettrait la dévirtualisation de %i appel"
 msgstr[1] "La déclaration de la méthode %qD comme étant finale permettrait la dévirtualisation de %i appels"
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19907,7 +20028,7 @@
 msgstr[0] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appel exécuté %lli fois"
 msgstr[1] "La déclaration du destructeur virtuel de %qD comme étant final permettrait la dévirtualisation de %i appels exécutés %lli fois"
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20181,30 +20302,38 @@
 msgstr "la cible ne supporte pas le répartiteur de version de fonction"
 
 #: multiple_target.c:91
-#, gcc-internal-format
-msgid "default target_clones attribute was not set"
+#, fuzzy, gcc-internal-format
+#| msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "l'attribut target_clones par défaut n'a pas été défini"
 
-#: multiple_target.c:324
-#, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+#: multiple_target.c:343
+#, fuzzy, gcc-internal-format
+#| msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "l'attribut target_clones isolé est ignoré"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "les clones pour l'attribut %<target_clones%> ne peuvent pas être créés"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "la fonction %q+F ne peut jamais être copiée car elle a l'attribut %<noclone%>"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr "la cible par défaut n'a pas été définie"
 
+#: multiple_target.c:379
+#, fuzzy, gcc-internal-format
+#| msgid "missing value in %<target()%> pragma or attribute"
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr "valeur manquante dans le pragma ou l'attribut %<target()%>"
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20516,12 +20645,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "argument non reconnu pour l'option %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "les arguments valables pour %qs sont: %s; vouliez vous utiliser %qs ?"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "les arguments valables pour %qs sont: %s"
@@ -21116,22 +21245,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "l'opérande de sortie %d doit utiliser la contrainte %<&%>"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] next_regno erroné pour une chaîne vide (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Boucle dans la chaîne regno (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] oldest_regno erroné (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Registre non vide dans la chaîne (%s %u %i)"
@@ -21176,7 +21305,7 @@
 msgstr "le registre de %qD est utilisé pour plusieurs variables-registre globales"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "en conflit avec %qD"
@@ -21417,157 +21546,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%qD renommé après avoir été référencé dans l'assembleur"
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "le symbole de la fonction n'est pas une fonction"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "le symbole de la variable n'est pas une variable"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "le nœud a un type inconnu"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nœud pas trouvé node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "le nœud diffère de node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "la liste de hachage des noms assembleur est corrompue"
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "le nœud n'a pas été trouvé dans le hachage des noms assembleur symtab"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "la liste doublement liée des noms assembleur est corrompue"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "le nœud a body_removed mais il est une définition"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "le nœud est analysé mais il n'est pas une définition"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "le nœud est un alias mais pas un alias implicite"
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "le nœud est un alias mais pas une définition"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "le nœud est une référence faible (weakref) mais pas un transparent_alias"
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "le nœud est un transparent_alias mais pas un alias"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "le nœud est dans la liste same_comdat_group mais il n'a aucun comdat_group"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "liste same_comdat_group au travers de groupes différents"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "le mélange de types de symboles différents dans les mêmes groupes comdat n'est pas supporté"
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "le nœud est seul dans un groupe comdat"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group n'est pas une liste circulaire"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "un symbole comdat local est référencé par %s hors de son comdat"
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "le fanion implicit_section est défini mais la section ne l'est pas"
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "La section et le groupe comdat sont tous les deux définis"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Les sections de l'alias et de la cible diffèrent"
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Les groupes comdat de l'alias et de la cible diffèrent"
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Les noms assembleurs de l'alias transparent et de la cible diffèrent"
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Alias transparents enchaînés"
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify a échoué"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Deux symboles avec le même comdat_group ne sont pas liés par la liste same_comdat_group."
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "la fonction %q+D fait partie du cycle des alias"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "la variable %q+D fait partie du cycle des alias"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "la section de l'alias %q+D doit correspondre à la section de sa cible"
@@ -22728,12 +22857,12 @@
 msgid "control reaches end of non-void function"
 msgstr "le contrôle a atteint la fin d'une fonction non « void »"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "la valeur retournée par %qD est ignorée alors qu'elle est déclarée avec l'attribut warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "la valeur retournée est ignorée pour une fonction déclarée avec l'attribut warn_unused_result"
@@ -23238,7 +23367,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "l'opération de brassage vectoriel sera développée à la pièce"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "la vectorisation n'a pas eu lieu pour une boucle simd"
@@ -23278,92 +23407,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "élément avec des effets de bord dans un CONSTRUCTOR sans effets de bord"
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "les tableaux de fonctions ne sont pas pertinents"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "le type retourné par une fonction ne peut être une fonction"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: n'attendait aucun parmi %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait la classe %qs, obtenu %qs (%s) dans %s, à %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: on n'attendait pas la classe %qs, obtenu %qs (%s) dans %s, à %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait omp_clause %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait un arbre contenant la structure %qs, obtenu %qs dans %s, à %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "vérification de l'arbre: accès à elt %d de tree_int_cst avec %d elts dans %s, à %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "vérification de l'arbre: accès à elt %d de tree_vec avec %d elts dans %s, à %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de %s avec %d opérandes dans %s, à %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de omp_clause %s avec %d opérandes dans %s, à %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD est obsolète: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD est obsolète"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE est obsolète: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE est obsolète"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "le type est obsolète: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "le type est obsolète"
@@ -23388,242 +23517,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "type variant differs by "
+msgid "type variant differs by %s"
 msgstr "la variante du type diffère sur "
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "la variante du type a un TYPE_SIZE_UNIT différent"
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT de la variante du type"
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT du type"
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "variante du type avec TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "la variante du type a un TYPE_VFIELD différent"
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "la variante du type a un TYPE_BINFO différent"
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "TYPE_BINFO de la variante du type"
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "TYPE_BINFO du type"
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "la variante du type a un TYPE_FIELDS différent"
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "le premier désaccord est le champ"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr "et le champ"
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "la variante du type a un TREE_TYPE différent"
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "TREE_TYPE de la variante du type"
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "TREE_TYPE du type"
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "le type n'est pas compatible avec sa variante"
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "La variante principale n'est pas définie"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT a un TYPE_MAIN_VARIANT différent"
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL a un TYPE_CANONICAL différent"
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL n'est pas compatible"
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "le TYPE_MODE de TYPE_CANONICAL n'est pas compatible"
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr "le TYPE_CANONICAL de la variante principale n'est pas la variante principale"
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD n'est pas FIELD_DECL ni TREE_LIST"
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO n'est pas POINTER_TYPE"
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO n'est pas REFERENCE_TYPE"
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO n'est pas TREE_BINFO"
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "le type TYPE_BINFO n'est pas TYPE_MAIN_VARIANT"
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE n'est pas un enregistrement ni une union"
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE n'est pas un enregistrement ni une union"
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE pas INTEGER_CST"
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW non NULL"
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "le champ TYPE_LANG_SLOT_1 (binfo) est non NULL"
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "La valeur de l'enum n'est pas CONST_DECL ou INTEGER_CST"
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "Le type de la valeur de l'enum n'est pas INTEGER_TYPE et n'est pas convertible en l'enum"
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "Le nom de la valeur de l'enum n'est pas IDENTIFIER_NODE"
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "le TYPE_DOMAIN du tableau n'est pas d'un type entier"
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS défini dans un type incomplet"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Arbre erroné dans la liste TYPE_FIELDS"
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P est %i tandis que TYPE_CACHED_VALUES est %p"
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES n'est pas TREE_VEC"
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "mauvaise entrée TYPE_CACHED_VALUES"
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE n'est pas NULL dans la liste TYPE_ARG_TYPES"
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Entrée erronée dans la liste TYPE_ARG_TYPES"
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "le champ TYPE_VALUES_RAW n'est pas NULL"
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "TYPE_CACHED_VALUES_P est défini alors qu'il ne le devrait pas"
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG est défini sur le mauvais code de type"
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE n'est pas la variante principale"
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type a échoué"
@@ -23649,12 +23779,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "valeur de profilage corrompue: %s le compteur de profilage (%d sur %d) est inconsistant avec le décompte du bloc de base (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "la limite de la taille de pistage des variables est dépassée avec -fvar-tracking-assignments, on réessaie sans"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "la limite de la taille de pistage des variables est dépassée"
@@ -24536,7 +24666,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "le compilateur peut supposer que l'adresse de %qD sera toujours évaluée à %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "parenthèses suggérées autour de l'affectation utilisée comme valeur dans une condition"
@@ -24788,7 +24918,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "l'index %E désigne un offset plus grand que la taille de %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "la taille du tableau est trop grande"
@@ -25397,7 +25527,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux variables différentes pour la mémoire"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "type invalide pour la variable d'itération %qE"
@@ -25412,22 +25542,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE n'est pas initialisé"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "prédicat de contrôle manquant"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "prédicat de contrôle invalide"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "expression d'incrémentation manquante"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expression d'incrémentation invalide"
@@ -25972,8 +26102,8 @@
 msgid "wrong type argument to %s"
 msgstr "argument de type erroné pour %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "débordement dans l'expression constante"
@@ -26604,7 +26734,7 @@
 msgstr "%<memset%> utilisé avec une longueur égale au nombre d'éléments sans être multiplié par la taille des éléments"
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparaison entre les types %qT et %qT"
@@ -26680,7 +26810,7 @@
 msgstr[0] "l'argument %i est passé à un paramètre avec un qualificatif restrictif alors qu'il est également passé dans l'argument %Z"
 msgstr[1] "l'argument %i est passé à un paramètre avec un qualificatif restrictif alors qu'il est également passé dans les arguments %Z"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "cette condition a des branches identiques"
@@ -26807,47 +26937,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s a une révision de silicium invalide"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops est obsolète, utilisez -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps est obsolète, utilisez -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions est obsolète, utilisez -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d n'est pas entre 0 et %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d n'est pas entre 0 et 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> n'est actuellement uniquement supporté que par GNU/Linux"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> a besoin de l'assistance d'un assembleur pour les directives CFI"
@@ -26873,31 +27003,31 @@
 msgstr "dans l'option -mcache-block-size=X, les valeurs valides pour X sont: 4, 8, 16, 32, 64, 128, 256, ou 512"
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "option -mdebug-%s inconnue"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "option -mlong-double-%s inconnue"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "l'option -msingle-float est équivalente à -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "option -msimple-fpu ignorée"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "%<-fsplit-stack%> est actuellement uniquement supporté sous PowerPC64 GNU/Linux avec glibc-2.18 ou ultérieur"
@@ -27377,8 +27507,8 @@
 msgstr "le pragma ou l'attribut %<target(\"%s=%s\")%> n'est pas valide"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
@@ -27458,8 +27588,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "valeur %qs erronée pour -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27568,11 +27698,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27582,145 +27712,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr "l'attribut %qE s'applique uniquement aux fonctions"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "__builtin_arc_aligned avec un alignement non constant"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "valeur d'alignement invalide pour __builtin_arc_aligned"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr "l'opérande intégré devrait être une valeur non signée sur 6 bits"
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "l'opérande 1 devrait être une valeur immédiate non signée sur 3 bits"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "l'opérande 2 devrait être une valeur non signée sur 3 bits (I0-I7)"
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "l'opérande 1 devrait être une valeur non signée sur 3 bits (I0-I7)"
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "l'opérande 2 devrait être une valeur non signée sur 8 bits"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "l'opérande 3 devrait être une valeur non signée sur 8 bits"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "l'opérande 4 devrait être une valeur non signée sur 8 bits (0-255)"
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "l'opérande 3 devrait être une valeur non signée sur 3 bits (I0-I7)"
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "l'opérande 2 devrait être une valeur non signée sur 3 bits (sous-registre 0-7)"
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "l'opérande 2 devrait être une valeur paire sur 3 bits (sous-registre 0,2,4,6)"
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "la fonction intégrée exige une valeur immédiate pour l'opérande %d"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "l'opérande %d devrait être une valeur immédiate non signée sur 6 bits"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "l'opérande %d devrait être une valeur immédiate non signée sur 8 bits"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "l'opérande %d devrait être une valeur immédiate non signée sur 3 bits"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr "type d'opérande immédiat de la fonction intégrée inconnu pour l'opérande %d"
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "le numéro de registre doit être une constante à la compilation. Essayez à des niveaux d'optimisation supérieurs"
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr "l'opérande de l'instruction « sleep » doit être une constante non signée sur 6 bits disponible lors de la compilation"
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "les adresses des insn ne sont pas définies après shorten_branches"
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "les adresses des insn ne sont pas libérées"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "l'attribut %qE est uniquement valable pour l'architecture ARCv2"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "l'argument de l'attribut %qE est manquant"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "l'attribut %qE n'accepte qu'une constante entière comme argument"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "l'attribut %qE est uniquement valable pour l'architecture ARC EM"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "l'attribut %qE ne s'applique qu'à des types"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "l'argument de l'attribut %qE est ignoré"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "l'attribut %qE ne s'applique qu'aux variables"
@@ -27746,153 +27866,153 @@
 msgstr "Vous devez activer les instructions crypto (par ex. inclure -mfloat-abi=softfp -mfpu=crypto-neon…) pour utiliser ces intrinsèques."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "sélecteur doit être un immédiat"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "la plage du sélecteur doit être entre 0 et 7"
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "la plage du sélecteur doit être entre 0 et 3"
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "la plage du sélecteur doit être entre 0 et 1"
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "le masque doit être un immédiat"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "la plage du masque doit être entre 0 et 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_rori_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_ror_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_si64 dans le code"
@@ -28697,12 +28817,12 @@
 msgid "invalid IACC argument"
 msgstr "argument IACC invalide"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs attend un argument constant"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "argument constant hors limite pour %qs"
@@ -28802,567 +28922,552 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "ne peut définir la position dans le fichier PCH: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argument %qs erroné pour l'option %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "les plages de tailles de l'option %qs devraient être croissantes"
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "nom de stratégie %qs erroné spécifié pour l'option %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "le nom de stratégie %qs spécifié pour l'option %qs n'est pas supporté pour du code 32 bits"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignement %qs inconnu spécifié pour l'option %qs"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "la valeur maximale pour la dernière plage de taille de l'option %qs devrait être -1"
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "trop de plages de tailles spécifiées dans l'option %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "paramètre inconnu dans l'option -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "la psABI du MCU Intel n'est pas supportée dans le mode %s"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> est déprécié; utilisez plutôt %<-mtune=k8%> ou %<-mtune=generic%> selon ce qui est approprié"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> est déprécié; utilisez plutôt %<target(\"tune=k8\")%> ou %<target(\"tune=generic\")%> selon ce qui est approprié"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte pas supporté pour du code 32 bits"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "le mode d'adresse %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mabi=ms pas supporté avec l'ABI X32"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode x32"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "le modèle de code %s ne supporte pas le mode PIC"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel n'est pas supporté dans cette configuration"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "mode %i bits pas compilé"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "le processeur sélectionné ne supporte pas le jeu d'instructions x86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "le MPX de Intel ne supporte pas x32"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "valeur erronée (%qs) pour l'option %<-march=%>"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "valeur erronée (%qs) pour l'attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "valeur erronée (%qs) pour l'option %<-mtune=%>"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "valeur erronée (%qs) pour l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm est ignoré avec la psABI du MCU Intel"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d n'est pas entre 0 et %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary n'est pas supporté pour cette cible"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d n'est pas entre %d et %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d n'est pas entre %d et 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount n'est pas compatible avec cette cible"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount n'est pas implémenté pour -fPIC"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, l'arithmétique 387 est utilisée"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, l'arithmétique SSE est utilisée"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "le sondage de la pile requiert %<-maccumulate-outgoing-args%> pour être correcte"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "le sondage de la pile requiert %<target(\"accumulate-outgoing-args\")%> pour être correcte"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "le registre ebp fixé requiert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "le registre ebp fixé requiert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry n'est pas supporté en 32 bits en combinaison avec -fpic"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry n'est pas compatible avec SEH (gestionnaire d'exceptions structuré)"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues n'est actuellement pas supporté avec SEH"
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "option inconnue pour -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs n'est pas un nombre valable dans -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs n'est pas un décalage valable dans -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs n'est pas un registre de base valable dans -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "%<-fcf-protection=branch%> requiert le support CET de Intel. Utilisez l'option -mcet ou -mibt pour activer CET"
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "%<-fcf-protection=return%> requiert le support CET de Intel. Utilisez l'option -mcet ou -mshstk pour activer CET"
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "%<-fcf-protection=full%> requiert le support CET de Intel. Utilisez -mcet ou les deux options -mibt et -mshstk pour activer CET"
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) est inconnu"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") a déjà été spécifié"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "les attributs d'interruption et nus sont incompatibles"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Seul le format de débogage DWARF est supporté pour les routines de service d'interruptions."
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> et %<-fcheck-pointer-bounds%> sont incompatibles"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> et %<-mcmodel=large%> sont incompatibles"
 
 # Le dernier %s est le texte non traduit « exception » ou « interrupt ».
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service de type « %s »"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l'attribut no_caller_saved_registers"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qD avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qT avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 ne supporte pas l'attribut ms_abi"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue n'est pas compatible avec les fonctions imbriquées"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "l'argument vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "le retour vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "l'argument vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "le retour vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "l'argument vectoriel SSE sans activer SSE modifie l'ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "le retour vectoriel SSE sans activer SSE change l'ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "l'argument vectoriel MMX sans activer MMX modifie l'ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "le retour vectoriel MMX sans activer MMX change l'ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un tableau flexible comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "l'ABI pour passer une union avec un double long a changé dans GCC 4.4"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un nombre décimal complexe comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "retour d'un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argument dans un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "retour d'un registre x87 alors que x87 est désactivé"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "appel de %qD avec la convention d'appel SSE sans avoir activé SSE/SSE2"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "ceci est un bogue de GCC qui peut être contourné en ajoutant l'attribut utilisé à la fonction appelée"
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "L'ABI pour passer des paramètres avec un alignement de %d octets a changé dans GCC 4.6"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues est incompatible avec %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "l'attribut ms_hook_prologue est incompatible avec -mfentry pour 32 bits"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "DRAP (Dynamic Realign Argument Pointer) n'est pas supporté dans une routine de service d'interruption. Ceci peut être contourné en évitant les fonctions avec un retour agrégé."
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack ne supporte pas fastcall avec des fonctions imbriquées"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack ne supporte pas deux paramètres registres pour une fonction imbriquée"
@@ -29369,311 +29474,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack ne supporte pas trois paramètres registres"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "modificateur « V » sur un registre non entier"
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "taille non supportée pour un registre entier"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "les registres étendus n'ont pas de moitié haute"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "taille d'opérande non supportée pour un registre étendu"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "opérande non entier utilise avec le code d'opérande « z »"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "une routine de service d'interruption ne peut pas être appelée directement"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr "l'ABI de passage de paramètres pour la classe vide %qT change avec -fabi-version=12 (GCC 8)"
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Pas de répartiteur trouvé pour les attributs de version"
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Pas de répartiteur trouvé pour %s"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Pas de répartiteur trouvé pour les attributs de version : %s"
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Les versions de fonctions ne peuvent pas être marquées avec gnu_inline, des corps de fonctions doivent être générés"
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "les versions multiples requièrent ifunc qui n'est pas supporté sur cette cible"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Le paramètre à une fonction interne doit être une chaîne sous forme constante ou littérale"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Le paramètre à la fonction interne n'est pas valable: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 2 bits"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "le cinquième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "le troisième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 3 bits"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "l'avant dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "le troisième argument doit être une constante de comparaison"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "mode de comparaison incorrect"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "opérande d'arrondi incorrect"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 32 bits"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "le sélecteur doit être une constante entière dans la plage 0..%wi"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE a besoin d'une option isa inconnue"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE a besoin de l'option isa %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "le dernier argument doit être une valeur immédiate"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "le dernier argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "le quatrième argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "opérande d'indice incorrect"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "l'argument de xabort doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "les attributs ms_abi et sysv_abi sont incompatibles"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante chaîne de caractères"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "la routine de service d'interruption devrait avoir un « unsigned %sint » comme deuxième argument"
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "la routine de service d'interruption ne peut pas avoir une valeur de retour non void"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "les alternatives ne sont pas autorisées dans la sortie du fanion asm"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "sortie du fanion asm %qs inconnue"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "type invalide pour la sortie du fanion asm"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modèle mémoire spécifique à l'architecture inconnu"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE n'est pas utilisé avec le modèle mémoire ACQUIRE ou un autre plus contraignant"
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE n'est pas utilisé avec le modèle mémoire RELEASE ou un autre plus contraignant"
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d non supportée"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "type de retour %qT non supporté pour simd"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "type d'argument %qT non supporté pour simd"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Le contrôleur de pointeurs requiert le support MPX sur cette cible. Utilisez les options -mmpx pour activer MPX."
@@ -29894,7 +29999,7 @@
 msgstr "interrupt_thread est disponible uniquement sur fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "l'expression limitant la pile n'est pas supportée"
@@ -30426,7 +30531,37 @@
 msgid "constant argument out of range for %s"
 msgstr "argument constant hors limite pour %s"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "cette fonction interne est seulement disponible sur le fr450"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "cette fonction interne est seulement disponible sur le fr450"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin is not supported for this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "cette fonction interne n'est pas supportée pour cette cible"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "don't support string extension instructions"
+msgid "don't support performance extension instructions"
+msgstr "ne pas supporter les instructions de l'extension de chaînes"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate performance extension version 2 instructions."
+msgid "don't support performance extension version 2 instructions"
+msgstr "Générer des instructions de l'extension de performance version 2."
+
+#: config/nds32/nds32-intrinsic.c:760
 #, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr "ne pas supporter les instructions de l'extension de chaînes"
@@ -30447,43 +30582,61 @@
 msgstr "attributs d'interruptions multiples pour la fonction %qD"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "une fonction imbriquée n'est pas supportée pour les registres réduits"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "l'index du registre intrinsèque est hors limite"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
+#, fuzzy, gcc-internal-format
+#| msgid "intrinsic register index is out of range"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "l'index du registre intrinsèque est hors limite"
+
+#: config/nds32/nds32.c:3508
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "valeur d'identifiant invalide pour l'attribut d'interruption/exception"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "valeur d'identifiant invalide pour l'attribut de réinitialisation"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "fonction nmi invalide pour l'attribut de réinitialisation"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "fonction « warm » invalide pour l'attribut de réinitialisation"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
 #, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
+#, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "le code indépendant de la position n'est pas supporté"
 
@@ -30692,37 +30845,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr "l'initialisation statique de la variable %q+D dans la mémoire %<.shared%> n'est pas supportée"
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr "ne peut produire des pointeurs non alignés dans l'assembleur ptx"
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX ne supporte pas les déclarations faibles (uniquement les définitions faibles)"
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "l'attribut %qE requiert un type de retour « void »"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "l'attribut %qE n'est pas permis avec une classe de stockage auto"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "utilisation de vector_length (%d), %d est ignoré"
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "utilisation de vector_length (%d), le paramètre à l'exécution est ignoré"
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "utilisation de num_workers (%d), %d est ignoré"
@@ -30816,12 +30969,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "rebut à la fin de #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
@@ -30871,7 +31024,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert accepte uniquement 3 arguments"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "le passage de l'argument %d de %qE abandonne les qualificatifs du type cible du pointeur"
@@ -31173,7 +31326,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "l'agencement des agrégats contenant des vecteurs alignés sur %d octets a changé avec GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC retourné par référence: extension ABI non standard sans aucune garantie de compatibilité"
@@ -31183,7 +31336,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "la valeur ne peut être retournée dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez -maltivec pour les autoriser"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats avec un alignement sur %d octets a changé avec GCC 5"
@@ -31193,12 +31346,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "l'argument ne peut pas être passé dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez -maltivec pour les autoriser"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats de flottants homogènes a changé avec GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC passé par référence: extension ABI non standard sans aucune garantie de compatibilité"
@@ -31208,28 +31361,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "erreur interne: fonction interne %s déjà traitée"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "l'argument 1 doit être une valeur de champ sur 8 bits"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "l'argument 1 doit être un littéral signé de 5 bits"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 7 bits"
@@ -31249,12 +31402,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "la fonction interne %s est uniquement valable en mode 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "l'argument %d doit être un littéral non signé"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "l'argument %d est un littéral non signé qui est hors limite"
@@ -31276,53 +31429,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "le hwcap %s est un argument invalide pour la fonction interne %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 2 bits"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 1 bit"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "l'argument 1 doit être 0 ou 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 1 bit"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "l'argument 1 doit être 0 ou 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "l'argument 3 doit être dans la plage 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "l'argument de %qs doit être un littéral non signé de 2 bits"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "surcharge non résolue pour la fonction Altivec interne %qF"
@@ -31447,7 +31600,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "erreur interne: pour la fonction interne %s, l'argument %d a le type %s inattendu"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "trame de pile trop grande"
@@ -31457,12 +31610,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack utilise le registre r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Une trame de pile plus grande que 2G n'est pas supportée par -fsplit-stack"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
@@ -31472,22 +31625,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option -mno-pointers-to-nested-functions."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
@@ -31497,7 +31650,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
@@ -31961,22 +32114,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "processeur %qs inconnu pour -mtune"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr "-mdiv requiert -march pour incorporer l'extension %<M%>"
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr "l'ABI demandée requiert -march pour incorporer l'extension %qc"
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr "l'ABI requiert -march=rv%d"
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d doit être entre %d et %d"
@@ -32041,30 +32194,36 @@
 "Nom de processeur non supporté retourné par le noyau pour -mcpu=native: %s\n"
 "Veuillez utiliser un nom de processeur explicite.  Les noms de processeurs valides sont: %s"
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "la fonction interne %qs n'accepte que 2 arguments"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "la fonction interne %qs n'accepte que 3 arguments"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "la fonction interne %qs n'accepte qu'un argument"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, fuzzy, gcc-internal-format
+#| msgid "builtin function %qs requires the %qs option"
+msgid "builtin %qs requires builtin %qs"
+msgstr "la fonction interne %qs requiert l'option %qs"
+
+#: config/rs6000/rs6000-c.c:7058
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "la fonction interne %qs n'est pas supportée dans cette configuration du compilateur"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinaison invalide de paramètres pour l'intrinsèque Altivec %qs"
@@ -32188,169 +32347,169 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs est déprécié et recommandé dans aucune circonstance"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "la valeur ne peut être retournée dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez %qs pour les autoriser"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "l'argument ne peut pas être passé dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez %qs pour les autoriser"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "erreur interne: fonction interne %qs déjà traitée"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "l'argument 1 de %qs doit être une constante"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "l'argument 1 de %qs est hors limite"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "la fonction interne %qs est uniquement valable en mode 64 bits"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "la fonction interne %qs n'accepte qu'une chaîne comme argument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "le processeur %qs est un argument invalide pour la fonction interne %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs est un argument invalide pour la fonction interne %qs"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "la fonction interne %qs requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "le deuxième argument de %qs doit être 0..12"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "le troisième argument de %qs doit être 0..12"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "l'argument 1 de %s doit être une constante"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "la fonction interne %qs est uniquement valable pour le processeur cell"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "la fonction interne %qs requiert l'option %qs"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "la fonction interne %qs requiert les options %qs et %qs"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "la fonction interne %qs requiert l'ISA 3.0 en virgule flottante IEEE 128 bits"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "la fonction interne %qs requiert les options %qs (ou plus récente) et %qs ou %qs"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "la fonction interne %qs n'est pas supportée avec les options actuelles"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "erreur interne: la fonction interne %qs a un type de retour %qs inattendu"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "erreur interne: pour la fonction interne %qs, l'argument %d a le type %qs inattendu"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs utilise le registre r29"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option %qs"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans %qs"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "processeur %qs invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> désactive %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "l'attribut target_clones requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
@@ -33144,7 +33303,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "la valeur void n'a pas été ignorée comme elle aurait dû l'être"
@@ -33396,7 +33555,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "la déclaration de %qD masque un paramètre"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la déclaration de %qD masque une déclaration globale"
@@ -33406,7 +33565,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "la déclaration de %qD masque la déclaration locale précédente"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "la déclaration masquée est ici"
@@ -33466,7 +33625,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "chaque identificateur non déclaré est rapporté une seule fois pour chaque fonction dans laquelle il apparaît"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "l'étiquette %qE est référencée à l'extérieur de toute fonction"
@@ -33496,7 +33655,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "déclaration de l'étiquette %qE en double"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "étiquette %qD dupliquée"
@@ -33614,7 +33773,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> n'est pas permis ailleurs que dans la portée du prototype d'une fonction"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
@@ -33869,7 +34028,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre sans nom"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "classe de stockage spécifiée pour un typename"
@@ -34028,7 +34187,7 @@
 msgid "function definition has qualified void return type"
 msgstr "la définition de la fonction a un type de retour « void » qualifié"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "les qualificatifs de type sont ignorés sur le type retourné par la fonction"
@@ -34155,7 +34314,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un membre d'une structure ou d'une union ne peut pas avoir de type modifié par une variable"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variable ou champ %qE déclaré « void »"
@@ -34336,7 +34495,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "définir le type dans l'expression %qs est invalide en C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la déclaration ne déclare rien du tout"
@@ -34386,7 +34545,7 @@
 msgid "struct has no members"
 msgstr "la structure n'a aucun membre"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "tableau flexible comme membre de l'union"
@@ -34422,7 +34581,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "redéclaration de %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "le mode spécifié est trop petit pour les valeurs de l'énumération"
@@ -34452,7 +34611,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "le C ISO restreint les valeurs de l'énumérateur à la plage d'un %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "la fonction à mettre en ligne %qD a reçu l'attribut « noinline »"
@@ -34482,7 +34641,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour %qD"
@@ -34597,12 +34756,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "le paramètre %qD est défini mais pas utilisé"
@@ -34665,7 +34824,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans le spécificateur de déclaration"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> est trop long pour GCC"
@@ -34810,37 +34969,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr "le C ISO interdit les types entiers complexes"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "le combinateur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "l'initialiseur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "décalage vers la gauche d'une valeur négative"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "le compteur de décalages vers la gauche est négatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "le compteur de décalages vers la droite est négatif"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "compteur de décalages vers la gauche >= à la largeur du type"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "compteur de décalages vers la droite >= à la largeur du type"
@@ -34870,7 +35029,7 @@
 msgid "to match this %qs"
 msgstr "pour correspondre à ce %qs"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -34911,7 +35070,7 @@
 msgstr "nom de type %qE inconnu"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "spécificateurs de déclaration attendus"
@@ -34926,7 +35085,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identificateur ou %<(%> attendu"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "les attributs de préfixes sont ignorés pour les méthodes"
@@ -34941,8 +35100,8 @@
 msgid "unexpected attribute"
 msgstr "attribut inattendu"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "l'attribut %<fallthrough%> n'est pas suivi par %<;%>"
@@ -34980,7 +35139,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> peut uniquement être utilisé avec un seul déclarateur"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> ou %<;%> attendu"
@@ -35008,7 +35167,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "le C90 ISO ne supporte pas %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "chaîne littérale attendue"
@@ -35072,13 +35231,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identificateur attendu"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "virgule à la fin de la liste d'énumerateurs"
@@ -35208,7 +35367,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> attendu avant %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sans %<if%> précédent"
@@ -35242,22 +35401,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "instruction attendue"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<else%>"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "des accolades explicites sont suggérées pour éviter toute ambiguïté sur le %<else%>"
@@ -35277,12 +35436,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable d'itération invalide dans l'énumération rapide"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC ivdep%>"
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC unroll%>"
@@ -35309,12 +35468,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la division %<sizeof (%T) / sizeof (%T)%> ne calcule pas le nombre d'éléments dans le tableau"
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "le premier opérande %<sizeof%> a été déclaré ici"
@@ -35590,7 +35749,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "opérandes de %<__builtin_complex%> de types différents"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_shuffle%>"
@@ -35650,76 +35809,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "aucun type ni classe de stockage ne peut être spécifié ici,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribut de propriété inconnu"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "l'attribut %<setter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "le nom du « setter » doit être terminé par %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "l'attribut %<getter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiert une expression d'affectation qui est évaluée en une constante entière non négative plus petite que %u"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> ne peut être utilisé que dans des instructions composées"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> doit être dans la portée au niveau du fichier"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "instruction « for », « while » ou « do » attendue"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> doit être le premier"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "trop de clauses %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "expression entière attendue avant « ) »"
@@ -35734,53 +35893,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD n'est pas une variable"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD n'est pas une variable pointeur"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'argument « collapse » a besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> ou %<present%> attendu"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> ou %<shared%> attendu"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> ou %<exit%> attendu"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> attendu"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "trop de %<if%> avec le modificateur %qs"
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "trop de clauses %<if%>"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "trop de clauses %<if%> sans modificateur"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si une clause %<if%> a un modificateur, alors toutes les clauses %<if%> doivent utiliser un modificateur"
@@ -35802,82 +35961,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "la valeur de %<num_tasks%> doit être positive"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "la valeur de %<grainsize%> doit être positive"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "la valeur de %<priority%> doit être positive ou nulle"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> attendu"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> attendu"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "l'expression %qs doit être un entier"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "la valeur de %qs doit être positive"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "trop d'arguments pour %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argument inattendu"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "l'argument %<tile%> a besoin d'une constante entière positive"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "les arguments ordonnés ont besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> ou identificateur attendu"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "les deux modificateurs %<monotonic%> et %<nonmonotonic%> sont spécifiés"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<runtime%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "la taille du fragment doit être positive"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "type d'ordonnancement invalide"
@@ -35887,12 +36046,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "la valeur de %<num_teams%> doit être positive"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "la valeur de %<thread_limit%> doit être positive"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "l'expression d'alignement %<aligned%> doit être une expression entière constante positive"
@@ -35912,17 +36071,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'expression %<simdlen%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "type de « depend » invalide"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "type de « map » invalide"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "type de « dist_schedule » invalide"
@@ -35932,67 +36091,67 @@
 msgid "invalid proc_bind kind"
 msgstr "type de « proc_bind » invalide"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "clause %<#pragma acc%> attendue"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs n'est pas valide pour %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs doit être la première clause de %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "clause %<#pragma omp%> attendue"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "pas de clause valide spécifiée dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "section de tableau dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD doit être une variable globale dans %<#pragma acc declare link%>"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "clause OpenACC invalide au niveau global du fichier"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<extern%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<globale%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variable %qD utilisée plus d'une fois avec %<#pragma acc declare%>"
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> attendu après %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> n'a pas clause de mouvement de données"
@@ -36007,7 +36166,7 @@
 msgid "expected function name"
 msgstr "nom de fonction attendu"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD ne fait pas référence à une fonction"
@@ -36017,42 +36176,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une déclaration ou d'une définition de fonction"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> déjà appliqué à %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> doit être appliqué avant l'utilisation"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> doit être appliqué avant la définition"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%>"
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forme invalide de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pour la mémoire"
@@ -36062,22 +36221,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> ou fin de ligne attendue"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "le paramètre de la clause %<ordered%> est plus petit que %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la clause %<linear%> ne peut pas être spécifiée avec la clause %<ordered%> comportant un paramètre"
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "instruction « for » attendue"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "déclaration ou initialisation d'itération attendue"
@@ -36087,72 +36246,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "pas assez de boucles parfaitement imbriquées"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "boucles coalescées imparfaitement imbriquées"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la clause %<ordered%> avec un paramètre ne devrait pas être spécifiée sur la construction %qs"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> avec une clause %<depend%> peut uniquement être utilisé dans des instructions composées"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> attendu après %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> attendu"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur un clause %<map%>"
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> doit contenir au moins une clause %<from%> ou %<to%>"
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> avec un type avec correspondance autre que %<to%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> avec un type « map » autre que %<from%>, %<release%> ou %<delete%> sur une clause %<map%>"
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
@@ -36172,32 +36331,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi par une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> avec des clauses entre %<#pragma omp declare target%> sans clauses et %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %<to%>"
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> attendu"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> attendu"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sans %<#pragma omp declare target%> correspondant"
@@ -36252,47 +36411,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<&omp_priv%>"
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> ou %<reduction%> ou %<target%> attendu"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE est déclaré %<threadprivate%> après la première utilisation"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automatique %qE ne peut être %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE a un type incomplet"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas à l'intérieur d'un %<__transaction_atomic%> extérieur"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  ou une fonction %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> pas à l'intérieur de %<__transaction_atomic%>"
@@ -36307,7 +36466,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD a un type incomplet %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "utilisation invalide de l'expression void"
@@ -36428,7 +36587,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "la valeur de l'indice n'est ni un tableau ni un pointeur ni un vecteur"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "l'indice du tableau n'est pas un entier"
@@ -36453,7 +36612,7 @@
 msgid "enum constant defined here"
 msgstr "constante enum définie ici"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sur le tableau %qE en paramètre de fonction retournera la taille de %qT"
@@ -36556,17 +36715,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "conversion implicite de %qT en %qT lors du passage de l'argument à la fonction"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "une comparaison avec une chaîne littérale produit un résultat non spécifié"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "comparaison entre un pointeur et la constante caractère zéro"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "vouliez-vous déréférencer le pointeur ?"
@@ -36591,7 +36750,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "arithmétique sur un pointeur vers un type incomplet"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "arithmétique sur un pointeur vers un agrégat vide"
@@ -36824,7 +36983,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "transtypage d'un appel de fonction de type %qT vers le type %qT ne correspondant pas"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "transtypage vers un pointeur depuis un entier de taille différente"
@@ -36976,7 +37135,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'initialisation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "le type de retour pourrait être un candidat pour un attribut de format"
@@ -37043,7 +37202,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "utilisation invalide d'un tableau n'étant pas une l-valeur"
@@ -37113,12 +37272,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "le C traditionnel rejette l'initialisation automatique d'agrégats"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisation d'un membre de tableau flexible"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "tableau de caractères initialisé à l'aide d'une chaîne de caractères larges"
@@ -37164,7 +37323,7 @@
 msgid "invalid initializer"
 msgstr "initialisation invalide"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
@@ -37179,7 +37338,7 @@
 msgid "braces around scalar initializer"
 msgstr "accolades autour d'une initialisation d'un scalaire"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisation d'un membre de tableau flexible dans un contexte imbriqué"
@@ -37309,7 +37468,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "le C ISO interdit %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la fonction est déclarée avec %<noreturn%> mais elle utilise l'instruction %<return%>"
@@ -37349,7 +37508,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "l'étiquette du « case » doit être une expression constante entière"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "étiquette « case » en dehors de tout « switch »"
@@ -37359,17 +37518,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "étiquette %<default%> en dehors de tout « switch »"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "mot-clé « break » à l'extérieur de toute boucle ou « switch »"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "mot-clé « continue » à l'extérieur de toute boucle"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "mot-clé « break » utilisé dans une boucle OpenMP"
@@ -37394,22 +37553,22 @@
 msgid "expression statement has incomplete type"
 msgstr "l'instruction de l'expression a un type incomplet"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "comparaison de vecteurs avec des types d'éléments différents"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "comparaison de vecteurs avec des nombres d'éléments différents"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "n'a pu trouver un type entier de la même taille que %qT"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "comparer des nombres flottants à l'aide de == ou != n'est pas sûr"
@@ -37460,7 +37619,7 @@
 msgstr "comparaison ordonnée d'un pointeur avec un pointeur nul"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparaison ordonnée d'un pointeur avec un zéro entier"
@@ -37490,12 +37649,12 @@
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « vector » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
@@ -37505,25 +37664,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE dans la clause %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "champ de bits %qE dans la clause %qs"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE est un membre d'une union"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE n'est pas une variable dans la clause %qs"
@@ -37534,70 +37693,70 @@
 msgstr "%<_Atomic%> %qD dans la clause %qs"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD est une variable « threadprivate » dans la clause %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "la borne inférieure %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longueur %qE de la section du tableau n'a pas un type entier"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "section de tableau ayant une longueur nulle dans la clause %qs"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type tableau dont la limite est inconnue"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "limite inférieure négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longueur négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "limite inférieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longueur %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "limite supérieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type pointeur"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la section du tableau n'est pas contigüe dans la clause %qs"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE n'a pas un type pointeur ou tableau"
@@ -37617,7 +37776,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE a un type invalide pour %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
@@ -37627,17 +37786,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "type d'élément de longueur variable dans la table de la clause %<reduction%>"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la clause %<nowait%> ne doit pas être utilisée avec %<copyprivate%>"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE doit être %<threadprivate%> pour %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "le modificateur ne devrait pas être spécifié dans la clause %<linear%> sur des constructions %<simd%> ou %<for%>"
@@ -37652,18 +37811,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<linear%>"
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "le pas %qE de la clause %<linear%> n'est ni une constante ni un paramètre"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de réduction"
@@ -37675,32 +37834,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de données"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD apparaît à la fois dans les clauses « data » et « map »"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<aligned%>"
@@ -37720,55 +37879,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<aligned%>"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<depend%>"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "la section du tableau n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de mouvement"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<map%>"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD n'a pas un type pour lequel la correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE n'est ni une variable ni un nom de fonction dans la clause %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE apparaît plus d'une fois dans la même directive %<declare target%>"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE n'est pas un argument dans la clause %<uniform%>"
@@ -37778,33 +37937,33 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "modificateur %<nonmonotonic%> spécifié pour le type d'ordonnancement %qs"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la clause %<inbranch%> est incompatible avec %<notinbranch%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE est prédéterminé %qs pour %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "la valeur de la clause %<simdlen%> est plus grande que la valeur de la clause %<safelen%>"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "modificateur d'ordonnancement %<nonmonotonic%> spécifié en même temps que la clause %<ordered%>"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "le pas de la clause %<linear%> est un paramètre %qD pas spécifié dans la clause %<uniform%>"
@@ -37933,7 +38092,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  pas de conversion connue pour convertir l'argument %d depuis %qH vers %qI"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38011,24 +38170,24 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  un constructeur hérité n'est pas un candidat pour une initialisation depuis une expression du même type ou d'un type dérivé"
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "la conversion de %qH vers %qI est ambiguë"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "initialiser %qH avec %qI dans une expression constante convertie n'est pas liée directement"
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversion de %qH vers %qI dans une expression constante convertie"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "pas de fonction correspondant à l'appel %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%D(%A)%>"
@@ -38035,606 +38194,606 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "le pointeur vers la fonction membre %qE ne peut être appelé sans un objet; utilisez %<.*%> ou %<->*%>"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "pas de concordance pour l'appel à %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "l'appel à %<(%T) (%A)%> est ambigu"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "surcharge ambiguë pour "
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr "pas de concordance pour "
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (les types des opérandes sont %qT, %qT et %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (les types des opérandes sont %qT et %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (le type de l'opérande est %qT)"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "%<operator?:%> ternaire"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<operator?:%> ternaire dans %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> dans %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> dans %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs dans %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> dans %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> dans %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "le C++ ISO interdit l'omission du terme au milieu de l'expression ?:"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr "le type scalaire inféré %qT n'est pas un type entier ou en virgule flottante de la même taille que %qT"
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "la conversion du scalaire %qH vers le vecteur %qI implique une troncature"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types vectoriels incompatibles dans l'expression conditionnelle: %qT, %qT et %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "le deuxième opérande de l'opérateur conditionnel a le type %<void%> mais le troisième opérande n'est ni une expression qui génère une exception ni le type %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "le troisième opérande de l'opérateur conditionnel a le type %<void%> mais le deuxième opérande n'est ni une expression qui génère une exception ni le type %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "les opérandes de ?: ont les types différents %qT et %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  et chaque type peut être converti en l'autre"
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "conversion implicite depuis %qH vers %qI pour correspondre à d'autres résultats de la condition"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "non concordance de type énuméré dans l'expression conditionnelle: %qT vs %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "type énuméré et non énuméré dans l'expression conditionnelle"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs, on essaie avec l'opérateur préfixé à la place"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparaison entre %q#T et %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr "le nettoyage pendant une exception pour cet opérateur « new » avec placement sélectionne l'opérateur « delete » sans placement"
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement) en C++14 (ou avec -fsized-deallocation)"
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement)"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "pas de fonction de désallocation correspondante pour %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "pas de %<operator %s%> adapté pour %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D est privé dans ce contexte"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "déclaré privé ici"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D est protégé dans ce contexte"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "déclaré protégé ici"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D est inaccessible dans ce contexte"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "passage de NULL pour l'argument non pointeur %P de %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "conversion vers un type non pointeur %qT à partir de NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "conversion de %<false%> vers un type pointeur pour l'argument %P de %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "conversion de %<false%> vers le type pointeur %qT"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "trop d'accolades autour de l'initialiseur pour %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "la conversion vers %qH depuis %qI requiert une initialisation directe"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "la conversion définie par l'utilisateur de %qH vers %qI est invalide"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initialisation de l'argument %P de %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversion invalide de %qH vers %qI"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversion de la liste d'initialisation vers %qT utiliserait le constructeur explicite %qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "en C++11 et au delà, un constructeur par défaut peut être explicite"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "impossible de lier la référence d'une r-valeur de type %qH à une l-valeur de type %qI"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une r-valeur de type %qI"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "lier la référence du type %qH à %qI abandonne les qualificatifs"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "ne peut lier le champ de bits %qE avec %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ne peut lier le champs empaqueté %qE avec %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ne peut lier la r-valeur %qE avec %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversion implicite de %qH en %qI lors du passage de l'argument à la fonction"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr "l'énumération %qT dans une portée limitée est passée au travers de ... en tant que %qT avant -fabi-version=6 et en tant que %qT après"
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "le passage d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "impossible de recevoir le type référencé %qT au travers de %<...%>"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la réception d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "évaluation récursive de l'argument par défaut pour %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "l'appel à %qD utilise l'argument par défaut du paramètre %P qui n'est pas encore défini"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "l'argument de l'appel de fonction pourrait être un candidat pour un attribut de format"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "utilisation d'une fonction ayant plusieurs versions sans version par défaut"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "le passage de %qT comme argument %<this%> abandonne les qualificatifs"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dans l'appel de %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT n'est pas une base accessible de %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT est déduit comme étant %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (vous pouvez désactiver ceci avec -fno-deduce-init-list)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "passage des arguments à l'élision du constructeur hérité %qD"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "écriture %qD vers un objet de type %#qT sans affectation par copie triviale"
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "écriture %qD vers un objet de type non trivial %#qT%s"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "écriture %qD vers un objet de type %#qT avec le membre %qs de %qD"
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "écriture %qD vers un objet de type %#qT contenant un pointer vers le membre de donnée%s"
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; utilisez plutôt une affectation ou une initialisation par valeur"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; utilisez plutôt une affectation"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; utilisez plutôt une initialisation par valeur"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD effacement d'un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD effacement d'un objet du type non trivial %#qT%s"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD effacement d'un objet de type %#qT contenant un pointeur vers un membre%s"
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; utilisez plutôt une affectation par copie ou une initialisation par copie"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; utilisez plutôt une affectation par copie"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; utilisez plutôt une initialisation par copie"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD écriture dans un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD écriture dans un objet du type non trivialement copiable %#qT%s"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD écriture dans un objet avec un constructeur par copie supprimé"
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD copie un objet du type non trivial %#qT depuis un tableau de %#qT"
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD copie un objet de type %#qT avec le membre %qs de %qD depuis un tableau de %#qT; utilisez plutôt une affectation ou une initialisation par copie"
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octets inchangés"
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octet inchangé"
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet du type non trivialement copiable %#qT; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet de type %#qT avec un constructeur par copie supprimé; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD déplacement d'un objet de type %#qT avec un destructeur supprimé"
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD déplacement d'un objet du type non trivial %#qT et de taille %E dans une région de taille %E"
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT déclaré ici"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "le constructeur délègue à lui-même"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "pour un transtypage de style « fonction », enlevez le %<::%D%> redondant"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de %<%s(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%s(%A)%>"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "appel à %q#D qui est pur virtuel depuis un initialisateur qui n'est pas un membre statique"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le constructeur"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le destructeur"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "impossible d'appeler la fonction membre %qD sans objet"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "le passage de %qT choisi %qT au lieu de %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "choix de %qD à la place de %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 msgid "  for conversion from %qH to %qI"
 msgstr "  pour la conversion de %qH vers %qI"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  parce que la séquence de conversion pour l'argument est meilleure"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "désaccord dans l'argument par défaut lors de la résolution de la surcharge"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidat 1: %q#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidat 2: %q#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "le C++ ISO indique que ceux-ci sont ambigus même si la plus mauvaise conversion pour le premier est meilleures que la plus mauvaise conversion pour le second:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 msgid "could not convert %qE from %qH to %qI"
 msgstr "impossible de convertir %qE de %qH vers %qI"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "une limite temporaire sur %qD existe uniquement jusqu'à la sortie du constructeur"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "initialisation invalide pour une référence non constante du type %qH à partir d'une r-valeur de type %qI"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "initialisation invalide pour une référence du type %qH à partir d'une expression de type %qI"
 
@@ -38674,8 +38833,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D ne peut pas être surchargé par %q#D"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "déclaration précédente de %q#D"
@@ -38716,7 +38875,7 @@
 msgstr "%qD hérite de l'étiquette de l'ABI %E que %qT (utilisé dans son type de retour) a déjà"
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT déclaré ici"
@@ -38796,7 +38955,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données publiques non statiques"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "cette flexibilité est dépréciée et sera supprimée"
@@ -39073,7 +39232,7 @@
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
@@ -39144,7 +39303,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un pointeur vers un membre peut seulement être formé avec %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "pas assez d'informations sur le type"
@@ -39240,333 +39399,333 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD n'est pas utilisable comme une fonction %<constexpr%> car:"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "l'appel %<constexpr%> déborde au delà de la fin de la fonction"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E n'est pas une expression constante"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "appel à la fonction interne %qE"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "l'expression %qE ne désigne pas une fonction %<constexpr%>"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "appel à la fonction non %<constexpr%> %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD est appelé dans une expression constante avant que sa définition soit complète"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD appelé dans une expression constante"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD utilisé avant sa définition"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "l'appel a une dépendance circulaire"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "la profondeur d'évaluation de la %<constexpr%> dépasse le maximum permis %d (utilisez -fconstexpr-depth= pour augmenter le maximum)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "l'opérande de droite de l'expression de décalage %q+E est négatif"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "l'opérande de droite de l'expression de décalage %q+E est >= à la précision de l'opérande de gauche"
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "l'opérande de gauche de l'expression de décalage %q+E est négatif"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "l'expression de décalage %q+E déborde"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "arithmétique impliquant un pointeur nul dans %qE"
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau %qD du type %qT"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec le tableau %qD de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau de type %qT"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec un tableau de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "accès à un élément non initialisé du tableau"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "déréférencement d'un pointeur nul dans %qE"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE n'est pas une expression constante"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "le mutable %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "accès au membre %qD au lieu du membre initialisé %qD dans l'expression constante"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "accès au membre non initialisé %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "déréférencement d'un pointeur nul"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "accès à la valeur de %qE au travers d'une gl-valeur %qT dans une expression constante"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "la valeur de %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD utilisé dans sa propre initialisation"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D n'est pas const"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D est volatile"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD n'a pas été initialisé par une expression constante"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD n'a pas été déclaré %<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD n'a pas un type entier ou énuméré"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "la modification de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "le décompte des itérations de la boucle %<constexpr%> dépasse la limite permise %d (utilisez -fconstexpr-loop-limit= pour augmenter la limite)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "la valeur %qE du type %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporaire du type %qT non littéral dans une expression constante"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "un reinterpret_cast n'est pas une expression constante"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "la conversion du pointeur nul %qT vers %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> n'est pas une expression constante"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "l'expression %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "l'instruction n'est pas une expression constante"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "l'expression %qE du sous-type %s est inattendue"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE n'est pas une expression constante car il fait référence aux sous-objets mutables de %qT"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE n'est pas une expression constante car il fait référence à une variable incomplètement initialisée"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversion depuis le type pointeur %qT vers le type arithmétique %qT dans une expression constante"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "l'expression %qE à des effets de bord"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la capture lambda de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "car il est utilisé comme gl-valeur"
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast d'un entier vers un pointeur"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "prendre l'adresse avec address-of d'un objet %qE qui est local au thread ou a un stockage automatique n'est pas une expression constante"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "utilisation de %<this%> dans une expression constante"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "expression lambda dans une expression constante avant C++17"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "l'expression typeid n'est pas une expression constante car %qE est un type polymorphique"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "transtypage vers le type non entier %qT dans une expression constante"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD déclaré %<static%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD déclaré %<thread_local%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "la division par zéro n'est pas une expression constante"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> n'est pas une expression constante"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "initialisation d'un tableau non constant"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> n'est pas une expression constante"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr "throw appellera toujours terminate()"
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr "en C++11, les destructeurs sont noexcept par défaut"
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr "en C++11, ce throw sera terminal car les destructeurs sont noexcept par défaut"
@@ -39607,7 +39766,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversion depuis %qH vers %qI écarte les qualificatifs"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "le transtypage de %qT vers %qT ne déréférence pas le pointeur"
@@ -39616,306 +39775,306 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "ne peut convertir le type %qH vers le type %qI"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "conversion de %q#T vers %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "le résultat de la conversion n'est pas spécifié car %qE est en dehors de la plage du type %qT"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T utilisé là où un %qT était attendu"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "ne peut convertir %qE de %<void%> vers %<bool%>"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T utilisé là où une valeur en virgule flottante était attendue"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "conversion de %qH vers le type non scalaire %qI demandée"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "la valeur de retour de %qD est ignorée alors qu'elle est déclarée avec l'attribut nodiscard"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "la valeur de retour de type %qT est ignorée alors qu'elle est déclarée avec l'attribut nodiscard"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "dans l'appel à %qD, déclaré ici"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "le pseudo-destructeur n'est pas appelé"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet de type incomplet %qT"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'instruction"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type incomplet %qT dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet du type %qT"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'instruction"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "le déréférencement implicite n'accèdera pas à l'objet du type %qT dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet du type non trivialement copiable %qT"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'instruction"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "l'indirection n'accèdera pas à l'objet du type non trivialement copiable %qT dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "la conversion vers void n'accèdera pas à l'objet %qE du type incomplet %qT"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans le deuxième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans le troisième opérande de l'expression conditionnelle"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'opérande de droite de l'opérateur virgule"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'opérande de gauche de l'opérateur virgule"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'instruction"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "la variable %qE du type incomplet %qT ne sera pas accédée dans l'expression d'incrémentation de « for »"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "la conversion vers void ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "le deuxième opérande de l'expression conditionnelle ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "le troisième opérande de l'expression conditionnelle ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "l'opérande de droite de l'opérateur virgule ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "l'opérande de gauche de l'opérateur virgule ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "l'instruction ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "l'expression d'incrémentation de « for » ne peut résoudre l'adresse de la fonction surchargée"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "le deuxième opérande de l'expression conditionnelle est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "le troisième opérande de l'expression conditionnelle est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "l'opérande de droite de l'opérateur virgule est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "l'opérande de gauche de l'opérateur virgule est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "l'instruction est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "l'expression d'incrémentation de « for » est une référence, pas un appel, à la fonction %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "le deuxième opérande de l'expression conditionnelle n'a pas d'effet"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "le troisième opérande de l'expression conditionnelle n'a pas d'effet"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "l'opérande de droite de l'opérateur virgule n'a pas d'effet"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "l'opérande de gauche de l'opérateur virgule n'a pas d'effet"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "l'instruction n'a pas d'effet"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "l'expression d'incrémentation de « for » n'a pas d'effet"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "conversion d'un NULL vers un type non pointeur"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "la conversion du type par défaut ne peut déduire l'argument du patron pour %qD"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "la conversion du type par défaut est ambiguë à partir de %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  les conversions candidates incluent %qD et %qD"
@@ -39955,197 +40114,197 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD a été déclaré %<extern%> puis, plus loin, %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "la déclaration de %qF spécifie des exceptions différentes"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "par rapport à la déclaration précédente de %qF"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "la redéclaration de %qD diffère de la déclaration précédente sur le %<constexpr%>"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "déclaration précédente de %qD"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr "impossible de spécialiser le concept %q#D"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "la redéclaration de %q#D peut ne pas avoir d'arguments par défaut"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "l'opérateur littéral avec patron %q+D est en conflit avec l'opérateur littéral de base %qD"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "l'opérateur littéral de base %q+D est en conflit avec l'opérateur littéral avec patron %qD"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "la définition précédente de %qD était ici"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "la déclaration précédente de %qD était ici"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "la fonction interne %qD est déclarée comme une non fonction"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "masquage de la fonction interne %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "masquage de la fonction %q#D de la bibliothèque"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "la fonction %q#D de la bibliothèque est redéclarée comme %q#D n'étant pas une fonction"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "la déclaration de %q+#D est en conflit avec la déclaration interne %q#D"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "redéclaration de %<pragma omp declare reduction%>"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "déclaration %<pragma omp declare reduction%> précédente"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "la déclaration de %q#D est en conflit avec la déclaration interne %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "la définition de %q#D rend ambigüe le déclaration interne %q#D"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "la nouvelle déclaration %q#D rend ambigüe le déclaration interne %q#D"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "la déclaration de %q#D est ignorée"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D redéclaré comme une sorte différente de symbole"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "déclaration conflictuelle du patron %q+#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "rend ambigüe la nouvelle déclaration %q+#D"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "ancienne déclaration %q#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "déclaration conflictuelle de la fonction C %q+#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "rend ambigüe la nouvelle déclaration de %q+#D"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "entre en conflit avec la déclaration %q+#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "déclaré précédemment en tant que %q#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr "%q#D précédemment défini ici"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D précédemment déclaré ici"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "prototype spécifié pour %q#D"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "la définition non prototype précédente est ici"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "déclaration conflictuelle de %q+#D avec la classe de liaison %qL"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "déclaration précédente avec la classe de liaison %qL"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "argument par défaut donné pour le paramètre %d de %q#D"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "la spécification précédente dans %q#D est ici"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "déclaration redondante de %qD dans la même étendue"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "définition supprimée de %q+D"
@@ -40158,39 +40317,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spécialisation explicite de %qD après la première utilisation"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: attribut de visibilité ignoré car il est en conflit avec la déclaration précédente"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redéfinition de %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD est en conflit avec la fonction utilisée"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D pas déclaré dans une classe"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne avec l'attribut %<gnu_inline%>"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne sans l'attribut %<gnu_inline%>"
@@ -40198,631 +40357,632 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redéclaration de l'ami %q#D ne peut pas avoir d'arguments de patron par défaut"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "la déclaration locale au thread de %q#D suit la déclaration non locale au thread"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "la déclaration non locale au thread de %q#D suit la déclaration locale au thread"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redéclaration de %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redéclaration redondante du membre statique %<constexpr%> %qD"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "l'étiquette locale %qE est en conflit avec l'étiquette existante"
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr "étiquette précédente"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  à partir d'ici"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sort du block structuré OpenMP"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  croise l'initialisation de %q#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  entre dans la portée de %q#D qui a un destructeur non trivial"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr "  %s"
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  entre dans le bloc « catch »"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  passe outre l'initialisation de %q#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  entre dans la portée de %q#D qui a un destructeur non trivial"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  entre dans le bloc « try »"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  entre dans l'instruction synchronisée ou atomique"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr "  entre dans l'instruction « if » %<constexpr%>"
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entre dans le bloc structuré OpenMP"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "sortie invalide du bloc structuré OpenMP"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD n'est pas un type"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD utilisé sans paramètres du patron"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T n'est pas une classe"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "pas de patron de classe nommé %q#T dans %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "pas de type nommé %q#T dans %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la recherche de %qT dans %qT est ambigüe"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un patron de classe"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un type"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "les paramètres du patron ne correspondent pas au patron %qD"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<-fno-for-scope%> a été rendue obsolète"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "%<-ffriend-injection%> est obsolète"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-faligned-new=%d n'est pas une puissance de deux"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un destructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un opérateur d'affectation par copie n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoré dans la déclaration de %q#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "l'attribut pour %q#T doit suivre le mot-clé %qs"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "types multiples dans une déclaration"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redéclaration du type interne C++ %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> peut seulement être spécifié pour des déclarations de variables ou de fonctions"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nom de type manquant dans la déclaration typedef"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "le C++ ISO interdit les structures anonymes"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> peut seulement être spécifié à l'intérieur d'une classe"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> peut seulement être spécifié pour des constructeurs"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "une classe de stockage peut seulement être spécifiée pour des objets et des fonctions"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> a été ignoré dans cette déclaration"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> ne peut pas être utilisé pour des déclarations de types"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoré dans l'instanciation explicite de %q#T"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "aucun attribut peut être appliqué à une instanciation explicite"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "les attributs sont ignorés si ils sont appliqués à la classe de type %qT en dehors de la définition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "attributs ignorés car ils sont appliqués au type dépendent %qT sans déclaration associée"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD est initialisé (utilisez plutôt decltype)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la déclaration de %q#D est %<extern%> et est initialisée"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la définition de %q#D est marquée %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D n'est pas un membre de donnée statique de %q#T"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "la déclaration du patron non membre de %qD"
 
 # le message ci-dessous est la suite de celui juste ci-dessus
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ne correspond pas à la déclaration du patron membre ici"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "le C++ ISO ne permet pas que %<%T::%D%> soit défini comme %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "initialisation en double de %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la déclaration de %q#D en dehors de la classe n'est pas une définition"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD déclaré %<thread_local%> dans une fonction %<constexpr%>"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qD déclaré %<static%> dans une fonction %<constexpr%>"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D a un initialiseur mais a un type incomplet"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "les éléments du tableau %q#D ont un type incomplet"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "l'agrégat %q#D a un type incomplet et ne peut être défini"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD est déclaré comme référence mais n'est pas initialisé"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nom utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nom %qD utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "les initialisations par désignation non triviales ne sont pas supportées"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "le champ désigné par l'indicateur C99 %qE n'est pas une expression constante entière"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "l'initialisation n'a pu déterminer la taille de %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "taille de tableau manquante dans %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "tableau %qD de taille zéro"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "la taille de stockage de %qD n'est pas connue"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "la taille de stockage de %qD n'est pas constante"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la variable en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la fonction statique en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "vous pouvez contourner cela en enlevant l'initialiseur"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "constante %qD non initialisée"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable %qD non initialisée dans une fonction %<constexpr%>"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "variable %qD non initialisée dans un contexte %<constexpr%>"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T n'a pas de constructeur par défaut fourni par l'utilisateur"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "le constructeur n'est pas défini par l'utilisateur car le constructeur par défaut est explicitement demandé dans le corps de la classe"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "et le constructeur implicitement défini n'initialise pas %q#D"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "type %qT invalide pour initialiser un vecteur de type %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "l'initialisation de %qT doit être entre accolades"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> utilisé dans une initialisation par désignation dans le style GNU pour la classe %qT"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT n'a pas de membre de données non statique nommé %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "initialisation invalide pour %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "le champ désigné par l'indicateur C99 %qE est hors de l'initialisation de l'agrégat"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "trop d'éléments d'initialisation pour %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades manquantes autour de l'initialisation pour %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "les éléments du tableau %q#T ont un type incomplet"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "littéral composé de taille variable"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D a un type incomplet"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "l'objet scalaire %qD requiert un élément dans l'initialisation"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98, %qD doit être initialisé par un constructeur et non par %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "le tableau %qD est initialisé par la chaîne littérale entre parenthèses %qE"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initialisation invalide pour un membre statique avec constructeur"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique pas en ligne %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(une initialisation en dehors de la classe est requise)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "la référence %qD est initialisée avec elle-même"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (pas une initialisation) dans la déclaration"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "le C++17 ISO n'autorise pas le spécificateur de classe de stockage %<register%>"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "spécificateur de classe de stockage %<register%> utilisé"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "l'initialisation pour %<decltype(auto) %D%> a un type fonction (avez-vous oublié les %<()%> ?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "le concept de variable n'a pas d'initialisation"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "masque la déclaration précédente du type de %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la fonction %q#D est initialisée comme une variable"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une structure anonyme comme membre"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une union anonyme comme membre"
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+#| msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "impossible de décomposer le membre non publique %qD de %qT"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: lui et sa classe de base %qT ont des membres de données non statiques"
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: ses classes de base %qT et %qT ont des membres de données non statiques"
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "la liaison structurée fait référence au type incomplet %qT"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "impossible de décomposer le tableau de longueur variable %qT"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40829,7 +40989,7 @@
 msgstr[0] "%u nom fourni pour la liaison structurée"
 msgstr[1] "%u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40836,7 +40996,7 @@
 msgstr[0] "seulement %u nom fourni pour la liaison structurée"
 msgstr[1] "seulement %u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40843,1327 +41003,1339 @@
 msgstr[0] "alors que %qT se décompose en %wu élément"
 msgstr[1] "alors que %qT se décompose en %wu éléments"
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "impossible de décomposer le vecteur de longueur variable %qT"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> n'est pas une expression constante entière"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "alors que %qT se décompose en %E éléments"
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dans l'initialisation de la variable de liaison structurée %qD"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "impossible de décomposer le type union %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "impossible de décomposer le type %qT qui n'est ni une classe ni un tableau"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "impossible de décomposer le type de fermeture lambda %qT"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
+#, fuzzy, gcc-internal-format
+#| msgid "structured binding refers to incomplete type %qT"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "la liaison structurée fait référence au type incomplet %qT"
+
+#: cp/decl.c:7774
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "impossible de décomposer le type de classe %qT sans membre de donnée non statique"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "la variable non locale %qD déclarée %<__thread%> a besoin d'une initialisation dynamique"
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "la variable non locale %qD déclarée %<__thread%> a un destructeur non trivial"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> en C++11 permet l'initialisation et la destruction dynamique"
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de %qT"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taille du tableau manquante dans %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "tableau %qT de taille zéro"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "le destructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "le constructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD est déclaré comme une variable %<virtual%>"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de variable"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD déclaré comme un paramètre %<virtual%>"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD déclaré comme un paramètre %<inline%>"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de paramètre"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD déclaré comme un type %<virtual%>"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD déclaré comme un type %<inline%>"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de type"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD déclaré comme un champ %<virtual%>"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD déclaré comme un champ %<inline%>"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de champ"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D déclaré comme un ami"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D déclaré avec une spécification d'exception"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la définition de %qD n'est pas dans l'espace de noms incluant %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la fonction membre statique %q#D est déclarée avec des qualificatifs de type"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "le concept %q#D est déclaré avec des paramètres de fonction"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "le concept %q#D est déclaré avec un type de retour déduit"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "le concept %q#D a le type de retour %qT qui n'est pas %<bool%>"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "le concept %qD n'a pas de définition"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "définition de la spécialisation explicite %qD dans la déclaration amie"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "utilisation invalide du template-id %qD dans la déclaration du patron primaire"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "les arguments par défaut ne sont pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> n'est pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "ne peut déclarer %<::main%> comme étant un patron"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "ne peut déclarer %<::main%> comme étant à mettre en ligne"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "ne peut déclarer %<::main%> comme étant %<constexpr%>"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "ne peut déclarer %<::main%> comme étant static"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "le guide de déduction %qD doit être déclaré au niveau de l'espace de noms"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "le guide de déduction %qD ne peut pas avoir un corps de fonction"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "opérateur littéral avec une classe de liaison C"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD a une liste d'arguments invalide"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "le suffixe entier %qs est masqué par l'implémentation"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "le suffixe en virgule flottante %qs est masqué par l'implémentation"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD doit être une fonction non membre"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> doit retourner %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "définition de %qD déclaré implicitement"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "définition de %qD explicitement par défaut"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicitement par défaut ici"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "pas de fonction membre %q#D déclarée dans la classe %qT"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "ne peut déclarer %<::main%> comme variable globale"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "une variable qui n'est pas un patron ne peut pas avoir %<concept%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "un concept doit avoir le type %<bool%>"
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D d'un type incomplet"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> est requis pour l'initialisation intra-classe du membre de donnée statique %q#D d'un type non entier"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D du type non littéral"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "initialisation intra-classe invalide du membre de donnée statique du type non entier %qT"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "le C++ ISO interdit l'initialisation intra-classe du membre statique non constant %qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "le C++ ISO interdit l'initialisation du membre constant %qD du type non entier %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "la taille du tableau %qD a le type non entier %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "la taille du tableau a le type non entier %qT"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "la taille du tableau n'est pas une expression constante entière"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "la taille du tableau %qD est négative"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "la taille du tableau est négative"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "le C++ ISO interdit le tableau de taille zéro %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "le C++ ISO interdit le tableau de taille zéro"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "la taille du tableau %qD n'est pas une expression constante de type entier"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "le C++ ISO interdit le tableau de taille variable %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "le C++ ISO interdit le tableau de taille variable"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "le tableau de taille variable %qD est utilisé"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "le tableau de taille variable est utilisé"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "débordement dans la dimension du tableau"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD est déclaré comme tableau de %qT"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "déclaration de %qD comme un tableau de « void »"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "création d'un tableau « void »"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "déclaration de %qD comme un tableau de fonctions"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "création d'un tableau de fonctions"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "déclaration de %qD comme un tableau de références"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "création d'un tableau de références"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "déclaration de %qD comme un tableau de fonctions membres"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "création d'un tableau de fonctions membres"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qD comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "le tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la spécification d'un type retourné pour un constructeur est invalide"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un constructeur"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la spécification d'un type retourné pour un destructeur est invalide"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un destructeur"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "type de retour spécifié pour %<operator %T%>"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration de %<operator %T%>"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "type de retour spécifié pour le guide de déduction"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration du guide de déduction"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "paramètre de patron %qT, qui est lui-même un patron, dans la déclaration du guide de déduction"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "spécificateur de type « decl-specifier » dans la déclaration du guide de déduction"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variable non nommée ou champ déclaré void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variable ou champ déclaré void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "spécificateur %<inline%> invalide pour la variable %qD déclarée au niveau du bloc"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "les variables « inline » sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "utilisation invalide du nom qualifié %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T n'est pas une classe ou un espace de noms"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de %qD comme non fonction"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "déclaration de %qD comme non membre"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "declarator-id manquant; utilisation du mot réservé %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la définition de fonction ne déclare aucun paramètre"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "déclaration de %qD comme %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "déclaration de %qD comme paramètre"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<concept%> ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "au moins deux types de données dans la déclaration de %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "spécificateurs conflictuels dans la déclaration de %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C++ ISO n'accepte pas qu'un simple %<complex%> signifie %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "le C++ ISO interdit la déclaration de %qs sans type"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> n'est pas supporté par la cible"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "le C++ ISO ne supporte pas %<__int%d%> pour %qs"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> ou %<unsigned%> sont invalides pour %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> et %<unsigned%> spécifiés ensemble pour %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> invalide pour %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> invalide pour %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> invalide pour %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> ou %<short%> sont invalides pour %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> ou %<char%> sont invalides pour %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> ou %<short%> spécifié avec « char » pour %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> et %<short%> spécifiés ensemble pour %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> ou %<long%> sont invalides pour %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "« long », « short », « signed » ou « unsigned » utilisé incorrectement pour %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "« complex » invalide pour %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "l'espace réservé par le type %qT dans le patron doit être suivi d'un simple declarator-id"
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<static%>"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<constexpr%>"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "la déclaration typedef est invalide dans la déclaration du paramètre"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs du patron"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "spécificateurs de classe de stockage invalides dans la déclaration des paramètres"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "un paramètre ne peut pas être déclaré %<concept%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "un paramètre ne peut pas être déclaré %<constexpr%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> en dehors de la déclaration de classe"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<inline%>"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "la déclaration d'une liaison structurée ne peut pas être %qs"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<concept%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<static%>"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le %<auto%> du C++98"
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le type %qT"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "le type doit être un %<auto%> qualifié avec CV ou une référence à un %<auto%> qualifié avec CV"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "classes de stockage multiples dans la déclaration de %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "classe de stockage spécifiée pour %qs"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fonction imbriquée %qs déclarée %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la déclaration de %qs hors de toute fonction spécifie %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs dans le champ de la fonction est implicitement déclaré auto et déclaré %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spécificateurs de classe de stockage invalides dans les déclarations de fonctions amies"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "parenthèses inutiles dans la déclaration de %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "clause « requires » sur le type de retour"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la fonction %qs utilise le spécificateur de type %<auto%> sans type de retour à la fin"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "le type de retour déduit est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "une fonction virtuelle ne peut pas avoir un type de retour déduit"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %qT comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
+#, fuzzy, gcc-internal-format
+#| msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "type de classe %qT déduit dans le type de retour de la fonction"
+
+#: cp/decl.c:11156
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "le guide de déduction pour %qT doit avoir un type de retour à la fin"
 
-#: cp/decl.c:11099
+#: cp/decl.c:11169
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
-msgstr "type de classe %qT déduit dans le type de retour de la fonction"
-
-#: cp/decl.c:11111
-#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "le type de retour %qT à la fin du guide de déduction n'est pas une spécialisation de %qT"
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "le type de retour à la fin est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "la fonction %qs avec le type de retour à la fin n'est pas déclarée avec le spécificateur de type %<auto%>"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "les constructeurs ne peuvent pas être déclarés %<virtual%>"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "les fonctions virtuelles ne peuvent pas être amies"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la déclaration amie n'est pas dans la définition de la classe"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "ne peut définir la fonction amie %qs dans une définition de classe locale"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "une fonction de conversion ne peut pas avoir de type de retour à la fin"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre %q#T"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut déclarer une référence vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "ne peut déclarer une référence vers %q#T qui n'est pas un typedef ou un argument vers un type d'un patron"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD utilisé comme un déclarateur"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amies de leur classe"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification %<%T::%> additionnelle sur le membre %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "ne peut définir la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "ne peut déclarer la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "le non paramètre %qs ne peut pas être un paquet de paramètres"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "les membres de données ne peuvent pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "le paramètre ne peut pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> en dehors de la déclaration de la classe"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> dans une déclaration amie"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs et les opérateurs de conversion peuvent être %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "le membre non objet %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la fonction %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "le %qs statique ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "le %qs constant ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la référence %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef déclaré %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "clause « requires » sur un typedef"
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "le nom du typedef ne peut pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "le C++ ISO interdit le type imbriqué %qD avec le même nom que la classe englobante"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "les paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre amie la classe %qT au niveau de la portée globale"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificatifs invalides sur un type de fonction non membre"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "clause « requires » sur type-id"
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstraite %qT utilisée comme déclaration"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "clause « requires » dans la déclaration du type non fonction %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser %<::%> dans la déclaration d'un paramètre"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "le paramètre %<auto%> n'est pas permis dans ce contexte"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "membre de donnée non statique déclaré avec %qT comme espace réservé"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "le C++ ISO interdit le membre tableau flexible %qs"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "le C++ ISO interdit les tableaux flexibles comme membres"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction %qD dans un contexte invalide"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fonction %qD déclarée %<virtual%> à l'intérieur d'une union"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD ne peut pas être déclaré %<virtual%> puisqu'il est toujours statique"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie du destructeur %qD"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de %qD comme membre de %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "un destructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "un destructeur ne peut pas être %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie pour le constructeur %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "un constructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "un concept ne peut être une fonction membre"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation du patron de variable %qD déclaré comme une fonction"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "le patron de variable a été déclaré ici"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "le champ %qD a le type incomplet %qT"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "le nom %qT a un type incomplet"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "membre statique %qE déclaré %<concept%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "le membre statique %<constexpr%> %qD doit avoir une initialisation"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "le membre non statique %qE est déclaré %<concept%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "le membre non statique %qE est déclaré %<constexpr%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la classe de stockage %<auto%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la classe de stockage %<register%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la classe de stockage %<__thread%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la classe de stockage %<thread_local%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "le spécificateur de type « virt-specifier » sur %qs n'est pas permis en dehors d'une définition de classe"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<static%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<inline%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "fonction non classe virtuelle %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs défini en dehors d'un contexte de classe"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs déclaré en dehors d'un contexte de classe"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "ne peut déclarer la fonction membre %qD comme ayant une classe de liaison statique"
@@ -42170,77 +42342,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> ne peut pas être utilisé lors de la définition (contrairement à la déclaration) d'un membre de donnée statique"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "membre statique %qD déclaré %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre %q#D comme ayant une classe de liaison externe"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la déclaration de la variable %<constexpr%> %qD n'est pas une définition"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la déclaration de %q#D n'est pas initialisée"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisé et déclaré %<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs a, à la fois, %<extern%> et une initialisation"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "l'argument par défaut %qE utilise %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "l'argument par défaut %qE utilise la variable locale %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide du type %qT qualifié CV dans la déclaration du paramètre"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du type %<void%> dans la déclaration du paramètre"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "le paramètre %qD est incorrectement déclaré comme type de méthode"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut un pointeur vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut une référence vers un tableau %qT dont les bornes sont inconnues"
@@ -42260,169 +42432,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement utiliser %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD ne peut pas être déclaré dans un espace de noms"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD ne peut pas être déclaré statique"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD doit être une fonction membre non statique"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD doit être soit une fonction membre non statique ou une fonction non membre"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD doit avoir un argument de type classe ou énuméré"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "le C++ ISO interdit la surcharge de l'opérateur ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD ne doit pas avoir un nombre variables d'arguments"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD doit avoir zéro ou un argument"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD doit avoir un ou deux arguments"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qD suffixé doit avoir %<int%> comme argument"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qD suffixé doit avoir %<int%> comme second argument"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD ne doit avoir aucun argument"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD doit avoir exactement un argument"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD doit avoir exactement deux arguments"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD ne peut avoir d'arguments par défaut"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "la conversion en une référence vers void n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "la conversion vers void n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "la conversion en une référence vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "la conversion vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "la conversion en une référence vers une classe de base n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "la conversion vers une classe de base n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "%qD défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "%qD préfixé devrait retourner %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "%qD suffixé devrait retourner %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD devrait retourner par valeur"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation du paramètre du type de patron %qT après %qs"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "utilisation de la spécialisation du patron d'alias %qT après %qs"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation du nom de typedef %qD après %qs"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD a une déclaration précédente ici"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT référé en tant que %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT a une déclaration précédente ici"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "il est fait référence à %qT comme un enum"
@@ -42434,94 +42606,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron requis pour %<%s %T%>"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de l'enum %q#D sans déclaration précédente"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de %qT sous une forme qui n'est pas un patron"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "l'union dérivée %qT est invalide"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT est défini avec des bases directes multiples"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT est défini avec des bases virtuelles directes"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "le type de base %qT n'est pas un « struct » ou une « class »"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "type récursif %qT non défini"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "le type de base dupliqué %qT est invalide"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "désaccord dans le type sous-jacent de l'enum %q#T"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "types sous-jacents différents dans l'enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "le type sous-jacent %qT de %qT doit être un type entier"
@@ -42530,77 +42702,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier ne peut représenter toutes les valeurs de l'énumération pour %qT"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "les valeurs énumérées de %qD doivent être de type entier ou une énumération simple (donc, pas fortement typée)"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "la valeur de l'énumération pour %qD n'est pas une constante entière"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<unsigned long%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<long%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "la valeur de l'énumération %qE est en dehors de la plage du type sous-jacent %qT"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "déclaration de fonction invalide"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "déclaration de fonction membre invalide"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD est déjà défini dans la classe %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "utilisation de %qD avant la déduction de %<auto%>"
@@ -42640,7 +42812,7 @@
 msgid "deleting %qT is undefined"
 msgstr "la destruction de %qT est non définie"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "déclaration du patron de %q#D"
@@ -42653,7 +42825,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "le destructeur %qD est déclaré en tant que patron membre"
@@ -42763,42 +42935,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "la largeur du champ de bits %qD a le type non entier %qT"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "membre de donnée statique %q+D à l'intérieur de la directive de déclaration de cible"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "struct anonyme pas à l'intérieur d'un type nommé"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données non statiques"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "membre privé %q#D dans une union anonyme"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "membre protégé %q#D dans une union anonyme"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "les agrégats anonymes dans la portée de l'espace de noms doivent être statiques"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "union anonyme sans aucun membre"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> doit retourner le type %qT"
@@ -42807,67 +42979,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "le premier paramètre de %<operator new%> ne peut pas avoir d'argument par défaut"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> prend le type %<size_t%> (%qT) comme premier paramètre"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> doit retourner le type %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> prend le type %qT comme premier paramètre"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT a un champ %qD dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT a un champ %qD dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT a un champ %qD dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT est déclaré avec une plus grande visibilité que le type de son champs %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT a la base %qT dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT a la base %qT dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT a la base %qT dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT est déclaré avec une plus grande visibilité que sa base %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D, déclaré avec un type non nommé, est utilisé mais jamais défini"
@@ -42876,62 +43048,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D ne réfère pas au type non qualifié, aussi n'est-il pas utilisé pour la liaison"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, déclaré avec le type local %qT, est utilisé mais jamais défini"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "la décoration de %q#D qui abouti à %qE entre en conflit avec une décoration précédente"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "décoration précédente de %q#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "un -fabi-version= plus récent (ou =0) évite cette erreur avec un changement de décoration"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "le programme devrait aussi définir %qD"
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "la fonction en ligne %qD est utilisée mais n'a jamais été définie"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argument par défaut manquant pour le paramètre %P de %q+#D"
@@ -42938,17 +43110,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "conversion d'une fonction lambda qui utilise %<...%> en pointeur de fonction"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "utilisation de la fonction supprimée %qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "utilisation du paquet de paramètres intégré %qD en dehors d'un patron"
@@ -42958,112 +43130,112 @@
 msgid "with"
 msgstr "avec"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(pas d'argument)"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[...]"
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "les listes d'initialisation étendues sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "les opérateurs de conversion explicites sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "les patrons variadiques sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "les expressions lambda sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "le auto du C++11 est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "les enums fortement typés sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "les fonctions par défaut ou supprimées sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "les espaces de noms en ligne sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "le contrôle de la surcharge (override/final) est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "les initialisations de membres de données non statiques sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "les littéraux définis par l'utilisateur sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "les constructeurs délégués sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "les constructeurs hérités sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "les attributs c++11 sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "les qualificatifs de références sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "type %qT incomplet utilisé dans un spécificateur de noms imbriqué"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "la référence à %<%T::%D%> est ambiguë"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD n'est pas un membre de %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD n'est pas un membre de %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> n'a pas été déclaré"
@@ -43209,358 +43381,358 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(si ce n'est pas ce que vous vouliez faire, assurez-vous que le patron de la fonction a déjà été déclaré et ajoutez <> après le nom de la fonction ici)"
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "initialisation par valeur du type incomplet %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "impossible d'initialiser par valeur le tableau ayant la limite %qT inconnue"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "initialisation par valeur du type fonction %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "initialisation par valeur du type référencé %qT"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "instanciation récursive de l'initialisation du membre par défaut pour %qD"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "l'initialisation du membre par défaut pour %qD est requise avant la fin de sa classe englobante"
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, gcc-internal-format
 msgid "defined here"
 msgstr "défini ici"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initialisation pour le membre tableau flexible %q#D"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD devrait être initialisé dans la liste d'initialisation du membre"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD est initialisé avec lui-même"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "initialisation invalide pour le membre tableau %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "membre constant non initialisé dans %q#T"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D devrait être initialisé"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "membre par référence non initialisé dans %q#T"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sera initialisé après"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT sera initialisée après"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  la base %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  quand elle est initialisée ici"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "initialisations multiples données pour %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "initialisations multiples données pour la base %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initialisations pour des membres multiples de %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la classe de base %q#T devrait être explicitement initialisée dans le constructeur par copie"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la classe %qT n'a aucun champ nommé %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D est un membre de donnée statique; il peut seulement être initialisé lors de sa définition"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D n'est pas un membre de donnée non statique de %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "initialisation sans nom pour %qT, lequel n'a pas de classe de base"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "initialisation sans nom pour %qT, lequel utilise de multiples héritages"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD est à la fois une base directe et une base virtuelle indirecte"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "le type %qT n'est pas une base directe ou virtuelle de %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "le type %qT n'est pas une base directe de %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT n'est pas un type de classe"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "le type incomplet %qT n'a pas de membre %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "pointeur invalide vers le champ de bits %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "utilisation invalide de la fonction membre non statique %qD"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "utilisation invalide du membre de donnée non statique %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "membre de référence non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "membre constant non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %<%T [%wu]%> et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un tableau d'objets de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "débordement d'entier dans la taille du tableau"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "la taille du tableau dans l'expression « new » doit être une constante"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "le type modifié par une variable n'est pas permis dans l'expression « new »"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée directement, pas par un typedef"
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée sans parenthèses autour du id de type"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "type %<void%> invalide pour « new »"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "constante non initialisée dans %<new%> de %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "pas de %qD convenable dans la classe %qT"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la requête pour le membre %qD est ambiguë"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> de type %qT avec l'alignement étendu %d"
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "utilisation de %qD qui n'a pas de paramètre d'alignement"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "utilisez %<-faligned-new%> pour activer le support du « new » sur-aligné du C++17"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initialisation entre parenthèses dans le « new » du tableau"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "la taille du tableau dans « new » doit avoir un type entier"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "« new » ne peut pas être appliqué à un type référencé"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "« new » ne peut être appliqué à un type de fonction"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "problème possible détecté dans l'invocation de l'opérateur delete[]:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur « delete[] » spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "fin prématurée de l'initialisation"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taille du tableau inconnue dans delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "problème possible détecté dans l'invocation de l'opérateur delete:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur « delete » spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "la destruction d'un objet de la classe abstraite %qT qui a un destructeur non virtuel provoquera un comportement indéfini"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "la destruction d'un objet de la classe polymorphique %qT qui a un destructeur non virtuel pourrait produire un comportement indéfini"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "le type passé au delete vectoriel n'est ni un pointeur ni un type tableau"
@@ -43571,8 +43743,9 @@
 msgstr "le tableau avec une limite déterminée à l'exécution ne peut pas être capturée par copie, uniquement par référence"
 
 #: cp/lambda.c:557
-#, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+#, fuzzy, gcc-internal-format
+#| msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "capture du type de taille variable %qT qui n'est pas un tableau N3639 avec une limite déterminée à l'exécution"
 
 #: cp/lambda.c:561
@@ -43655,67 +43828,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(si vous utilisez %<-fpermissive%>, G++ acceptera votre code, mais permettre l'utilisation d'un nom non déclaré est obsolète)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "décoration de typeof, utilisez plutôt decltype"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "décoration de __underlying_type"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "décoration du type en virgule fixe inconnu"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "utilisation du trait interne %qE dans la signature de la fonction, utilisez plutôt la bibliothèque des traits"
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "décoration de %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "l'opérande omis au milieu de %<?:%> ne peut pas être décoré"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "chaîne littérale dans la signature du patron de la fonction"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "le nom décoré pour %qD changera dans le C++17 car la spécification de l'exception fait partir du type de la fonction"
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "le nom décoré de %qD a changé entre %<%s=%d%> (%qD) et %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "le nom décoré de %qD change entre %<%s=%d%> (%qD) et %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "le nom décoré d'un fragment pour %qD change entre -fabi-version=%d et -fabi-version=%d"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "le nom décoré de %qD change entre -fabi-version=%d et -fabi-version=%d"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "le nom décoré de la variable de protection de l'initialisation pour %qD change entre -fabi-version=%d et -fabi-version=%d"
@@ -43834,42 +44007,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "fonction %q+D imposée par défaut avec un argument par défaut"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D entre en conflit avec une déclaration précédente"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D cache le constructeur pour %q#D"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "déclarations conflictuelles de l'édition de liens du langage C %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "à cause de spécifications d'exceptions différentes"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la déclaration de %q#D masque un paramètre"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "la déclaration de %qD masque un membre de %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "déclaration externe locale de %q#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "ne correspond pas à la déclaration précédente %q#D"
@@ -43877,57 +44050,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "déclaration amie %qD dans la classe locale sans déclaration locale antérieure"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr "l'ami injecté %qD est visible à cause de %<-ffriend-injection%>"
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "la recherche du nom de %qD a changé"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr "concorde avec %qD selon les règles du standard ISO"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr "  concorde avec %qD selon les vieilles règles"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "la recherche du nom de %qD a changé pour la portée du %<for%> ISO"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "ne peut utiliser la liaison obsolète à %qD parce qu'il a un destructeur"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr "utilisation de la liaison obsolète à %qD"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %<%s(%E)%> %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%qT n'est pas un enum dans l'espace de noms ou hors de toute portée"
@@ -43934,12 +44107,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "une déclaration « using » ne peut pas spécifier un template-id.  Essayez %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "l'espace de noms %qD n'est pas permis dans une déclaration « using »"
@@ -43946,103 +44119,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT n'est pas un espace de noms"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD est déjà déclaré dans cette portée"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD n'est pas déclaré"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "déclaration « using » pour un non membre au niveau de la portée de la classe"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> nomme le destructeur"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nomme le constructeur dans %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "impossible d'hériter des constructeurs depuis la base indirecte %qT"
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "aucun membre concordant avec %<%T::%D%> dans %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la déclaration de %qD n'est pas dans l'espace de noms entourant %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "qualificatifs explicites dans la déclaration de %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD n'a pas été déclaré dans %qD"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "uniquement ici comme un %<friend%>"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD aurait dû être déclaré à l'intérieur de %qD"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "l'attribut %qD requiert un seul argument NTBS"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "l'attribut %qD n'a pas de signification puisque les membres de l'espace de noms anonyme obtiennent des symboles locaux"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms anonyme"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms pas en ligne"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "la directive d'attribut %qD est ignorée"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "limite maximale de %d espaces de noms recherchés pour %qE"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -44049,78 +44222,85 @@
 msgstr[0] "alternative suggérée:"
 msgstr[1] "alternatives suggérées:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "alternatives suggérées: %qs"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> est défini dans l'en-tête %qs ; avez-vous oublié %<#include %s%> ?"
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
+#, fuzzy, gcc-internal-format
+#| msgid "%s is not available for %s architecture"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%s n'est pas disponible pour l'architecture %s"
+
+#: cp/name-lookup.c:5929
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "la macro %qs n'a pas encore été définie"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "elle a été définie ici plus tard"
 
-#: cp/name-lookup.c:6476
-#, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+#: cp/name-lookup.c:6687
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "la déclaration de std::initializer_list ne correspond pas à #include <initializer_list> et n'est pas un patron"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "la directive « using » forte n'est plus supportée"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "vous pouvez utiliser un espace de noms en ligne à la place"
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "attributs ignorés sur une directive « using » locale"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "l'alias de l'espace de noms %qD n'est pas permis ici, on suppose %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "impossible d'imbriquer plus de %d espaces de noms"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "un espace de nom en ligne doit être spécifié à la définition initiale"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD défini ici"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entre dans pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX quitte pop_everything ()\n"
@@ -44140,7 +44320,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P n'est pas défini à vrai"
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi par une déclaration ou une définition de fonction"
@@ -44165,7 +44345,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "requête du membre %qE dans le type %qT qui n'est pas une classe"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> n'a pas été déclaré"
@@ -44245,7 +44425,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "le C++ ISO interdit l'utilisation d'un littéral en virgule flottante dans une expression constante"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "un transtypage vers un type autre qu'un entier ou une énumération ne peut pas apparaître dans une expression constante"
@@ -44467,7 +44647,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "impossible de trouver l'opérateur littéral de chaîne %qD avec les arguments %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "déclaration attendue"
@@ -44548,7 +44728,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "la portée %qT avant %<~%> n'est pas un nom de classe"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> est uniquement disponible avec -std=c++14 ou -std=gnu++14"
@@ -44563,863 +44743,854 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "nom du typedef %qD utilisé comme déclaration de destructeur"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualified-id attendu"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> trouvé dans le spécificateur de nom imbriqué, %<::%> attendu"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype est évalué en %qT qui n'est ni une classe ni un type énuméré"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "template-id de la fonction %qD dans le spécificateur de nom imbriqué"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "template-id de la variable %qD dans le spécificateur de nom imbriqué"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD n'est pas un patron"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "spécificateur de nom imbriqué attendu"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "les types ne peuvent pas être définis dans les transtypages"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "le C++ ISO interdit les littéraux composés"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "deux %<[%> consécutifs n'introduiront qu'un attribut"
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "utilisation invalide de %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> n'est pas un membre de classe"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "type non scalaire"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "le C++ ISO ne permet pas %<alignof%> avec un non type"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "les types ne peuvent pas être définis dans des expressions %<noexcept%>"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "les types ne peuvent pas être définis dans une expression « new »"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "les limites de tableau sont interdites après un type-id entre parenthèses"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "essayez d'enlever les parenthèses autour du type-id"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "l'initialisation de l'expression « new » pour le type %<auto%> exige exactement un élément"
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "liste-expression ou type-id attendu"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "les types ne peuvent pas être définis dans un new-type-id"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "l'expression dans la déclaration « new » doit être un type entier ou un type énuméré"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "utilisation d'un vieux style de transtypage vers %q#T"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "l'opérateur %<>>%> est traité comme deux caractères > en C++11"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "parenthèses suggérées autour de l'expression %<>>%>"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "le C++ ISO ne permet pas d'omettre l'opérande du milieu de ?:"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in conditions"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "des types ne peuvent pas être définis dans des conditions"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "expression lambda dans un contexte non évalué"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "expression lambda dans l'argument du patron"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "fin de liste de capture attendue"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %<this%> est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "la capture de %<*this%> est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "les initialisations par capture des fonctions lambda sont uniquement disponibles avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "initialisation vide pour la capture par initialisation d'une fonction lambda"
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "capture de %qE qui n'est pas une variable"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D déclaré ici"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture de la variable %qD avec une durée de stockage non automatique"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %qD est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la capture par référence explicite de %qD est redondante avec la capture par référence par défaut"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "les patrons lambda sont uniquement disponibles avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "les patrons lambda sont uniquement disponibles avec -std=c++2a ou -std=gnu++2a"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argument par défaut spécifié pour un paramètre lambda"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "%<mutable%> dupliqué"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "les lambda %<constexpr%> sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "les attributs au début d'une instruction sont ignorés"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "instruction étiquetée attendue"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "le « case » %qE n'est pas à l'intérieur de l'instruction « switch »"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> doit être utilisé avant %qE car %qT est une portée dépendante"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nomme le constructeur, pas le type"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "instruction composée dans une fonction %<constexpr%>"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "%<if constexpr%> uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "l'instruction init dans des instructions de sélection est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "instruction de sélection attendue"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "des types ne peuvent pas être définis dans des conditions"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "l'expression %<for%> parcourant une plage de type %qT a un type incompatible"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "l'expression %<for%> parcourant une plage de type %qT a un membre %<end%> mais pas de %<begin%>"
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "l'expression %<for%> parcourant une plage de type %qT a un membre %<begin%> mais pas de %<end%>"
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "types différents pour « begin » et « end » de l'instruction %<for%> parcourant une plage: %qT et %qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "instruction d'itération attendue"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "les boucles %<for%> parcourant une plage sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> dans une fonction %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "le C++ ISO interdit les gotos calculés"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "instruction de saut attendue"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> superflu"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> pas au début du bloc"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "non variable %qD dans la déclaration avec plus d'une déclaration contenant un type à remplacer"
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "déduction incohérente pour %qT: %qT et puis %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "mélanger des déclarations et des définitions de fonctions est interdit"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "des types ne peuvent pas être définis dans la déclaration d'une instruction « for » parcourant une plage"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initialisation dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "déclarations multiples dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "les liaisons structurées sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "déclaration de liaison structurée vide"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "initialisation invalide pour la déclaration de liaison structurée"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> utilisé en dehors d'une classe"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> a changé de signification en C++11; retirez-le"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "spécificateur de déclaration invalide dans une condition"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD est invalide dans une lambda"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la définition de classe ne peut pas être déclarée comme amie"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "les patrons ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "spécification de classe de liaison invalide"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "un static_assert sans message est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "les types ne peuvent pas être définis dans les expressions %<decltype%>"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "les types ne peuvent pas être définis dans un conversion-type-id"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "utilisation invalide de %<auto%> dans un opérateur de conversion"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "un %<auto%> dans un opérateur de conversion d'un patron membre ne peut jamais être déduit"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "seuls les constructeurs prennent des initialisions membres"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "impossible de développer l'initialisation du membre %qD"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "ancien style anachronique d'initialisation de classe de base"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (une initialisation de membre qualifiée est implicitement un type)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "mot-clé inattendu; enlevez l'espace entre les guillemets et l'identificateur du suffixe"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "identificateur de suffixe attendu"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "une chaîne vide était attendue après le mot-clé %<operator%>"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "préfixe d'encodage invalide dans l'opérateur littéral"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "opérateur attendu"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "le mot-clé %<export%> n'est pas implémenté et sera ignoré"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "paramètre de type contraint invalide"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "paramètre de type qualifié avec CV"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "contrainte variadique introduite sans %<...%>"
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "utilisation invalide de %<auto%> dans l'argument par défaut du patron"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "les paquets de paramètres des patrons ne peuvent pas avoir d'arguments par défaut"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "template-id attendu"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> ne peut pas être au début d'une liste d'arguments d'un patron"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> est une écriture alternative pour %<[%>. Insérer un espace entre %<<%> et %<::%>"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si vous utilisez %<-fpermissive%> ou %<-std=c++11%> ou %<-std=gnu++11%> G++ acceptera votre code)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "erreur d'analyse dans la liste des arguments du patron"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "nom de patron attendu"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD n'est pas un patron mais il est utilisé comme patron"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilisez %<%T::template %D%> pour indiquer que c'est un patron"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "paquet de paramètres attendu avant %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "argument de patron attendu"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argument de patron invalide car ce n'est pas un type"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<inline%>"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<constexpr%>"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "spécialisation de patron avec édition de liens C"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "spécificateur du type attendu"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "l'utilisation de %<auto%> dans la déclaration d'un paramètre lambda est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec -fconcepts"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "template-id attendu pour le type"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "un spécificateur de type élaboré pour un enum fortement typé ne peut pas utiliser le mot-clé %qD"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la déclaration %qD ne déclare rien du tout"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributs ignorés sur un type non instancié"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attributs ignorés sur une instanciation de patron"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attributs ignorés sur un spécificateur de type élaboré qui n'est pas une déclaration anticipée"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD est un patron d'énumération"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD ne nomme pas une énumération dans %qT"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "un enum fortement typé sans nom n'est pas permis"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> ou %<{%> attendu"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "impossible d'ajouter une liste d'énumération à l'instanciation d'un patron"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "le spécificateur de nom imbriqué %qT pour la déclaration d'un enum ne nomme pas une classe ou un espace de noms"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans l'espace de noms %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "qualification supplémentaire pas permise"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "le C++ ISO interdit un enum vide et sans nom"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "spécificateur enum opaque sans nom"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "un spécificateur enum opaque doit utiliser un simple identificateur"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD n'est pas un espace de noms"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "espace de noms attendu"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "les définitions d'espace de noms imbriqués sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nom d'espace de nom imbriqué attendu"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "nom d'espace de nom attendu"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "une définition d'espace de noms imbriqué ne peut pas avoir d'attribut"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "une définition d'un espace de noms imbriqué ne peut pas être « inline »"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "entrée dans l'espace de noms %qD"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la définition %<namespace%> n'est pas permise ici"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "l'expansion de paquets dans une déclaration « using » est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un template-id ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "une liste séparée par des virgules dans une déclaration « using » est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "les déclarations d'accès sont dépréciées en faveur des déclarations « using »; suggestion: ajoutez le mot-clé %<using%>"
 
 # alias template est un patron appliqué à un alias == patron d'alias
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "les types ne peuvent pas être définis dans des déclarations de patrons d'alias"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> dans une fonction %<constexpr%>"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "une définition de fonction n'est pas permise ici"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "une spécification asm n'est pas permise dans une définition de fonction"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "des attributs ne sont pas permis dans une définition de fonction"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "constructeur, destructeur ou conversion de type attendu"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initialisation attendue"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initialisation fournie pour une fonction"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "les attributs après l'initialisation entre parenthèses sont ignorés"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "la non fonction %qD est déclarée comme un patron implicite"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "la limite du tableau n'est pas une constante entière"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "impossible de définir le membre du typedef dépendant %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> n'est pas un type"
@@ -45428,17 +45599,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "déclarateur invalide"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "utilisation invalide du constructeur comme patron"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "utilisez %<%T::%D%> au lieu de %<%T::%D%> pour nommer le constructeur dans un nom qualifié"
@@ -45445,383 +45616,383 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id dans une déclaration"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "déclarateur attendu"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD est un espace de noms"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "impossible de former un pointeur vers un membre de la non classe %q#T"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "opérateur pointeur attendu"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "qualificatif CV dupliqué"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "qualificatifs de référence multiples"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE requiert %<-fgnu-tm%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "spécificateurs virtuels (virt-specifier) multiples"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "arguments de patron manquants après %qT"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "utilisation invalide de %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "les types ne peuvent pas être définis dans les arguments du patron"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "utilisation invalide de %<auto%> dans un argument de patron"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "spécificateur de type attendu"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> ou %<...%> attendu"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "des types ne peuvent pas être définis dans des types de paramètres"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "des arguments par défaut sont uniquement permis pour des paramètres de fonction"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "les initialisations désignées du C++ sont uniquement disponibles avec -std=c++2a ou -std=gnu++2a"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation de GNU"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation du C99"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "soit toutes les instructions d'initialisation devraient être désignées ou aucune ne devrait l'être"
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> pas permis dans une liste d'initialisation par désignation"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "désignateur %<.%s%> utilisé plusieurs fois dans la même liste d'initialiseurs"
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "nom de classe attendu"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> attendu après la définition de la classe"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> attendu après la définition de la structure"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> attendu après la définition de l'union"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> ou %<:%> attendu"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ne peut spécifier %<override%> pour une classe"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la qualification globale du nom de la classe est invalide"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "le nom qualifié ne nomme pas une classe"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "le mot-clé %<template%> n'est pas permis dans class-head-name (NdT: nom de classe)"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nom de classe invalide dans la déclaration de %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "une spécialisation explicite doit être précédée par %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "le patron de fonction %qD est redéclaré comme un patron de classe"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "impossible de résoudre le type de typename"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "définition précédente de %q#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "mot-clé de type classe (class ou struct) attendu"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr "le C++ ISO interdit le mot-clé typename dans un paramètre de patron qui est un patron; utilisez -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> ou %<typename%> attendu"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03, le mot-clé class (ou struct) doit être utilisé lors de la déclaration d'un ami"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "une classe de stockage sur un agrégat anonyme dans une classe n'est pas permis"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "les initialiseurs de membre par défaut pour les champs de bits sont uniquement disponibles avec -std=c++2a ou -std=gnu++2a"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "initialiseur d'un membre par défaut pour un champ de bits sans nom"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "le C++ ISO autorise les attributs de champs de bits uniquement avant l'élément %<:%>"
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "spécificateur pur sur une définition de fonction"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%<;%> supplémentaire après la définition dans la classe"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<,%> égarée à la fin de la déclaration du membre"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> attendu à la fin de la déclaration du membre"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "spécificateur pur invalide (seul %<= 0%> est autorisé)"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "une initialisation entre accolades n'est par permise ici"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> spécifié plus d'une fois dans le spécificateur de base"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "plus d'un spécificateur d'accès dans le spécificateur de base"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "le mot-clé %<typename%> n'est pas permis en dehors des patrons"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (la classe de base est implicitement un type)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "les types ne peuvent pas être définis dans une spécification d'exception"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "le C++17 ISO n'autorise pas la spécification dynamique des exceptions"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "les spécifications dynamiques d'exceptions sont dépréciées en C++11"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "utilisation invalide de %<auto%> dans une spécification d'exception"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> dans une fonction %<constexpr%>"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "des types ne peuvent pas être définis dans une déclaration d'exception"
 
 # Je ne suis pas sûr du tout de la signification de « scoped attribute token »…
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "l'attribut de préfixe « using » est utilisé en même temps qu'un élément d'attribut agissant sur une portée"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "un identificateur est attendu pour le nom d'attribut"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<noreturn%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<deprecated%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut attendu avant %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "l'attribut de préfixe « using » est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> uniquement disponible avec -fconcepts"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "une expression « requires » ne peut pas apparaître en dehors d'un patron"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "la syntaxe %<template<>%> est requise pour spécialiser %<%T::%E%>"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "déclaration invalide de %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de listes de paramètres pour le patron"
@@ -45830,518 +46001,518 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de listes de paramètres pour le patron"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "les valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet d'arguments de type non patron tels que <char...> ou <typename CharT, CharT...>"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet d'arguments de type non patron tel que <char...>"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "liste d'instructions vide"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "pas de concept correspondant pour l'introduction du patron"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron membre dans la classe locale"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite invalide"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration de patron de %<typedef%>"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "une déclaration de patron de classe ne doit rien déclarer d'autre"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "une spécialisation explicite de patron ne peut pas avoir une classe de stockage"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> devrait être %<> >%> à l'intérieur d'une liste d'arguments de patron imbriqués"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "le %<>>%> est faux, utilisez %<>%> pour terminer la liste d'arguments du patron"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "l'argument %<sizeof...%> doit être entouré de parenthèses"
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "utilisation invalide de %qD dans la spécification de la classe de liaison"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "le C++ ISO 1998 ne permet pas %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "%<__thread%> et %<thread_local%> sont tous les deux spécifiés"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qD dupliqué"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs dupliqué"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> attendu"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> attendu"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> attendu"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> attendu"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> attendu"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> attendu"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> attendu"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> attendu"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> attendu"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> attendu"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> attendu"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> attendu"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> attendu"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> attendu"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> attendu"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> attendu"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> attendu"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> attendu"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> attendu"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> attendu"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> attendu"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> attendu"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> attendu"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> attendu"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> attendu"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<;%> ou %<::%> attendu"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> ou %<template%> attendu"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette %qs utilisée en nommant %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T a été précédemment déclaré ici"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD redéclaré avec un accès différent"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "en C++98, %<template%> (afin de lever une ambigüité) est seulement permis à l'intérieur des patrons"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construction Objective-C++ %<@%D%> mal placée"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "récepteur de message objective-c++ attendu"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "un ou des argument(s) de message objective-c++ est/sont attendu(s)"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> doit spécifier un type comme un argument"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nom de sélecteur Objective-C++ invalide"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "une déclaration de méthode objective-c++ est attendue"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "les attributs de méthodes doivent être spécifiés à la fin"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs égaré entre des méthodes Objective-C++"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "type invalide pour la variable d'instance"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identificateur attendu après %<@protocol%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "des attributs ne peuvent pas être spécifiés avant le mot-clé %<@%D%> en Objective-C++"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "les attributs de préfixes sont ignorés avant %<@%D%>"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "type invalide pour une propriété"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "l'expression %<wait%> doit être un nombre entier"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "identificateur de réduction invalide"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle %<for%> de OpenMP"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "pas assez de boucles « for » à combiner"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "clause d'initialisation invalide"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "expression id (arguments) attendue"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<omp_priv%> ou %<&omp_priv%>"
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "des types ne peuvent pas être définis dans une liste de types de réductions"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique %qT prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "type tableau ou fonction %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "type référence %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "type %qT qualifié avec const, volatile ou __restrict dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> nomme un ensemble de surcharges"
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD ne fait pas référence à une fonction à l'intérieur de l'espace de noms"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rebut à la fin de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "les optimisations inter-modules ne sont pas implémentées pour le C++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "les patrons implicites ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "édition de liens %<extern \"C\"%> démarrée ici"
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "le membre de données %qD ne peut pas être un patron membre"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "déclaration de patron membre %qD invalide"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "spécialisation explicite dans la portée d'un non espace de noms %qD"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "les patrons de classe englobants ne sont pas explicitement spécialisés"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la spécialisation de %qD doit apparaître dans la portée de l'espace de noms"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spécialisation de %qD dans différents espaces de noms"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  à partir de la définition de %q#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciation explicite de %qD dans l'espace de noms %qD (qui n'englobe pas l'espace de noms %qD)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "le nom de la classe masque le paramètre de patron %qD qui est lui-même un patron"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "spécialisation du patron d'alias %qD"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spécialisation explicite du non patron %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spécialisation de %qT après instanciation"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "spécialisation de %q#T dans différents espaces de noms"
@@ -46348,88 +46519,88 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spécialisation de %qT après instanciation %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "la spécialisation du patron de %qD n'est pas permise par le C++ ISO"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spécialisation de %qD après instanciation"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD n'est pas un patron de fonction"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD n'est pas un patron de variable"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD pour %q+D ne concorde avec aucune déclaration de patron"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "on a vu %d %<template<>%>, on a besoin de %d pour spécialiser un patron de fonction membre"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spécialisation de patron %qD ambiguë pour %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "les patrons de variables sont uniquement disponibles avec -std=c++14 ou -std=gnu++14"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "trop d'en-têtes de patrons pour %qD (devrait être %d)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "des membres d'une classe spécialisée explicitement sont définis sans en-tête de patron"
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "une spécialisation explicite de %qD en dehors de son espace de noms doit utiliser un spécificateur de nom imbriqué"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "une instanciation explicite de %qD en dehors de son espace de noms doit utiliser un spécificateur de nom imbriqué"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "il pourrait manquer des attributs dans la spécialisation explicite de %q#D"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "attributs de patron principal %s manquant"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "attribut de patron principal %s manquant"
@@ -46436,57 +46607,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id %qD dans la déclaration de patron primaire"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "liste de paramètres de patron utilisée dans une instanciation explicite"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "définition fournie pour une instanciation explicite"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "trop de listes de paramètres de patron dans la déclaration de %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "trop peu de listes de paramètres de patron dans la déclaration de %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la spécialisation explicite de %qD doit être introduite par %<template <>%>"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "la spécialisation explicite doit être déclarée %<concept%>"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "la spécialisation partielle du non type %qD n'est pas permise"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "la spécialisation partielle de la non variable ou non classe %qD n'est pas permise"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argument par défaut spécifié dans la spécialisation explicite"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD n'est pas un patron de fonction"
@@ -46499,137 +46670,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spécialisation d'une fonction membre spéciale déclarée implicitement"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "pas de fonction membre %qD déclarée dans %qT"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "la déclaration amie %qD n'est pas visible par la spécialisation explicite"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "déclaration amie ici"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "spécialisation explicite du concept de fonction %qD"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "l'argument de __integer_pack doit être compris entre 0 et %d"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "l'expansion de l'initialisation de base %qT ne contient pas de paquet de paramètres"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "le motif d'expansion %qT ne contient pas de paquet d'arguments"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "le motif d'expansion %qE ne contient pas de paquet d'arguments"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "les paquets de paramètres ne sont pas étendus avec %<...%>"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonyme>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la déclaration du paramètre de patron %q+D masque le paramètre de patron"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la déclaration de %q+#D masque un paramètre de patron"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "le paramètre de patron %qD est déclaré ici"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "spécialisation du concept de variable %q#D"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "les paramètres du patron ne peuvent pas être déduits dans la spécialisation partielle:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron et n'a pas plus de contrainte que le patron primaire; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "le patron primaire ici"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "la spécialisation partielle n'est pas plus spécialisée que le patron primaire car elle remplace des paramètres multiples par une expansion d'un paquet"
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la spécialisation partielle de %qD n'est pas plus spécialisée que"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "le patron primaire %qD"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "l'argument %qE du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "l'argument %qT du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "l'argument %qE du patron implique des paramètres du patron"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46636,17 +46807,17 @@
 msgstr[0] "le type %qT de l'argument %qE du patron dépend d'un paramètre du patron"
 msgstr[1] "le type %qT de l'argument %qE du patron dépend de paramètres du patron"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "la déclaration de %qD rend ambigüe l'instanciation précédente du patron pour %qD"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spécialisation partielle de %qD après l'instanciation de %qD"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "pas d'argument par défaut pour %qD"
@@ -46654,47 +46825,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "le paquet de paramètres %q+D doit être à la fin de la liste des paramètres du patron"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans la redéclaration d'un ami d'un patron d'une fonction"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans les déclarations d'un ami d'un patron"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des patrons de fonctions sans -std=c++11 ou -std=gnu++11"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des spécialisations partielles"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argument par défaut pour le paramètre de patron pour la classe englobant %qD"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "patron %qD déclaré"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "patron de classe sans nom"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (virt-specifier)"
@@ -46704,57 +46875,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "déclaration de patron %qD invalide"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "définition de patron d'un non patron %q#D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "on attendait %d niveaux de paramètres du patron pour %q#D mais on en a obtenu %d"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "a obtenu %d paramètres de patron pour %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "a obtenu %d paramètres de patron pour %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mais %d son requis"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "les arguments du patron %qD ne correspondent pas à ceux du patron original %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilisez %<template<>%> pour une spécialisation explicite"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT n'est pas un type de patron"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "spécificateurs de patron pas spécifiés dans la déclaration de %qD"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46761,7 +46932,7 @@
 msgstr[0] "redéclaré avec %d paramètre dans le patron"
 msgstr[1] "redéclaré avec %d paramètres dans le patron"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46768,12 +46939,12 @@
 msgstr[0] "la déclaration précédente %qD utilisait %d paramètre dans le patron"
 msgstr[1] "la déclaration précédente %qD utilisait %d paramètres dans le patron"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "paramètre %q+#D du patron"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redéclaré ici comme %q#D"
@@ -46782,117 +46953,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redéfinition de l'argument par défaut pour %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la définition originale apparaît ici"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "redéclaration de %q#D avec des contraintes différentes"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "la déclaration originale apparaît ici"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE n'est pas un argument de patron valide pour le type %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "il doit être le nom d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison externe"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "il doit être un pointeur vers un membre de la forme %<&X::Y%>"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "car il est un membre de %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  n'a pu déduire le paramètre %qD du patron"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  les types %qT et %qT ont des qualificatifs CV incompatibles"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  types %qT et %qT non concordants"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  le paramètre %qD du patron n'est pas un paquet de paramètres mais l'argument %qD en est un"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  l'argument %qE du patron ne correspond pas à la constante %qE qui est un pointeur vers un membre"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE n'est pas équivalent à %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  déduction du paquet de paramètres inconsistante entre %qT et %qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  types déduits conflictuels pour le paramètre %qT (%qT et %qT)"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  valeurs déduites conflictuelles pour le paramètre non type %qE (%qE et %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  le type tableau %qT dimensionné par une variable n'est pas un argument de patron valable"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  le type fonction membre %qT n'est pas un argument de patron valable"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46899,287 +47070,293 @@
 msgstr[0] "  le candidat attend au moins %d argument, %d fourni(s)"
 msgstr[1] "  le candidat attend au moins %d arguments, %d fourni(s)"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  ne peut convertir %qE (type %qT) vers le type %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT est une classe de base ambigüe de %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT n'est pas dérivé de %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  les paramètres du patron d'un argument de patron qui est lui-même un patron sont inconsistants avec les autres arguments déduits pour le patron"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  impossible de déduire un patron pour %qT depuis le type non patron %qT"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  l'argument de patron %qE ne correspond pas à %qE"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car les chaînes littérales ne peuvent jamais être utilisées dans ce contexte"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "dans l'argument de patron pour le type %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "l'argument de patron %qE pour le type %qT n'est pas un entier constant"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD n'est pas un argument de patron valable car %qD est une variable, pas une adresse d'une variable"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE n'est pas un argument de patron valable pour %qT car ce n'est pas l'adresse d'une variable"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qE n'est pas une variable"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable de type %qT car %qD n'a pas une classe de liaison externe"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "l'adresse du sous-objet %qT de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable car elle n'a pas une durée de stockage statique"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT à cause de conflits dans les qualificatifs CV"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas une l-valeur"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D n'est pas un argument de patron valable pour le type %qT car une variable de référence n'a pas une adresse constante"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas un objet avec une classe de liaison"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car l'objet %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est un pointeur"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "essayez d'utiliser %qE à la place"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est du type %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "les attributs sur l'argument %qT du patron sont ignorés"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "les attributs dans l'argument %qE du patron sont ignorés"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nom de classe injecté %qD utilisé comme argument de patron qui est lui-même un patron"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "utilisation invalide du destructeur %qE comme un type"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour faire référence à un membre type d'un paramètre de patron, utilisez %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  on attendait une constante de type %qT, on a obtenu %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  on attendait un patron de classe, on a obtenu %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  on attendait un type, on a obtenu %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  on attendait un type, on a obtenu %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  on attendait un patron de classe, on a obtenu %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  on attendait un patron de type %qD, on a obtenu %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "désaccord de contrainte à l'argument %d dans la liste des paramètres du patron pour %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  on attendait %qD, on a obtenu %qD"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "impossible de convertir l'argument %qE du patron de %qT vers %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "l'argument %d du patron est invalide"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être au moins %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "fournis pour %qD"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du patron d'alias %qD"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du concept %qD"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "ainsi, toute instanciation avec un paquet de paramètres non vide serait mal formée"
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D n'est pas un patron de fonction"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "type non patron %qT utilisé comme un patron"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "échec de la contrainte du patron"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "utilisation du patron de variable invalide %qE"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum qui est %d (utilisez -ftemplate-depth= pour augmenter le maximum)"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "tableau flexible comme membre de l'union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "repli de l'expansion vide sur %O"
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qT"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qE"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  lors de l'instanciation de l'argument par défaut pour l'appel à %qD"
@@ -47197,276 +47374,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD a un type fonction"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "type de paramètre %qT invalide"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fonction retournant un tableau"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointer vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "la spécification d'exception %qD dépend d'elle-même"
@@ -47478,106 +47655,112 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez -ftemplate-depth= pour augmenter le maximum)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "le mot-clé %<template%> n'est pas permis dans declarator-id"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert %<#include <initializer_list>%>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "le patron non classe %qT est utilisé sans arguments de patron"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "impossible de déduire les arguments du patron de %qT car il n'a pas de guides de déduction viables"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les indications de contraintes ne sont pas satisfaites"
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les indications de contraintes"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of %<auto%> in template argument"
+msgid "invalid use of %qT in template argument"
+msgstr "utilisation invalide de %<auto%> dans un argument de patron"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -47780,7 +47963,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "étendue de qualification invalide dans le nom du pseudo-destructeur"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne concorde pas avec le nom du destructeur ~%qT"
@@ -47830,7 +48013,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
@@ -47902,294 +48085,296 @@
 msgstr "%qT n'est pas un type énuméré"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Le paquet de paramètres __bases est uniquement valable dans la déclaration d'un patron"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "impossible d'appliquer %<offsetof%> au destructeur %<~%T%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr "le deuxième opérande de %<offsetof%> n'est ni un simple identificateur ni une séquence d'accès aux membres et de références de tableaux"
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "impossible d'appliquer %<offsetof%> à la fonction membre %qD"
+
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "impossible d'appliquer %<offsetof%> à un énumérateur %qD"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "l'utilisation de offsetof à l'intérieur du type %qT (qui ne respecte pas l'agencement standard) est indéfini"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> est autorisé dans OpenMP uniquement dans les clauses %<declare simd%>"
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la recherche de la réduction définie par l'utilisateur est ambiguë"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE a le type const pour %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "réduction définie par l'utilisateur avec une initialisation du constructeur pour la classe de base %qT"
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "la clause linéaire avec le modificateur %qs est appliquée à la variable non référence ayant le type %qT"
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "clause linéaire appliquée à la variable non entière non pointeur ayant le type %qT"
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "l'expression du pas de « linear » doit être un entier"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "l'expression statique %<gang%> doit être un entier"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "la valeur statique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "l'expression numérique de %<gang%> doit être un entier"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "l'expression de longueur de %<vector%> doit être un entier"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "l'expression numérique de %<worker%> doit être un entier"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "la valeur numérique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "la valeur de longueur de %<vector%> doit être positive"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "la valeur numérique de %<worker%> doit être positive"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "l'expression de taille des tranches d'ordonnancement doit être un entier"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "l'expression de longueur de %qs doit être un entier"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "l'expression de longueur %qs doit être une expression entière constante positive"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "l'expression de %<async%> doit être un entier"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "l'expression de %<thread_limit%> doit être un entier"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "l'identifiant de %<device%> doit être entier"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "l'expression de la taille des tranches de %<dist_schedule%> doit être un entier"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<aligned%>"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau ni une référence vers un pointeur ou un tableau"
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<aligned%>"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "l'expression d'alignement de la clause %<aligned%> doit être un entier"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<depend%>"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "patron %qE dans la clause %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "nom de fonction surchargée %qE dans la clause %qs"
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "l'expression de %<grainsize%> doit être un entier"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "l'expression de %<priority%> doit être un entier"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "l'expression de %<num_tasks%> doit être un entier"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau ni une référence à un pointeur ou un tableau"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "l'argument de %<tile%> doit être de type entier"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD n'est pas un fichier, un espace de noms ou une variable déclarée dans un bloc"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directive %<threadprivate%> %qE n'est pas dans la définition de %qT"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la différence entre %qE et %qD n'est pas un type entier"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> utilisé avec la variable d'itération de classe %qE"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> utilise deux expressions différentes pour la mémoire"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "l'assertion statique a échoué"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "l'assertion statique a échoué: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condition non constante pour l'assertion statique"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "l'argument de decltype doit être une expression"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype ne sait pas résoudre l'adresse d'une fonction surchargée"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
@@ -48314,12 +48499,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribut %qE appliqué à la déclaration extern \"C\" %qD"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "zéro comme constante de pointeur nul"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "vérification lang_* : échec dans %s, à %s:%d"
@@ -48379,726 +48564,722 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "nœud de type canonique identique pour les types différents %qT et %qT"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "application invalide de %qs à une fonction membre"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "application invalide de %<sizeof%> sur un champ de bits"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<sizeof%> à une expression d'un type de fonction"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "application invalide de %<__alignof%> sur un champ de bits"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<__alignof%> à une expression d'un type de fonction"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "l'argument de %<alignas%> a le type non entier %qT"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "utilisation invalide de la fonction membre non statique de type %qT"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "prise de l'adresse d'un tableau temporaire"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "le C++ ISO interdit la conversion d'une chaîne constante vers %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversion obsolète de la chaîne constante vers %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "requête du membre %qD dans %qE, lequel est le type pointeur %qT (vous avez peut-être oublié d'utiliser %<->%> ?)"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "requête du membre %qD dans %qE, lequel est de type non classe %qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "utilisation invalide du membre de donnée non statique %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "accès invalide au membre de donnée non statique %qD dans la base virtuelle d'un objet NULL"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "l'objet de type %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "le type devant être détruit est %qT, mais le destructeur réfère à %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "le champ %q#D peut être accessible via %q#D"
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> n'est pas un membre de %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT n'est pas une base de %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %qE ?"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T n'a pas de membre nommé %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD n'est pas une fonction patron membre"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT n'est pas un type pointeur vers un objet"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "utilisation invalide de l'indexation de tableau sur un pointeur vers un membre"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "utilisation invalide du %<*%> unaire sur un pointeur vers un membre"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "utilisation invalide de la conversion implicite d'un pointeur vers un membre"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "l'opérande de gauche de %<->*%> doit être un pointeur vers une classe mais il est un pointeur vers un membre du type %qT"
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indice manquant dans la référence du tableau"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "l'accès indicé du tableau est déclaré %<register%>"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "la valeur indicée n'est ni un tableau ni un pointeur"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objet manquant dans l'usage de %qE"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "impossible d'appeler la fonction %qD"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "le C++ ISO interdit l'appel de %<::main%> depuis l'intérieur du programme"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "il faut utiliser %<.*%> ou %<->*%> pour appeler une fonction via un pointeur vers un membre dans %<%E (...)%>, par ex: %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "l'expression ne peut pas être utilisée comme une fonction"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "trop d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "pas assez d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "trop d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "trop peu d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "trop d'arguments pour la fonction %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "trop peu d'arguments pour la fonction %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "trop d'arguments pour la méthode %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "pas assez d'arguments pour la méthode %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "le paramètre %P de %qD a un type incomplet %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "le paramètre %P a un type incomplet %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "le compilateur peut supposer que l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "suppose un transtypage vers le type %qT depuis la fonction surchargée"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL utilisé en arithmétique"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "le compteur de rotations vers la gauche est négatif"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "le compteur de rotations vers la droite est négatif"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "le compteur de rotations vers la gauche >= largeur du type"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "le compteur de rotations vers la droite >= largeur du type"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "le C++ ISO interdit la comparaison entre un pointeur et un entier"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "les types des opérandes sont %qT et %qT"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "comparaison non ordonnée sur un argument n'étant pas en virgule flottante"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversion implicite de %qH vers %qI pour correspondre à d'autres opérandes de l'expression binaire"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "les opérandes des types %qT et %qT sont invalides pour le %qO binaire"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur de type %<void *%> dans une soustraction"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une fonction dans une soustraction"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une méthode dans une soustraction"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "utilisation invalide d'un pointeur vers un type incomplet dans un pointeur arithmétique"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "utilisation invalide de %qE pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  un qualified-id est requis"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "les parenthèses autour de %qE ne peuvent pas être utilisées pour former un pointeur vers une fonction membre"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre non statique non qualifié ou entre parenthèses pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre liée pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "prise de l'adresse du temporaire"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "prise de l'adresse d'une x-valeur (référence à une r-valeur)"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "le C++ ISO interdit de prendre l'adresse de la fonction %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ne peut créer un pointeur vers le membre de référence %qD"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "tentative de prendre l'adresse d'un champ de bits"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr "%<~%> sur une expression de type booléen"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "vouliez-vous utiliser le non logique (%<!%>) ?"
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "le C++ ISO interdit d'incrémenter un enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "le C++ ISO interdit de décrémenter un enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ne peut incrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ne peut décrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit d'incrémenter un pointeur du type %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit de décrémenter un pointeur du type %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator--%> est interdite"
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est interdite en C++17"
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est dépréciée"
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ne peut prendre l'adresse de %<this%> qui est une expression r-valeur"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adresse de la variable registre explicite %qD requise"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse requise pour %qD qui est déclaré %<register%>"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "une initialisation par liste pour un type non classe ne doit pas être entre parenthèses"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation mémoire"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "la liste d'expressions est traitée comme une expression composée dans le transtypage fonctionnel"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "la liste d'expressions dans « %s » est traitée comme une expression composée"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "pas de contexte pour résoudre le type de %qE"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "le transtypage du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser « static_cast » pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser « reinterpret_cast » pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "transtypage inutile vers le type %q#T"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "les qualificatifs de type sont ignorés sur le type résultant du transtypage"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "« static_cast » invalide depuis le type %qT vers le type %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 msgid "converting from %qH to %qI"
 msgstr "conversion de %qH vers %qI"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "transtypage invalide d'une expression r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr "le transtypage de %qH vers %qI perd en précision"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "transtypage entre types de fonctions incompatibles de %qH vers %qI"
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "transtypage entre des pointeurs incompatibles vers des types membres de %qH vers %qI"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "le transtypage de %qH vers %qI augmente l'alignement requis pour le type ciblé"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "le transtypage entre un pointeur vers une fonction et un pointeur vers un objet est supporté conditionnellement"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "transtypage invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "utilisation invalide de const_cast avec le type %qT qui n'est pas un pointeur, une référence, ni un type pointeur vers une donnée membre"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "utilisation invalide de const_cast avec le type %qT qui est un pointeur ou une référence à un type fonction"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "const_cast invalide d'une r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "const_cast invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "le C++ ISO interdit le transtypage vers un type tableau %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "transtypage invalide vers le type fonction %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  lors de l'évaluation de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "affectation à un tableau depuis une liste d'initialisation"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "types incompatibles dans l'affectation de %qT vers %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "tableau utilisé comme initialisation"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "affectation de tableau invalide"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dans la conversion d'un pointeur vers une fonction membre"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "conversion d'un pointeur vers un membre via la base virtuelle %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dans la conversion d'un pointeur vers un membre"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversion invalide vers le type %qT à partir du type %qT"
 
-#: cp/typeck.c:8786
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "ne peut convertir %qH en %qI pour l'argument %qP de %qD"
+#: cp/typeck.c:8812 cp/typeck.c:8829
+msgid "cannot convert %qH to %qI"
+msgstr "ne peut convertir %qH en %qI"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ne peut convertir %qH en %qI dans l'argument par défaut"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ne peut convertir %qH en %qI dans le passage d'argument"
 
-#: cp/typeck.c:8800
-msgid "cannot convert %qH to %qI"
-msgstr "ne peut convertir %qH en %qI"
-
-#: cp/typeck.c:8804
+#: cp/typeck.c:8833
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ne peut convertir %qH en %qI dans l'initialisation"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 msgid "cannot convert %qH to %qI in return"
 msgstr "ne peut convertir %qH en %qI dans le retour"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ne peut convertir %qH en %qI dans l'affectation"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "le type classe %qT est incomplet"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "le paramètre %qP de %qD pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "le paramètre pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "la cible de la conversion pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "la cible de l'initialisation pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "dans le passage de l'argument %P de %qD"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "retourne une référence vers un temporaire"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "référence vers une non l-valeur retournée"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "référence vers la variable locale %qD retournée"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adresse de l'étiquette %qD retournée"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adresse de la variable locale %qD retournée"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "retourne une valeur depuis un destructeur"
@@ -49105,55 +49286,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "ne peut retourner depuis le gestionnaire d'un try..catch sur tout le constructeur"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "retourne une valeur depuis un constructeur"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "instruction « return » sans valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "liste d'initialisation retournée"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "les types incohérents %qT et %qT sont déduits du type retourné par la lambda"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "déduction incohérente pour le type de retour auto: %qT et puis %qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "instruction « return » avec une valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> ne doit pas retourner NULL à moins qu'il soit déclaré %<throw()%> (ou -fcheck-new est actif)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "utilisation d'un temporaire comme l-valeur"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "utilisation d'une x-valeur (référence à une r-valeur) comme l-valeur"
@@ -49374,140 +49555,140 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "syntaxe de constructeur utilisée mais aucun constructeur déclaré pour le type %qT"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "la conversion réductrice de %qE depuis %qH vers %qI à l'intérieur de { } est mal formée en C++11"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "conversion réductrice de %qE depuis %qH vers %qI à l'intérieur de { }"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "l'expression a une valeur constante mais elle n'est pas une expression constante du C++"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "tableau d'entiers initialisé à l'aide d'une chaîne non-large"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "tableau d'entiers initialisé à l'aide d'une chaîne large incompatible"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "la chaîne d'initialisation est trop longue pour le tableau de caractères"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "impossible d'initialiser l'agrégat du type %qT avec un littéral composé"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initialisation manquante pour le membre %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "le membre %qD est une référence non initialisée"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre %qD avec des champs de référence non initialisés"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "l'ordre du désignateur pour le champ %qD ne correspond pas à l'ordre de la déclaration dans %qT"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ %qD trouvé dans l'union initialisée"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur d'index au lieu d'un nom de champ dans l'initialisation de l'union"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détectée"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de %<->%> a un type non pointeur %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "le résultat de %<operator->()%> est un non pointeur"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de %<->%> n'est pas un pointeur"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE ne peut pas être utilisé comme pointeur de membre puisqu'il est de type %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer le pointeur membre %qE à %qE lequel est d'un type non classe %qT"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "le pointeur vers le type membre %qT est incompatible avec le type d'objet %qT"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une r-valeur"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur avant C++2a"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "transtypage fonctionnel vers le type tableau %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "impossible de déduire les arguments du patron pour %qT depuis ()"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "l'initialisation par valeur du type référence est invalide"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "appel à la fonction %qD qui génère une exception du type incomplet %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "appel à une fonction qui génère une exception du type incomplet %q#T"
@@ -49932,48 +50113,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr "La valeur du constructeur du tableau à %L ne sera point polymorphique sans limite [F2008: C4106]"
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Longueurs de CHARACTER différentes (%ld/%ld) dans le constructeur du tableau à %L"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr "spec_dimen_size(): Mauvaise dimension"
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr "gfc_ref_dimen_size(): Mauvaise dimension"
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Mauvaise dimension de tableau à %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr "Erreur de simplification"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr "gfc_ref_dimen_size(): Mauvais dimen_type"
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr "gfc_array_dimen_size(): Mauvaise dimension"
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr "gfc_array_dimen_size(): Mauvaise expression EXPR_ARRAY"
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr "gfc_find_array_ref(): Pas de référence trouvée"
@@ -50968,7 +51149,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Niveau d'extension maximum atteint avec le type %qs à %L"
@@ -51138,7 +51319,7 @@
 msgid "deferred type parameter at %C"
 msgstr "paramètre de type différé à %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Expression INTEGER scalaire attendue à %L"
@@ -51388,449 +51569,449 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Tableau de forme explicite avec des limites non constantes à %C"
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs à %C est une redéfinition de la déclaration dans l'interface correspondante pour MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "L'entité %qs ne peut pas avoir un initialiseur à %C"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Spécificateur de tableau dupliqué pour le pointé de type Cray à %C"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Impossible de définir la spécification du tableau pointé"
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisation dans l'ancien style à %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Initialisation dans l'ancien style invalide pour le composant de type dérivé à %C"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Erreur de syntaxe dans l'initialisation de %s dans l'ancien style à %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "L'initialisation à %C n'est pas pour une variable pointeur"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "L'initialisation du pointeur à %C requiert %<=>%> et non %<=%>"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Une expression d'initialisation est attendue à %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "L'initialisation de la variable à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "L'initialisation du composant allouable à %C n'est pas permise"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Le composant avec l'attribut KIND ou LEN à %C n'apparaît pas dans la liste des paramètres de type à %L"
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Le composant à %C qui apparaît dans la liste des paramètres de types à %L n'a ni l'attribut KIND ni l'attribut LEN"
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Le composant à %C, qui est un paramètre de type, doit être un scalaire"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "La déclaration du type %s*%d dans l'ancien style n'est pas supportée à %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Déclaration du type non standard %s*%d à %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Parenthèse droite manquante à %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Expression d'initialisation attendue à %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Expression d'initialisation d'un scalaire attendue à %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Le sous-type %d n'est pas supporté pour le type %s à %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Le paramètre d'un type du sous-type C est pour le type %s mais le type à %L est %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Parenthèse droite ou virgule manquante à %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Le sous-type %d n'est pas supporté pour CHARACTER à %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration CHARACTER à %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr "RECORD à %C est une extension, activez-la avec -fdec-structure"
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Nom de structure attendu après RECORD à %C"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "La liste de spec des paramètres de type à %C ne peut pas contenir les paramètres ASSUMED et DEFERRED en même temps"
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "La liste de spec des paramètres de types à %C ne contient pas assez d'expressions de paramètres"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Le paramètre dérivé %qs à %C n'a pas de valeur par défaut"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "L'expression paramètre à %C doit être de type INTEGER et non de type %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "Le paramètre KIND %qs à %C ne peut pas être ASSUMED ou DEFERRED"
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "La valeur pour le paramètre KIND à %qs à %C ne se réduit pas en une expression constante"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "La liste de spec des paramètres de type à %C contient trop d'expressions de paramètres"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Le type dérivé paramétrisé à %C est ambigu"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "Type BYTE à %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Le type BYTE utilisé à %C n'est pas disponible sur la machine cible"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Le type tacite à %C n'est pas autorisé pour des composants"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Type tacite à %C"
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE avec une spécification de type intrinsèque à %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX à %C"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Le nom de type %qs à %C est ambigu"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Instruction CLASS à %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Le nom du type %qs à %C est en conflit avec l'entité précédemment déclarée à %L qui a le même nom"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Instruction IMPLCIT NONE dupliquée à %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE avec une liste de spécifications à %C"
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Plage de caractères manquante dans IMPLICIT à %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Les lettres doivent être dans l'ordre alphabétique dans l'instruction IMPLICIT à %C"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "L'instruction IMPLICIT à %C suit une instruction IMPLICIT NONE (type)"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Instruction IMPLICIT vide à %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "L'instruction IMPORT à %C est uniquement permise dans un corps d'INTERFACE"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: l'instruction IMPORT C1210 à %C n'est pas permise dans le corps d'interface d'une procédure d'un module"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Instruction IMPORT à %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste d'entités nommées attendue à %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Impossible d'utiliser IMPORT %qs depuis l'unité dans la portée de l'hôte à %C – n'existe pas."
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs est déjà IMPORTé depuis l'unité dans la portée de l'hôte à %C"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction IMPORT à %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Spécification de co-dimension manquante à %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Spécification de dimension manquante à %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Attribut %s dupliqué à %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s à %L est une extension DEC, activez-la avec %<-fdec-static%>"
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE à %C dans une définition TYPE"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attribut KIND à %C dans une définition TYPE"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Le composant avec l'attribut KIND à %C doit être un INTEGER"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Le composant avec l'attribut KIND à %C doit être du sous-type entier par défaut (%d)"
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Attribut LEN à %C dans une définition TYPE"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Le composant avec l'attribut LEN à %C doit être un INTEGER"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Le composant avec l'attribut LEN à %C doit être du sous-type entier par défaut (%d)"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "L'attribut à %L n'est pas permis dans une définition TYPE"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s à %L dans une définition TYPE"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "L'attribut %s à %L n'est pas permis en dehors de la partie de la spécification d'un module"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "L'attribut à %L n'est pas permis en dehors d'une définition TYPE"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attribut ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attribut CONTIGUOUS à %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED à %C est uniquement autorisé dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attribut PROTECTED à %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attribut VALUE à %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attribut VOLATILE à %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Mauvais attribut"
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Identificateurs multiples fournis avec un seul spécificateur NAME= à %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La déclaration implicite de la fonction BIND(C) %qs à %L pourrait ne pas être interopérable avec le C"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable %qs dans le bloc commun %qs à %L ne peut pas être un sous-type interopérable avec le C bien que le bloc commun %qs est BIND(C)"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La déclaration de type %qs à %L n'est pas interopérable avec le C mais elle est BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable %qs à %L peut ne pas être d'un sous-type interopérable avec le C mais elle est BIND(C)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable %qs dans le bloc commun %qs à %L ne peut pas être déclarée avec BIND(C) puisqu'elle n'est pas globale"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable %qs à %L ne peut pas avoir les attributs POINTER et BIND(c) en même temps"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable %qs à %L ne peut pas avoir les attributs ALLOCATABLE et BIND(C) en même temps"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Le type de retour de la fonction BIND(C) %qs à %L ne peut pas être un tableau"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Le type de retour de la fonction BIND(C) %qs à %L ne peut pas être une chaîne de caractères"
@@ -51837,951 +52018,951 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Le symbole %qs à %L est marqué PRIVATE mais il a reçu l'étiquette de liaison %qs"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "L'instruction de spécification d'attribut a besoin de soit un nom d'entité ou soit un nom de bloc commun à %C"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Il manque le nom d'entité ou le nom de bloc commun pour l'instruction de spécification d'attribut à %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbole manquant"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Instruction BIND(C) à %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Le type dérivé à %C n'a pas été précédemment défini et, par conséquent, il ne peut pas apparaître dans une définition de type dérivé"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration de la structure anonyme à %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration de donnée à %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Préfixe de MODULE à %C"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Procédure IMPURE à %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE et IMPURE ne peuvent pas apparaître ensemble à %C"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe ELEMENTAL dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe PURE dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe RECURSIVE dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Argument de retour alternatif à %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Un nom de paramètre est requis à %C"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Le nom %qs à %C est le nom de la procédure"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Liste de paramètres attendue dans la déclaration du type à %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Rebut inattendu dans la liste d'arguments formels à %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Nom %qs en double dans la liste des paramètres à %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Symbole %qs dupliqué dans la liste d'arguments formels à %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Désaccord dans les noms des arguments formels de MODULE PROCEDURE (%s/%s) à %C"
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Désaccord dans le nombre d'arguments formels de MODULE PROCEDURE à %C"
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT à %C doit être différente du nom de la fonction"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Rebut inattendu après la déclaration de la fonction à %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "L'attribut BIND(C) à %L ne peut pas être spécifié pour une procédure interne"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "L'attribut BIND(C) à %C requiert une interface avec BIND(C)"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "La procédure BIND(C) avec NAME ne peut pas avoir l'attribut POINTER à %C"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "La procédure muette à %C ne peut pas avoir d'attribut BIND(C) avec NAME"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "La procédure %qs à %L a déjà le type de base de %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction PROCEDURE à %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> attendu après les attributs de liaison à %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS ou interface explicite requise à %C"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Erreur de syntaxe dans un composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE à %C doit être une interface générique"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "double : dans l'instruction MODULE PROCEDURE à %L"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Instruction PROCEDURE à %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Liste d'arguments formels attendue dans la définition de la fonction à %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "L'attribut BIND(C) à %L peut uniquement être utilisé pour des variables ou des blocs communs"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Instruction ENTRY à %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un PROGRAM"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un MODULE"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un SUBMODULE"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "L'instruction ENTRY à %C ne peut apparaître dans un BLOCK DATA"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une INTERFACE"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc STRUCTURE"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc DERIVED TYPE"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc IF-THEN"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc DO"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc SELECT"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc FORALL"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc WHERE"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un sous programme contenu"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Instruction ENTRY inattendue à %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une procédure contenue"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Parenthèse requise manquante avant BIND(C) à %C"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Identificateur C invalide dans le spécificateur NAME= à %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Erreur de syntaxe dans le spécificateur NAME= pour l'étiquette de liaison à %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Le spécificateur NAME= à %C devrait être une expression constante"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "Le spécificateur NAME= à %C devrait être un scalaire du sous-type de caractère par défaut"
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Parenthèse fermante manquante pour l'étiquette de liaison à %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Le nom de liaison n'est pas permis dans BIND(C) à %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Pour la procédure muette %s, aucun nom de liaison est autorisé dans BIND(C) à %C"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME pas autorisé sur BIND(C) pour ABSTRACT INTERFACE à %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Instruction END inattendue à %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Instruction END au lieu de l'instruction %s à %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Instruction %s attendue à %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "On attendait l'instruction %s à %L"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "On attendait le nom du bloc de %qs dans l'instruction %s à %L"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "On attendait un nom de terminaison à %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "On attendait l'étiquette %qs pour l'instruction %s à %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Spécification de tableau manquante à %L dans l'instruction DIMENSION"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensions spécifiées pour %s à %L après son initialisation"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Spécification de tableau manquante à %L dans l'instruction CODIMENSION"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La spécification de tableau doit être différée à %L"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Caractère inattendu dans la liste de variable à %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> attendu à %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Nom de variable attendu à %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Le pointeur Cray à %C doit être un entier"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Le pointeur Cray à %C a %d octets de précision; les adresses mémoire requièrent %d octets"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "« , » attendu à %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "N'a pu définir la spécification de tableau dans le pointé de type Cray"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "« ) » attendue à %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> ou fin d'instruction attendue à %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT n'est pas permis à l'intérieur de BLOCK à %C"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL n'est pas permis à l'intérieur du BLOCK à %C"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "La déclaration de pointeur Cray à %C requiert l'option -fcray-pointer"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Instruction CONTIGUOUS à %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La spécification d'accès de l'opérateur %s à %C a déjà été spécifiée"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La spécification d'accès de l'opérateur .%s. à %C a déjà été spécifiée"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Instruction PROTECTED à %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction PROTECTED à %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "L'instruction PRIVATE à %C est uniquement permise dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "L'instruction PUBLIC à %C est uniquement permise dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nom de variable attendu à %C dans l'instruction PARAMETER"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Signe = attendu dans l'instruction PARAMETER à %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Expression attendue à %C dans l'instruction PARAMETER"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisation d'une variable déjà initialisée à %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER sans « () » à %C"
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caractères inattendus dans l'instruction PARAMETER à %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s à %C est une extension DEC, activez-la avec %<-fdec-static%>"
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Liste d'entités attendue dans l'instruction AUTOMATIC à %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction AUTOMATIC à %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Liste d'entités attendue dans l'instruction STATIC à %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction STATIC à %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "L'instruction SAVE générale à %C suit une instruction SAVE précédente"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "L'instruction SAVE à %C suit une instruction SAVE générale"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction SAVE à %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE n'est pas autorisé à l'intérieur de BLOCK à %C"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Instruction VALUE à %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction VALUE à %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Instruction VOLATILE à %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Spécification de VOLATILE pour la variable co-tableau %qs à %C qui est associée à use ou à l'hôte"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction VOLATILE à %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Instruction ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Déclaration de MODULE PROCEDURE à %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE à %C doit être dans une interface de module générique"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "La procédure intrinsèque à %L ne peut pas être un MODULE PROCEDURE"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Symbole ambigu dans la définition TYPE à %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Le symbole %qs à %C n'a pas été défini précédemment"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs dans l'expression EXTENDS à %C n'est pas un type dérivé"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs ne peut pas être étendu à %C car il est BIND(C)"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs ne peut pas être étendu à %C car il est un type SEQUENCE"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Le type dérivé à %C peut uniquement être PRIVATE dans la partie de spécification d'un module"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Le type dérivé à %C peut uniquement être PUBLIC dans la partie de spécification d'un module"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Type ABSTRACT à %C"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Échec lors de la création du type structure « %s » à %C"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "La définition du type de %qs à %C a déjà été définie à %L"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Rebut après l'instruction MAP à %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Rebut après l'instruction UNION à %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s à %C est une extension DEC, activez-la avec %<-fdec-structure%>"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Nom de structure attendu dans la déclaration de structure non imbriquée à %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Rebut après l'instruction STRUCTURE non imbriquée à %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Le nom de structure %qs à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: attendu dans la définition de TYPE à %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Le nom de type %qs à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Le nom du type dérivé %qs à %C a déjà le type de base %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La définition du type dérivé %qs à %C a déjà été défini"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Rebut après la déclaration PARAMETERIZED TYPE à %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Le pointé de type Cray à %C ne peut pas être un tableau de forme tacite"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM et ENUMERATOR à %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "L'énumérateur excède le type entier du C à %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L pas initialisé avec une expression entière"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Instruction de définition ENUM attendue avant %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Erreur de syntaxe dans la définition ENUMERATOR à %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Spécificateurs d'accès dupliqués à %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Les attributs de liaison spécifient déjà « PASS », NOPASS illégal à %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Les attributs de liaison spécifient déjà « PASS »; PASS illégal à %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Attribut POINTER dupliqué à %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE dupliqué à %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED dupliqué à %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Spécificateur d'accès attendu à %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Attribut de liaison attendu à %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE et DEFERRED ne peuvent pas apparaître tous les deux à %C"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "L'attribut POINTER est requis pour un composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Nom d'interface attendu après %<(%> à %C"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> attendu à %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Une interface doit être spécifiée pour une liaison DEFERRED à %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) à %C devrait être déclarée DEFERRED"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Nom de liaison attendu à %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Liste PROCEDURE à %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> est invalide pour la liaison DEFERRED à %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> nécessaire dans une liaison PROCEDURE avec une cible explicite à %C"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Cible de liaison attendue après %<=>%> à %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Le type %qs contenant la liaison DEFERRED à %C n'est pas ABSTRACT"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Il y a déjà une procédure avec le nom de liaison %qs pour le type dérivé %qs à %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "Le GENERIC à %C doit être à l'intérieur du type dérivé CONTAINS"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> attendu à %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Nom générique ou descripteur d'opérateur attendu à %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Instruction GENERIC mal formée à %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> attendu à %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Il y a déjà une procédure non générique avec le nom de liaison %qs pour le type dérivé %qs à %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "La liaison à %C doit avoir le même accès que la liaison %qs déjà définie"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Nom de liaison spécifique attendu à %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs est déjà défini comme liaison spécifique pour le %qs générique à %C"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Rebut après la liaison GENERIC à %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La déclaration FINAL à %C doit être à l'intérieur d'une section CONTAINS du type dérivé"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La déclaration de type dérivé avec FINAL à %C doit être dans la partie de spécification d'un MODULE"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vide à %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Nom de procédure de module attendu à %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> attendu à %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nom de procédure %qs inconnu à %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs à %C est déjà défini comme procédure FINAL"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Attribut inconnu dans l'instruction !GCC$ ATTRIBUTES à %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction !GCC$ ATTRIBUTES à %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Directive %<GCC unroll%> requiert une constante entière non négative plus petite ou égale à %u à %C"
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Erreur de syntaxe dans la directive !GCC$ UNROLL à %C"
@@ -53116,27 +53297,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Un littéral BOZ à %L est utilisé pour initialiser la variable non entière %qs"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Littéral BOZ à %L en dehors d'une instruction DATA et en dehors de INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "Le littéral BOZ à %L est le symbole non entier %qs transféré bit à bit"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Débordement arithmétique vers le bas du BOZ transféré bit à bit à %L. Cette vérification peut être désactivée avec l'option %<-fno-range-check%>"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Débordement arithmétique du BOZ transféré bit à bit à %L. Cette vérification peut être désactivée avec l'option %<-fno-range-check%>"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "NaN (pas un nombre) arithmétique du BOZ transféré bit à bit à %L. Cette vérification peut être désactivée avec l'option %<-fno-range-check%>"
@@ -53461,7 +53642,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Création d'un tableau temporaire à %L"
@@ -53471,62 +53652,62 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Suppression de l'appel à la fonction %qs à %L"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "mauvaise expression"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr "mauvais op"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "OP illégal dans optimize_comparison"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "La variable %qs à %L a une valeur non définie à l'intérieur de la boucle commençant à %L comme argument INTENT(OUT) de la sous-routine %qs"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "La variable %qs à %L n'est pas définissable à l'intérieur de la boucle commençant à %L comme argument INTENT(INOUT) de la sous-routine %qs"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la boucle commençant à %L"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la boucle commençant à %L"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "La variable %qs à %L a une valeur non définie à l'intérieur de la boucle commençant à %L comme argument INTENT(OUT) de la fonction %qs"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable %qs à %L n'est pas définissable à l'intérieur de la boucle commençant à %L comme argument INTENT(INOUT) de la fonction %qs"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Le code pour réallouer le tableau allouable à %L sera ajouté"
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr "La transformation en scalaire grâce à DIMEN_RANGE n'est pas implémentée"
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "Interchangeage de boucles à %L"
@@ -53646,12 +53827,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -54841,7 +55022,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
@@ -56276,12 +56457,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP FLUSH à %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr "Redéfinition de %s !$OMP DECLARE REDUCTION prédéfini à %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr "Redéfinition de !$OMP DECLARE REDUCTION prédéfini à %L"
@@ -56521,8 +56702,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "Le paramètre de la clause ORDERED est plus petit que COLLAPSE à %L"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause IF à %L requiert une expression LOGICAL scalaire"
@@ -56564,7 +56745,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Le symbole %qs est présent dans de multiples clauses à %L"
@@ -56906,186 +57087,186 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "Les boucles coalescées %s ne forment pas un espace d'itération rectangulaire à %L"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "boucles coalescées %s imparfaitement imbriquées à %L"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "pas assez de boucle DO pour le %s coalescé à %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "La directive %s ne peut pas être spécifiée dans une région %s à %L"
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$ACC LOOP ne peut pas être DO WHILE ou DO sans contrôle de boucle à %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "La variable d'itération !$ACC LOOP doit être d'un type entier à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "Les boucles %s !$ACC LOOP ne forment pas un espace d'itération rectangulaire à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "Les boucles %s !$ACC LOOP sont imparfaitement imbriquées à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "pas assez de boucles DO pour la boucle %s !$ACC LOOP à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr "La boucle %s !$ACC LOOP dans la région PARALLEL n'autorise pas les arguments %s à %L"
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr "Une boucle parallélisée sur plusieurs « gangs » n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs « gangs » à %L"
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr "Une boucle parallélisée sur plusieurs « gangs » n'est pas permise à l'intérieur d'une boucle parallélisée sur plusieurs « workers » à %L"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr "Une boucle parallélisée sur plusieurs « workers » n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs « workers » à %L"
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Une boucle parallélisée sur plusieurs « workers » n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs vecteurs à %L"
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Une boucle parallélisée sur plusieurs vecteurs n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs vecteurs à %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "La clause SEQ est en conflit avec INDEPENDENT à %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "La clause SEQ est en conflit avec GANG à %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "La clause SEQ est en conflit avec WORKER à %L"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "La clause SEQ est en conflit avec VECTOR à %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "La clause SEQ est en conflit avec AUTO à %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "La clause AUTO est en conflit avec GANG à %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "La clause AUTO est en conflit avec WORKER à %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "La clause AUTO est en conflit avec VECTOR à %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr "Une boucle découpée en blocs ne peut pas être parallélisée sur plusieurs « gangs », « workers » ou vecteurs en même temps à %L"
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE requiert une expression constante à %L"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "L'objet PARAMETER %qs n'est pas permis à %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Les sections de tableaux %qs ne sont pas permises dans !$ACC DECLARE à %L"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr "OMP TARGET UPDATE à %L requiert au moins une clause TO ou FROM"
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr "!$OMP DECLARE SIMD devrait faire référence à la procédure contenante %qs à %L"
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Une variable autre que OMP_PRIV ou OMP_ORIG est utilisée dans la clause INITIALIZER de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Une variable autre que OMP_OUT ou OMP_IN est utilisée dans le combinateur de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr "Opérateur invalide pour !$OMP DECLARE REDUCTION %s à %L"
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr "La longueur de CHARACTER dans !$OMP DECLARE REDUCTION %s n'est pas constante à %L"
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Appel à une sous-routine avec des retours alternatifs dans le combinateur de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Appel à une sous-routine avec des retours alternatifs dans la clause INITIALIZER de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr "Un des arguments effectifs de la sous-routine dans la clause INITIALIZER de !$OMP DECLARE REDUCTION doit être OMP_PRIV à %L"
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr "Clause INITIALIZER manquante pour !$OMP DECLARE REDUCTION du type dérivé sans initialisation par défaut à %L"
@@ -58441,7 +58622,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs à %L semble s'appeler elle-même récursivement. Déclarez là RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "L'étiquette %d référencée à %L n'est jamais définie"
@@ -58551,7 +58732,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT, vouliez-vous employer %qs ?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
@@ -58927,231 +59108,231 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objet co-indexé avec un sous-composant allouable polymorphique à %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "L'objet passé à %L doit être scalaire"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de composant pointeur de procédure à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de procédure liée au type à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "L'objet de base pour l'appel de procédure liée au type NOPASS à %L doit être scalaire"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Aucune liaison spécifique correspondante pour l'appel à GENERIC %qs à %L"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs à %L devrait être une SUBROUTINE"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs à %L devrait être une FUNCTION"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Mauvais type d'expression"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s à %L doit être un scalaire"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s à %L doit être un entier"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s à %L doit être INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "L'expression de pas dans la boucle DO à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "La boucle DO à %L sera exécutée zéro fois"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde"
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde vers le bas"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Le nom d'index FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "L'expression de départ de FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "L'expression de fin de FORALL à %L doit être un INTEGER scalaire"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "L'expression de pas de FORALL à %L doit être un %s scalaire"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "L'expression de pas de FORALL à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "L'index %qs de FORALL ne peut pas apparaître dans une spécification de triplet à %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "L'objet allouable à %L doit être ALLOCATABLE ou un POINTER"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objet allouable co-indexé à %L"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "L'expression source à %L doit être scalaire ou avoir le même rang que l'objet allouable à %L"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "L'expression source à %L et l'objet allouable à %L doivent avoir la même forme"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Le type de l'entité à %L a un type incompatible avec l'expression source à %L"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "L'objet allouable à %L et l'expression source à %L auront le même paramètre de sous-type"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type LOCK_TYPE ni un composant LOCK_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type EVENT_TYPE ni un composant EVENT_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "L'allocation de %s du type de base ABSTRACT à %L requiert une spécification de type ou une expression source"
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "L'allocation de %s à %L avec la spécification de type requiert la même longueur de caractères dans le paramètre que dans la déclaration"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spécification de tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Une spécification de tableau ou une expression SOURCE= avec une valeur tableau est requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spécification de co-tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs ne doit pas apparaître dans la spécification de tableau à %L dans la même instruction ALLOCATE où il est lui-même alloué"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "« * » attendu dans la spécification du co-index dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de co-tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat à %L doit être une variable INTEGER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG à %L est inutile sans la balise STAT"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "La variable errmsg à %L doit être une variable CHARACTER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "L'objet alloué à %L apparaît aussi à %L"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
@@ -59160,232 +59341,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "L'étiquette CASE à %L chevauche l'étiquette CASE à %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "L'expression dans l'instruction CASE à %L doit être du type %s"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "L'expression dans l'instruction CASE à %L doit être du sous-type %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "L'expression dans l'instruction CASE à %L doit être scalaire"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "L'expression de sélection dans le GOTO calculé à %L doit être une expression entière scalaire"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "L'argument de l'instruction SELECT à %L ne peut pas être %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "L'argument de l'expression SELECT à %L doit être une expression scalaire"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "L'expression dans l'instruction CASE à %L n'est pas dans la plage de %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Le DEFAULT CASE à %L ne peut pas être suivi par un second DEFAULT CASE à %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Une plage logique n'est pas permise dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "La valeur logique constante est répétée dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La spécification d'étendue à %L ne peut jamais correspondre à quoi que ce soit"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Le bloc SELECT CASE logique à %L a plus de deux cas"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Le sélecteur à %L ne peut pas NULL()"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Le sélecteur à %L n'a pas de type"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Le nom associé %qs à %L est utilisé comme tableau"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Le sélecteur CLASS à %L a besoin d'un temporaire qui n'est pas encore implémenté"
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Le sélecteur sera polymorphique dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Le sélecteur à %L ne doit pas être co-indexé"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS à %L chevauche TYPE IS à %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Le type dérivé %qs à %L doit être extensible"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Le type dérivé %qs à %L doit être une extension de %qs"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Type intrinsèque %qs inattendu à %L"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La spécification de type à %L doit spécifier que chaque paramètre de type de longueur est tacite"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloc CLASS IS en double dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexte invalide pour l'intrinsèque NULL () à %L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "La procédure DTIO %s à %L doit être récursive"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas être polymorphique à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants POINTER à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants de pointeur de procédure"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants ALLOCATABLE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "L'élément de transfert de données à %L ne peut pas être une référence complète à un tableau de taille tacite"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable verrou à %L doit être un scalaire de type LOCK_TYPE"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable d'événement à %L doit être un scalaire de type EVENT_TYPE"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau ou co-indexé"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau mais pas co-indexé"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "L'argument STAT= à %L doit être une variable INTEGER scalaire"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "L'argument ACQUIRED_LOCK= à %L doit être une variable LOGICAL scalaire"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "L'argument UNTIL_COUNT= à %L doit être une expression INTEGER scalaire"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "L'argument imageset à %L doit être une expression scalaire ou INTEGER de rang 1"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "L'argument imageset à %L doit être entre 1 et num_images()"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "L'instruction à %L n'est pas une instruction cible valable pour l'instruction de branchement à %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Le branchement à %L peut conduire à une boucle infinie"
@@ -59392,12 +59573,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction CRITICAL pour l'étiquette à %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'étiquette à %L"
@@ -59405,107 +59586,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "L'étiquette à %L n'est pas dans le même bloc que l'instruction GOTO à %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Le masque WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "La cible de l'affectation WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Affectation définie par l'utilisateur non ELEMENTAL dans WHERE à %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Instruction non supportée à l'intérieur de WHERE à %L"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Affectation à une variable d'index FORALL à %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Le FORALL avec l'index %qs n'est pas utilisé dans le membre de gauche de l'affectation à %L et, par conséquent, pourrait causer de multiples affectations à cet objet"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Le nom d'index de FORALL à %L doit être une variable scalaire de type entier"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Une construction de boucle FORALL extérieure a déjà un index avec ce nom à %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "La clause WHERE/ELSEWHERE à %L requiert un tableau LOGICAL"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Mauvais type de bloc"
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans l'affectation (%ld/%ld) à %L"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "L'expression co-indexée à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "La variable impure à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Affectation à une variable co-indexée à %L dans une procédure PURE"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "L'affectation à un co-tableau polymorphique à %L n'est pas permise"
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Affectation à une variable polymorphique allouable à %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "L'affectation à une variable polymorphique allouable à %L requiert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable non allouable ne doit pas être polymorphique dans l'affectation intrinsèque à %L – vérifiez qu'il existe une sous-routine spécifique correspondante pour l'opérateur « = »"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable co-indexée ne doit pas avoir un composant ultimement allouable dans l'affectation à %L"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "À FAIRE: la/les affectation(s) liée(s) au type à %L n'ont pas été réalisées car des références multiples à des parties de tableaux apparaîtraient dans des expressions intermédiaires."
@@ -59512,67 +59693,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Affectation à une procédure pointeur à %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Le résultat de la fonction dans le membre de gauche de l'affectation à %L doit avoir l'attribut pointeur."
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Une étiquette cible n'a pas été affectée à la variable %qs à %L"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "L'instruction RETURN alternatif à %L requiert un spécificateur de retour SCALAR-INTEGER"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "L'instruction ASSIGN à %L requiert une variable scalaire INTEGER par défaut"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL invalide à %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "L'instruction IF arithmétique à %L requiert une expression scalaire REAL ou INTEGER"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Pas d'expression dans le DO WHILE"
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condition de sortie de la boucle DO WHILE à %L doit être une expression LOGICAL scalaire"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause de masque FORALL à %L requiert une expression scalaire LOGICAL"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mauvais code d'instruction"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La variable %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
@@ -59579,7 +59760,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L du module %qs"
@@ -59587,57 +59768,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La procédure %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longueur de chaîne à %L est trop grande"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le tableau allouable %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "L'objet scalaire %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le pointeur tableau %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Le tableau %qs à %L ne peut pas avoir une forme différée"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Le type %qs de la variable CLASS %qs à %L n'est pas extensible"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS %qs à %L doit être muette, allouable ou pointeur"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Le type %qs ne peut pas être associé à un hôte à %L car il est bloqué par un objet incompatible du même nom déclaré à %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "SAVE implicite pour la variable module %qs à %L, nécessaire à cause de l'initialisation par défaut"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre de type différé et requiert soit l'attribut POINTER ou ALLOCATABLE"
@@ -59644,627 +59825,627 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Le tableau %qs à %L du module ou du programme principal doit avoir une forme constante"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "L'entité avec une longueur de caractère tacite à %L doit être un argument muet ou un PARAMETER"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs à %L doit avoir une longueur de caractère constante dans ce contexte"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON %qs à %L doit avoir une longueur de caractère constante"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "L'allouable %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "L'externe %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Le muet %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "L'intrinsèque %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Le résultat de fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Le tableau automatique %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s à %L"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La fonction-instruction %qs avec une valeur de caractère à %L doit avoir une longueur constante"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs est d'un type PRIVATE et ne peut pas être un argument muet de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "La procédure %qs dans l'interface PUBLIC %qs à %L prend des arguments muets de %qs qui est PRIVATE"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "L'objet externe %qs à %L ne peut pas avoir d'initialisation"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La fonction ELEMENTAL %qs à %L doit avoir un résultat scalaire"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La fonction-instruction %qs à %L ne peut pas avoir l'attribut pointeur ou allouable"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un tableau"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un pointeur"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être pure"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être récursive"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fonction CHARACTER(*) %qs à %L"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Le pointeur de procédure %qs à %L ne sera point élémental"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "La procédure muette %qs à %L ne sera point élémentale"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable résultat %qs de la fonction à %L de la fonction élémentale %qs n'aura point l'attribut ALLOCATABLE ou POINTER"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut SAVE dans %qs à %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut INTENT dans %qs à %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut RESULT dans %qs à %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "L'attribut EXTERNAL est en conflit avec l'attribut FUNCTION dans %qs à %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Le résultat du pointeur de procédure %qs à %L n'a pas d'attribut pointeur"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut ELEMENTAL entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut PURE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut RECURSIVE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s entre la déclaration MODULE PROCEDURE dans MODULE %qs et la déclaration à %L dans (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "La procédure FINAL %qs à %L n'est pas une SUBROUTINE"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "La procédure FINAL à %L doit avoir exactement un argument"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "L'argument de la procédure FINAL à %L doit être du type %qs"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être un POINTER"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être OPTIONAL"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "La procédure FINAL non scalaire à %L devrait avoir un argument de forme tacite"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "La procédure FINAL %qs déclarée à %L a le même rang (%d) que %qs"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Seules des procédures FINAL tableaux déclarées pour le type dérivé %qs à %L, une scalaire est également suggérée"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs et %qs ne peuvent pas être FUNCTION/SUBROUTINE mixte pour GENERIC %qs à %L"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs et %qs pour GENERIC %qs à %L sont ambigus"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Liaison spécifique %qs non définie comme cible du GENERIC %qs à %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs à %L doit cibler une liaison spécifique, %qs est GENERIC aussi"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs à %L ne peut écraser la liaison spécifique avec le même nom"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "L'opérateur lié au type à %L ne peut pas être NOPASS"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs doit être une procédure de module ou une procédure externe avec une interface explicite à %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "La procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "La procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argument muet passé comme objet non polymorphique de %qs à %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "L'argument muet de type objet passé de %qs à %L doit être scalaire"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être POINTER"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant de %qs"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant hérité de %qs"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Le type dérivé %qs déclaré à %L doit être ABSTRACT car %qs est DEFERRED et pas surchargé"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Le composant co-tableau %qs à %L doit être allouable avec une forme différée"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Le composant %qs à %L ayant TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Le composant %qs à %L avec le composant co-tableau sera un scalaire non pointeur, non allouable"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Le composant %qs à %L a l'attribut CONTIGUOUS mais n'est pas un pointeur de tableau"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Le composant %qs du type BIND(C) à %L doit avoir la longueur un"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Le composant pointeur de procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Le composant pointeur de procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être scalaire"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas avoir l'attribut POINTER"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Le composant %qs de %qs à %L a le même nom qu'une procédure liée au type héritée"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longueur de caractère du composant %qs doit être une expression de spécification constante à %L"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Le composant caractère %qs de %qs à %L avec une longueur différée doit être POINTER ou ALLOCATABLE"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "le composant %qs est un type PRIVATE et ne peut pas être un composant de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Le composant polymorphique %s à %L dans le type %s SEQUENCE ou BIND(C)"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Le composant %s du type SEQUENCE déclaré à %L n'a pas l'attribut SEQUENCE"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Le composant pointeur %qs de %qs à %L est un type qui n'a pas été déclaré"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initialisations conflictuelles dans l'union à %L et %L"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Puisque l'extension du type %qs à %L a un composant co-tableau, le type parent %qs en aura un aussi"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Le type dérivé non extensible %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Le type paramétrisé %qs n'a pas de composant correspondant au paramètre %qs à %L"
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "L'objet %qs à %L a un paramètre LEN différé %qs et n'est ni allouable ni un pointeur"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "L'objet AUTOMATIC %qs à %L ne doit pas avoir l'attribut SAVE ou être une variable déclarée dans le programme principal, un module ou un sous-module(F08/C513)"
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "L'objet %qs à %L avec des paramètres de type ASSUMED doit être fictif ou un sélecteur SELECT TYPE(F08/4.2)"
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Mauvaise spécification pour le tableau de taille tacite à %L"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable BIND(C) %qs à %L doit avoir la longueur un"
@@ -60271,262 +60452,262 @@
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type EVENT_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Mauvaise expression"
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc COMMON à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -60962,7 +61143,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Type inattendu"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Le caractère %qs dans la chaîne à %L ne peut pas être converti en un caractère du sous-type %d"
@@ -61603,18 +61784,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Fonction intrinsèque %qs (%d) non reconnue"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "L'argument %<dim%> de l'intrinsèque %s à %L n'est pas un index de dimension valide"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Désolé, le composant de l'événement du type dérivé à %L n'est pas encore supporté"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "La variable d'événement à %L ne sera point co-indexée"
@@ -61795,178 +61976,178 @@
 msgid "previously defined here as %s"
 msgstr "précédemment défini ici comme %s"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "plusieurs définitions existantes pour %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD a déjà été défini"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "précédemment défini ici"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "%qD viole la règle de la définition unique du C++ "
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "le type de %qD ne correspond pas à la déclaration originale"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "l'alignement de %qD est plus grand que la déclaration originale"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr "la taille de %qD diffère de la taille de la déclaration originale"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "%qD précédemment déclaré ici"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr "le code peut être mal optimisé à moins que -fno-strict-aliasing soit utilisé"
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "variable %qD redéclarée comme une fonction"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "fonction %qD redéclarée comme une variable"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "précédemment déclarée ici"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "flux bytecode: rebut à la fin de la section des symboles"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "impossible de décoder le nombre hexadécimal"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "nom de fichier %s inattendu dans la résolution du fichier de l'éditeur de liens. %s attendu"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "impossible de décoder le décalage dans le fichier"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "décalage inattendu"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ligne invalide dans le fichier de résolution"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "résolution invalide dans le fichier de résolution"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "la résolution avec le sub id %wx n'est pas dans le fichier objet"
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "impossible de lire les déclarations LTO depuis %s"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Impossible d'ouvrir %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Impossible de mapper %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Impossible de lire %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() a échoué"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid a échoué"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "la mise en ligne du sous processus a échoué"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "la mise en ligne du sous processus a été tuée par un signal"
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "aucun nom de fichier fourni pour la liste de sortie LTRANS"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "ouverture de la liste de sortie LTRANS %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "écriture de la liste de sortie LTRANS %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "fermeture de la liste de sortie LTRANS %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "n'a pu ouvrir le fichier de résolution des symboles: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "donnée de résolution manquante pour %s"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "erreurs durant la fusion des unités de traductions"
@@ -62908,6 +63089,51 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "création d'un sélecteur pour la méthode inexistante %qE"
 
+#~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+#~ msgstr "Supporter les fonctions internes CET (Control-flow Enforcement Technology) et la génération de code."
+
+#~ msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+#~ msgstr "Activer spécifiquement une fonctionnalité de suivi d'un branchement indirect de CET (Control-flow Enforcement Technology)."
+
+#~ msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#~ msgstr "Spécifier le nombre maximum d'octets à comparer en ligne avec le code qui ne participe pas à la boucle. Si cette valeur vaut 0, toutes les expansions en ligne (non boucle et boucle) de memcmp sont désactivées."
+
+#~ msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+#~ msgstr "Spécifier le nombre maximum d'octets à comparer en ligne avec la génération de code de boucle. Si la longueur n'est pas connue au moment de la compilation, memcmp sera appelé après que ce nombre d'octets ait été comparé. Par défaut, la longueur est choisie sur base des paramètres de réglages."
+
+#~ msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
+#~ msgstr "%K%qD: l'écriture de %E octets dans une région de taille %E déborde de la destination"
+
+#~ msgid "%K%qD reading %E bytes from a region of size %E"
+#~ msgstr "%K%qD lecture de %E octets depuis une région de taille %E"
+
+#~ msgid "builtin operand should be an unsigned 6-bit value"
+#~ msgstr "l'opérande intégré devrait être une valeur non signée sur 6 bits"
+
+#~ msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
+#~ msgstr "l'opérande de l'instruction « sleep » doit être une constante non signée sur 6 bits disponible lors de la compilation"
+
+#~ msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
+#~ msgstr "%<-fcf-protection=branch%> requiert le support CET de Intel. Utilisez l'option -mcet ou -mibt pour activer CET"
+
+#~ msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
+#~ msgstr "%<-fcf-protection=return%> requiert le support CET de Intel. Utilisez l'option -mcet ou -mshstk pour activer CET"
+
+#~ msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
+#~ msgstr "%<-fcf-protection=full%> requiert le support CET de Intel. Utilisez -mcet ou les deux options -mibt et -mshstk pour activer CET"
+
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "l'expression %<for%> parcourant une plage de type %qT a un membre %<end%> mais pas de %<begin%>"
+
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "l'expression %<for%> parcourant une plage de type %qT a un membre %<begin%> mais pas de %<end%>"
+
+#~ msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+#~ msgstr "le deuxième opérande de %<offsetof%> n'est ni un simple identificateur ni une séquence d'accès aux membres et de références de tableaux"
+
+#~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#~ msgstr "ne peut convertir %qH en %qI pour l'argument %qP de %qD"
+
 #~ msgid "%G%qD output truncated copying %E byte from a string of length %E"
 #~ msgstr "la sortie de %G%qD a été tronquée en copiant %E octet depuis une chaîne de longueur %E"
 
Index: gcc/po/hr.po
===================================================================
--- gcc/po/hr.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/hr.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.7.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2012-07-05 15:49+0200\n"
 "Last-Translator: Tomislav Krznar <tomislav.krznar@gmail.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
@@ -158,40 +158,40 @@
 msgid "negative insn length"
 msgstr "negativna insn duljina"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "ne mogu razdvojiti insn"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "neispravni „asm”: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr ""
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr ""
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr ""
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "broj operanada je izvan granica"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "neispravni %%-kod"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "operand „%%l” nije oznaka"
@@ -202,13 +202,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1198,25 +1198,25 @@
 msgid "At top level:"
 msgstr ""
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr ""
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr ""
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr ""
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr ""
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr ""
@@ -2967,9 +2967,9 @@
 msgid "invalid address mode"
 msgstr "neispravni „asm”: "
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2985,7 +2985,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2992,13 +2992,13 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr ""
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr ""
@@ -3029,7 +3029,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr ""
@@ -3040,7 +3040,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr ""
@@ -3051,7 +3051,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3062,62 +3062,62 @@
 msgid "invalid operand address"
 msgstr ""
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%Z code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%z code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operands to %%c code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%M code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr ""
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr ""
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr ""
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr ""
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr ""
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%V code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%O code"
@@ -3125,19 +3125,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "neispravni izraz kao operand"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr ""
 
@@ -3172,7 +3172,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr ""
@@ -3293,8 +3293,8 @@
 msgstr ""
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3511,101 +3511,101 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr ""
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'O'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid vector immediate"
 msgstr "neispravni %%-kod"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3643,7 +3643,7 @@
 msgstr ""
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3697,7 +3697,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr ""
 
@@ -3861,142 +3861,142 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%e value"
 msgstr "neispravni %%-kod"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4122,43 +4122,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4373,14 +4373,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekujem %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekujem %<,%>"
@@ -4395,7 +4395,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekujem %<)%>"
@@ -4403,7 +4403,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekujem %<]%>"
@@ -4417,7 +4417,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekujem %<(%>"
@@ -4424,7 +4424,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekujem %<{%>"
@@ -4434,13 +4434,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekujem %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekujem %<while%>"
@@ -4449,18 +4449,18 @@
 msgid "expected %<.%>"
 msgstr "očekujem %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekujem %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekujem %<,%> ili %<)%>"
@@ -4468,23 +4468,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekujem %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekujem %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekujem %<[%>"
@@ -4493,7 +4493,7 @@
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -4505,39 +4505,39 @@
 msgid "expected label"
 msgstr "očekujem %<while%>"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr ""
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr ""
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr ""
 
@@ -4626,7 +4626,7 @@
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4645,114 +4645,114 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr ""
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr ""
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr ""
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr ""
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr ""
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr ""
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr ""
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr ""
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr ""
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4799,48 +4799,48 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5111,11 +5111,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr ""
 
@@ -5270,47 +5270,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5352,12 +5352,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5609,6 +5609,7 @@
 msgstr ""
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -8274,7 +8275,7 @@
 msgstr ""
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr ""
 
@@ -8717,7 +8718,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr ""
 
@@ -9376,7 +9377,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr ""
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9778,7 +9779,7 @@
 msgstr ""
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -9787,12 +9788,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -9805,41 +9806,41 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
 msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 msgid "Make all function calls indirect."
 msgstr ""
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr ""
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1057
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr ""
@@ -10214,7 +10215,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -10222,7 +10223,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10306,7 +10307,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr ""
 
@@ -10334,7 +10335,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr ""
 
@@ -10410,23 +10411,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -10446,19 +10447,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -10474,15 +10475,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr ""
 
@@ -10490,15 +10491,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -10506,7 +10507,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
@@ -10535,12 +10536,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr ""
 
@@ -11196,7 +11196,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -11385,14 +11385,22 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+msgid "Max number of pairs of load insns for compare."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr ""
@@ -11401,10 +11409,38 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:410
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:24
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:28
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr ""
@@ -12497,79 +12533,119 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr ""
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr ""
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 msgid "Generate string extension instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr ""
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr ""
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 #, fuzzy
 #| msgid ""
 #| "\n"
@@ -12579,10 +12655,26 @@
 "\n"
 "izlaz ldd-a s konstruktorima/destruktorima.\n"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr ""
 
+#: config/nds32/nds32.opt:314
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:318
+msgid "Generate single-precision floating-point instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:322
+msgid "Generate double-precision floating-point instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr ""
@@ -13405,13 +13497,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr ""
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr ""
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr ""
@@ -15648,8 +15733,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -15675,7 +15760,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected integer"
@@ -16091,7 +16176,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16117,12 +16202,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -16171,9 +16256,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16186,8 +16271,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -16319,82 +16404,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr ""
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr ""
@@ -16401,72 +16482,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr ""
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr ""
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr ""
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr ""
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr ""
@@ -16473,7 +16554,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -16480,12 +16561,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -16492,62 +16573,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr ""
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -17712,37 +17793,37 @@
 msgid "conversion to incomplete type"
 msgstr ""
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr ""
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr ""
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr ""
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -17897,12 +17978,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18012,12 +18093,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18032,12 +18113,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr ""
@@ -18047,42 +18128,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18622,28 +18703,28 @@
 msgid "can%'t write PCH file"
 msgstr ""
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -18657,12 +18738,13 @@
 msgid "null pointer dereference"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr ""
@@ -19197,10 +19279,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -19229,7 +19311,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -19568,252 +19650,257 @@
 msgid "function cannot be instrumented"
 msgstr ""
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr ""
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr ""
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr ""
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr ""
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -19834,7 +19921,7 @@
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -19842,7 +19929,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19850,7 +19937,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -19858,7 +19945,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -19866,7 +19953,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19874,7 +19961,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20155,29 +20242,34 @@
 
 #: multiple_target.c:91
 #, gcc-internal-format
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr ""
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr ""
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20491,12 +20583,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -21083,22 +21175,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21142,7 +21234,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -21382,157 +21474,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr ""
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -22694,12 +22786,12 @@
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23206,7 +23298,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -23246,92 +23338,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -23356,242 +23448,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr ""
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "verify_type failed"
@@ -23617,12 +23709,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -24502,7 +24594,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -24753,7 +24845,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr ""
@@ -25361,7 +25453,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25376,22 +25468,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -25937,8 +26029,8 @@
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -26569,7 +26661,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -26646,7 +26738,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -26774,47 +26866,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -26840,31 +26932,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -27346,8 +27438,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -27427,8 +27519,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27537,11 +27629,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27551,145 +27643,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr ""
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr ""
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr ""
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr ""
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr ""
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr ""
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr ""
@@ -27715,153 +27797,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -28663,12 +28745,12 @@
 msgid "invalid IACC argument"
 msgstr ""
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr ""
@@ -28768,566 +28850,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr ""
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr ""
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -29334,311 +29401,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29863,7 +29930,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -30390,8 +30457,33 @@
 msgid "constant argument out of range for %s"
 msgstr "broj operanada je izvan granica"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, gcc-internal-format
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:702
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:717
+#, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:736
+#, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:748
+#, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:760
+#, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr ""
 
@@ -30411,43 +30503,60 @@
 msgstr ""
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr ""
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr ""
+
+#: config/nds32/nds32.c:3508
+#, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
 #, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
+#, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr ""
 
@@ -30658,37 +30767,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -30782,12 +30891,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -30837,7 +30946,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -31139,7 +31248,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31149,7 +31258,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31159,12 +31268,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31174,28 +31283,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
@@ -31215,12 +31324,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
@@ -31242,53 +31351,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -31413,7 +31522,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
@@ -31423,12 +31532,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -31438,22 +31547,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -31463,7 +31572,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -31927,22 +32036,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr ""
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr ""
@@ -32005,30 +32114,35 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
+#, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
@@ -32151,169 +32265,169 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33108,7 +33222,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -33360,7 +33474,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -33370,7 +33484,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -33430,7 +33544,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -33460,7 +33574,7 @@
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
@@ -33578,7 +33692,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -33833,7 +33947,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -33992,7 +34106,7 @@
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -34119,7 +34233,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -34299,7 +34413,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -34349,7 +34463,7 @@
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -34385,7 +34499,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
@@ -34415,7 +34529,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
@@ -34445,7 +34559,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -34560,12 +34674,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -34628,7 +34742,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
@@ -34773,37 +34887,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -34833,7 +34947,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekujem kraj retka"
@@ -34874,7 +34988,7 @@
 msgstr ""
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -34889,7 +35003,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -34904,8 +35018,8 @@
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -34943,7 +35057,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -34971,7 +35085,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr ""
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -35035,13 +35149,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -35171,7 +35285,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -35205,22 +35319,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -35240,12 +35354,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -35273,12 +35387,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -35554,7 +35668,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr ""
@@ -35614,76 +35728,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -35698,56 +35812,56 @@
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<data%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -35769,85 +35883,85 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<tofrom%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<scalar%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr ""
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "unexpected argument"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -35857,12 +35971,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -35882,19 +35996,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid depend kind"
 msgstr "neispravni izraz kao operand"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid map kind"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -35904,68 +36018,68 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -35981,7 +36095,7 @@
 msgid "expected function name"
 msgstr "očekujem kraj retka"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -35991,42 +36105,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -36036,22 +36150,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -36061,74 +36175,74 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<for%> after %qs"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<point%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36148,34 +36262,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<target%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected %<declare%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36231,48 +36345,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -36287,7 +36401,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -36408,7 +36522,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -36433,7 +36547,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -36536,17 +36650,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -36571,7 +36685,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -36804,7 +36918,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -36956,7 +37070,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -37023,7 +37137,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -37093,12 +37207,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -37144,7 +37258,7 @@
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -37159,7 +37273,7 @@
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -37289,7 +37403,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -37329,7 +37443,7 @@
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -37339,17 +37453,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -37374,22 +37488,22 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -37440,7 +37554,7 @@
 msgstr ""
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -37470,12 +37584,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -37485,25 +37599,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -37514,70 +37628,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -37597,7 +37711,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -37607,17 +37721,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -37632,18 +37746,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -37655,32 +37769,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -37700,55 +37814,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -37758,32 +37872,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -37916,7 +38030,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -37995,24 +38109,24 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -38019,607 +38133,607 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -38658,8 +38772,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
@@ -38700,7 +38814,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr ""
@@ -38780,7 +38894,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -39057,7 +39171,7 @@
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
@@ -39127,7 +39241,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
@@ -39222,333 +39336,333 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr ""
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -39589,7 +39703,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -39598,306 +39712,306 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr ""
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr ""
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr ""
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -39937,197 +40051,197 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr ""
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr ""
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr ""
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr ""
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr ""
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr ""
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr ""
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr ""
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr ""
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr ""
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr ""
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr ""
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr ""
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr ""
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr ""
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr ""
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr ""
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr ""
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr ""
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr ""
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr ""
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr ""
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr ""
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr ""
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr ""
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr ""
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr ""
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr ""
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr ""
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr ""
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr ""
@@ -40140,39 +40254,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -40180,630 +40294,630 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr ""
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr ""
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr ""
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40811,7 +40925,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40819,7 +40933,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40827,868 +40941,878 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr ""
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr ""
+
+#: cp/decl.c:7774
+#, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr ""
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr ""
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
+msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:11099
+#: cp/decl.c:11156
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
+msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -41695,459 +41819,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -42154,77 +42278,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -42244,169 +42368,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -42418,94 +42542,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -42514,77 +42638,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr ""
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr ""
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -42624,7 +42748,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -42637,7 +42761,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -42748,42 +42872,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -42792,67 +42916,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -42861,62 +42985,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr ""
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr ""
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -42923,17 +43047,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -42943,112 +43067,112 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr ""
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -43194,358 +43318,358 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr ""
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr ""
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr ""
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr ""
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -43557,7 +43681,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -43640,67 +43764,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -43819,12 +43943,12 @@
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr ""
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%d constructor found\n"
 #| msgid_plural "%d constructors found\n"
@@ -43831,32 +43955,32 @@
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d konstruktor pronađen\n"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr ""
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr ""
@@ -43864,57 +43988,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr ""
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr ""
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr ""
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr ""
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr ""
@@ -43921,12 +44045,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr ""
@@ -43933,103 +44057,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr ""
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr ""
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr ""
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -44037,78 +44161,83 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr ""
+
+#: cp/name-lookup.c:5929
+#, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr ""
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -44128,7 +44257,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44153,7 +44282,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -44233,7 +44362,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -44455,7 +44584,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -44537,7 +44666,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -44552,863 +44681,853 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
 #, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr ""
+
+#: cp/parser.c:10119
+#, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr ""
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "neispravni izraz kao operand"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -45417,17 +45536,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -45434,384 +45553,384 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected attribute before %<...%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -45820,518 +45939,518 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr ""
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -46338,88 +46457,88 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr ""
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr ""
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr ""
@@ -46426,57 +46545,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr ""
@@ -46489,137 +46608,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr ""
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46627,17 +46746,17 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -46645,47 +46764,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -46695,57 +46814,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46753,7 +46872,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46761,12 +46880,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -46775,117 +46894,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46893,287 +47012,292 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
 #, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr ""
+
+#: cp/pt.c:11691
+#, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
@@ -47191,276 +47315,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -47472,109 +47596,114 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
+#: cp/pt.c:26912
+#, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr ""
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -47777,7 +47906,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -47827,7 +47956,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -47899,294 +48028,294 @@
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4071
+#: cp/semantics.c:4056
 #, gcc-internal-format
-msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -48311,12 +48440,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -48376,727 +48505,723 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot call function %qD"
 msgstr "[ne mogu naći %s]"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8786
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#: cp/typeck.c:8812 cp/typeck.c:8829
+msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8800
-msgid "cannot convert %qH to %qI"
-msgstr ""
-
-#: cp/typeck.c:8804
+#: cp/typeck.c:8833
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -49103,55 +49228,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -49373,140 +49498,140 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr ""
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr ""
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr ""
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -49930,48 +50055,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -50966,7 +51091,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -51137,7 +51262,7 @@
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -51387,449 +51512,449 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -51836,956 +51961,956 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "očekujem %<(%>"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "nisam uspio zatvoriti datoteku stanja %s [%s]"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>"
 msgid "Expected %<::%> at %C"
 msgstr "očekujem %<:%>"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "očekujem %<=%>"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "očekujem %<,%>"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -53120,27 +53245,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -53465,7 +53590,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr ""
@@ -53475,63 +53600,63 @@
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "bad expression"
 msgstr "neispravni izraz kao operand"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -53651,12 +53776,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -54846,7 +54971,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56285,12 +56410,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -56530,8 +56655,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -56573,7 +56698,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -56914,182 +57039,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -58442,7 +58567,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -58552,7 +58677,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -58926,228 +59051,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -59156,232 +59281,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -59388,12 +59513,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -59401,107 +59526,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -59508,67 +59633,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -59575,7 +59700,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -59583,57 +59708,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -59640,887 +59765,887 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -60958,7 +61083,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -61598,18 +61723,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -61792,178 +61917,178 @@
 msgid "previously defined here as %s"
 msgstr ""
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr ""
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr ""
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr ""
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr ""
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr ""
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr ""
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr ""
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr ""
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr ""
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr ""
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr ""
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr ""
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr ""
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr ""
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init nije uspio"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/nl.po
===================================================================
--- gcc/po/nl.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/nl.po	(.../branches/gcc-8-branch)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -151,40 +151,40 @@
 msgid "negative insn length"
 msgstr "negatieve insn-lengte"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "kon insn niet splitsen"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "ongeldige 'asm': "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr ""
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "onbeëindigd alternatief assembly-dialect"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "operandnummer ontbreekt na %%-letter"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "operandnummer buiten bereik"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "ongeldige %%-code"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "operand van '%%l' is geen label"
@@ -195,13 +195,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "floating-point constante verkeerd gebruikt"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1137,25 +1137,25 @@
 msgid "At top level:"
 msgstr "Op bovenste niveau:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "In memberfunctie %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "In functie %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    inline gemaakt vanuit %qs op %r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    inline gemaakt vanuit %qs op %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    inline gemaakt vanuit %qs"
@@ -2923,9 +2923,9 @@
 msgid "invalid address mode"
 msgstr "ongeldige adresseringsmodus"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2941,7 +2941,7 @@
 msgstr "ongeldige waarde voor %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2948,13 +2948,13 @@
 msgstr "ongeldige waarde voor %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
@@ -2985,7 +2985,7 @@
 msgstr "ongeldige waarde voor %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
@@ -2996,7 +2996,7 @@
 msgstr "ongeldige waarde voor %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
@@ -3008,7 +3008,7 @@
 msgstr "onbekende 'unspec' relocatie"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3019,58 +3019,58 @@
 msgid "invalid operand address"
 msgstr "Ongeldige modus voor gen_tst_reg"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ongeldige operand voor %%Z-code"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ongeldige operand voor %%z-code"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "ongeldige operand voor %%Z-code"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ongeldige operand voor %%M-code"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ongeldige operand voor %%p-code"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ongeldige operand voor %%s-code"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ongeldige operand voor %%R-code"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ongeldige operand voor %%H/%%L-code"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ongeldige operand voor %%U-code"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ongeldige operand voor %%V-code"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ongeldige operand voor %%O-code"
@@ -3077,19 +3077,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ongeldige code voor operanduitvoer"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ongeldige UNSPEC als operand: %d"
 
 # betere vertaling voor "supposed"?  "denkelijk"?
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "vermoedelijke constante niet herkend"
 
@@ -3125,7 +3125,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
@@ -3253,8 +3253,8 @@
 msgstr "ongeldige const_double operand"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3472,99 +3472,99 @@
 msgid "bad output_condmove_single operand"
 msgstr "ongeldige output_condmove_single operand"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ongeldige UNSPEC als operand"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ongeldige operand voor '%c'"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ongeldige constraints voor operand"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Ongeldig token in expressie"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "onbekende insn-modus"
 
@@ -3602,7 +3602,7 @@
 msgstr "ongeldige operand voor %%P"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -3660,7 +3660,7 @@
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -3828,145 +3828,145 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4098,43 +4098,43 @@
 msgid "created and used with different endianness"
 msgstr "aangemaakt en gebruikt met verschillende \"endianness\""
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ongeldige operand voor %%Y"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ongeldige operand voor %%A"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ongeldige operand voor %%B"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ongeldige operand voor %%f"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ongeldige operand voor %%s"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4356,14 +4356,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -4378,7 +4378,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -4386,7 +4386,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -4401,7 +4401,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
@@ -4408,7 +4408,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -4418,13 +4418,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
@@ -4434,18 +4434,18 @@
 msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
@@ -4453,23 +4453,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
@@ -4478,7 +4478,7 @@
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -4489,42 +4489,42 @@
 msgid "expected label"
 msgstr "ongeldige operand van %s"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "kandidaat 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "herhaald label %qs"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr ""
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr ""
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 msgid "enters OpenMP structured block"
 msgstr "continue-statement niet in een lus"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 msgid "enters synchronized or atomic statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 msgid "enters constexpr if statement"
 msgstr "ongeldige beginwaarde"
@@ -4622,7 +4622,7 @@
 msgid "<statement>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, fuzzy, gcc-internal-format
 msgid "<unknown>"
 msgstr "onbekende machine-modus %qs"
@@ -4641,120 +4641,120 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr ""
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 #, fuzzy
 msgid "<unknown operator>"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 msgid "In static member function %qs"
 msgstr "In memberfunctie %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 msgid "In constructor %qs"
 msgstr "In functie %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 msgid "In destructor %qs"
 msgstr "In functie %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 msgid "In lambda function"
 msgstr "In memberfunctie %qs"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 msgid "required from %q#D\n"
 msgstr "eerdere grant voor %qs"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 msgid "recursively required from here\n"
 msgstr "van hieruit opgeroepen"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 msgid "required from here\n"
 msgstr "van hieruit opgeroepen"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "kandidaten zijn:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4808,54 +4808,54 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argument van verkeerd type voor unaire min"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argument van verkeerd type voor bit-complement"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argument van verkeerd type voor abs"
 
 # OK, ik geef het op: wat is hier een goede vertaling voor 'conjugation'?
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argument van verkeerd type voor vervoeging"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5146,12 +5146,12 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
@@ -5319,49 +5319,49 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5403,12 +5403,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5664,6 +5664,7 @@
 msgstr "-Xbind-now en -Xbind-lazy zijn incompatibel"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -8596,7 +8597,7 @@
 msgstr ""
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 msgid "Specify the name of the target architecture."
 msgstr "Geef de naam op van hardware/formaat voor floating-point getallen op het doelplatform"
@@ -9076,7 +9077,7 @@
 msgstr "Geef het register op dat voor PIC-adressering gebruikt moet worden"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr ""
 
@@ -9786,7 +9787,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "case-label niet in een switch-statement"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -10258,7 +10259,7 @@
 msgstr "ingebouwde functie %qs is niet geïmplementeerd"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -10267,12 +10268,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -10285,45 +10286,46 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "ingebouwde functie %qs is niet geïmplementeerd"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 msgid "Make all function calls indirect."
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "ingebouwde functie %qs is niet geïmplementeerd"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "ingebouwde functie %qs is niet geïmplementeerd"
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr ""
@@ -10752,7 +10754,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -10760,7 +10762,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10852,7 +10854,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr ""
 
@@ -10883,7 +10885,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Pngeldige optie %<-%s%>"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr ""
 
@@ -10968,25 +10970,25 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -11006,19 +11008,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -11034,15 +11036,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 msgid "Generate the integer modulo instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -11051,16 +11053,16 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -11068,7 +11070,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Pngeldige optie %<-%s%>"
@@ -11100,14 +11102,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Use portable calling conventions"
 msgid "Select ABI calling convention."
 msgstr "Overdraagbare aanroepconventies gebruiken"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr ""
 
@@ -11803,7 +11804,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -12004,14 +12005,22 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+msgid "Max number of pairs of load insns for compare."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr ""
@@ -12020,10 +12029,40 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:410
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+msgid "%qs is deprecated"
+msgstr "%<%.*s%> is niet gedefinieerd"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Use portable calling conventions"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Overdraagbare aanroepconventies gebruiken"
+
+#: config/rs6000/sysv4.opt:28
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use registers r2 and r5"
@@ -13289,88 +13328,128 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 msgid "Generate code in big-endian mode."
 msgstr "case-label niet in een switch-statement"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 msgid "Generate code in little-endian mode."
 msgstr "case-label niet in een switch-statement"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 msgid "Generate conditional move instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 msgid "Generate performance extension instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 msgid "Generate performance extension version 2 instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 msgid "Generate string extension instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 msgid "Generate 16-bit instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 msgid "Enable Virtual Hosting support."
 msgstr "Geef de naam op van hardware/formaat voor floating-point getallen op het doelplatform"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr ""
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 #, fuzzy
 msgid "Enable constructor/destructor feature."
 msgstr ""
@@ -13377,11 +13456,30 @@
 "\n"
 "uitvoer van ldd met constructors/destructors.\n"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 msgid "Guide linker to relax instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "ongeldig gebruik van %<restrict%>"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+msgid "Generate single-precision floating-point instructions."
+msgstr "ISO C staat het testen van asserties niet toe"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+msgid "Generate double-precision floating-point instructions."
+msgstr "ISO C staat het testen van asserties niet toe"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr ""
@@ -14288,13 +14386,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-msgid "%qs is deprecated"
-msgstr "%<%.*s%> is niet gedefinieerd"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 msgid "Do not generate mpy instructions for ARC700."
@@ -16695,8 +16786,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, fuzzy, gcc-internal-format
 msgid "value computed is not used"
 msgstr "modus van %qs is geen modus"
@@ -16727,7 +16818,7 @@
 msgstr "ongeldige operand van %s"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ongeldige operand van %s"
@@ -17190,7 +17281,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -17216,12 +17307,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuut wordt genegeerd"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -17270,9 +17361,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -17285,8 +17376,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "eerdere declaratie van %qs"
@@ -17418,82 +17509,76 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "ongeldige waarde voor %%C"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "ongebruikte argumenten in $-stijl formaat"
@@ -17500,72 +17585,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "ISO C verbiedt geneste functies"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "onbekende machine-modus %qs"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
@@ -17572,7 +17657,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
@@ -17579,12 +17664,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
@@ -17591,63 +17676,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> gebruikt in functie met vaste argumenten"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -18820,37 +18905,37 @@
 msgid "conversion to incomplete type"
 msgstr "conversie naar incompleet type"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "cast van pointer naar integer met andere grootte"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "cast van pointer naar integer met andere grootte"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -19006,12 +19091,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -19121,12 +19206,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -19141,12 +19226,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "grootte van %qs is %u bytes"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "kan bestand '%s' niet openen"
@@ -19156,42 +19241,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "grote integer impliciet afgekapt naar 'unsigned' type"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -19731,28 +19816,28 @@
 msgid "can%'t write PCH file"
 msgstr "kan bestand '%s' niet openen"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -19766,12 +19851,13 @@
 msgid "null pointer dereference"
 msgstr "herhaald lid %qs"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -20291,10 +20377,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -20325,7 +20411,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -20668,252 +20754,257 @@
 msgid "function cannot be instrumented"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, fuzzy, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr "eerdere definitie van %qs"
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, fuzzy, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr "eerdere definitie van %qs"
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "geen beginwaarde voor variant-veld %qs"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, fuzzy, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, fuzzy, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "eerdere definitie van %qs"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 msgid "array types have different bounds"
 msgstr "array subscript is geen integer"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "ongeldige operand voor %p-code"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, fuzzy, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "eerdere definitie van %qs"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, fuzzy, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, fuzzy, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -20934,7 +21025,7 @@
 msgid "the extra base is defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -20941,7 +21032,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20948,7 +21039,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -20955,7 +21046,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -20962,7 +21053,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20969,7 +21060,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -21250,32 +21341,35 @@
 msgstr "doel-CPU ondersteunt geen interworking"
 
 #: multiple_target.c:91
-#, fuzzy, gcc-internal-format
-#| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
-msgstr "versie-attribuut is geen string"
+#, gcc-internal-format
+msgid "default %<target_clones%> attribute was not set"
+msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
-#| msgid "%qE incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
-msgstr "incompatibel attribuut %qE wordt genegeerd"
+msgid "single %<target_clones%> attribute is ignored"
+msgstr "attribuut-commando %qs wordt genegeerd"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 msgid "default target was not set"
 msgstr "ongeldig type-argument %qs"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -21588,13 +21682,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "niet-herkend argument bij optie %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
@@ -22190,22 +22284,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "operand %<%d%> is geen register"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -22249,7 +22343,7 @@
 msgstr "registernaam opgegeven voor niet-registervariabele %qs"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "conflicterende types voor %qs"
@@ -22489,157 +22583,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "opgeroepen object is geen functie"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "opgeroepen object is geen functie"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -23801,12 +23895,12 @@
 msgid "control reaches end of non-void function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "%Hde returnwaarde van een functie, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
@@ -24314,7 +24408,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -24354,92 +24448,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "arrays van functies zijn niet betekenisvol"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -24464,242 +24558,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 msgid "verify_type failed"
 msgstr "pex_init mislukt"
@@ -24724,12 +24818,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -25631,7 +25725,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gebruik liefst haakjes rond toewijzingen die als waarheid gebruikt worden"
@@ -25885,7 +25979,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "omvang van array %qs is te groot"
@@ -26500,7 +26594,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -26516,22 +26610,22 @@
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -27080,8 +27174,8 @@
 msgid "wrong type argument to %s"
 msgstr "argument van verkeerd type voor abs"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow in constante expressie"
@@ -27720,7 +27814,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
@@ -27800,7 +27894,7 @@
 msgstr[0] "cast laat qualifiers van doeltype van pointer vallen"
 msgstr[1] "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -27935,47 +28029,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, fuzzy, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, fuzzy, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, fuzzy, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d ligt niet tussen 0 en 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -28002,31 +28096,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "onbekende machine-modus %qs"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -28508,8 +28602,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
@@ -28590,8 +28684,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "slechte waarde %qs voor -mmeroy-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28700,11 +28794,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -28714,151 +28808,141 @@
 msgid "%qE attribute only applies to functions"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, fuzzy, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, fuzzy, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "een long long constante is geen geldige onmiddellijke operand"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
 # pre-increment vertalen? zoja, als wat?
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "pre-increment adres is geen register"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "attribuut %qE wordt genegeerd"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
@@ -28884,153 +28968,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -29846,12 +29930,12 @@
 msgid "invalid IACC argument"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, fuzzy, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "te veel argumenten voor procedure `%s'"
@@ -29951,579 +30035,564 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s ondersteunt %s niet"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ondersteunt geen multilib"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
@@ -30530,312 +30599,312 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "herdefinitie van %<union %s%>"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "niet-ondersteunde versie"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -31057,7 +31126,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -31589,8 +31658,33 @@
 msgid "constant argument out of range for %s"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:702
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:717
 #, fuzzy, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr "ongeldig gebruik van %<restrict%>"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr "ongeldig gebruik van %<restrict%>"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr "ongeldige operand in de instructie"
 
@@ -31610,42 +31704,59 @@
 msgstr ""
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "ongeldig register in de instructie"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
+#, fuzzy, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "ongeldig register in de instructie"
+
+#: config/nds32/nds32.c:3508
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
@@ -31859,39 +31970,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "attribuut %qE wordt genegeerd voor types"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -31985,12 +32096,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "rommel aan einde van #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -32041,7 +32152,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
@@ -32343,7 +32454,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32353,7 +32464,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -32363,12 +32474,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32378,28 +32489,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
@@ -32419,12 +32530,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
@@ -32446,54 +32557,54 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -32619,7 +32730,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "bestand %qs is te groot"
@@ -32629,12 +32740,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -32644,22 +32755,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -32669,7 +32780,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -33133,22 +33244,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
@@ -33213,30 +33324,35 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
@@ -33361,173 +33477,173 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "argument moet een constante zijn"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "second argument to %qs must be 0..12"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "third argument to %qs must be 0..12"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "argument moet een constante zijn"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -34333,7 +34449,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-waarde niet genegeerd zoals het hoort"
@@ -34589,7 +34705,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
@@ -34599,7 +34715,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "%Jde verborgen declaratie is hier"
@@ -34660,7 +34776,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Elke niet-gedeclareerde naam wordt slechts één"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -34690,7 +34806,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "herhaald label %qs"
@@ -34810,7 +34926,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -35066,7 +35182,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "opslagklasse opgegeven voor typenaam"
@@ -35226,7 +35342,7 @@
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
@@ -35354,7 +35470,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabele of veld %qs als void gedeclareerd"
@@ -35534,7 +35650,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
@@ -35584,7 +35700,7 @@
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
@@ -35620,7 +35736,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "herdeclaratie van %<enum %qs%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "opgegeven modus is te klein voor enumeratiewaarden"
@@ -35650,7 +35766,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
@@ -35680,7 +35796,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
@@ -35795,12 +35911,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -35863,7 +35979,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
@@ -36010,38 +36126,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
@@ -36073,7 +36189,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -36114,7 +36230,7 @@
 msgstr "onbekende machine-modus %qs"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -36129,7 +36245,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -36144,8 +36260,8 @@
 msgid "unexpected attribute"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -36185,7 +36301,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -36213,7 +36329,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -36277,13 +36393,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma aan het einde van enumerator-lijst"
@@ -36413,7 +36529,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -36447,22 +36563,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -36482,12 +36598,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ongeldig register in de instructie"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -36515,12 +36631,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -36806,7 +36922,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -36866,76 +36982,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attribuut %<getter%> mag slechts één keer opgegeven worden"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "ongeldige waarheidsexpressie"
@@ -36950,53 +37066,53 @@
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -37018,83 +37134,83 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "zowel %<long%> als %<void%> opgegeven bij declaratie"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -37104,12 +37220,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -37129,17 +37245,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -37149,67 +37265,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "lege declaratie"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ongeldige linker operand van %s"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -37224,7 +37340,7 @@
 msgid "expected function name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qs is meestal een functie"
@@ -37234,42 +37350,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -37279,22 +37395,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
@@ -37304,73 +37420,73 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -37390,32 +37506,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -37470,47 +37586,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -37525,7 +37641,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qs heeft een onvolledig type"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ongeldig gebruik van een void-expressie"
@@ -37647,7 +37763,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscript is geen integer"
@@ -37672,7 +37788,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -37775,18 +37891,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "vergelijking tussen pointer en integer"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "kan niet derefereren, is geen pointer."
@@ -37813,7 +37929,7 @@
 msgstr "rekensom met pointer naar onvolledig type"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "rekensom met pointer naar onvolledig type"
@@ -38050,7 +38166,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast naar pointer van integer met andere grootte"
@@ -38211,7 +38327,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -38284,7 +38400,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
@@ -38354,12 +38470,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisatie van flexibel array-lid"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-array heeft wide string als beginwaarde"
@@ -38405,7 +38521,7 @@
 msgid "invalid initializer"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -38420,7 +38536,7 @@
 msgid "braces around scalar initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisatie van flexibel array-lid in een geneste context"
@@ -38551,7 +38667,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C verbiedt %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
@@ -38592,7 +38708,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-label niet in een switch-statement"
@@ -38602,17 +38718,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "default-label niet in een switch-statement"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-statement niet in een lus of switch"
@@ -38638,22 +38754,22 @@
 msgid "expression statement has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -38705,7 +38821,7 @@
 msgstr "geordende vergelijking van pointer met null-pointer"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordende vergelijking van pointer met integer nul"
@@ -38735,12 +38851,12 @@
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -38750,25 +38866,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qs is meestal een functie"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -38779,70 +38895,70 @@
 msgstr "te veel invoerbestanden"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qs is smaller dan waarden van zijn type"
@@ -38862,7 +38978,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "grootte van %qs is %u bytes"
@@ -38872,17 +38988,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -38897,18 +39013,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -38920,32 +39036,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -38965,55 +39081,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qs is geen static veld"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -39023,32 +39139,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -39185,7 +39301,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -39263,26 +39379,26 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -39289,618 +39405,618 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "ongeldige operand voor %P"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ verbiedt het weglaten van de middelste term van een ?: expresie"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, fuzzy, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "vergelijking tussen %q#T en %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "impliciete declaratie van functie %qE"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%s is niet addresseerbaar"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is too large"
 msgid "; use assignment instead"
 msgstr "gevraagd alignment is te groot"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ongeldige registernaam voor %qs"
@@ -39940,8 +40056,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "eerdere declaratie van %qs"
@@ -39982,7 +40098,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -40062,7 +40178,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -40340,7 +40456,7 @@
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
@@ -40410,7 +40526,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
@@ -40505,334 +40621,334 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40877,7 +40993,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "kan niet derefereren, is geen pointer."
@@ -40887,307 +41003,307 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, fuzzy, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "conversie naar niet-scalair type gevraagd"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "ongeldige toepassing van %qs op onvolledig type %qT "
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "statement zonder effect"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -41227,198 +41343,198 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qs was als %<extern%> gedeclareerd en daarna als %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "%Jeerdere definitie van %qD was hier"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "%Jeerdere declaratie van %qD was hier"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, fuzzy, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "bibliotheekfunctie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "lege declaratie"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, fuzzy, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "prototype voor %qs volgt"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "niet-prototype definitie hier"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, fuzzy, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "%Jherdefinitie van %qD"
@@ -41431,39 +41547,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "herdefinitie van %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD botst met gebruikte functie"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -41471,631 +41587,631 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%Jdeclaratie van %qD als thread-local volgt declaratie als niet-thread-local"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%Jdeclaratie van %qD als niet-thread-local volgt declaratie als thread-local"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, fuzzy, gcc-internal-format
 msgid "  from here"
 msgstr "van hieruit opgeroepen"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr ""
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr ""
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nutteloos sleutelwoord of typenaam in lege declaratie"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabele %qs heeft beginwaarde, maar een onvolledig type"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr "herhaald lid %qs"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "dereferentie van pointer naar onvolledig type"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -42102,7 +42218,7 @@
 msgstr[0] "opslagklasse opgegeven voor structure-veld %qs"
 msgstr[1] "opslagklasse opgegeven voor structure-veld %qs"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -42109,7 +42225,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -42116,1176 +42232,1186 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "herhaald lid %qs"
 
 # Betere vertaling voor 'decompose'?
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan adres niet ontleden"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "teruggeeftype is onvolledig"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Ongeldige optie %qs"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, fuzzy, gcc-internal-format
 msgid "size of array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ verbiedt lid-declaraties zonder leden"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "zowel 'signed' als 'unsigned' opgegeven voor %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "'long' of 'short' opgegeven bij 'char' voor %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "zowel 'long' als 'short' opgegeven voor %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "ongeldig gebruik van 'long', 'short', 'signed' of 'unsigned' voor %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
-#, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
-msgstr ""
-
-#: cp/decl.c:11099
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/decl.c:11111
+#: cp/decl.c:11156
 #, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.c:11169
+#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -43292,157 +43418,157 @@
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -43449,78 +43575,78 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -43540,169 +43666,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -43714,94 +43840,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
@@ -43810,78 +43936,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43921,7 +44047,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "herdeclaratie van %qs"
@@ -43934,7 +44060,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "%<%s %s%> binnen parameterlijst gedeclareerd"
@@ -44045,42 +44171,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qs is geen static veld"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, fuzzy, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -44089,67 +44215,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, fuzzy, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -44158,62 +44284,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "parameternaam ontbreekt uit parameterlijst"
@@ -44220,17 +44346,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -44240,113 +44366,113 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "geen argumenten"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -44492,358 +44618,358 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "ongeldige toepassing van %qs op onvolledig type %qT "
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "ongeldige beginwaarde"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 msgid "  %q#D"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, fuzzy, gcc-internal-format
 msgid "  base %qT"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "integer overflow in expressie"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44855,7 +44981,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -44938,67 +45064,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -45117,42 +45243,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
@@ -45160,57 +45286,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr ""
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr ""
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr ""
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%qs is geen iterator"
@@ -45217,12 +45343,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
@@ -45229,103 +45355,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qs is geen iterator"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, fuzzy, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, fuzzy, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%qs is geen iterator"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attribuut-commando %qD wordt genegeerd"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -45332,78 +45458,83 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%s voor %qs"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%<this%> is niet beschikbaar in static member-funties"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "herhaalde definitie %qs"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -45423,7 +45554,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45448,7 +45579,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -45528,7 +45659,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45750,7 +45881,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "lege declaratie"
@@ -45832,7 +45963,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -45847,865 +45978,855 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:6110
-#, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gebruik liefst haakjes rond && binnen ||"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "%<%.*s%> is niet gedefinieerd"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "herhaalde %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
 # vertaling voor 'statement'?
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "lege declaratie"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ongeldige const_double operand"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "onverwachte operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "%qs is geen iterator"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "ongeldige beginwaarde"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%qs is geen iterator"
@@ -46714,17 +46835,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -46731,382 +46852,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "[kan %s niet vinden]"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "eerdere definitie van %qs"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -47115,521 +47236,521 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qs is meestal een functie"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rommel aan einde van %<#pragma GCC pch_preprocess%>"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "herdefinitie van %qs"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -47636,90 +47757,90 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %qs"
 msgid "%s %#qD"
 msgstr "%s %qs"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "impliciete declaratie van functie %qs"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "misvormde #pragma pack"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "ontbrekende witruimte na getal %qs"
@@ -47726,57 +47847,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qs is meestal een functie"
@@ -47789,137 +47910,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, fuzzy, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "%qs impliciet als functie gedeclareerd"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anoniem>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "herhaald label %qs"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47926,17 +48047,17 @@
 msgstr[0] "argument %d is alleen-lezen"
 msgstr[1] "argument %d is alleen-lezen"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "ongeldig type-argument %qs"
@@ -47944,47 +48065,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -47994,57 +48115,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -48051,7 +48172,7 @@
 msgstr[0] "macro %qs gebruikt zonder argumenten"
 msgstr[1] "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -48058,12 +48179,12 @@
 msgstr[0] "eerdere declaratie van %qs"
 msgstr[1] "eerdere declaratie van %qs"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ongeldige naam %qs"
@@ -48072,117 +48193,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -48189,289 +48310,294 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "iterator %qs is van een afgeleid type"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr "%Jflexibel array-lid in union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "herdefinitie van %<struct %s%>"
@@ -48489,279 +48615,279 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#qS"
 msgstr "%s %qs"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "impliciete declaratie van functie %qs"
@@ -48773,108 +48899,113 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "ongeldig type-argument %qs"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -49077,7 +49208,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -49127,7 +49258,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
@@ -49201,295 +49332,295 @@
 msgstr "%qs is geen iterator"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "%<this%> is niet beschikbaar in static member-funties"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "%<vector%> length expression must be integral"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "te veel invoerbestanden"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "pex_init mislukt"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -49622,12 +49753,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -49688,742 +49819,737 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qs is meestal een functie"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qs is geen iterator"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ verbiedt accolade-groepen in expressies"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "te veel argumenten voor functie"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "te weinig argumenten voor functie"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "teller van links shift is negatief"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ verbiedt een vergelijking tussen pointer en integer"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operand-types zijn %qT en %qT"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, fuzzy, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ verbiedt voorwaardelijke expressies tussen 0 en een functiepointer"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
+msgid "cannot convert %qH to %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-msgid "cannot convert %qH to %qI"
-msgstr "kon 0x%l.8x niet naar een regio omzetten"
-
-#: cp/typeck.c:8804
-#, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -50430,55 +50556,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -50699,142 +50825,142 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-array heeft niet-wide string als beginwaarde"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-array heeft niet-wide string als beginwaarde"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "beginwaarde-string voor array van chars is te lang"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -51262,48 +51388,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 msgid "Simplification error"
 msgstr "herdeclaratie van %qs"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -52375,7 +52501,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -52552,7 +52678,7 @@
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -52805,451 +52931,451 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
 # vertaling voor 'statement'?
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
@@ -53256,951 +53382,951 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%qs is geen iterator"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "%Jparameternaam weggelaten"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Array subscript-stap verwacht op %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Functienaam '%s' niet toegestaan op %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "herhaalde case-waarde"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "%s voor %qs"
@@ -54536,27 +54662,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
@@ -54883,7 +55009,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "doorgeven van argument %d van %qs"
@@ -54893,62 +55019,62 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 msgid "bad expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "slechte test"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "ongeldige operand in de instructie"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -55068,12 +55194,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -56266,7 +56392,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -57704,12 +57830,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -57950,8 +58076,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -57993,7 +58119,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -58335,182 +58461,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -59863,7 +59989,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -59973,7 +60099,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -60348,228 +60474,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -60578,235 +60704,235 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60813,12 +60939,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60826,107 +60952,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60933,69 +61059,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -61002,7 +61128,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -61010,57 +61136,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -61067,892 +61193,892 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -62390,7 +62516,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -63033,18 +63159,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Intrinsieke functie %s(%d) wordt niet herkend"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "ongeldig type-argument %qs"
@@ -63228,177 +63354,177 @@
 msgid "previously defined here as %s"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "%Jmeerdere parameters hebben de naam %qD"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "kan klasse '%s' niet vinden"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 msgid "previously defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, fuzzy, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "eerdere definitie van %qs"
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 msgid "previously declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "kan antwoordbestand %s niet openen"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, fuzzy, gcc-internal-format
 msgid "unexpected offset"
 msgstr "onverwachte operand"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ongeldig register in de instructie"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ongeldig register in de instructie"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "kan %s niet vinden"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "open %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr ""
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "open %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 msgid "waitpid failed"
 msgstr "pex_init mislukt"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, fuzzy, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, fuzzy, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, fuzzy, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "kan antwoordbestand %s niet openen"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/ChangeLog
===================================================================
--- gcc/po/ChangeLog	(.../tags/gcc_8_1_0_release)
+++ gcc/po/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,13 @@
+2018-05-03  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
+2018-05-02  Joseph Myers  <joseph@codesourcery.com>
+
+	* es.po: Update.
+
 2018-05-02  Release Manager
 
 	* GCC 8.1.0 released.
Index: gcc/po/vi.po
===================================================================
--- gcc/po/vi.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/vi.po	(.../branches/gcc-8-branch)
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -151,40 +151,40 @@
 msgid "negative insn length"
 msgstr "chiều dài insn âm"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "không thể chia tách insn"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "“asm” không hợp lệ: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "các sự xen kẽ phương ngôn assembly lồng nhau"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "sự xen kẽ phương ngôn assembly chưa chấm dứt"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "số thứ tự toán hạng còn thiếu đằng sau %%-letter"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "số thứ tự toán hạng ở ngoại phạm vi"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "%%-code sai"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "toán hạng “%%l” không phải là một nhãn"
@@ -195,13 +195,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "sai sử dụng hằng số dấu chấm động"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1197,25 +1197,25 @@
 msgid "At top level:"
 msgstr "Ở cấp đầu:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "Trong hàm bộ phận %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "Trong hàm %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    trực tiếp từ %qs tại %r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    trực tiếp từ %qs tại %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    trực tiếp từ %qs"
@@ -2968,9 +2968,9 @@
 msgid "invalid address mode"
 msgstr "sai đặt chế độ đặt địa chỉ"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
@@ -2986,7 +2986,7 @@
 msgstr "giá trị %%r sai"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2993,13 +2993,13 @@
 msgstr "giá trị %%R sai"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
@@ -3030,7 +3030,7 @@
 msgstr "giá trị %%U sai"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
@@ -3041,7 +3041,7 @@
 msgstr "giá trị %%C sai"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
@@ -3052,7 +3052,7 @@
 msgstr "không rõ bỏ ghi rõ bố trí lại"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3063,58 +3063,58 @@
 msgid "invalid operand address"
 msgstr "địa chỉ toán hạng không hợp lệ"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "toán hạng không hợp lệ cho mã %%Z"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "toán hạng không hợp lệ cho mã %%z"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "toán hạng không hợp lệ cho mã %%Z"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "toán hạng không hợp lệ cho mã %%M"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "sai đặt toán hạng tới mã %%p"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "sai đặt toán hạng tới mã %%s"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "sai đặt toán hạng tới mã %%R"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "sai đặt toán hạng tới mã %%H/%%L"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "sai đặt toán hạng tới mã %%U"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "toán hạng không hợp lệ cho mã %%V"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "toán hạng không hợp lệ cho mã %%O"
@@ -3121,18 +3121,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "sai đặt mã kết xuất toán hạng"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "không nhận ra điều nên là hằng số"
 
@@ -3167,7 +3167,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
@@ -3298,8 +3298,8 @@
 msgstr "toán hạng const_double sai"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3516,103 +3516,103 @@
 msgid "bad output_condmove_single operand"
 msgstr "đặt sai toán hạng output_condmove_single"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "đặt sai UNSPEC như là toán hạng"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "dùng %<restrict%> không hợp lệ"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "sử dụng kết xuất cờ asm sai"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “O”"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “z”"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “Z”"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “D”"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng không hợp lệ “%c”"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "mã toán hạng sai “%c”"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid zero extract"
 msgid "invalid vector immediate"
 msgstr "trích số không không hợp lệ"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "không rõ chế độ lệnh"
 
@@ -3650,7 +3650,7 @@
 msgstr "gặp toán hạng %%P sai"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -3704,7 +3704,7 @@
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -3867,141 +3867,141 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion yêu cầu mô hình mã medium/large"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 và __ibm128 không thể được dùng trong cùng một biểu thức"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, reg #1 sai"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, reg #2 sai"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load không MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, reg #1 sai"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, reg #2 sai"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store không MEM"
 
@@ -4129,43 +4129,43 @@
 msgid "created and used with different endianness"
 msgstr "tạo và sử dụng với các trình trạng cuối khác nhau"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "toán hạng %%Y sai"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "toán hạng %%A sai"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "toán hạng %%B sai"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "sai toán hạng %%C"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "sai toán hạng %%D"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "toán hạng %%f sai"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "toán hạng %%s sai"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "hằng số dấu chấm động không phải là một giá trị trực tiếp hợp lệ"
@@ -4380,14 +4380,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -4402,7 +4402,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -4410,7 +4410,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -4424,7 +4424,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
@@ -4431,7 +4431,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -4441,13 +4441,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
@@ -4456,18 +4456,18 @@
 msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
@@ -4475,23 +4475,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
@@ -4500,7 +4500,7 @@
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -4511,46 +4511,46 @@
 msgid "expected label"
 msgstr "cần kênh"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "ứng cử 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "nhảy tới nhãn %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "nhảy tới nhãn lệnh case"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  vào khối try"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  vào khối catch"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 #| msgid "  enters OpenMP structured block"
 msgid "enters OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 msgid "enters synchronized or atomic statement"
 msgstr "cần biểu thức"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 msgid "enters constexpr if statement"
 msgstr "cần biểu thức"
@@ -4641,7 +4641,7 @@
 msgid "<statement>"
 msgstr "<lời khai báo>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<không rõ>"
@@ -4661,118 +4661,118 @@
 msgstr "<chưa phân tích cú pháp>"
 
 # Literal: don't translate; Nghĩa chữ: dừng dịch
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr "<lambda>"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<lỗi biểu thức>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<không rõ toán hạng>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "Theo phạm vi toàn cục:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "Trong hàm bộ phận tĩnh %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "Trong cấu tử bản sao %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "Trong cấu tử %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "Trong bộ hủy %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "Trong hàm λ"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: Trong thay thế của %qS:\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: Trong minh dụ của %q#D:\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr "%r%s:%d:%d:%R   "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr "%r%s:%d:%R   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "yêu cầu đệ quy bởi thay thế của %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr "được yêu cầu bởi thay thế của %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr "yêu cầu đệ quy từ %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr "được yêu cầu từ %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr "yêu cầu đệ quy từ đây\n"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr "được yêu cầu từ đây\n"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%d:%R   [ bỏ qua %d ngữ cảnh minh dụ, dùng -ftemplate-backtrace-limit=0 để tắt ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%R   [ bỏ qua %d ngữ cảnh minh dụ, dùng -ftemplate-backtrace-limit=0 để tắt ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 #, fuzzy
 #| msgid "%r%s:%d:%d:%R   in constexpr expansion of %qs"
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%d:%R   trong khai triển constexpr của %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 #, fuzzy
 #| msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   trong khai triển constexpr của %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "các ứng cử là:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
@@ -4817,48 +4817,48 @@
 msgid "source type is not polymorphic"
 msgstr "nguồn không có loại nhiều dạng"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "đối số có loại sai đối với dấu trừ nguyên phân"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "đối số có loại sai đối với dấu cộng nguyên phân"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "đối số có loại sai đối với phần bù bit"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "đối số có loại sai đối với phần chia"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "trong đối số tới bộ nguyên phân !"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "không có toán tử tiền gia cho loại"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "không có toán tử hậu gia cho loại"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "không có toán tử giảm gia cho loại"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "không có toán tử hậu giảm cho loại"
 
@@ -5133,11 +5133,11 @@
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
@@ -5293,47 +5293,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tại %%L và %%L có một toán tử với các phân hàng mâu thuẫn nhau"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
@@ -5375,12 +5375,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Tham số NCOPIES của REPEAT (lặp lại) hạn chế là âm (giá trị của nó là %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Điều thực chất REPEAT (lặp lại) có đối số NCOPIES (số các bản sao) quá lớn"
 
@@ -5616,6 +5616,7 @@
 msgstr "hai tùy chọn -Xbind-now và -Xbind-lazy không tương thích với nhau"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "sử dụng gprof(1) thì đề nghị bạn dùng \"-pg\" thay cho \"-p\""
 
@@ -8338,7 +8339,7 @@
 msgstr "Xếp hàng tất cả các biến theo một biên giới 32-byte."
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr "Ghi rõ tên của kiến trúc đích."
 
@@ -8799,7 +8800,7 @@
 msgstr "Ghi rõ phạm vi các thanh ghi cần làm cho cố định."
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr "Ghi rõ kích cỡ bit của hiệu số TLS trực tiếp."
 
@@ -9465,7 +9466,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Tạo ra mã thích hợp với ABI đưa ra."
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "Chưa biết ABIs (để dùng với tùy chọn -mabi=):"
 
@@ -9891,7 +9892,7 @@
 msgstr "Hỗ trợ các hàm dựng sẵn và chức năng tạo ra mã loại PKU."
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -9900,12 +9901,12 @@
 msgstr "Chưa biết bảo vệ bộ bảo vệ ngăn xếp (để dùng với tùy chọn -mstack-protector-guard=):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -9918,49 +9919,51 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation."
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Hỗ trợ các hàm dựng sẵn và chức năng tạo ra mã loại MMX và SSE."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Warn about function call elimination."
 msgid "Make all function calls indirect."
 msgstr "Cảnh báo về lời gọi hàm ngầm."
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 #, fuzzy
 #| msgid "Known data alignment choices (for use with the -malign-data= option):"
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Không hiểu lựa chọn cân chỉnh dữ liệu (để dùng với tùy chọn -malign-data=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Hỗ trợ các hàm dựng sẵn và chức năng tạo ra mã loại BMI."
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Hỗ trợ các hàm dựng sẵn và chức năng tạo ra mã loại BMI."
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr "Coi là mã sẽ được liên kết bởi ld của GNU."
@@ -10339,7 +10342,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Tùy chọn đã lạc hậu.  Dùng -mvrsave để thay thế."
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -10347,7 +10350,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10431,7 +10434,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\tĐịnh thời mã cho CPU đưa ra."
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr "-mtraceback=\tChọn bảng vét lùi đầy đủ (full), bộ phận (part) hoặc không có (none)."
 
@@ -10459,7 +10462,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Đối số hợp lệ cho -mfloat-gprs=:"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr "-mlong-double-<số>\tGhi rõ kích cỡ của đôi dài (64 hay 128 bit)."
 
@@ -10536,23 +10539,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Sử dụng câu lệnh ISA 2.07 Category:Vector.AES và Category:Vector.SHA2."
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -10572,20 +10575,20 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 #, fuzzy
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Đừng sử dụng chỉ lệnh callt (mặc định)."
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 #, fuzzy
 msgid "Use vector instructions added in ISA 3.0."
 msgstr "Đừng sử dụng chỉ lệnh callt (mặc định)."
@@ -10605,16 +10608,16 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr "Đừng sử dụng chỉ lệnh callt (mặc định)."
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 #, fuzzy
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Đừng sử dụng chỉ lệnh callt (mặc định)."
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr ""
 
@@ -10622,15 +10625,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "Bậ sử dụng câu lệnh só thực dấu chấm động thập phân 128-bit IEEE thông qua từ khóa __float128."
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Bật sử dụng câu lệnh dấu số thực chấm động 128-bit IEEE."
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -10638,7 +10641,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 #| msgid "Valid arguments to -mfloat-gprs=:"
 msgid "Valid arguments to -mstack-protector-guard=:"
@@ -10669,12 +10672,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Gọi mcount để đo hiệu năng sử dụng đẳng trước một đoạn mở đầu hàm."
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr "Chọn quy ước gọi ABI."
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr "Chọn phương pháp để quản lý sdata."
 
@@ -11345,7 +11347,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Tránh các thanh ghi đích và địa chỉ chồng chéo lên nhau đối với câu lệnh LDRD"
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -11545,14 +11547,28 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mfused-madd%> đã lạc hậu; dùng %<-ffp-contract=%> để thay thế"
 
-#: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:338
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare without loops."
+msgstr "Số tối đa các lệnh của một vòng lặp chưa chuyển đổi nhánh."
+
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare with loops."
+msgstr "Số tối đa các lệnh của một vòng lặp chưa chuyển đổi nhánh."
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop."
+msgid "Max number of pairs of load insns for compare."
+msgstr "Số tối đa các lần lột một vòng lặp riêng lẻ."
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
@@ -11565,10 +11581,48 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-mcpu=%> đã lạc hậu; dùng %<-mtune=%> hoặc %<-march=%> để thay thế"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table."
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tChọn bảng vét lùi đầy đủ (full), bộ phận (part) hoặc không có (none)."
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<số>\tGhi rõ kích cỡ của đôi dài (64 hay 128 bit)."
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs đã lạc hậu"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention."
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Chọn quy ước gọi ABI."
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling."
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Chọn phương pháp để quản lý sdata."
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets."
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Ghi rõ kích cỡ bit của hiệu số TLS trực tiếp."
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr "Sử dụng thanh ghi dấu chấm động."
@@ -12661,96 +12715,162 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Cho phép gcc tạo chỉ lệnh SETLB và Lcc."
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "Tạo mã trong chế độ về cuối lớn."
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "Tạo ra mã trong chế độ về cuối nhỏ."
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr "Sử dụng cả bộ thanh ghi cho phân bổ thanh ghi."
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+#, fuzzy
+#| msgid "Align code and data to 32 bits."
+msgid "Align function entry to 4 byte."
+msgstr "Xếp hàng mã và dữ liệu theo 32-bit."
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr "Tạo chỉ lệnh di chuyển điều kiện"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr "Tạo chỉ lệnh năng suất mở rộng."
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate performance extension instructions."
 msgid "Generate performance extension version 2 instructions."
 msgstr "Tạo chỉ lệnh năng suất mở rộng."
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate performance extension instructions."
 msgid "Generate string extension instructions."
 msgstr "Tạo chỉ lệnh năng suất mở rộng."
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Tạo ra câu lệnh push25/pop25 v3."
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr "Tạo ra câu lệnh 16-bit."
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Enable multicore support."
 msgid "Enable Virtual Hosting support."
 msgstr "Bật khả năng hỗ trợ đa lõi."
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr "Hiểu kiến trúc (để dùng với tùy chọn -march=):"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "Hiểu cmodel (để dùng với tùy chọn -mcmodel=):"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the code model."
 msgid "Specify the cpu for pipeline model."
 msgstr "Chỉ định mô hình mã."
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 #, fuzzy
 #| msgid "Known arch types (for use with the -march= option):"
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Hiểu kiến trúc (để dùng với tùy chọn -march=):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+#, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "Không hiểu kiểu dấu chấm động ABIs (để dùng với tùy chọn -mfloat-abi=):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr "Bật tính năng cấu/hủy tử"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr ""
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Tạo ra câu lệnh nhân-cộng kiểu dấu chấm động"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions."
+msgid "Generate single-precision floating-point instructions."
+msgstr "Sử dụng câu lệnh dấu chấm động đôi-đơn."
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Tạo ra mã sử dụng chỉ lệnh dấu chấm động 68881."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr "Ghi rõ CPU cho mục đích tạo ra mã."
@@ -13573,13 +13693,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Tạo ra câu lệnh mul64 và mulu64."
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs đã lạc hậu"
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr "Đừng tạo chỉ lệnh mpy cho ARC700."
@@ -15848,8 +15961,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "giá trị được tính không được sử dụng"
@@ -15875,7 +15988,7 @@
 msgstr "cần kiểu boolean"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Mong đợi một số nguyên"
@@ -16295,7 +16408,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16321,12 +16434,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "thuộc tính bị bỏ qua"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -16375,9 +16488,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16390,8 +16503,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "khai báo trước đây của %qD"
@@ -16526,82 +16639,74 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "đối số không được hỗ trợ cho %D"
@@ -16608,72 +16713,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "cả hai đối số cho %<__builtin___clear_cache%> phải là các con trỏ"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD đã đổi ngữ nghĩa trong GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "đối số mô hình bộ nhớ không hợp lệ cho phần tích hợp"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer không được hỗ trợ trên đích này"
@@ -16680,7 +16785,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -16687,12 +16792,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> đối số thứ hai phải là 1"
@@ -16699,63 +16804,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Nền tảng đích của bạn không hỗ trợ -fcheck-pointer-bounds"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "định dạng đích không hỗ trợ vô cực"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "sai số lượng đối số cho hàm %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "sai số lượng đối số cho hàm %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "đối số thứ hai của %<va_start%> không là đối số có tên cuối"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "đối số %qd không phải hằng số"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -17931,37 +18036,37 @@
 msgid "conversion to incomplete type"
 msgstr ""
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr ""
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr ""
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "không thể chuyển đổi giá trị thành kiểu vector"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -18117,12 +18222,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18232,12 +18337,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18253,12 +18358,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr ""
@@ -18268,42 +18373,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "so sánh luôn là %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18844,28 +18949,28 @@
 msgid "can%'t write PCH file"
 msgstr "can%'t ghi tập tin PCH"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -18879,12 +18984,13 @@
 msgid "null pointer dereference"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "được khai báo ở đây"
@@ -19384,10 +19490,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -19418,7 +19524,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -19759,254 +19865,259 @@
 msgid "function cannot be instrumented"
 msgstr ""
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "phương thức ảo %qD"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT should match type %qT"
 msgid "type name %qs should match type name %qs"
 msgstr "kiểu %qT nên khớp kiểu %qT"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "kiểu không tương thích được định nghĩa ở đây"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr ""
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "không khớp kiểu trong tham số %i"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, fuzzy, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "định nghĩa trước ở đây"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "kiểu %qT nên khớp kiểu %qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here, later in the translation unit"
 msgid "fields have different layout in another translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -20027,37 +20138,37 @@
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20335,30 +20446,37 @@
 msgstr "CPU đích không hỗ trợ truy cập chưa cân chỉnh"
 
 #: multiple_target.c:91
-#, gcc-internal-format
-msgid "default target_clones attribute was not set"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "default target was not set"
+msgid "default %<target_clones%> attribute was not set"
+msgstr "chưa đặt đích mặc định"
 
-#: multiple_target.c:324
-#, gcc-internal-format
-msgid "single target_clones attribute is ignored"
-msgstr ""
+#: multiple_target.c:343
+#, fuzzy, gcc-internal-format
+#| msgid "%qs attribute ignored"
+msgid "single %<target_clones%> attribute is ignored"
+msgstr "thuộc tính %qs bị bỏ qua"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr "chưa đặt đích mặc định"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20671,12 +20789,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "không nhận ra đối số tới tùy chọn %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
@@ -21294,22 +21412,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21353,7 +21471,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "xung đột với %qD"
@@ -21594,158 +21712,158 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "ký hiệu hàm không phải là một hàm"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "ký hiệu biến đổi không là một biến"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "nút có kiểu không hiểu"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify gặp lỗi"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -22923,12 +23041,12 @@
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23431,7 +23549,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -23476,92 +23594,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "kiểm tra cây: %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "tree check: cần không gì của %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: cần lớp %qs, có %qs (%s) trong %s, tại %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "tree check: cần omp_clause %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD đã lạc hậu: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD đã lạc hậu"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE đã lạc hậu: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE đã lạc hậu"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "kiểu đã lạc hậu"
@@ -23586,243 +23704,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr ""
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type gặp lỗi"
@@ -23847,12 +23965,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -24750,7 +24868,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh phép gán được dùng như là giá trị chân lý"
@@ -25002,7 +25120,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "kích cỡ mảng là quá lớn"
@@ -25614,7 +25732,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25629,22 +25747,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -26190,8 +26308,8 @@
 msgid "wrong type argument to %s"
 msgstr "sai kiểu đối số cho %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "tràn trong biểu thức hằng"
@@ -26842,7 +26960,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -26919,7 +27037,7 @@
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -27055,47 +27173,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s có số sửa đổi silíc không hợp lệ"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops đã cũ, hãy dùng -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps đã cũ, hãy dùng -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions đã cũ, hãy dùng -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d không nằm giữa 0 và %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d không nằm trong khoảng 0 và 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> hiện nay chỉ được hỗ trợ trên GNU/Linux"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -27122,31 +27240,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "không hiểu tùy chọn -mdebug-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "không hiểu tùy chọn -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "tùy chọn -msingle-float tương đương với -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "tùy chọn -msimple-fpu bị bỏ qua"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "%<-fsplit-stack%> hiện nay chỉ được hỗ trợ trên GNU/Linux PowerPC64 với glibc-2.18 hay mới hơn"
@@ -27636,8 +27754,8 @@
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
@@ -27718,8 +27836,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "giá trị sai %qs cho -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27831,11 +27949,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27845,150 +27963,140 @@
 msgid "%qE attribute only applies to functions"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "argument of %qE attribute is missing"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to SH2A"
 msgid "%qE attribute only applies to types"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho SH2A"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "thuộc tính %qE bị lờ đi"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
@@ -28015,153 +28123,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "bộ chọn phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 7"
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 3"
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 1"
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mặt nạ phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "vùng mặt nạ phải nằm từ 0 đến 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_rori_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_ror_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_si64 trong mã."
@@ -28966,12 +29074,12 @@
 msgid "invalid IACC argument"
 msgstr "đối số IACC không hợp lệ"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs cần một đối số hằng"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
@@ -29071,576 +29179,561 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "Không thể đặt vị trí trong tập tin PCH: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "không hiểu hàm đặc tả %qs"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "không chỉ định tên lớp với %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "không hiểu tên thanh ghi: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "%<-Wabi=1%> không được hỗ trợ, dùng =2"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel không được hỗ trợ trong cấu hình này"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "chế độ %i-bit chưa được biên dịch bên trong"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU bạn chọn không hỗ trợ chỉ lệnh x86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX không hỗ trợ x32"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d không nằm giữa 0 và %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "%<-msseregparm%> used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Chỉ lệnh SSE đặt là tắt, sử dụng số học 387"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "“%qs” không phải là một tùy chọn hợp lệ cho bộ tiền xử lý"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "tùy chọn (\"%s\") đã sẵn được đưa ra rồi"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "cdecl and thiscall attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -29647,314 +29740,314 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 2-bít"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "đối số thứ ba phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 3-bít"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "chế độ so sánh không đúng"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "đối số cuối phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "đối số thứ tư phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 #| msgid "unknown pointer size model %qs"
 msgid "unknown architecture specific memory model"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported return type %qT for simd"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported argument type %qT for simd"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30175,7 +30268,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -30704,9 +30797,38 @@
 msgid "constant argument out of range for %s"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "hàm dựng sẵn chỉ sẵn có trên fr405"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "hàm dựng sẵn chỉ sẵn có trên fr405"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "-pie không được hỗ trợ trong cấu hình này"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
 #| msgid "Generate performance extension instructions."
+msgid "don't support performance extension instructions"
+msgstr "Tạo chỉ lệnh năng suất mở rộng."
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate performance extension instructions."
+msgid "don't support performance extension version 2 instructions"
+msgstr "Tạo chỉ lệnh năng suất mở rộng."
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
+#| msgid "Generate performance extension instructions."
 msgid "don't support string extension instructions"
 msgstr "Tạo chỉ lệnh năng suất mở rộng."
 
@@ -30726,42 +30848,59 @@
 msgstr ""
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr ""
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr ""
+
+#: config/nds32/nds32.c:3508
+#, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "position-independent code not supported"
@@ -30978,37 +31117,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -31102,12 +31241,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -31157,7 +31296,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert chỉ chấp nhận ba tham số"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -31461,7 +31600,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31471,7 +31610,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31481,12 +31620,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31496,28 +31635,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "đối số 1 phải là trường 8-bit"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "đối số 1 phải là kiểu văn có dấu 5-bit"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
@@ -31537,12 +31676,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
@@ -31564,53 +31703,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 4-bit"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 2-bit"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 6-bit"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "đối số 2 phải là 0 hay 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -31735,7 +31874,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "khung stack quá lớn"
@@ -31745,12 +31884,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -31760,22 +31899,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -31785,7 +31924,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -32251,22 +32390,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -32330,33 +32469,39 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, fuzzy, gcc-internal-format
+#| msgid "Function %qs requires an argument list at %C"
+msgid "builtin %qs requires builtin %qs"
+msgstr "Hàm %qs cần một danh sách đối số tại %C"
+
+#: config/rs6000/rs6000-c.c:7058
+#, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "-pie không được hỗ trợ trong cấu hình này"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
@@ -32495,45 +32640,45 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs đã lỗi thời và không có tác động gì"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "đối số %qd không phải hằng số"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs is too large (max. %d)"
 msgid "argument 1 of %qs is out of range"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts a string argument"
@@ -32540,7 +32685,7 @@
 msgstr "%s chỉ chấp nhận một tham số"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -32547,132 +32692,132 @@
 msgstr "đối số không hợp lệ cho %qD"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be 0 or 2"
 msgid "second argument to %qs must be 0..12"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be 0 or 2"
 msgid "third argument to %qs must be 0..12"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 of %s must be a constant"
 msgstr "đối số 1 phải là ánh xạ"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "hàm dựng sẵn chỉ sẵn có trên fr405"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "-pie không được hỗ trợ trong cấu hình này"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qs uses register r29"
 msgstr "%qE được dùng với %<register%>"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33483,7 +33628,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -33735,7 +33880,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -33745,7 +33890,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -33805,7 +33950,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -33835,7 +33980,7 @@
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "trùng nhãn %qD"
@@ -33953,7 +34098,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -34208,7 +34353,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -34367,7 +34512,7 @@
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -34494,7 +34639,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -34674,7 +34819,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -34724,7 +34869,7 @@
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -34760,7 +34905,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "khai báo lại của %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
@@ -34790,7 +34935,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
@@ -34820,7 +34965,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
@@ -34935,12 +35080,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
@@ -35003,7 +35148,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
@@ -35148,37 +35293,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "dịch trái của một giá trị âm"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
@@ -35209,7 +35354,7 @@
 msgid "to match this %qs"
 msgstr "không khớp cho"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -35250,7 +35395,7 @@
 msgstr "không hiểu tên kiểu %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -35265,7 +35410,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -35280,8 +35425,8 @@
 msgid "unexpected attribute"
 msgstr "cần thuộc tính"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -35319,7 +35464,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> có lẽ chỉ được dùng với khai báo đơn"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "cần %<,%> hoặc %<;%>"
@@ -35347,7 +35492,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 không hỗ trợ %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "cần chuỗi văn chương"
@@ -35411,13 +35556,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "dấu phẩy ở cuối của danh dánh liệt kê"
@@ -35547,7 +35692,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> mà không có %<if%> ở trước"
@@ -35581,22 +35726,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "cần biểu thức"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -35616,12 +35761,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -35649,12 +35794,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -35940,7 +36085,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_complex%> toán hạng không đúng kiểu"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "sai số tham số cho %<__builtin_shuffle%>"
@@ -36000,77 +36145,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "cần biểu thức nguyên trước “)”"
@@ -36085,54 +36230,54 @@
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến trỏ"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "cần %<data%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -36154,83 +36299,83 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%> giá trị phải dương"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%> giá trị phải dương"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "cần %<tofrom%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "cần %<scalar%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "biểu thức %qs phải là số nguyên"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "gặp tham số thừa"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -36240,12 +36385,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%> giá trị phải dương"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%> giá trị phải dương"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -36265,17 +36410,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -36285,67 +36430,67 @@
 msgid "invalid proc_bind kind"
 msgstr "kiểu proc_bind không hợp lệ"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "cần mệnh đề %<#pragma acc%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
@@ -36360,7 +36505,7 @@
 msgid "expected function name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD không phải là hàm thành viên mẫu"
@@ -36370,44 +36515,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> đã được áp dụng với %D"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau cho bộ nhớ"
@@ -36417,22 +36562,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
@@ -36442,72 +36587,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> với mệnh đề %<depend%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36527,32 +36672,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "cần %<declare%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36607,47 +36752,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
@@ -36662,7 +36807,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "sử dụng sai biểu thức void"
@@ -36783,7 +36928,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "chỉ số mảng không phải là số nguyên"
@@ -36808,7 +36953,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -36911,18 +37056,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about use of multi-character character constants."
 msgid "comparison between pointer and zero character constant"
 msgstr "Cảnh báo về sử dụng hằng số ký tự đa ký tự."
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "did you mean to use logical not?"
 msgid "did you mean to dereference the pointer?"
@@ -36948,7 +37093,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -37181,7 +37326,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -37337,7 +37482,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -37407,7 +37552,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sai sử dụng mảng không phải lvalue"
@@ -37477,12 +37622,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "mảng ký tự bị khởi tạo từ chuỗi rộng"
@@ -37528,7 +37673,7 @@
 msgid "invalid initializer"
 msgstr "bộ khởi tạo sai"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -37543,7 +37688,7 @@
 msgid "braces around scalar initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "bộ phận mảng dẻo bị khởi tạo trong một ngữ cảnh lồng nhau"
@@ -37673,7 +37818,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C cấm %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
@@ -37713,7 +37858,7 @@
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -37723,17 +37868,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "câu lệnh “continue” nằm ở ngoài một vòng lặp"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -37758,22 +37903,22 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -37824,7 +37969,7 @@
 msgstr ""
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -37854,12 +37999,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -37869,25 +38014,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE không phải là thành viên của union"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
@@ -37898,70 +38043,70 @@
 msgstr "%<_Atomic%> %qD trong mệnh đề %qs"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
@@ -37981,7 +38126,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE có kiểu không hợp lệ cho %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -37991,17 +38136,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE phải là %<threadprivate%> với %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -38016,18 +38161,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -38039,32 +38184,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
@@ -38084,55 +38229,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE không phải một kiểu ánh xạ được trong mệnh đề %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE không phải một biến cũng không phải tên hàm trong mệnh đề %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
@@ -38142,32 +38287,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -38308,7 +38453,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38392,27 +38537,27 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%D(%A)%> chưa rõ ràng"
@@ -38419,623 +38564,623 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "cú gọi của %<(%T) (%A)%> chưa rõ ràng"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "quá tải chưa rõ ràng đối với"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr "không khớp cho"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (các kiểu toán hạng là %qT, %qT, and %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (các kiểu toán hạng là %qT và %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (kiểu toán hạng là %qT)"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "bộ tam nguyên %<operator?:%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "bộ tam nguyên %<operator?:%> trong %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> trong %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> trong %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs trong %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> trong %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> trong %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "so sánh giữa %q#T và %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "đã được khai báo ở đây"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "được khai báo bảo vệ ở đây"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D là không thể truy cập trong ngữ cảnh này"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  đang khởi tạo đối số %P của %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "suy diễn %qT như là %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 #| msgid "re-initialization of %qs at %L"
 msgid "; use copy-initialization instead"
 msgstr "khởi tạo lại của %qs tại %L"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%#qT declared here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%s(%A)%> chưa rõ ràng"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "đóng %qD thông qua %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ứng cử 1: %q#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ứng cử 2: %q#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -39077,8 +39222,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D không thể được quá tải"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "khai báo trước đây %q#D"
@@ -39122,7 +39267,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT được khai báo ở đây"
@@ -39202,7 +39347,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -39480,7 +39625,7 @@
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
@@ -39550,7 +39695,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "không đủ thông tin kiểu"
@@ -39648,336 +39793,336 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD không phải là đối số hàm"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E không phải biểu thức hằng"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "gọi hàm nội bộ"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "gọi hàm nội bộ"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD được gọi trong một biểu thức hằng"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD được dùng trước khi nó được định nghĩa"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "toán hạng phải của biểu thức dịch %q+E là số âm"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "con trỏ rỗng"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D không là const"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D là volatile"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD không được khởi tạo với một biểu thức hằng"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<constexpr%> outside its class"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD được khai báo %<constexpr%> ngoài lớp của nó"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40026,7 +40171,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -40037,308 +40182,308 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "chuyển đổi từ %q#T sang %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T được dùng ở nơi mà %qT cần"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "Conversion from %qs to %qs at %L"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "Chuyển đổi từ %qs sang %qs tại %L"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "câu lệnh không có tác động gì"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -40379,201 +40524,201 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr ""
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as array of function members"
 msgid "declaration of %qF has a different exception specifier"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "từ khai báo trước đây %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr ""
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr ""
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "định nghĩa trước đây của %q+D là đây"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "khai báo trước đây của %q+D ở đây"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as inline"
 msgid "built-in function %qD declared as non-function"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline)"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr ""
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr ""
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr ""
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr ""
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "xung đột với khai báo trước %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "derived type declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "lời khai báo loại có hướng"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr ""
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr ""
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr ""
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "khai báo cũ %q#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr ""
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr ""
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "khai báo trước đây là %q#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr "%q#D trước được định nghĩa ở đây"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D trước định nghĩa ở đây"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr ""
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr ""
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr ""
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "khai báo trước đây của %qL là linkage"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr ""
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "sau đặc tả trước đây trong %q#D"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr ""
@@ -40586,39 +40731,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "định nghĩa lại của %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -40626,635 +40771,635 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "khai báo lại của %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "khai báo trước"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  từ đây"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  thoát khỏi khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  sự khởi tạo chéo của %q+#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  vào khối catch"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  bỏ qua sự khởi tạo của %q#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  vào khối try"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr "cần biểu thức"
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T không phải là một lớp"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "không có kiểu có tên %q#T trong %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mpcommit%> was deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<-mpcommit%> đã lạc hậu"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mpcommit%> was deprecated"
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "%<-mpcommit%> đã lạc hậu"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-falign-labels=%d không được hỗ trợ"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> chỉ có thể được chỉ định trong một lớp"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> chỉ có thể được chỉ định cho cấu tử"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> chỉ có thể được chỉ định cho lớp và hàm"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> bị bỏ qua trong khai báo này"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D không phải là thành viên tĩnh của %q#T"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ không cho phép %<%T::%D%> được định nghĩa như là %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa được khởi tạo"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "thiếu kích thước mảng trong %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr ""
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "đối số %q#D có kiểu chưa đầy đủ"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "tham chiếu %qD được khởi tạo bằng chính nó"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "nguồn là một hàm trỏ tới loại không hoàn toàn"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -41261,883 +41406,894 @@
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
+#, fuzzy, gcc-internal-format
+#| msgid "source is of incomplete class type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "nguồn có loại lớp không hoàn toàn"
+
+#: cp/decl.c:7774
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> phải trả về %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D đã là mặc định rõ ràng ở đây"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "kích cỡ mảng %qD bị âm"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "kích cỡ mảng bị âm"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ cấm mảng có kích thước bằng không"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ cấm biến có kích thước biến đổi %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ cấm biến có kích thước biến đổi"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tràn kích thước mảng"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD được khai báo là mảng của %qT"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "sự khai báo của %qD như là mảng void"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "tạo mảng void"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "sự khai báo của %qD như là mảng của các hàm"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "tạo mảng hàm"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "sự khai báo của %qD như là mảng của các tham chiếu"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "tạo mảng tham chiếu"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "tạo mảng của thành viên hàm"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "no processor type specified for linking"
 msgid "return type specified for deduction guide"
 msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T không phải là một lớp hay namespace"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "sự khai báo của %qD như là non-member"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "sự khai báo của %qD như là %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ không hỗ trợ %<__int%d%> cho %qs"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> hoặc %<unsigned%> không hợp lệ với %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> và %<unsigned%> được chỉ định cùng với nhau cho %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%>không hợp lệ với %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> không hợp lệ với %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> hoặc %<short%> không hợp lệ với %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%>, hoặc %<char%> không hợp lệ cho %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> hoặc %<short%> đựoc chỉ định với kiểu char với %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> và %<short%> được chỉ định cùng nhau với %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> hoặc %<long%> không hợp lệ với %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "định nghĩa hàm được khai báo là %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
+#, fuzzy, gcc-internal-format
+msgid "deduced class type %qD in function return type"
+msgstr "kiểu lớp %qT chưa hoàn thiện"
+
+#: cp/decl.c:11156
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11099
-#, fuzzy, gcc-internal-format
-msgid "deduced class type %qT in function return type"
-msgstr "kiểu lớp %qT chưa hoàn thiện"
-
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42144,306 +42300,306 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not have parameters"
 msgid "constructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> ngoài khai báo lớp"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -42450,158 +42606,158 @@
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "cấu tử không thể là %<concept%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -42608,77 +42764,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -42698,176 +42854,176 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "hậu tố %qD cần trả về %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -42879,94 +43035,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT được định nghĩa với cơ sở đa trực tiếp"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT được định nghĩa cơ sở trực tiếp ảo"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
@@ -42975,78 +43131,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "increment of enumeration value is invalid in C++"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "khai báo hàm không hợp lệ"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43086,7 +43242,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "cho khai báo hàm mẫu %q+D"
@@ -43099,7 +43255,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -43212,42 +43368,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "thành viên dữ liệu tĩnh %q+D bên trong của chỉ thị khai báo đích"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "thành viên riêng %q+#D trong hỗn hợp nặc danh"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "thành viên bảo vệ %q+#D trong hỗn hợp nặc danh"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> phải trả về kiểu %qT"
@@ -43256,67 +43412,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> nhận kiểu %<size_t%> (%qT) như là đối số thứ nhất"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> phải trả về kiểu %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nhận kiểu %qT như là đối số thứ nhất"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
@@ -43325,64 +43481,64 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D xung đột với khai báo trước"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q#D"
 msgid "previous mangling %q#D"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -43389,18 +43545,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 #| msgid "converting far pointer to near pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -43410,113 +43566,113 @@
 msgid "with"
 msgstr "với"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "không có đối số nào"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 auto inline chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "ref-qualifiers chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD không phải là thành viên của %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> chưa được khai báo"
@@ -43662,360 +43818,360 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr ""
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr ""
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr ""
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D nên được khởi tạo"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sẽ được khởi tạo sau"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  cơ sở %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  khi khởi tạo ở đây"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "con trỏ cho trường bít %qD không hợp lệ"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "tràn số nguyên trong kích thước mảng"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "kiểu không hợp lệ %<void%> cho new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "bộ khởi tạo kết thúc bất ngờ"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44027,7 +44183,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -44110,67 +44266,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -44291,12 +44447,12 @@
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D xung đột với khai báo trước"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%d constructor found\n"
 #| msgid_plural "%d constructors found\n"
@@ -44303,34 +44459,34 @@
 msgid "%q#D hides constructor for %q#D"
 msgstr "Tìm thấy %d bộ cấu trúc\n"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr ""
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "sự khai báo của các bóng %qD như là thành viên của %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q#D"
 msgid "local external declaration %q#D"
 msgstr "khai báo toàn cục %q#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q#D"
 msgid "does not match previous declaration %q#D"
@@ -44339,60 +44495,60 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr ""
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %qD under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  khớp %q+D này dưới quy tắc ISO tiêu chuẩn"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr "  khớp %q+D này dưới quy tắc cũ"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr ""
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "use of deleted function %qD"
 msgid "using obsolete binding %qD"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%qT không phải là một namespace hay enum không hoạt vi"
@@ -44399,12 +44555,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr ""
@@ -44411,187 +44567,192 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT không phải là một namespace"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr ""
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD chưa được khai báo"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> tên hủy tử"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> các tên cấu tử trong %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD chưa được khai báo trong %qD"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "các khả năng được gợi ý:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "các khả năng được gợi ý:"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%qD không phải một biến trong mệnh đề %qs"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD đã định nghĩa rồi"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "switch %qs không còn tiếp tục được hỗ trợ nữa"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "attributes ignored on local using directive"
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX vào pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX rời bỏ pop_everything ()\n"
@@ -44611,7 +44772,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44636,7 +44797,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> chưa được khai báo"
@@ -44716,7 +44877,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -44939,7 +45100,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "cần khai báo"
@@ -45020,7 +45181,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
@@ -45035,872 +45196,863 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD không phải một mẫu"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ cấm compound-literals"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "dùng %qD không hợp lệ"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> không phải là thành viên lớp"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "kiểu không-scalar"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "dùng áp kiểu theo cách cũ"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gợi ý bao quanh biểu thức %<>>%> bằng dấu ngoặc đơn"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in casts"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "cần kết thúc của capture-list"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 #| msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "chụp %<*this%> chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "capture of non-variable %qE"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D được khai báo ở đây"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "lặp lại %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "cần labeled-statement"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> tên cấu tử, không phải kiểu"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> mở rộng"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> không ở đầu của một khối"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "khai báo trống rỗng"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> được dùng bên ngoài lớp"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> thay đổi ý nghĩa trong C++11; hãy bỏ nó đi"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "đặc tả linkage không hợp lệ"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 #| msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "static_assert không có lời nhắn chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "cần định danh hậu tố"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "cần toán tử"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu mặc định"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "cần template-id"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "cần template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "cần template-argument"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "cần bộ chỉ định kiểu"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "cần template-id cho kiểu"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "cần type-name (tên kiểu)"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD là một mẫu liệt kê"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD không phải tên một kiểu enumeration trong %qT"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "cần %<;%> hoặc %<{%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "không cho phép từ hạn định mở rộng"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ cấm kiểu liệt kê nặc danh không tên trống rỗng"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD không là một namespace-name"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> không cho phép định nghĩa ở đây"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "cần bộ khởi tạo"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> không phải một kiểu"
@@ -45909,17 +46061,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "bộ khai báo không hợp lệ"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "dùng %<%T::%D%> thay cho %<%T::%D%> cho tên của cấu tử trong tên hạn định"
@@ -45926,387 +46078,387 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "mã hạn định trong khai báo"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "cần câu khai báo"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD là một namespace"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "cần ptr-operator"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "đa ref-qualifiers"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "cách dùng không hợp lệ %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "cần type-specifier"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "cần %<,%> hoặc %<…%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "cần class-name"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "cần %<;%> sau định nghĩa cấu trúc"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "cần %<{%> hoặc %<:%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "không thể chỉ định %<override%> cho lớp"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "khai báo trước đây của %q+#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "cần %<;%> tại cuối khai báo thành viên"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "dùng %<auto%> không hợp lệ trong đặc tả ngoại lệ"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "cần %<:%> hoặc %<…%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -46315,519 +46467,519 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression (các đối số)"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma grainsize%> must be inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma grainsize%> phải ở bên trong một hàm"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  từ định nghĩa của %q#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -46834,91 +46986,91 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %#D"
 msgid "%s %#qD"
 msgstr "%s %#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD không phải là một mẫu hàm"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD cho %q+D không khớp bất kỳ khai báo mẫu nào"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing primary template attributes %s"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing primary template attribute %s"
@@ -46926,57 +47078,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id %qD trong khai báo của mẫu nguyên gốc"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD không phải là một hàm mẫu"
@@ -46989,153 +47141,153 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "khai báo trước ở đây"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <nặc danh>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -47143,47 +47295,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -47193,75 +47345,75 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "phần khai báo mẫu của %qD không hợp lệ"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "nhận được %d đối số mẫu cho %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  nhưng cần %d"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "invalid explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
@@ -47270,407 +47422,412 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "định nghĩa nguyên bản xuất hiện ở đây"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  kiểu không khớp %qT và %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE không tương đương với %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ứng cử cần ít nhất %d đối số, nhưng cung cấp %d"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  không thể chuyển đổi %qE (kiểu %qT) thành kiểu %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT không được dẫn xuất từ %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "in template argument for type %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần mẫu kiểu %qD, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  cần %qD nhưng lại nhận %qD"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "được cung cấp cho %qD"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "ràng buộc mẫu gặp lỗi nghiêm trọng"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr "cấu có không thành viên đã đặt tên"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -47689,278 +47846,278 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %#S"
 msgid "%s %#qS"
 msgstr "%s %#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "previous specification in %q#D here"
 msgid "exception specification of %qD depends on itself"
@@ -47973,107 +48130,113 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of %<auto%> in template argument"
+msgid "invalid use of %qT in template argument"
+msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -48282,7 +48445,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -48332,7 +48495,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
@@ -48406,298 +48569,299 @@
 msgstr "%qT không phải một kiểu enumeration"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
+#, fuzzy, gcc-internal-format
+#| msgid "a concept cannot be a member function"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "cấu tử không thể là hàm thành viên tĩnh"
+
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "biểu thức tĩnh %<gang%> phải nguyên"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<gang%> static value must bepositive"
 msgid "%<gang%> static value must be positive"
 msgstr "giá trị tĩnh %<gang%> phải dương"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "biểu thức số %<gang%> phải nguyên"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "biểu thức số %<worker%> phải là số nguyên"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> giá trị phải dương"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length value must bepositive"
 msgid "%<vector%> length value must be positive"
 msgstr "chiều dài %<vector%> giá trị phải dương"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<worker%> num value must bepositive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> giá trị phải dương"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> biểu thức phải nguyên"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> biểu thức phải nguyên"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_teams%> biểu thức phải nguyên"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<tile%> value must be integral"
 msgid "%<tile%> argument needs integral type"
 msgstr "giá trị %<tile%> phải là số nguyên"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "thẩm tra tĩnh gặp lỗi"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "thẩm tra tĩnh gặp lỗi: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
@@ -48824,12 +48988,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: gặp lỗi trong %s, tại %s:%d"
@@ -48891,751 +49055,745 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 has invalid type"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "đối số 2 có kiểu không hợp lệ"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "lấy địa chỉ của mảng tạm"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ cấm chuyển đổi hằng chuỗi thành %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "việc chuyển đổi từ chuỗi thành %qT đã lỗi thời"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> không phải là thành viên của %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT không là cơ sở của %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T không có thành viên nào mang tên %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT không phải kiểu con trỏ đến đối tượng"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "không thể gọi hàm %qD"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ cấm gọi %<::main%> từ bên trong chương trình"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD không thể được dùng như một hàm"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "quá nhiều đối số cho cấu tử %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "quá nhiều đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "quá ít đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "quá nhiều đối số cho hàm %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "quá ít đối số cho hàm %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "quá nhiều đối số cho phương thức %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "quá ít đối số cho phương thức %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "quá nhiều đối số cho hàm"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "quá ít đối số cho hàm"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL được dùng trong số học"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "số lượng quay trái bị âm"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "số lượng quay phải bị âm"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "số lượng quay trái >= độ rộng của kiểu"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "số lượng quay phải >= độ rộng của kiểu"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "các kiểu toán hạng là %qT và %qT"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "lấy địa chỉ của cấu tử %qE"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  cần qualified-id"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "đang lấy địa chỉ của mẫu"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "không thể lấy địa chỉ của %qs"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "useless cast to type %qT"
 msgid "useless cast to type %q#T"
 msgstr "trừ phi ép thành kiểu %qT"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "%E qualifier ignored on asm"
 msgid "type qualifiers ignored on cast result type"
 msgstr "từ hạn định %E bị bỏ qua trên asm"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "đang chuyển đổi từ %qT thành %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "áp đổi kiểu tử %qT thành %qT làm mất độ chính xác"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "áp đổi kiểu tử %qT thành %qT yêu cầu tăng cân chỉnh của kiểu đích"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ cấm việc áp đổi kiểu của mảng %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  trong định giá %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "gán giá trị cho mảng từ một danh sách bộ khởi tạo"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "mảng được dùng như là bộ khởi tạo"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "gán mảng không hợp lệ"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "could not convert %qE from %qT to %qT"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
+#| msgid "cannot convert %qT to %qT"
+msgid "cannot convert %qH to %qI"
+msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "%qD cannot have default arguments"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
-msgid "cannot convert %qH to %qI"
-msgstr "không thể chuyển đổi %qT thành %qT"
-
-#: cp/typeck.c:8804
-#, fuzzy
-#| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in return"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "trong đối số chuyển qua %P của %qD"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "tham chiếu đến biến cục bộ %qD được trả về"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "địa chỉ của nhãn %qD được trả về"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "địa chỉ của biến cục bộ %q+D được trả về"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "trả về một giá trị từ hủy tử"
@@ -49642,56 +49800,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "trả về danh sách bộ khởi tạo"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "biểu thức trả về với một giá trị, trong hàm trả lại “void”"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "đang dùng mẫu như là lvalue"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -49913,142 +50071,142 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "  no known conversion from %qT to %qT"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr ""
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr ""
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -50473,29 +50631,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Bộ dựng mảng chứa các chiều dài KÝ_TỰ khác nhau (%ld/%ld)"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray declaration at %C"
 msgid "Bad array dimension at %L"
 msgstr "Khai báo Coarray tại %C"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -50502,22 +50660,22 @@
 msgid "Simplification error"
 msgstr "gimplification gặp lỗi"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -51519,7 +51677,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -51689,7 +51847,7 @@
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -51942,454 +52100,454 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Sự khởi tạo kiểu cũ tại %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "đối số kiểu được dẫn suất tham số hóa"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "kiểu BYTE tại %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Giả định kiểu tại %C"
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "câu lệnh CLASS tại %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "thuộc tính ASYNCHRONOUS tại%C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "thuộc tính CONTIGUOUS tại %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "thuộc tính BẢO VỆ tại %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "thuộc tính VALUE tại %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "thuộc tính VOLATILE tại %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Thuộc tính sai"
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -52396,956 +52554,956 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Thiếu ký hiệu"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C) tại %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Tiền tố MODULE tại %C"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "thủ tục IMPURE tại %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A parameter name is required at %C"
 msgstr "Đẳng sau “%<*%>” thì yêu cầu một dấu ngoặc đơn mở"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Cần một giao diện không tên tại %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol %qs in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Trùng ký hiệu %qs trong danh sách đối số hình thức tại %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Trùng ký hiệu %qs trong danh sách đối số hình thức tại %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Thủ tục “%qs” tại %L đã sẵn có kiểu cơ bản của %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "Hàm khai báo tại %L không phải xuất hiện trong một GIAO DIỆN"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Không cần câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "cần lệnh %s tại %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Cần tên chấm dứt tại %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "Cần %<(%> tại %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Cần tên biến tại %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Cần \")\" tại %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "cần %<,%> hoặc kết thúc câu lệnh tại %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "câu lệnh CONTIGUOUS tại %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "câu lệnh VALUE tại %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "câu lệnh VOLATILE tại %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "câu lệnh ASYNCHRONOUS tại %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Kiểu TRỪU TƯỢNG tại %C"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "gặp lỗi khi đóng tập tin thống kê %s [%s]"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM và ENUMERATOR tại %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Trùng DEFERRED tại %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Cần access-specifier tại %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "cần %<)%> tại %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Cần tên ràng buộc tại %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "danh sách PROCEDURE tại %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Cần %<::%> tại %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Cần %<=>%> tại %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL trống rỗng tại %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "Cần %<,%> tại %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Không rõ tên thủ tục “%qs” tại %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -53684,27 +53842,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -54030,7 +54188,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Đang tạo mảng tạm tại %L"
@@ -54040,64 +54198,64 @@
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "cần biểu thức"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "sai di chuyển"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "containing loop"
 msgid "Interchanging loops at %L"
@@ -54220,12 +54378,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -55419,7 +55577,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56865,12 +57023,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -57114,8 +57272,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -57157,7 +57315,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -57499,182 +57657,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE cần biểu thức hằng tại %L"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -59031,7 +59189,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -59141,7 +59299,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -59515,228 +59673,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs tại %L phải là THỦ TỤC CON"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs tại %L phải là HÀM"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): sai kiểu biểu thức"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -59745,233 +59903,233 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "tham số %u có kiểu void"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ngữ cảnh sai cho hạn chế NULL() tại %L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -59978,12 +60136,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -59991,107 +60149,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60098,67 +60256,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL không hợp lệ %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -60165,7 +60323,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -60173,57 +60331,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -60230,890 +60388,890 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s tại %L"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của thủ tục FINAL tại %L phải là kiểu %qs"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là dẫn xuất kiểu %qs"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -61550,7 +61708,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -62190,18 +62348,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The event variable at %L shall not be coindexed "
 msgid "The event variable at %L shall not be coindexed"
@@ -62385,178 +62543,178 @@
 msgid "previously defined here as %s"
 msgstr "đã định nghĩa trước là %s"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr ""
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD đã định nghĩa rồi"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "đã định nghĩa trước ở đây"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "%qD trước đã khai báo ở đây"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "biến %qD được định nghĩa lại là một hàm"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "hàm %qD được định nghĩa lại thành một biến"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "đã khai báo trước ở đây"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "không thể phân tích số thập lục phân"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "không thể phân tích khoảng bù tập tin"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "không cần offset"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "gặp dòng sai trong tập tin phân giải"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "phân giải không hợp lệ trong tập tin phân giải"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "không thể đọc “LTO decls” từ %s"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Không thể mở %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Không thể map %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Không thể đọc %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() gặp lỗi"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid bị lỗi"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing argument to %qs"
 msgid "missing resolution data for %s"
 msgstr "thiếu đối số đối cho %qs"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/uk.po
===================================================================
--- gcc/po/uk.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/uk.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1-b20180401\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2018-04-04 20:22+0200\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <translation-team-uk@lists.sourceforge.net>\n"
@@ -154,40 +154,40 @@
 msgid "negative insn length"
 msgstr "від’ємна довжина інструкції"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "не вдалося розділити інструкцію"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "некоректна asm: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "вкладені варіанти діалектів асемблера"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "незавершена вставка діалектом асемблера"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "пропущено операнд після %%-літери"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "кількість операндів поза межами припустимого діапазону"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "некоректний %%-код"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "операнд «%%l» не є міткою"
@@ -198,13 +198,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "помилкове використання сталої із рухомою крапкою"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1155,25 +1155,25 @@
 msgid "At top level:"
 msgstr ""
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "У функції-члені %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr ""
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr ""
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr ""
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr ""
@@ -2909,9 +2909,9 @@
 msgid "invalid address mode"
 msgstr "некоректний режим адресування"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' використано без будь-яких локальних динамічних посилань TLS"
@@ -2927,7 +2927,7 @@
 msgstr "некоректне значення %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2934,13 +2934,13 @@
 msgstr "некоректне значення %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "некоректне значення %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "некоректне значення %%P"
@@ -2971,7 +2971,7 @@
 msgstr "некоректне значення %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "некоректне значення %%s"
@@ -2982,7 +2982,7 @@
 msgstr "некоректне значення %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "некоректне значення %%E"
@@ -2993,7 +2993,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3004,57 +3004,57 @@
 msgid "invalid operand address"
 msgstr ""
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr ""
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr ""
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "некоректні операнди для коду %%c"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr ""
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr ""
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr ""
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr ""
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr ""
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr ""
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr ""
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr ""
@@ -3061,18 +3061,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr ""
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr ""
 
@@ -3107,7 +3107,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr ""
@@ -3228,8 +3228,8 @@
 msgstr ""
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3446,97 +3446,97 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "некоректне використання регістру «%s»"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr ""
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, c-format
 msgid "invalid vector immediate"
 msgstr "некоректна векторна константа"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3574,7 +3574,7 @@
 msgstr ""
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "некоректне значення %%p"
@@ -3628,7 +3628,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "помилкова адреса"
 
@@ -3791,141 +3791,141 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr "Помилкове 128-бітове пересування"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "некоректне значення %%e"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "некоректне значення %%f"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "некоректне значення %%F"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "некоректне значення %%G"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "некоректне значення %%u"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4051,43 +4051,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "некоректний операнд %%Y"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "некоректний операнд %%A"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "некоректний операнд %%B"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "некоректний операнд %%C"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "некоректний операнд %%D"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "некоректний операнд %%f"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "некоректний операнд %%s"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4302,14 +4302,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "мало бути %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "мало бути %<,%>"
@@ -4324,7 +4324,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "мало бути %<)%>"
@@ -4332,7 +4332,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "мало бути %<]%>"
@@ -4346,7 +4346,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "мало бути %<(%>"
@@ -4353,7 +4353,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "мало бути %<{%>"
@@ -4363,13 +4363,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "мало бути %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "мало бути %<while%>"
@@ -4378,18 +4378,18 @@
 msgid "expected %<.%>"
 msgstr "мало бути %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "мало бути %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "мало бути %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "мало бути %<,%> або %<)%>"
@@ -4397,23 +4397,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "мало бути %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "мало бути %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "мало бути %<#pragma omp section%> або %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "мало бути %<[%>"
@@ -4422,7 +4422,7 @@
 msgid "(anonymous)"
 msgstr "(анонімний)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "мало бути %<<%>"
@@ -4433,39 +4433,39 @@
 msgid "expected label"
 msgstr "мало бути вказано мітку"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr ""
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr ""
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr ""
 
@@ -4554,7 +4554,7 @@
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4573,114 +4573,114 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr ""
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<невідомий оператор>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "У статичній функції-члені %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr ""
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr ""
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr ""
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr ""
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr ""
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr "потрібен звідси\n"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%d:%R   у розгортанні %<constexpr%> %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4727,48 +4727,48 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5039,11 +5039,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "присвоювання"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr ""
 
@@ -5198,47 +5198,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5280,12 +5280,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5519,6 +5519,7 @@
 msgstr ""
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -8179,7 +8180,7 @@
 msgstr ""
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr ""
 
@@ -8622,7 +8623,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr ""
 
@@ -9281,7 +9282,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr ""
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -9683,7 +9684,7 @@
 msgstr ""
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -9692,12 +9693,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -9710,41 +9711,41 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
 msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 msgid "Make all function calls indirect."
 msgstr ""
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr ""
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1057
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr ""
@@ -10119,7 +10120,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -10127,7 +10128,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10211,7 +10212,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr ""
 
@@ -10239,7 +10240,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr ""
 
@@ -10315,23 +10316,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -10351,19 +10352,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -10379,15 +10380,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr ""
 
@@ -10395,15 +10396,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -10411,7 +10412,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
@@ -10440,12 +10441,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr ""
 
@@ -11101,7 +11101,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -11290,14 +11290,22 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mvrsave=yes%> є застарілим, замість нього слід користуватися %<-mvrsave%>"
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+msgid "Max number of pairs of load insns for compare."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr "%<-misel=no%> є застарілим, замість нього слід користуватися %<-mno-isel%>"
@@ -11306,10 +11314,38 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-misel=yes%> є застарілим, замість нього слід користуватися %<-misel%>"
 
+#: config/rs6000/rs6000.opt:410
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs вважається застарілим"
+
+#: config/rs6000/sysv4.opt:24
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:28
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr "Використовувати fp-регістри."
@@ -12402,86 +12438,148 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr ""
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr ""
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 msgid "Generate string extension instructions."
 msgstr "Створити інструкції розширення рядків."
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr ""
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr ""
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr ""
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr ""
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate string extension instructions."
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Створити інструкції розширення рядків."
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Generate string extension instructions."
+msgid "Generate single-precision floating-point instructions."
+msgstr "Створити інструкції розширення рядків."
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate string extension instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Створити інструкції розширення рядків."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr ""
@@ -13302,13 +13400,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr ""
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs вважається застарілим"
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr ""
@@ -15539,8 +15630,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -15566,7 +15657,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "мало бути ціле число"
@@ -15981,7 +16072,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16007,12 +16098,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -16061,9 +16152,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16076,8 +16167,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -16207,82 +16298,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "некоректний аргумент %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr ""
@@ -16289,72 +16376,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr ""
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr ""
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr ""
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr ""
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr ""
@@ -16361,7 +16448,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -16368,12 +16455,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -16380,62 +16467,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr ""
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -17599,37 +17686,37 @@
 msgid "conversion to incomplete type"
 msgstr ""
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr ""
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr ""
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr ""
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -17784,12 +17871,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -17899,12 +17986,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -17919,12 +18006,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr ""
@@ -17934,42 +18021,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18506,28 +18593,28 @@
 msgid "can%'t write PCH file"
 msgstr ""
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -18541,12 +18628,13 @@
 msgid "null pointer dereference"
 msgstr "розіменування нульового вказівника"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "оголошено тут"
@@ -19081,10 +19169,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -19113,7 +19201,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -19452,252 +19540,257 @@
 msgid "function cannot be instrumented"
 msgstr ""
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr ""
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr ""
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr ""
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr ""
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -19718,7 +19811,7 @@
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -19726,7 +19819,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19734,7 +19827,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -19742,7 +19835,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -19750,7 +19843,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19758,7 +19851,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20034,29 +20127,35 @@
 
 #: multiple_target.c:91
 #, gcc-internal-format
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr ""
 
-#: multiple_target.c:324
-#, gcc-internal-format
-msgid "single target_clones attribute is ignored"
-msgstr ""
+#: multiple_target.c:343
+#, fuzzy, gcc-internal-format
+#| msgid "argument of %qE attribute ignored"
+msgid "single %<target_clones%> attribute is ignored"
+msgstr "аргумент атрибута %qE проігноровано"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr ""
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20368,12 +20467,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -20959,22 +21058,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21018,7 +21117,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -21258,157 +21357,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr ""
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -22569,12 +22668,12 @@
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23081,7 +23180,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -23121,92 +23220,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD вважається застарілим: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD вважається застарілим"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE вважається застарілим: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE вважається застарілим"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "тип вважається застарілим: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип вважається застарілим"
@@ -23231,242 +23330,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr ""
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "помилка verify_type"
@@ -23491,12 +23590,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -24376,7 +24475,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -24627,7 +24726,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr ""
@@ -25235,7 +25334,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25250,22 +25349,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -25810,8 +25909,8 @@
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -26442,7 +26541,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -26519,7 +26618,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -26646,47 +26745,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -26712,31 +26811,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -27216,8 +27315,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -27297,8 +27396,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27407,11 +27506,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27421,145 +27520,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr ""
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr ""
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr ""
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr ""
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr ""
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "аргумент атрибута %qE проігноровано"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr ""
@@ -27585,153 +27674,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -28533,12 +28622,12 @@
 msgid "invalid IACC argument"
 msgstr ""
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr ""
@@ -28638,566 +28727,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr ""
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "помилковий аргумент %qs параметра %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> вважається застарілим; скористайтеся одним із відповідників: %<-mtune=k8%> або %<-mtune=generic%>"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> вважається застарілим; скористайтеся одним із відповідників: %<target(\"tune=k8\")%> або %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "підтримки -mabi=ms для ABI X32 не передбачено"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr ""
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-march=%> є такі: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-mtune=%> є такі: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "Для %<-fcf-protection=branch%> потрібна підтримка Intel CET. Скористайтеся параметром -mcet або -mibt, щоб увімкнути CET"
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "Для %<-fcf-protection=return%> потрібна підтримка Intel CET. Скористайтеся параметром -mcet або -mshstk, щоб увімкнути CET"
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "Для %<-fcf-protection=full%> потрібна підтримка Intel CET. Скористайтеся параметром -mcet або парою параметрів -mibt та -mshstk, щоб увімкнути CET"
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -29204,311 +29278,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29729,7 +29803,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -30255,8 +30329,35 @@
 msgid "constant argument out of range for %s"
 msgstr "сталий аргумент поза припустимим діапазоном для %s"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, gcc-internal-format
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:702
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:717
+#, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "Generate string extension instructions."
+msgid "don't support performance extension instructions"
+msgstr "Створити інструкції розширення рядків."
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate string extension instructions."
+msgid "don't support performance extension version 2 instructions"
+msgstr "Створити інструкції розширення рядків."
+
+#: config/nds32/nds32-intrinsic.c:760
+#, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr ""
 
@@ -30276,43 +30377,60 @@
 msgstr ""
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr ""
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr ""
+
+#: config/nds32/nds32.c:3508
+#, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
 #, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
+#, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "підтримки коду із незалежним позиціюванням не передбачено"
 
@@ -30521,37 +30639,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -30645,12 +30763,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -30700,7 +30818,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -31002,7 +31120,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31012,7 +31130,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31022,12 +31140,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31037,28 +31155,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
@@ -31078,12 +31196,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
@@ -31105,53 +31223,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -31276,7 +31394,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
@@ -31286,12 +31404,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -31301,22 +31419,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -31326,7 +31444,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -31790,22 +31908,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr ""
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr ""
@@ -31868,30 +31986,36 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, fuzzy, gcc-internal-format
+#| msgid "%qs requires %qs"
+msgid "builtin %qs requires builtin %qs"
+msgstr "%qs потребує %qs"
+
+#: config/rs6000/rs6000-c.c:7058
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
@@ -32014,169 +32138,169 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент 1 %qs має бути сталою"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 %qs лежить поза припустимим діапазоном"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "аргумент 1 %s має бути сталим"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs використовує регістр r29"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "некоректний процесор %qs для %s%qs%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> вимикає %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -32970,7 +33094,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -33222,7 +33346,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -33232,7 +33356,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -33292,7 +33416,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -33322,7 +33446,7 @@
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
@@ -33440,7 +33564,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -33695,7 +33819,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -33854,7 +33978,7 @@
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -33981,7 +34105,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -34161,7 +34285,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -34211,7 +34335,7 @@
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -34247,7 +34371,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
@@ -34277,7 +34401,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
@@ -34307,7 +34431,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -34422,12 +34546,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -34490,7 +34614,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
@@ -34635,37 +34759,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -34695,7 +34819,7 @@
 msgid "to match this %qs"
 msgstr "для відповідності цьому %qs"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -34736,7 +34860,7 @@
 msgstr ""
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -34751,7 +34875,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -34766,8 +34890,8 @@
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -34805,7 +34929,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "мало бути %<,%> або %<;%>"
@@ -34833,7 +34957,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "У ISO C90 не передбачено підтримки %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -34897,13 +35021,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -35033,7 +35157,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -35067,22 +35191,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -35102,12 +35226,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -35134,12 +35258,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "перший операнд %<sizeof%> було оголошено тут:"
@@ -35415,7 +35539,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "помилкова кількість аргументів %<__builtin_shuffle%>"
@@ -35475,76 +35599,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> має перебувати у області видимості файла"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -35559,53 +35683,53 @@
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "мало бути %<none%> або %<present%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "мало бути %<none%> або %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "мало бути %<data%>, %<update%>, %<enter%> або %<exit%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "мало бути %<data%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -35627,82 +35751,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "значення %<num_tasks%> має бути додатним"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значення %<grainsize%> має бути додатним"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значення %<priority%> має бути невід’ємним"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "мало бути %<tofrom%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "мало бути %<scalar%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значення %qs має бути додатним"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "забагато аргументів %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "несподіваний аргумент"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значення розміру фрагмента має бути додатним"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -35712,12 +35836,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "значення %<num_teams%> має бути додатним"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значення %<thread_limit%> має бути додатним"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -35737,17 +35861,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr ""
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -35757,67 +35881,67 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "мало бути %<data%> після %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -35832,7 +35956,7 @@
 msgid "expected function name"
 msgstr "мало бути вказано назву функції"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -35842,42 +35966,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> вже застосовано до %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> має бути застосовано до використання"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> має бути застосовано до визначення"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -35887,22 +36011,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -35912,72 +36036,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "мало бути %<for%> після %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "мало бути %<point%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -35997,32 +36121,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "мало бути %<target%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "мало бути %<declare%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36077,47 +36201,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -36132,7 +36256,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -36253,7 +36377,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -36278,7 +36402,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -36381,17 +36505,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -36416,7 +36540,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -36649,7 +36773,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -36801,7 +36925,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -36868,7 +36992,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -36938,12 +37062,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -36989,7 +37113,7 @@
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -37004,7 +37128,7 @@
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -37134,7 +37258,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -37174,7 +37298,7 @@
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -37184,17 +37308,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -37219,22 +37343,22 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -37285,7 +37409,7 @@
 msgstr ""
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -37315,12 +37439,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -37330,25 +37454,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -37359,70 +37483,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -37442,7 +37566,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -37452,17 +37576,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -37477,18 +37601,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -37500,32 +37624,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -37545,55 +37669,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -37603,32 +37727,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -37757,7 +37881,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -37836,24 +37960,24 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -37860,606 +37984,606 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr "немає відповідників "
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr ""
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs у %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 msgid "invalid conversion from %qH to %qI"
 msgstr "некоректне перетворення з %qH на %qI"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT оголошено тут:"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -38498,8 +38622,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
@@ -38540,7 +38664,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT оголошено тут:"
@@ -38620,7 +38744,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -38897,7 +39021,7 @@
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
@@ -38967,7 +39091,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
@@ -39062,333 +39186,333 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "виклик внутрішньої функції %qE"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "розіменування нульового вказівника"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "зміна %qE не є сталим виразом"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значення %qE типу %qT не є сталим виразом"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "reinterpret_cast не є сталим виразом"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "перетворення нульового вказівника %qT на %qT не є сталим виразом"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є сталим виразом"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "вираз %qE не є сталим виразом"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "інструкція не є сталим виразом"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ділення на нуль не є сталим виразом"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не є сталим виразом"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не є сталим виразом"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -39429,7 +39553,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -39438,306 +39562,306 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "не вдалося перетворити тип %qH на тип %qI"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr ""
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "у виклику %qD, оголошено тут"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -39777,197 +39901,197 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr ""
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "оголошення %qF містить інше визначення виключення"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "з попереднього оголошення %qF"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "повторне оголошення %qD відрізняється у %<constexpr%> від попереднього оголошення"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "попереднє оголошення %qD"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr ""
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr ""
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "попереднє визначення %qD було тут"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "попереднє оголошення %qD було тут"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr ""
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr ""
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr ""
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr ""
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "попереднє оголошення %<pragma omp declare reduction%>"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "визначення %q#D робить неоднозначним вбудоване оголошення %q#D"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr ""
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr ""
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr ""
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr ""
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr ""
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr ""
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr ""
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr ""
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr ""
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr ""
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D раніше оголошено тут"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr ""
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr ""
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr ""
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr ""
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr ""
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr ""
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "вилучене визначення %q+D"
@@ -39980,39 +40104,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -40020,630 +40144,631 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr "попередня мітка"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  звідси"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr "  %s"
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr ""
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr ""
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<-fno-for-scope%> вважається застарілим"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "%<-ffriend-injection%> вважається застарілим"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr ""
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr ""
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+#| msgid "cannot decompose union type %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "не вдалося розкласти тип об'єднання %qT"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40651,7 +40776,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40659,7 +40784,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40667,868 +40792,878 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не є інтегральним сталим виразом"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "не вдалося розкласти тип об'єднання %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr ""
+
+#: cp/decl.c:7774
+#, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явним чином типово визначено тут"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr ""
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr ""
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
+msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:11099
+#: cp/decl.c:11156
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
+msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -41535,459 +41670,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -41994,77 +42129,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -42084,169 +42219,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD не приймає аргументів"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT має попереднє оголошення тут"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -42258,94 +42393,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -42354,77 +42489,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr ""
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr ""
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -42464,7 +42599,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -42477,7 +42612,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -42587,42 +42722,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -42631,67 +42766,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -42700,62 +42835,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr ""
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr ""
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -42762,17 +42897,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -42782,112 +42917,112 @@
 msgid "with"
 msgstr "з"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(немає аргументів)"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -43033,358 +43168,358 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr ""
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr ""
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr ""
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, gcc-internal-format
 msgid "defined here"
 msgstr "визначено тут"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr ""
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -43396,7 +43531,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -43479,67 +43614,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -43658,42 +43793,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr ""
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D приховує конструктор для %q#D"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "конфліктує із оголошенням компонування мови C %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "через різні специфікації виключення"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "локальне зовнішнє оголошення %q#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "не відповідає попередньому оголошенню %q#D"
@@ -43701,57 +43836,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr ""
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr ""
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %<%s(%E)%> %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr ""
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr ""
@@ -43758,12 +43893,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr ""
@@ -43770,103 +43905,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr ""
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr ""
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr ""
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -43874,78 +44009,83 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr ""
+
+#: cp/name-lookup.c:5929
+#, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr ""
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD визначено тут"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -43965,7 +44105,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -43990,7 +44130,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -44070,7 +44210,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -44292,7 +44432,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -44372,7 +44512,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -44387,862 +44527,852 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "помилкова кількість аргументів %<__builtin_launder%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
 #, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr ""
+
+#: cp/parser.c:10119
+#, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "визначено типовий аргумент для лямбда-параметра"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "дублювання %<mutable%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> у функції %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "зайве %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD є некоректним у лямбді"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некоректний параметр обмеженого типу"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "мало бути вказано тип-назву"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "мало бути %<;%> або %<{%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "У ISO C++ заборонено порожні enum без назви"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> у функції %<constexpr%>"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не є типом"
@@ -45251,17 +45381,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -45268,382 +45398,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE потребує %<-fgnu-tm%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "мало бути %<,%> або %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "мало бути %<{%> або %<:%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "не вдалося визначити тип typename"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "попереднє визначення %q#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "мало бути %<class%> або %<typename%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "У ISO C++17 не можна визначати динамічні специфікації виключень"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> у функції %<constexpr%>"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "мав бути атрибут перед %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -45652,518 +45782,518 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "У ISO C++ 1998 не передбачено підтримки %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "вказано одразу %<__thread%> і %<thread_local%>"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублювання %qD"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублювання %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "мало бути %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "мало бути %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "мало бути %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "мало бути %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "мало бути %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "мало бути %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "мало бути %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "мало бути %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "мало бути %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "мало бути %<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "мало бути %<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "мало бути %<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "мало бути %<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "мало бути %<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "мало бути %<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "мало бути %<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "мало бути %<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "мало бути %<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "мало бути %<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "мало бути %<__transaction_atomic%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "мало бути %<__transaction_relaxed%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "мало бути %<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "мало бути %<...%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "мало бути %<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "мало бути %<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "мало бути %<:%> або %<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "мало бути %<class%>, %<typename%> або %<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "теґ %qs використано у назві %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> має перебувати всередині функції"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> має перебувати всередині функції"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr ""
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  із оголошення %q#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -46170,88 +46300,88 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr ""
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "пропущено атрибути основного шаблона %s"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "пропущено атрибут основного шаблона %s"
@@ -46258,57 +46388,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr ""
@@ -46321,137 +46451,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "оголошення friend тут:"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46459,17 +46589,17 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -46477,47 +46607,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "оголошено шаблон %qD"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -46527,57 +46657,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46585,7 +46715,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46593,12 +46723,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -46607,117 +46737,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46725,287 +46855,292 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "в аргументі шаблона для типу %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  мало бути %qD, втім, маємо %qD"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
 #, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr ""
+
+#: cp/pt.c:11691
+#, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
@@ -47023,276 +47158,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -47304,106 +47439,112 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "missing template arguments"
+msgid "invalid use of %qT in template argument"
+msgstr "пропущено аргументи шаблона"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -47606,7 +47747,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -47656,7 +47797,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -47728,294 +47869,294 @@
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4071
+#: cp/semantics.c:4056
 #, gcc-internal-format
-msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "статичне значення %<gang%> має бути додатним"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "значення num %<gang%> має бути додатним"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "значення довжини %<vector%> має бути додатним"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "значення num %<worker%> має бути додатним"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, у %<__builtin_launder%>"
@@ -48140,12 +48281,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -48205,726 +48346,722 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "не вдалося викликати функцію %qD"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8786
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr ""
+#: cp/typeck.c:8812 cp/typeck.c:8829
+msgid "cannot convert %qH to %qI"
+msgstr "не вдалося перетворити %qH на %qI"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8800
-msgid "cannot convert %qH to %qI"
-msgstr "не вдалося перетворити %qH на %qI"
-
-#: cp/typeck.c:8804
+#: cp/typeck.c:8833
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -48931,55 +49068,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -49200,140 +49337,140 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr ""
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr ""
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr ""
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -49757,48 +49894,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -50793,7 +50930,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -50963,7 +51100,7 @@
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -51213,449 +51350,449 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Синтаксична помилка у ініціалізації у старому стилі %s, адреса — %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Значення параметра KIND %qs у %C не спрощується до сталого виразу"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -51662,951 +51799,951 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксична помилка у оголошенні анонімної структури у %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Потрібна назва параметра у %C"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "У оголошенні типу у %C мав бути список параметрів"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксична помилка у інструкції AUTOMATIC у %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксична помилка у інструкції STATIC у %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Зайві команди після інструкції MAP у %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Зайві команди після інструкції UNION у %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Зайві команди після невкладеної інструкції STRUCTURE у %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -52941,27 +53078,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -53286,7 +53423,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr ""
@@ -53296,62 +53433,62 @@
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "помилковий вираз"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr "помилковий оператор"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -53471,12 +53608,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -54666,7 +54803,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56100,12 +56237,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -56345,8 +56482,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -56388,7 +56525,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -56729,182 +56866,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -58254,7 +58391,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -58364,7 +58501,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -58738,228 +58875,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -58968,232 +59105,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -59200,12 +59337,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -59213,107 +59350,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -59320,67 +59457,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -59387,7 +59524,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -59395,57 +59532,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -59452,887 +59589,887 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -60768,7 +60905,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -61407,18 +61544,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -61599,177 +61736,177 @@
 msgid "previously defined here as %s"
 msgstr ""
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr ""
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr ""
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr ""
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr ""
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr ""
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr ""
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr ""
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr ""
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr ""
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr ""
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr ""
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Не вдалося відкрити %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr ""
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Не вдалося прочитати %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "помилка waitpid"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -62711,6 +62848,15 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr ""
 
+#~ msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
+#~ msgstr "Для %<-fcf-protection=branch%> потрібна підтримка Intel CET. Скористайтеся параметром -mcet або -mibt, щоб увімкнути CET"
+
+#~ msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
+#~ msgstr "Для %<-fcf-protection=return%> потрібна підтримка Intel CET. Скористайтеся параметром -mcet або -mshstk, щоб увімкнути CET"
+
+#~ msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
+#~ msgstr "Для %<-fcf-protection=full%> потрібна підтримка Intel CET. Скористайтеся параметром -mcet або парою параметрів -mibt та -mshstk, щоб увімкнути CET"
+
 #~ msgid "%s:unknown function '%u'\n"
 #~ msgstr "%s:невідома функція «%u»\n"
 
Index: gcc/po/sr.po
===================================================================
--- gcc/po/sr.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/sr.po	(.../branches/gcc-8-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -170,40 +170,40 @@
 msgid "negative insn length"
 msgstr "негативна дужина ије"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "нисам могао да поделим ију"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "неисправна ‘asm’: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "алтернативе дијалекта угњежденог асемблера"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "неодређена алтернатива дијалекта асемблера"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "број операнда недостаје после %%-слова"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "број операнда изван опсега"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "неисправан %%-код"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "операнд уз ‘%%l’ није етикета"
@@ -214,13 +214,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "лоша употреба реалне константе"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1308,31 +1308,31 @@
 msgid "At top level:"
 msgstr "На највишем нивоу:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, fuzzy, c-format
 #| msgid "In member function %qs:"
 msgid "In member function %qs"
 msgstr "У чланској функцији %qs:"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In function %qs"
 msgstr "У функцији %qs:"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 #, fuzzy
 #| msgid "    Included at %s:%d:"
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    Укључено код %s:%d:"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 #| msgid "    Included at %s:%d:"
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    Укључено код %s:%d:"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, fuzzy, c-format
 #| msgid "complex invalid for %qs"
 msgid "    inlined from %qs"
@@ -3247,9 +3247,9 @@
 msgid "invalid address mode"
 msgstr "неисправна адреса"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3265,7 +3265,7 @@
 msgstr "неисправна %%r вредност"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3272,13 +3272,13 @@
 msgstr "неисправна %%R вредност"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
@@ -3309,7 +3309,7 @@
 msgstr "неисправна %%U вредност"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
@@ -3320,7 +3320,7 @@
 msgstr "неисправна %%C вредност"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
@@ -3331,7 +3331,7 @@
 msgstr "непознато unspec релокације"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3343,61 +3343,61 @@
 msgid "invalid operand address"
 msgstr "неисправна адреса"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "неисправан операнд за %%p кôд"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "неисправан операнд за %%s кôд"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "неисправан операнд за %%H/%%L кôд"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "неисправан операнд за %%U кôд"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "неисправан операнд за %%V кôд"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3405,19 +3405,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "неисправан кôд излаза операнада"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "непрепозната претпостављена константа"
 
@@ -3453,7 +3453,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
@@ -3588,8 +3588,8 @@
 msgstr "неисправан const_double операнд"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3808,112 +3808,112 @@
 msgid "bad output_condmove_single operand"
 msgstr "лош операнд output_condmove_single"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "неисправна употреба %<restrict%>"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "неисправна ограничења за операнд"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "непознат режим ије"
 
@@ -3953,7 +3953,7 @@
 msgstr "неисправан %%P операнд"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -4011,7 +4011,7 @@
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -4196,149 +4196,149 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4478,43 +4478,43 @@
 msgid "created and used with different endianness"
 msgstr "направљено и употребељно са различитом крајношћу"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "неисправан %%Y операнд"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "неисправан %%A операнд"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "неисправан %%B операнд"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "неисправан %%C операнд"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "неисправан %%D операнд"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "неисправан %%f операнд"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "неисправан %%s операнд"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4752,14 +4752,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4775,7 +4775,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4784,7 +4784,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4801,7 +4801,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
@@ -4808,7 +4808,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -4818,14 +4818,14 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4837,20 +4837,20 @@
 msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4859,24 +4859,24 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4888,7 +4888,7 @@
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4901,47 +4901,47 @@
 msgid "expected label"
 msgstr "Очекивано је име"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "скок на етикету %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "скок на етикету случаја"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  улази у блок покушаја"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  улази у блок хватања"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 #| msgid "  enters OpenMP structured block"
 msgid "enters OpenMP structured block"
 msgstr "  улази структуирани блок ОпенМПа"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 #| msgid "Generate code for huge switch statements"
 msgid "enters synchronized or atomic statement"
 msgstr "Створи кôд за огромне наредбе прекидача"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -5053,7 +5053,7 @@
 msgid "<statement>"
 msgstr "очекивана је наредба"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown src"
 msgid "<unknown>"
@@ -5075,129 +5075,129 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 #, fuzzy
 #| msgid "parse error"
 msgid "<expression error>"
 msgstr "грешка у рашчлањивању"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 #, fuzzy
 #| msgid "Bad operator"
 msgid "<unknown operator>"
 msgstr "Лош оператор"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 #| msgid "In member function %qs:"
 msgid "In static member function %qs"
 msgstr "У чланској функцији %qs:"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In constructor %qs"
 msgstr "У функцији %qs:"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In destructor %qs"
 msgstr "У функцији %qs:"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 #| msgid "In member function %qs:"
 msgid "In lambda function"
 msgstr "У чланској функцији %qs:"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 #| msgid "explicit instantiation of %q#D"
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 #| msgid "provided for %q+D"
 msgid "required from %q#D\n"
 msgstr "дат за %q+D"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr ""
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "called from here"
 msgid "required from here\n"
 msgstr "позвано одавде"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "кандидати су:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5261,50 +5261,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "погрешан тип аргумента уз унарно минус"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "погрешан тип аргумента уз битски комплемент"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "погрешан тип аргумента за abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "погрешан тип аргумента за конјугацију"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5597,11 +5597,11 @@
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "додела показивача"
 
@@ -5795,59 +5795,59 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5891,13 +5891,13 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES уз сопствено REPEAT негативан је"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 #, fuzzy
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
@@ -6175,6 +6175,7 @@
 msgstr "-Xbind-now и -Xbind-lazy нису сагласни"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -9668,7 +9669,7 @@
 msgstr "Поравнај променљиве на 32-бајтну границу"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 #| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
@@ -10241,7 +10242,7 @@
 msgstr "Наведите опсег регистара које треба фиксирати"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -11111,7 +11112,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Створи кôд који поштује дати АБИ"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -11651,7 +11652,7 @@
 msgstr "Подржи уграђене ММИкс и ССЕ функције и стварање кôда"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -11660,12 +11661,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -11678,47 +11679,49 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Подржи уграђене ММИкс и ССЕ функције и стварање кôда"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
 msgstr "Користи call и rtc за позиве и повратке из функција"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "повратни тип функције не може бити функција"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Подржи уграђене ММИкс и ССЕ функције и стварање кôда"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Подржи уграђене ММИкс и ССЕ функције и стварање кôда"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -12257,7 +12260,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Превазиђена опција; користите -mvrsave и -mno-vrsave"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -12265,7 +12268,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -12389,7 +12392,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "Распореди кôд за дати ЦПУ"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -12431,7 +12434,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "неисправна опција за -mfloat-gprs: „%s“"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -12531,25 +12534,25 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Стварај инструкције вишеструког учитавања/складиштења"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12569,19 +12572,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -12597,15 +12600,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12615,17 +12618,17 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Use paired-single floating-point instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Користи упарене једноструке инструкције покретног зареза"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12635,7 +12638,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Враћај мале скупине у регистрима"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
@@ -12672,14 +12675,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Позивај mcount за профилисање пре пролога функције"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "Изаберите конвенцију позивања АБИја"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -13536,7 +13538,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -13785,14 +13787,30 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
+#: config/rs6000/rs6000.opt:334
+#, fuzzy
+#| msgid "Maximum number of errors to report"
+msgid "Max number of bytes to move inline."
+msgstr "Највећи број грешака за пријављивање"
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
-msgstr ""
+#, fuzzy
+#| msgid "Maximum number of errors to report"
+msgid "Max number of bytes to compare without loops."
+msgstr "Највећи број грешака за пријављивање"
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare with loops."
+msgstr "Највећи број ија непребачене петље"
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop"
+msgid "Max number of pairs of load insns for compare."
+msgstr "Највећи број љушћења једне петље"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
@@ -13805,6 +13823,36 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "Select full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "Изаберите пуну или делимичну табелу повратног трага, или без ње"
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs је превазиђено"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Изаберите конвенцију позивања АБИја"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Изаберите метод руковања с-подацима"
+
 #: config/rs6000/sysv4.opt:32
 #, fuzzy
 #| msgid "Put read-only data in SECTION"
@@ -13811,6 +13859,12 @@
 msgid "Allow readonly data in sdata."
 msgstr "Стави само-за-читање податке у SECTION"
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Наведите битску величину непосредних ТЛС помака"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -15240,112 +15294,176 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Не стварај инструкције стопљеног множења-додавања"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "Стварај кôд у режиму велике крајности"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "Створи кôд у режиму мале крајности"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "Прераспореди инструкције пре резервисања регистара"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "Прераспореди инструкције пре резервисања регистара"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate conditional move instructions."
 msgstr "Стварај инструкције isel"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate performance extension instructions."
 msgstr "Стварај инструкције вишеструког учитавања/складиштења"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate floating point mathematics using given instruction set"
 msgid "Generate performance extension version 2 instructions."
 msgstr "Стварај математику у покретном зарезу користећи дати скуп инструкција"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate string extension instructions."
 msgstr "Стварај инструкције isel"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Стварај инструкције isel"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate 16-bit instructions."
 msgstr "Стварај инструкције isel"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr ""
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the register allocation order"
 msgid "Specify the cpu for pipeline model."
 msgstr "Одредите редослед резервисања регистара"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "Упозори када су сви конструктори и деструктори приватни"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "Стварај инструкције isel"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Стварај инструкције множење-додавање у покретном зарезу"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "Користи упарене једноструке инструкције покретног зареза"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "Створи кôд који користи инструкције од 68881 за рачунање у покретном зарезу"
+
+#: config/nds32/nds32.opt:326
+#, fuzzy
+#| msgid "Pass arguments on the stack"
+msgid "Always save $lp in the stack."
+msgstr "Прослеђуј аргументе на стеку"
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -16466,13 +16584,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Стварај инструкције вишеструког учитавања/складиштења"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs је превазиђено"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate fused multiply/add instructions"
@@ -19372,8 +19483,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "израчуната вредност се не користи"
@@ -19409,7 +19520,7 @@
 msgstr "Очекиван је тип израза"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19950,7 +20061,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -19980,13 +20091,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -20037,9 +20148,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -20052,8 +20163,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -20193,83 +20304,81 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+msgstr[3] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
+msgstr[3] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid argument to %qD"
 msgstr "неисправан аргумент типа за %qs"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported argument to %qD"
@@ -20277,78 +20386,78 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 #| msgid "-mstackrealign ignored for nested functions"
 msgid "trampoline generated for nested function %qD"
 msgstr "-mstackrealign се игнорише за угњеждене функције"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid memory model argument to builtin"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -20356,7 +20465,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -20364,13 +20473,13 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
@@ -20377,67 +20486,67 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "циљни формат не подржава бесконачност"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "циљни формат не подржава бесконачност"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> употребљено у функцији са фиксним аргументима"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Hпоследњи аргумент за %D није целобројна константа између 0 и 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -21682,40 +21791,40 @@
 msgid "conversion to incomplete type"
 msgstr "претварање у непотпун тип"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "не могу да претварам између векторских вредности различитих величина"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "скупинска вредност употребљена где се очекивала целобројна"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "показивачка вредност употребљена где се очекивала комплексна"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "скупинска вредност употребљена где се очекивала комплексна"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "не могу да претварам између векторских вредности различитих величина"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert value to a vector"
 msgid "can%'t convert value to a vector"
 msgstr "не могу да претворим вредност у вектор"
 
-#: convert.c:1168
+#: convert.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate value used where a float was expected"
 msgid "aggregate value used where a fixed-point was expected"
@@ -21878,12 +21987,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -21997,13 +22106,13 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: expr.c:10986
+#: expr.c:10992
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute warning: %s"
@@ -22021,13 +22130,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "величина %q+D је већа од %wd бајтова"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "нисам могао да отворим датотеку пописа %qs: %s"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close final insn dump file %qs: %m"
@@ -22039,44 +22148,44 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "велики целобројни имплицитно подсечен на неозначени тип"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "поређење је увек %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> непоклопљених тестова неједнакости је увек 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> међусобно искључивих тестова једнакости је увек 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "провера сажимања: првобитно дрво измењено сажимањем"
@@ -22673,28 +22782,28 @@
 msgid "can%'t write PCH file"
 msgstr "не могу да запишем ПЦХ датотеку"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -22709,12 +22818,13 @@
 msgid "null pointer dereference"
 msgstr "Одредба мора бити упућивач"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -23275,10 +23385,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -23312,7 +23422,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -23682,262 +23792,267 @@
 msgid "function cannot be instrumented"
 msgstr "унија не може бити учињена провидном"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "успостављач наведен за невиртуелни метод %q+D"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "a different type is defined in another translation unit"
 msgstr "Различити типови у додели показивача код %L"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "the incompatible type defined in another translation unit"
 msgstr "несагласни типови у успостављању"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in return"
 msgid "the incompatible type is defined here"
 msgstr "несагласни типови у повратку"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
 msgstr "Упућивач низа ван граница"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "return value type mismatch"
 msgstr "неслагање типа успостављача поља"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "implicit this pointer type mismatch"
 msgstr "неслагање типа успостављача поља"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "type mismatch in parameter %i"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type %qT should match type %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "has different parameters in another translation unit"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -23959,7 +24074,7 @@
 msgid "the extra base is defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -23968,7 +24083,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23977,7 +24092,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -23986,7 +24101,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -23995,7 +24110,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24004,7 +24119,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24306,32 +24421,37 @@
 
 #: multiple_target.c:91
 #, gcc-internal-format
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "функција %q+F се не може уткати јер користи нелокално goto"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for %qD"
 msgid "default target was not set"
 msgstr "нема подразумеваног аргумента за %qD"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -24666,13 +24786,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s"
@@ -25315,22 +25435,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "излазни операнд %d мора користити ограничење %<&%>"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Лош next_regno за празан ланац (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Петља у regno ланцу (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Лош oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Непразан рег. у ланцу (%s %u %i)"
@@ -25379,7 +25499,7 @@
 msgstr "регистар се користи за две глобалне регистарске променљиве"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25627,165 +25747,165 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D преименован пошто је поменут у асемблеру"
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
 msgstr "функција враћа функцију"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "чвор није нађен у cgraph_hash"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "позвани објекат %qE није функција"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa није успело"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has function type"
 msgid "variable %q+D part of alias cycle"
 msgstr "променљива %qD има функцијски тип"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -27066,13 +27186,13 @@
 msgid "control reaches end of non-void function"
 msgstr "%Hконтрола стиже до краја функције непразног типа"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute warn_unused_result"
@@ -27607,7 +27727,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -27649,99 +27769,99 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "низови функција немају смисла"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "повратни тип функције не може бити функција"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: %s, имам %s у %s, код %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: не очекивах ниједно од %s, имам %s у %s, код %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "провера стабла: очекивах класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "провера стабла: нисам очекивао класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: очекивах omp_clause %s, имам %s у %s, код %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected tree that contains %qs structure, have %qs  in %s, at %s:%d"
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "провера стабла: очекивах стабло које садржи структуру %qs, имам %qs у %s, код %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "провера стабла: приступих елту %d у tree_vec са %d елтова у %s, код %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "провера стабла: приступих елту %d у tree_vec са %d елтова у %s, код %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од %s са %d операнада у %s, код %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од omp_clause %s са %d операнада у %s, код %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "тип је превазиђен"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип је превазиђен"
@@ -27766,245 +27886,245 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "Main variant is not defined"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "поље %qs има непотпун тип"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_eh_tree failed"
 msgid "verify_type failed"
@@ -28032,12 +28152,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "%HИскварена вредност профила: укупни број профилизатора %s (%d) не поклапа се са бројем об. (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -28992,7 +29112,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "предлажем заграде око израза употребљеног као истинитосна вредност"
@@ -29263,7 +29383,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array is too large"
@@ -29907,7 +30027,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -29925,25 +30045,25 @@
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
 msgstr "%Hнедостаје израз увећања"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -30524,8 +30644,8 @@
 msgid "wrong type argument to %s"
 msgstr "погрешан тип аргумента за abs"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "преливање у константном изразу"
@@ -31226,7 +31346,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
@@ -31314,7 +31434,7 @@
 msgstr[2] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 msgstr[3] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -31454,49 +31574,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops је застарело, користите -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps је застарело, користите -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions је застарело, користите -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-loops=%d није између 0 и %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d није између 0 и 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -31523,13 +31643,13 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "непознат прекидач -mdebug-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown switch -mlong-double-%s"
 msgid "unknown switch -mlong-double-%s"
@@ -31536,19 +31656,19 @@
 msgstr "Непознат прекицач -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -32057,8 +32177,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -32140,8 +32260,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "лоша вредност %qs за -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32259,11 +32379,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32274,131 +32394,121 @@
 msgid "%qE attribute only applies to functions"
 msgstr "атрибут %qs примењује се само на функције"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required as increment operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "неопходна л-вредност као операнд увећања"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 #| msgid "pre-increment address is not a register"
 msgid "insn addresses not freed"
 msgstr "адреса предувећања није регистар"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -32405,27 +32515,27 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
@@ -32453,153 +32563,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор мора бити непосредни"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33474,12 +33584,12 @@
 msgid "invalid IACC argument"
 msgstr "неодговарајући аргумент за IACC"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs очекује константан аргумент"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "константан аргумент ван опсега за %qs"
@@ -33589,18 +33699,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "не могу да поставим положај у ПЦХ датотеци: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "превише аргумената за функцију %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33607,47 +33717,47 @@
 msgstr "име регистра није наведено за %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "равнање се не може навести за %q+D"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "непознато име регистра: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -33654,561 +33764,546 @@
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "profiling not supported with -mg\n"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "профилисање није подржано уз -mg\n"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битни режим није укомпилован"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ЦПУ који сте изабрали не подржава скуп инструкција икс86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не подржава %s"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "-mrtd calling convention not supported in the 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "конвенција позивања -mrtd није подржана у 64-битном режиму"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "непозната опција типа -m%s=: „%s“"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qT са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не подржава вишебиб"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "ССЕ векторски аргумент без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "ССЕ векторско враћање без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "ССЕ враћање регистра уз искључене ССЕ"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "ССЕ регистарски аргумент уз искључене ССЕ"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "враћање из регистра x87 када је x87 искључено"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -34216,267 +34311,267 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 #| msgid "%s functions limited to %d register parameters"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "%s функције ограничене на %d регистарских параметара"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "проширени регистри немају високе половине"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "No dispatcher found for %s"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Аргумент за -ffpe-trap није исправан: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "помак мора бити непосредни"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "нетачно дељење чворова стабла"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -34483,84 +34578,84 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Аргумент-по-вредности код %L није дозвољен у овом контексту"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown asm flag output %qs"
 msgstr "непознат машински режим %qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподржана комбинација: %s"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "unsupported argument type %qT for simd"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -34804,7 +34899,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "израз ограничења стека није подржан"
@@ -35373,8 +35468,37 @@
 msgid "constant argument out of range for %s"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "ова уграђена функција доступна је само на фр450"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "ова уграђена функција доступна је само на фр450"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "instruction scheduling not supported on this target machine"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "распоређивање инструкција није подржано на овој циљној машини"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "%s not supported for nested functions"
+msgid "don't support performance extension instructions"
+msgstr "%s није подржано за угњеждене функције"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "don't support string extension instructions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
@@ -35398,11 +35522,11 @@
 msgstr "не могу да поставим атрибут прекида: нема текуће функције"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35409,37 +35533,55 @@
 msgstr "-fdata-sections није подржано за овај циљ"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "неисправан регистар у инструкцији"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+#| msgid "Intrinsic function %s(%d) not recognized"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "Сопствена функција %s(%d) није препозната"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -35664,39 +35806,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "атрибут %qE се игнорише на типовима"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "атрибут __BELOW100__ није дозвољен са аутом. складишном класом"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -35790,12 +35932,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "смеће на крају #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -35848,7 +35990,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -36166,7 +36308,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор враћен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
@@ -36176,7 +36318,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -36186,12 +36328,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор прослеђен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
@@ -36202,30 +36344,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36246,13 +36388,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36278,60 +36420,60 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "број мора бити 0 или 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "број мора бити 0 или 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Аргумент у ATANH код %L мора бити у опсегу -1 до 1"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
@@ -36468,7 +36610,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "оквир стека превелик"
@@ -36478,12 +36620,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
@@ -36493,22 +36635,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
@@ -36519,7 +36661,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
@@ -36994,22 +37136,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr ""
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -37081,31 +37223,36 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "%Jдефиниције алијаса нису подржане у овој конфигурацији"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -37241,48 +37388,48 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент %qd није константа"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "builtin %qs only accepts a string argument"
@@ -37289,7 +37436,7 @@
 msgstr "%qs очекује константан аргумент"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37296,138 +37443,138 @@
 msgstr "неисправан аргумент за уграђену функцију"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "други аргумент за %q+D треба да је %<char **%>"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "third argument to %qs must be 0..12"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "ова уграђена функција доступна је само на фр450"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "Користи регистре r2 и r5"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "неисправан апстрактни тип %qT за %qE"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not initialized"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%qE није успостављено"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38287,7 +38434,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "празна вредност није игнорисана а требало би"
@@ -38548,7 +38695,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларација %qD заклања глобалну декларацију"
@@ -38558,7 +38705,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "декларација %qD заклања претходну локалну"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -38626,7 +38773,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Сваки недекларисани идентификатор пријављен је само једном"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "на етикету %qE упућено ван било које функције"
@@ -38658,7 +38805,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "Удвостручена декларација етикете %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "удвостручена етикета %qD"
@@ -38784,7 +38931,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> није дозвољено другде осим у досегу прототипа функције"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39059,7 +39206,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "складишна класа наведена за име типа"
@@ -39244,7 +39391,7 @@
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
@@ -39388,7 +39535,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "променљива или поље %qE декларисано празним"
@@ -39583,7 +39730,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
@@ -39635,7 +39782,7 @@
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -39675,7 +39822,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "поновљена декларација %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "наведени режим је премали за набројиве вредности"
@@ -39706,7 +39853,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
@@ -39740,7 +39887,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -39871,12 +40018,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -39945,7 +40092,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
@@ -40105,38 +40252,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "негативан десни помак"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "десни помак >= од ширине типа"
@@ -40168,7 +40315,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -40213,7 +40360,7 @@
 msgstr "непознато име регистра: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -40230,7 +40377,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -40248,8 +40395,8 @@
 msgid "unexpected attribute"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -40291,7 +40438,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "очекивано је %<,%> или %<;%>"
@@ -40321,7 +40468,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "очекивана је дословна ниска"
@@ -40393,13 +40540,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "зарез на крају листе набрајања"
@@ -40533,7 +40680,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "очекивано је %<,%> или %<}%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -40567,24 +40714,24 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "очекивана је наредба"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hпразно тело у наредби if"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%Hпразно тело у наредби else"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -40606,12 +40753,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "неисправан регистар у инструкцији"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -40640,12 +40787,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -40956,7 +41103,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -41020,83 +41167,83 @@
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jадресна област атрибута не може бити наведена за функције"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -41114,60 +41261,60 @@
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41190,96 +41337,96 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Неочекивани елемент"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "и %<long%> и %<void%> у наводиоцима декларације"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -41290,13 +41437,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -41317,19 +41464,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -41341,73 +41488,73 @@
 msgid "invalid proc_bind kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "неисправна употреба %<--%> на логичкој променљивој %qD"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Променљива %qs употребљена више од једном у листи аргумената метода %qs"
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41424,7 +41571,7 @@
 msgid "expected function name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -41435,44 +41582,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41482,22 +41629,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
@@ -41507,77 +41654,77 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41598,34 +41745,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -41683,48 +41830,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -41741,7 +41888,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD има непотпун тип"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неисправна употреба израза празног типа"
@@ -41868,7 +42015,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс низа није целобројан"
@@ -41893,7 +42040,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42002,19 +42149,19 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, fuzzy, gcc-internal-format
 #| msgid "comparison with string literal results in unspecified behaviour"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "поређење са дословном ниском резултује неодређеним понашањем"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "поређење између показивача и целобројног"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -42041,7 +42188,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -42291,7 +42438,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "претапање из целобројног у показивач различите величине"
@@ -42469,7 +42616,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
@@ -42542,7 +42689,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "неисправна употреба не-л-вредносног низа"
@@ -42621,12 +42768,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "традиционални Ц одбија аутоматску успостављање скупина"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "успостављање флексибилног чланског низа"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-низ успостављен широком ниском"
@@ -42675,7 +42822,7 @@
 msgid "invalid initializer"
 msgstr "неисправан успостављач"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
@@ -42690,7 +42837,7 @@
 msgid "braces around scalar initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "успостављање флексибилног чланског низа у угњежденом контексту"
@@ -42822,7 +42969,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ИСО Ц забрањује %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
@@ -42865,7 +43012,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
@@ -42875,17 +43022,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "етикета %<default%> није у оквиру наредбе прекидача"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "наредба искакања употребљена са ОпенМПом за петљу"
@@ -42912,22 +43059,22 @@
 msgid "expression statement has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "поређење реалних помоћу == или != није безбедно"
@@ -42980,7 +43127,7 @@
 msgstr "поређење уређености показивача са целобројном нулом"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "поређење уређености показивача са целобројном нулом"
@@ -43012,12 +43159,12 @@
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -43028,27 +43175,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD није чланска шаблонска функција"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -43061,19 +43208,19 @@
 msgstr "превише %qs одредби"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -43080,55 +43227,55 @@
 msgstr "величина у низовном new мора бити интегралног типа"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -43149,7 +43296,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE има неисправан тип за %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
@@ -43160,17 +43307,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -43185,18 +43332,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -43209,33 +43356,33 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -43258,63 +43405,63 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -43326,33 +43473,33 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -43502,7 +43649,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43589,28 +43736,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%D(%A)%> "
@@ -43617,678 +43764,678 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "показивач на чланску функцију %E не може бити позван без објекта; покушајте помоћу .* или ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "нема поклапања за позив %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "двосмислен позив %<(%T) (%A)%>"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "двосмислено претварање за индекс низа"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid " (operand types are %qT and %qT)"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Кориснички оператори:\n"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s за тернарно %<operator?:%> у %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s за %<operator%s%> у %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Лош оператор"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s за %<operator[]%> у %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s за %qs у %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s за %<operator%s%> у %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s за %<operator%s%> у %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ИСО Ц++ забрањује изостављање средњег члана израза ?:"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "неслагање набројивих у условном изразу: %qT пр. %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "поређење између %q#T и %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for `%D'"
 msgid "no corresponding deallocation function for %qD"
 msgstr "нема одговарајуће функције за ослобађање меморије за ‘%D’"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нема погодног %<operator %s%> за %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D није приступно"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "прослеђивање NULL непоказивачком аргументу %P од %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "претварање у непоказивачки тип %qT из NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  успостављање аргумента %P од %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "не може се повезати битско поље %qE са %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "не може се повезати паковано поље %qE са %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не може се повезати д-вредност %qE са %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "не могу се проследити објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "не могу се примати објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "подразумевани аргумент за параметер %d у %qD још увек није рашчлањен"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  у позиву %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT није приступна основа од %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "deducing %qT as %qT"
 msgstr "декларација %qD као %s"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%s(%A)%>"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "враћање вредности из конструктора"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "враћање вредности из деструктора"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "чланска функција %qD не може се позвати без објекта"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "прослеђивање %qT бира %qT пре него %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "бирам %qD пре него %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  зато што је редослед претварања за аргумент бољи"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid " candidate 1: %q#F"
 msgstr "кандидат 1:"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 2:"
 msgid " candidate 2: %q#F"
 msgstr "кандидат 2:"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "не могу да претворим %qE у %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -44335,8 +44482,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
@@ -44382,7 +44529,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
@@ -44468,7 +44615,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -44772,7 +44919,7 @@
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
@@ -44846,7 +44993,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "нема довољно података о типу"
@@ -44948,379 +45095,379 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "протокол %qs има кружну зависност"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "негативан десни помак"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "array used as initializer"
 msgid "%qD used in its own initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D је приватно"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
 msgstr "Неочекиван крај датотеке у ‘%s’"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45373,7 +45520,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "претапање %qT у %qT не разрешава показивач"
@@ -45384,342 +45531,342 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "претварање из %q#T у %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T употребљено где је %qT очекивано"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "не могу да претворим %qE у %qT"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T употребљено где је очекивана вредност у покретном зарезу"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "захтевано претварање из %qT у нескаларни тип %qT"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "псеудодеструктор се не позива"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "претварање у непотпун тип"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "неисправна примена %qs на непотпун тип %qT"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "претварање у непотпун тип"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "објекту %qE непотпуног типа %qT неће се приступити у %s"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s је упућивач, а не позив, за функцију %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "наредба без ефекта"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "двосмислено подразумевано претварање типа из %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  могућа претварања укључују %qD и %qD"
@@ -45764,229 +45911,229 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD је прво декларисано као %<extern%> а касније %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of %qF has a different exception specifier"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "од претходне декларације %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "декларација коришћења %q+D коси се са претходном декларацијом коришћења"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
 msgstr "претходна декларација %q+D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "претходна дефиниција %q+D беше овде"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "претходна декларација %q+D беше овде"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "shadowing built-in function %q#D"
 msgstr "заклањање %s функције %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "shadowing library function %q#D"
 msgstr "заклањање %s функције %q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "библиотечка функција %q#D поново декларисана као не-функција %q#D"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "коси се са декларацијом уграђеног %q#D"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "декларација %qD заклања глобалну декларацију"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration %q+#D"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "претходна нефункцијска декларација %q+#D"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "коси се са декларацијом уграђеног %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "чини декларацију уграђеног %q#D двосмисленом"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "чини декларацију уграђеног %q#D двосмисленом"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "derived type declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "декларација изведеног типа"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D поново декларисано као другачија врста симбола"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "чини стару декларацију %q+#D двосмисленом"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "old declaration %q#D"
 msgstr "глобална декларација %q+#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "чини стару декларацију %q+#D двосмисленом"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D"
 msgid "previous declaration as %q#D"
 msgstr "претходна декларација %q+#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "прототип за %q+#D"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfollows non-prototype definition here"
 msgid "previous non-prototype definition here"
 msgstr "%Jпрати не-прототипску дефиницију овде"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "previous declaration with %qL linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in %q+#D"
 msgid "previous specification in %q#D here"
 msgstr "после претходног навода у %q+#D"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %q+D"
@@ -46000,12 +46147,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -46012,7 +46159,7 @@
 msgstr "%q+D: атрибут видљивости игнорисан зато што"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
@@ -46019,25 +46166,25 @@
 msgid "redefinition of %q#D"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD није декларисано у %qD"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
@@ -46046,309 +46193,309 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "нитно-локална декларација %q+D прати не-нитно-локалну декларацију"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не-нитно-локална декларација %q+D прати нитно-локалну декларацију"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  одавде"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  излази из структуираног блока ОпенМПа"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  пресеца успостављање %q+#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  улази у блок хватања"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  прескаче успостављање %q+#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  улази у блок покушаја"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  улази структуирани блок ОпенМПа"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD није тип"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T није класа"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "нема шаблона класе по имену %q#T у %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именује %q#T, што није шаблон класе"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> именује %q#T, што није тип"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%qs је превазиђено"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "захтевано равнање није степен двојке"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са конструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са деструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у анонимној скупини"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут за %q+#T мора пратити кључну реч %qs"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "вишеструки типови у једној декларацији"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "недостаје име типа у наредби typedef"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ИСО Ц++ забрањује анонимне структуре"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бити наведено само за конструкторе"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> у празној декларацији у досегу датотеке"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -46355,379 +46502,380 @@
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ИСО Ц++ не дозвољава да %<%T::%D%> буде дефинисано као %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "удвостручено успостављање %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "променљива %q#D има успостављач али је непотпуног типа"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "скупина %q#D има непотпун тип и не може се дефинисати"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривијални утврђени успостављачи нису подржани"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  можете ово заобићи уклањањем успостављача"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "неисправан тип %qT као успостављач за вектор типа %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "неисправан успостављач"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ИСО Ц 90 забрањује сложене дословне ниске"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скаларни објекат %qD захтева један елемент у успостављачу"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD мора бити успостављен конструктором, не помоћу %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "низ %qD успостављен заграђеном константном ниском %qE"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "успостављач неисправан за статички члан са конструктором"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потребно је успостављање изван класе)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "параметар %qD је успостављен"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "заклањање претходне декларације типа за %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr ""
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+#| msgid "%qT is an inaccessible base of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare variable %q+D to be of abstract type %qT"
 msgid "cannot decompose variable length array %qT"
 msgstr "не може се декларисати променљива %q+D апстрактног типа %qT"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -46737,7 +46885,7 @@
 msgstr[2] "успостављач дат за функцију"
 msgstr[3] "успостављач дат за функцију"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46746,7 +46894,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46755,1013 +46903,1024 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не могу да разложим адресу"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "cannot %s a pointer to incomplete type %qT"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "не може се %s показивач на непотпуни тип %qT"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "јавански метод %qD има не-јавански повратни тип %qT"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "дефиниција експлицитне специјализације %qD у декларацији пријатеља"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неисправна употреба ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "неисправан аргумент опције %qs"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> мора враћати %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "чланска функција %q#D није декларисана у класи %qT"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ИСО Ц++ забрањује успостављање чланске константе %qD неинтегралног типа %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "негативна величина низа %qD"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "негативна величина низа"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ИСО Ц++ забрањује низ променљиве величине %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ИСО Ц++ забрањује низ променљиве величине"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "преливање у димензији низа"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "декларација %qs као низа празних"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "вишедимензиони низ мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "навод повратног типа за конструктор није исправан"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "наведен повратни тип за %<operator %T%>"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неименована променљива или поље декларисано празним"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неисправна употреба одређеног имена %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неисправна употреба одређеног имена %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неисправна употреба одређеног имена %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "декларација %qD као не-члана"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "недостаје ид. декларатора; користи се резервисана реч %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларација %qD као %s"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или више типова података у декларацији %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ИСО Ц++ забрањује декларацију %qs без типа"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> или %<unsigned%> неисправни за %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> и %<unsigned%> наведени заједно за %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> неисправно за %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> неисправно за %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> неисправно за %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> или %<short%> наведено уз char за %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> и %<short%> наведени заједно за %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed или unsigned употребљени неисправно за %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex неисправно за %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "дефиниција функције декларисана као %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "декларација %qs на највишем нивоу наводи %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs досега функције имплицитно аутоматска и декларасина као %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама пријатељских функција"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
-#, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
-msgstr ""
-
-#: cp/decl.c:11099
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/decl.c:11111
+#: cp/decl.c:11156
 #, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.c:11169
+#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -47768,264 +47927,264 @@
 msgstr "конструктор не може бити виртуелан"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -48032,177 +48191,177 @@
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<concept%>"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
@@ -48209,83 +48368,83 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -48306,185 +48465,185 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -48496,96 +48655,96 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "underlying type %qT of %qT must be an integral type"
@@ -48595,85 +48754,85 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "вредност набрајача за %qD није целобројна константа"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid function declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -48714,7 +48873,7 @@
 msgid "deleting %qT is undefined"
 msgstr "брисање %qT није дефинисано"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "декларација шаблона %q#D"
@@ -48728,7 +48887,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD декларисан као члански шаблон"
@@ -48847,45 +49006,45 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "анонимна структура није унутар именованог типа"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "приватни члан %q+#D у анонимној унији"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "анонимне скупине у досегу именског простора морају бити статичке"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "анонимна унија без чланова"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> мора враћати тип %qT"
@@ -48894,72 +49053,72 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> мора враћати тип %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT декларисано са већом видљивошћу од типа његовог поља %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -48969,68 +49128,68 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не упућује на неодређени тип, тако да се не користи за повезивост"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "одељак за %q+D коси се са претходном декларацијом"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "претходна декларација %q+D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "недостаје подразумевани аргумент за параметар %P од %q+#D"
@@ -49037,18 +49196,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -49059,113 +49218,113 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "без аргумената"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "двосмислено упућивање на %<%T::%D%>"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD није члан у %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> није декларисано"
@@ -49319,78 +49478,78 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(ако нисте ово намеравали, проверите да ли је шаблон функције већ декларисан, и додајте овде <> после имена функције) -Wno-non-template-friend искључује ово упозорење"
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "value-initialization of incomplete type %qT"
 msgstr "неисправна примена %qs на непотпун тип %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "value-initialization of function type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "value-initialization of reference type %qT"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "успостављање флексибилног чланског низа"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD треба да се успостави у листи успостављања чланова"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "класа %qT је имплицитно сама себи пријатељска"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "неуспостављени константни члан %qD"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
@@ -49397,312 +49556,312 @@
 msgid "%q#D should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "основно %qT ће бити успостављено после"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  основног %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  када се успостави овде"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%Jвишеструка успостављања дата за %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jвишеструка успостављања дата за основно %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%Jуспостављања за више чланова из %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D је статички члански податак; може се успостављати само при дефинисању"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "неименовани успостављач за %qT, која нема основних класа"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "неименовани успостављач за %qT, која користи вишеструко наслеђивање"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD је и непосредна основа и посредна виртуелна основа"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%qT is not a class type"
 msgstr "%q#T није класа"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "непотпун тип %qT нема члан %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "неисправан показивач на битско поље %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "целобројно преливање у изразу"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "неисправан тип %<void%> за new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ниједно погодно %qD није нађено у класи %qT"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "двосмислен захтев за чланом %qD"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new се не може применити на упућивачки тип"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "успостављач се прерано окончава"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "непозната величина низа за delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
@@ -49714,7 +49873,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -49801,68 +49960,68 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(ако употребите %<-fpermissive%>, Г++ ће прихватити овакав кôд, али дозвољавање недекларисаног имена је превазиђено)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "изостављени средњи операнд у %<?:%> не може бити запетљан"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "запетљано име за %qD биће измењено у будућим верзијама ГЦЦа"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -49992,48 +50151,48 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D скрива конструктор за %q#T"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "due to different exception specifications"
 msgstr "Створи кôд за проверу одредница изузетака"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларација %q#D заклања параметар"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "глобална декларација %q+#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -50042,64 +50201,64 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "декларација коришћења %q+D коси се са претходном декларацијом коришћења"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "измењена потрага имена за %qD"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  одговара овом %q+D по правилима ИСО стандарда"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  одговара овом %q+D по старим правилима"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "name lookup of %qD changed for new ISO %<for%> scoping"
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "измењена потрага %qD према новом досезању ИСО %<for%>"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "  користи се застарело везивање код %q+D"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -50107,12 +50266,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "декларација употребе не може навести ид. шаблона. Покушајте %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "именски простор %qD није дозвоље у декларацији употребе"
@@ -50119,106 +50278,106 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT није именски простор"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD је већ декларисано у овом досегу"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> именује деструктор"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "нема члана који одговара %<%T::%D%> у %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD треба да је декларисано унутар %qD"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибутска директива %qD игнорисана"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -50227,85 +50386,91 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%<this%> is unavailable for static member functions"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%<this%> није доступно за статичке чланске функције"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "алијас именског простора %qD није дозвољен овде, претпостављам %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entering pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX leaving pop_everything ()\n"
@@ -50326,7 +50491,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50354,7 +50519,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "захтев за члан %qD у некласном типу %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -50446,7 +50611,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "претапање у тип који није ни интегрални ни набројиви не може се јавити у изразу константе"
@@ -50692,7 +50857,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -50783,7 +50948,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "досег %qT пре %<~%> није име класе"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -50798,549 +50963,540 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-име %qD употребљено као декларатор деструктора"
 
-#: cp/parser.c:6110
-#, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "очекивана је листа наводилаца-одредби"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD није шаблон"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_frame_address%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ИСО Ц++ забрањује сложене константе"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница низа забрањена је после заграђеног ид. типа"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "употреба старовремског претапања"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "предложи заграде око && унутар ||"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "new types may not be defined in a return type"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "не могу се дефинисати нови типови у повратном типу"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "lambda-expression in template-argument"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Неочекиван крај модула"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "удвостручено %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "етикета случаја %qE ван наредбе пребацивања"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "сувишно %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "забрањено је мешање декларација и дефиниција функција"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "празна декларација"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> употребљено изван класе"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D неисправно у %q#T"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "само конструктори узимају успостављаче основе"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "анахронистични старовремски успостављач основне класе"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (успостављач одређеног члана имплицитно је тип)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неисправан операнд услова"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -51347,75 +51503,75 @@
 msgstr "неочекиван операнд"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> је другачије написано %<[%>. Убаците размак између %<<%> и %<::%>"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(Г++ ће прихватити ово ако задате -fpermissive)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -51422,320 +51578,320 @@
 msgstr "очекивана је наредба"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "употребите %<%T::template %D%> да назначите да је шаблон"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "очекивани су наводиоци декларације или %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специјализација шаблона са Ц повезивошћу"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибут се игнорише при предоченом-наводиоцу-типа који није унапредна декларација"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD није шаблон функције"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Инструкције min/max нису дозвољене"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "сувишне одредбе се игноришу"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: дефиниција функције није претворена\n"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "успостављач дат за функцију"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -51745,18 +51901,18 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid declarator"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "неисправна употреба конструктора као шаблона"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "употреба %<%T::%D%> уместо %<%T::%D%> за именовање конструктора у одређеном имену"
@@ -51763,425 +51919,425 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD је именски простор"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "недостаје справљачки циљ после %qs"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "подразумевани аргументи су дозвољени само за параметре функција"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "неисправно име класе у декларацији %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "експлицитној специјализацији мора претходити %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "претходна дефиниција %q+#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "при декларацији пријатеља мора бити употребљена кључна реч class"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (основна класа је имплицитно тип)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD in linkage specification"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -52190,456 +52346,456 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Use media instructions"
 msgid "empty introduction-list"
 msgstr "Користи медија-инструкције"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52646,118 +52802,118 @@
 msgstr "%qD није чланска шаблонска функција"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  из дефиниције %q+#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специјализација %qT после извођења"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "специјализација %q#T у различитом именском простору"
@@ -52764,71 +52920,71 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специјализација %qT после извођења %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD није шаблон"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "ид. шаблона %qD за %q+D не одговара ниједној декларацији шаблона"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -52835,25 +52991,25 @@
 msgstr "експлицитна специјализација %qD после прве употребе"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "недостаје атрибут Code"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
@@ -52861,60 +53017,60 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "листа шаблонских параметара употребљена у експлицитном извођењу"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "дефиниција дата за експлицитно извођење"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "премало листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "експлицитна специјализација %qD мора бити уведена помоћу %<template <>%>"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD није шаблонска функција"
@@ -52927,150 +53083,150 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "нема чланске функције %qD декларисане у %qT"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "friend declaration here"
 msgstr "%Jзаклоњена декларација је овде"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<анонимно>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "шаблонски параметарски тип %qT декларисан пријатељским"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -53080,19 +53236,19 @@
 msgstr[2] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 msgstr[3] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нема подразумеваног аргумента за %qD"
@@ -53100,53 +53256,53 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумевани аргумент за параметар типа %qT има тип %qT"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "параметар %qD декларисан празним"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблонска класа без имена"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -53157,59 +53313,59 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "неисправна декларација шаблона %qD"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "шаблонска дефиниција нешаблонског %q#D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очекивах %d нивоа шаблонских параметара за %q#D, добих %d"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  а потребно је %d"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "наводиоци шаблона нису задати у декларацији %qD"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -53219,7 +53375,7 @@
 msgstr[2] "%qD употребљено без параметара шаблона"
 msgstr[3] "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -53229,12 +53385,12 @@
 msgstr[2] "претходном декларацијом %q+#D овде"
 msgstr[3] "претходном декларацијом %q+#D овде"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "шаблонски параметар %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
@@ -53243,132 +53399,132 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT није члан из %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs није исправно за %qs"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53377,316 +53533,322 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се константне ниске не могу користити у овом контексту"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "template argument for %qD uses local type %qT"
 msgid "in template argument for type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "акумулатор није целобројна константа"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "ignoring attributes in template argument %qE"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очекивах шаблон типа %qD, добих %qD"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "%Jflexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "%Jфлексибилан члански низ у унији"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -53705,294 +53867,294 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -54005,118 +54167,124 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "use of %qs in template"
+msgid "invalid use of %qT in template argument"
+msgstr "употреба %qs у шаблону"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -54337,7 +54505,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неисправан одредбени досег у имену псеудодеструктора"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
@@ -54388,7 +54556,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
@@ -54465,334 +54633,335 @@
 msgstr "%qT није шаблонски тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не може се применити %<offsetof%> на деструктор %<~%T%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<firstprivate%>"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<device%> id must be integral"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "поновљена имплементација класе %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -54934,13 +55103,13 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "провера lang_*: крах у %s, код %s:%d"
@@ -55011,811 +55180,805 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "неисправна примена %qs на чланску функцију"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "неисправна примена %<sizeof%> на битско поље"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<sizeof%> на израз функцијског типа"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "неисправна примена %<__alignof%> на битско поље"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<__alignof%> на израз функцијског типа"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "неисправна употреба нестатичког чланског податка %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "неисправан приступ нестатичком чланском податку %qD нултог објекта"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "тип који се уништава је %qT, али деструктор упућује на %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT није основа за %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD није чланска шаблонска функција"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT није типа показивач-на-објекат"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "недостаје објекат у употреби %qE"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "не могу да искључим уграђену функцију %qs"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ИСО Ц++ забрањује звање %<::main%> унутар програма"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "мора се употребити или %<.*%> или %<->*%> за позив показивача на чланску функцију у %<%E (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметар %P за %qD непотпуног је типа %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "претпоставља се претапање у тип %qT из препуњене функције"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL употребљено аритметички"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "негативно ротирање %s"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "негативно ротирање %s"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "ротирање %s >= ширина типа"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "ротирање %s >= ширина типа"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ИСО Ц++ забрањује поређење показивача и целобројног"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "неисправни операнди типова %qT и %qT за бинарно %qO"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача типа %<void *%> у одузимању"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на метод у одузимању"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "неисправна употреба показивача на непотпун тип у аритметици са показивачима"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "неисправна употреба %qE за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  неопходан је одређен ид."
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "заграде око %qE не могу бити коришћене за добијање показивача-на-чланску-функцију"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе неодређене или заграћене нестатичке чланске функције, за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе везане чланске функције за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ИСО Ц++ забрањује узимање адресе функције %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "не може се створити показивач на упућивачки члан %qD"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "не може се узети адреса битског поља %qD"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "затражена је адреса експлицитне регистарске променљиве %qD"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "затражена је адреса од %qD, а декларисано је као %<register%>"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "претварање из %qT у %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "претапање из %qT у %qT губи на тачности"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "претапање из %qT у %qT повећава неопходно равнање циљног типа"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ИСО Ц++ забрањује претапање између показивача на функцију и показивача на објекат"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "неисправно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "неисправна употреба константног претапања са типом %qT, који није показивач, нити показивач на члански податак"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "неисправна употреба константног претапања са типом %qT, који је показивач или упућивач на функцијски тип"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "неисправно константно претапање д-вредности типа %qT у тип %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "неисправно константно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ИСО Ц++ забрањује претапање у низовни тип %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  у израчунавању %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "неисправна додела низа"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   у претварању показивача на чланску функцију"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "претварање показивача на члан преко виртуелне основе %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   у претварању показивача на члан"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
+#| msgid "cannot convert %qT to %qT in %s"
+msgid "cannot convert %qH to %qI"
+msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
-msgid "cannot convert %qH to %qI"
-msgstr "не може се претворити %qT у %qT у %s"
-
-#: cp/typeck.c:8804
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "у прослеђивању аргумента %P за %q+D"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "враћање упућивача на не-л-вредност"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "враћање упућивача на локалну променљиву %q+D"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "враћање вредности из деструктора"
@@ -55822,59 +55985,59 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не може се враћати из руковаоца у блоку покушаја у конструктору"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "враћање вредности из конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "недостаје успостављач"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> не сме вратити NULL, осим ако је декларисан уз %<throw()%> (или је задато -fcheck-new)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -56122,152 +56285,152 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "употребљена синтакса конструктора, али конструктор није декларисан за тип %qT"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "двосмислено претварање %qE из %qT у %qT"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "двосмислено претварање %qE из %qT у %qT"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-низ успостављен из не-широке ниске"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-низ успостављен из не-широке ниске"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "предугачка ниска успостављача за низ знакова"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "прототип за %q#D не одговара ниједном у класи %qT"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#T"
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -56722,28 +56885,28 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -56750,22 +56913,22 @@
 msgid "Simplification error"
 msgstr "гимплификација није успела"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -57880,7 +58043,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -58074,7 +58237,7 @@
 msgid "deferred type parameter at %C"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -58344,483 +58507,483 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Удвостручена одредница низа за Крејов показиваног код %C."
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Успостављање код %C није за показивачку променљиву"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Успостављање променљиве код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Успостављање резервљиве компоненте код %C није дозвољено"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Показивачка компонента ‘%s’ у ‘%s’ код %L припада типу који није декларисан"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старовремска декларација типа %s*%d није подржана код %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандардна декларација типа %s*%d код %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Очекиван је скаларни успостављачки израз код %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Израз код %L мора бити целобројног типа"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Параметар врсте за %s код %L мора бити инцијализовани израз"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Проширење: тип BYTE код %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Тип BYTE употребљен код %C није доступан на циљној машини"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument list function at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Функција листе аргумената код %L није дозвољена у овом контексту"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Удвостручена наредба IMPLICIT NONE код %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Недостаје знаковни опсег за имплицитно код %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Слова морају бити у алфабетском поретку у наредби IMPLICIT код %C"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Атрибут %s код %L није дозвољен изван модула"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "Линија одсечена код %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -58828,369 +58991,369 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Недостаје генеричка одредница у наредби USE код %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "недостаје име"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Изведени тип код %C није претходно дефинисан и зато се не може појавити у дефиницији изведеног типа."
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Очекивана је етикета алтернативног повратка код %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "A parameter name is required at %C"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Име ‘%s’ код %C је име процедуре"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Очекивана је друга димензија у декларацији низа код %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "Променљива RESULT код %C мора бити различита од имена функције"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксна грешка у конструктору структуре код %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Очекивана је формална листа аргумената у дефиницији функције код %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "Наредба ENTRY код %C не може бити унутар PROGRAM"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "Наредба ENTRY код %C не може бити унутар BLOCK DATA"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DERIVED TYPE"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока IF-THEN"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока FORALL"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока WHERE"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "Наредба ENTRY код %C не може бити унутар садржаног потпрограма"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "Наредба ENTRY код %C не може бити у садржаној процедури"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Недостаје етикета формата код %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Име функције ‘%s’ није дозвољено код %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -59197,176 +59360,176 @@
 msgstr "Наредба %s код %C не може пратити наредбу %s код %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Очекивана је наредба %s код %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Очекивана је етикета ‘%s’ за наредбу %s код %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Одредница низа мора бити одложена код %L"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неочекиван знак у листи променљивих код %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Очекивано је име променљиве код %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Крејов показивач код %C има %d бајтова тачности; меморијска адреса захтева %d бајтова."
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Очекивано је ‘)’ код %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Очекивано је ‘,’ или крај наредбе код %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Декларација Крејовог показивача код %C захтева заставицу -fcray-pointer."
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Одредница приступа оператора %s код %C је већ наведена"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Одредница приступа оператора .%s. код %C је већ наведена"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Очекивано је име променљиве код %C у наредби PARAMETER"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Очекиван је знак = у наредби PARAMETER код %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Очекиван је израз код %C у наредби PARAMETER"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
@@ -59373,502 +59536,502 @@
 msgstr "Успостављач није дозвољен за заједничку променљиву ‘%s’ код %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Покривачка наредба SAVE код %C прати претходну наредбу SAVE"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD не може бити нитно-локално зато што је не-ПОД типа %qT"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Изведени тип код %C може бити само приватан унутар модула"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Изведени тип код %C може бити само јаван унутар модула"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Удвостручена етикета конструкције ‘%s’ код %C"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Крејов показивани код %C не може бити низ претпостављеног облика"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Ново у фортрану 2003: ENUM и ENUMERATOR код %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Набрајач премашује Ц-ов целобројни тип код %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "Набрајач %L није успостављен целобројним изразом"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Очекивана је наредба дефиниције ENUM пре %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксна грешка у дефиницији ENUMERATOR код %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "Очекивано је безимено сучеље код %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Очекиван је индекс низа код %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Неисправан облик наредбе PROGRAM код %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected module procedure name at %C"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -60236,27 +60399,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -60608,7 +60771,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
 msgid "Creating array temporary at %L"
@@ -60620,69 +60783,69 @@
 msgid "Removing call to function %qs at %L"
 msgstr "позив не-функције %qD"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "очекиван је израз"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "Interchanging loops at %L"
@@ -60812,12 +60975,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -62137,7 +62300,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -63707,12 +63870,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -63984,8 +64147,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
@@ -64030,7 +64193,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
@@ -64411,192 +64574,192 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO не може бити DO WHILE или DO без контроле петље код %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "Променљива итерације у !$OMP DO мора бити целобројног типа код %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOGICAL operands are required in expression at %L"
 msgid "TILE requires constant expression at %L"
 msgstr "Неопходни су логички операнди у изразу код %L"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -66073,7 +66236,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
@@ -66198,7 +66361,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66610,23 +66773,23 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -66633,220 +66796,220 @@
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Одредница UNIT код %L мора бити целобројни израз или знаковна променљива"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -66855,257 +67018,257 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -67113,12 +67276,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67126,114 +67289,114 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -67240,73 +67403,73 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -67313,7 +67476,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67321,63 +67484,63 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -67384,119 +67547,119 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "у %s, код %s:%d"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
@@ -67503,13 +67666,13 @@
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
@@ -67516,849 +67679,849 @@
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Показивачка компонента ‘%s’ у ‘%s’ код %L припада типу који није декларисан"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -68821,7 +68984,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): неисправан тип: %s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -69525,19 +69688,19 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Сопствена функција %s(%d) није препозната"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "The event variable at %L shall not be coindexed"
@@ -69743,202 +69906,202 @@
 msgid "previously defined here as %s"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "multiple prevailing defs for %qE"
 msgstr "complex неисправно за %qs"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in %qT"
 msgid "%qD has already been defined"
 msgstr "%qD је већ дефинисано у %qT"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "previously defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "type of %qD does not match original declaration"
 msgstr "ид. шаблона %qD за %q+D не одговара ниједној декларацији шаблона"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%qD was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "variable %qD redeclared as function"
 msgstr "поље %qs декларисано као функција"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %qD redeclared as variable"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "could not find specs file %s\n"
 msgid "could not parse file offset"
 msgstr "нисам могао да нађем датотеку навода %s\n"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected offset"
 msgstr "неочекиван операнд"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid line in the resolution file"
 msgstr "неисправан регистар у инструкцији"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid resolution in the resolution file"
 msgstr "неисправан регистар у инструкцији"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot read LTO decls from %s"
 msgstr "не могу да нађем класу %qs"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init није прошло"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr "преименујем .rpo датотеку"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "opening LTRANS output list %s: %m"
 msgstr "отварам улазну датотеку %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, fuzzy, gcc-internal-format
 #| msgid "when writing output to %s: %m"
 msgid "writing to LTRANS output list %s: %m"
 msgstr "када уписујем излаз у %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "closing LTRANS output list %s: %m"
 msgstr "отварам улазну датотеку %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "%s:нисам могао да отворим излазну датотеку ‘%s’\n"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/da.po
===================================================================
--- gcc/po/da.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/da.po	(.../branches/gcc-8-branch)
@@ -137,7 +137,7 @@
 msgstr ""
 "Project-Id-Version: gcc-8.1-b20180128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2018-04-02 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -280,40 +280,40 @@
 msgid "negative insn length"
 msgstr "negativ instruktionslængde"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "kunne ikke dele instruktion"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "ugyldig »asm«: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "indlejrede alternativer for maskinkodedialekter"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "uafsluttet alternativ for maskinkodedialekt"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "operandtal mangler efter %%-letter"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "operandtal er uden for det gyldige interval"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "ugyldig %%-kode"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "»%%l«-operand er ikke en etiket"
@@ -324,13 +324,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "kommatalskonstant misbrugt"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1298,25 +1298,25 @@
 msgid "At top level:"
 msgstr "Ved øverste niveau:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "I medlemsfunktionen %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "I funktionen %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    indlejret fra %qs ved %r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    indlejret fra %qs ved %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    indlejret fra %qs"
@@ -3080,9 +3080,9 @@
 msgid "invalid address mode"
 msgstr "ugyldig adresseringstilstand"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« brugt uden nogle lokale dynamiske TLS-referencer"
@@ -3098,7 +3098,7 @@
 msgstr "ugyldig %%r-værdi"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3105,13 +3105,13 @@
 msgstr "ugyldig %%R-værdi"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
@@ -3142,7 +3142,7 @@
 msgstr "ugyldig %%U-værdi"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
@@ -3153,7 +3153,7 @@
 msgstr "ugyldig %%C-værdi"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
@@ -3164,7 +3164,7 @@
 msgstr "ukendt relokaliserings-unspec"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3175,58 +3175,58 @@
 msgid "invalid operand address"
 msgstr "ugyldig operandadresse"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ugyldig operand til %%Z-koden"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ugyldig operand til %%z-koden"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "ugyldig operand til %%Z-koden"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ugyldig operand til %%M-koden"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ugyldig operand til %%p-koden"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ugyldig operand til %%s-koden"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ugyldig operand til %%R-koden"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ugyldig operand til %%H/%%L-koden"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ugyldig operand til %%U-koden"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ugyldig operand til %%V-koden"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ugyldig operand til %%O-koden"
@@ -3233,18 +3233,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ugyldig operand-uddatakode"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ugyldig UNSPEC som operand: %d"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "ukendt formodet konstant"
 
@@ -3281,7 +3281,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
@@ -3412,8 +3412,8 @@
 msgstr "ugyldig const_double-operand"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3630,100 +3630,100 @@
 msgid "bad output_condmove_single operand"
 msgstr "ugyldig output_condmove_single-operand"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ugyldig UNSPEC som operand"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of register '%s'"
 msgstr "ugyldig brug af 'restrict'"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ugyldig brug af asm-flaguddata"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ugyldig operandstørrelse for operandkoden »O«"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ugyldig operandstørrelse for operandkoden »z«"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ugyldig operandtype brugt med operandkoden »Z«"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ugyldig operandstørrelse for operandkoden »Z«"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »Y«"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »D«"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »%c«"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand er ikke en offsettable-hukommelsesreference, ugyldig operandkode »H«"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »K«"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »R«"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is not a specific integer, invalid operand code 'r'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ugyldig operandkode »%c«"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ugyldige begrænsninger for operand"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector immediate"
 msgstr "ugyldig konstant:"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "ukendt instruktionstilstand"
 
@@ -3761,7 +3761,7 @@
 msgstr "ugyldig %%P-operand"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -3815,7 +3815,7 @@
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -3981,143 +3981,143 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 og __ibm128 kan ikke bruges i det samme udtryk"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 og lang dobbelt kan ikke bruges i det samme udtryk"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 og lang dobbelt kan ikke bruges i det samme udtryk"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr "Kunne ikke generere addis-værdi for fusion"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kunne ikke generere indlæsning/lagring af forskydning for fusion"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr "Ugyldig GPR-fusion"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, ugyldig reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, ugyldig reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load ikke MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, ugyldig reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, ugyldig reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store ikke MEM"
 
@@ -4243,43 +4243,43 @@
 msgid "created and used with different endianness"
 msgstr "oprettet og brugt med en anden endianness"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ugyldig %%Y-operand"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ugyldig %%A-operand"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ugyldig %%B-operand"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ugyldig %%C-operand"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ugyldig %%D-operand"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ugyldig %%f-operand"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ugyldig %%s-operand"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "kommatalskonstant er ikke en gyldig umiddelbar operand"
@@ -4494,14 +4494,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> forventet"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> forventet"
@@ -4516,7 +4516,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> forventet"
@@ -4524,7 +4524,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> forventet"
@@ -4538,7 +4538,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> forventet"
@@ -4545,7 +4545,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> forventet"
@@ -4555,13 +4555,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> forventet"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> forventet"
@@ -4570,18 +4570,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> forventet"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> forventet"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> forventet"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> forventet"
@@ -4589,23 +4589,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> forventet"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> forventet"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> forventet"
@@ -4614,7 +4614,7 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> forventet"
@@ -4625,39 +4625,39 @@
 msgid "expected label"
 msgstr "forventet etiket"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "spring til etiketten %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "spring til case-etiket"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr "går ind i try-blok"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr "går ind i catch-blok"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr "går ind i OpenMP-struktureret blok"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr "går ind i synkroniseret eller atomar udtryk"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr "går ind i constexpr if-udtryk"
 
@@ -4757,7 +4757,7 @@
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4778,130 +4778,130 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 #, fuzzy
 #| msgid "parse error"
 msgid "<expression error>"
 msgstr "tolkningsfejl"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr ""
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 #| msgid "In member function `%s':"
 msgid "In static member function %qs"
 msgstr "I medlemsfunktionen '%s':"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, fuzzy, c-format
 #| msgid "In construct"
 msgid "In copy constructor %qs"
 msgstr "I konstruktionen"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 #| msgid "In construct"
 msgid "In constructor %qs"
 msgstr "I konstruktionen"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 #| msgid "In construct"
 msgid "In destructor %qs"
 msgstr "I konstruktionen"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 #| msgid "In function"
 msgid "In lambda function"
 msgstr "I funktionen"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, fuzzy, c-format
 #| msgid "%s: In instantiation of `%s':\n"
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: i instantiering af '%s':\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 #| msgid "%s: In instantiation of `%s':\n"
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: i instantiering af '%s':\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 #| msgid "called from here"
 msgid "recursively required from here\n"
 msgstr "kaldt herfra"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "called from here"
 msgid "required from here\n"
 msgstr "kaldt herfra"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 #, fuzzy
 msgid "candidates are:"
 msgstr "candidate%s: %+#D"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4964,50 +4964,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "forkert parametertype til unært minus"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "forkert parametertype til abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "forkert parametertype til konjugation"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5331,11 +5331,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
@@ -5524,49 +5524,49 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5608,12 +5608,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5872,6 +5872,7 @@
 msgstr "-membedded-pic og -mabicalls er indbyrdes uforenelige"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -9034,7 +9035,7 @@
 msgstr "Justér variabler til 32 bit-grænserne"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr "Angiv navnet på målarkitekturen."
 
@@ -9598,7 +9599,7 @@
 msgstr "Angiv interval af registre der skal gøres faste"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -10451,7 +10452,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Opret kode som overholde den angivne ABI"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "Kendte ABI'er (for brug med tilvalget -mabi=):"
 
@@ -11007,7 +11008,7 @@
 msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -11016,12 +11017,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -11034,49 +11035,51 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
 msgstr "Benyt call og rtc til funktionskald og returneringer"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "en funktions returtype kan ikke være en funktion"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 #, fuzzy
 #| msgid "Known CPUs (for use with the -mcpu= and -mtune= options):"
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Kendte cpu'er (for brug med tilvalgene -mcpu= og -mtune=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -11619,7 +11622,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Forældet tilvalg. Brug -mvrsave i stedet"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -11627,7 +11630,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -11742,7 +11745,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "Planlæg koden til en given processor"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -11777,7 +11780,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -11870,27 +11873,27 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Benyt AltiVec-instruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Generér char-instruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -11910,21 +11913,21 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 #, fuzzy
 #| msgid "Use pattern compare instructions"
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Benyt mønstersammenligningsinstruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector instructions added in ISA 3.0."
@@ -11942,19 +11945,19 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 #, fuzzy
 #| msgid "Enable parallel instructions"
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Aktivér parallelle instruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 #, fuzzy
 #| msgid "Serialize volatile memory references with MEMW instructions"
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr "Serialisér volatile hukommelsesreference med MEMW-instruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate the integer modulo instructions."
@@ -11964,19 +11967,19 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -11985,7 +11988,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Returnér små sammensatte værdier i registre"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 #| msgid "Pass all arguments on stack"
 msgid "Valid arguments to -mstack-protector-guard=:"
@@ -12025,14 +12028,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Flyt ikke instruktioner til en funktions begyndelse"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "Angiv ABI-kaldekonvention"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -12855,7 +12857,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -13102,14 +13104,28 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:338
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare without loops."
+msgstr "Det maksimale antal instruktioner for en ikke løkke uden afbryder."
+
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare with loops."
+msgstr "Det maksimale antal instruktioner for en ikke løkke uden afbryder."
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop."
+msgid "Max number of pairs of load insns for compare."
+msgstr "Det maksimale antal skrælninger for en enkel løkke."
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
@@ -13120,10 +13136,49 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "Select full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "Vælg komplet, partiel eller ingen tilbagesporingstabel"
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "Specify size of long double (64 or 128 bits)"
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "Angiv størrelsen af long double (64 eller 128 bit)"
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+#| msgid "`%s' is deprecated"
+msgid "%qs is deprecated"
+msgstr "'%s' er forældet"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Angiv ABI-kaldekonvention"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Angiv metode for sdata-håndtering"
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Angiv bitstørrelse for umiddelbar TLS-afsæt"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -14600,107 +14655,173 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Tillad at gcc opretter SETLB- og Lcc-instruktioner."
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "Opret kode i storendet tilstand."
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "Opret kode i lilleendet tilstand."
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr "Brug reduceret sæt af registre for registerallokering."
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "Omplanlæg instruktioner før registerallokering"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+#, fuzzy
+#| msgid "Use alternate leaf function entries"
+msgid "Align function entry to 4 byte."
+msgstr "Benyt alternative elementer til yderste funktioner"
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr "Opret betingede flytteinstruktioner."
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate performance extension instructions."
 msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate performance extension version 2 instructions."
 msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate string extension instructions."
 msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Generér char-instruktioner"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate 16-bit instructions."
 msgstr "Generér char-instruktioner"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "hexadecimal floating constants require an exponent"
 msgid "Enable Virtual Hosting support."
 msgstr "hexadecimal kommatalskonstant skal have en eksponent"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the MCU name"
 msgid "Specify the cpu for pipeline model."
 msgstr "Angiv MCU-navnet"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 #, fuzzy
 #| msgid "Known FR-V CPUs (for use with the -mcpu= option):"
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Kendt FR-V CPU'er (for brug med -mcpu= option):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
 #, fuzzy
+#| msgid "Known ABIs (for use with the -mabi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "Kendte ABI'er (for brug med tilvalget -mabi=):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
+#, fuzzy
 msgid "Enable constructor/destructor feature."
 msgstr "Advar ikke når alle konstruktions-/destruktionsfunktioner er private"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Guide linker to relax instructions."
 msgstr "Generér char-instruktioner"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Generér kommatalsmatematik vha. givent instruktionssæt"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use hardware floating point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "Benyt hardware-kommatalsinstruktioner"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Opret kode som bruger 68881-kommatalsinstruktioner."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -15807,14 +15928,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-#| msgid "`%s' is deprecated"
-msgid "%qs is deprecated"
-msgstr "'%s' er forældet"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate multm instructions"
@@ -18602,8 +18715,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "beregnet værdi benyttes ikke"
@@ -18631,7 +18744,7 @@
 msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "uventet operand"
@@ -19105,7 +19218,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
@@ -19135,13 +19248,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -19192,9 +19305,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -19209,8 +19322,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %qD"
@@ -19354,86 +19467,80 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "too few arguments to function %<va_start%>"
 msgstr "for mange parametre til funktionen 'va_start'"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid argument to %qD"
 msgstr "ugyldig typeparameter"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument to %qD"
@@ -19441,78 +19548,78 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_eh_return_regno' must be constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "parameteren til '__builtin_eh_return_regno' skal være konstant"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "trampoline generated for nested function %qD"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, fuzzy, gcc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `%T' for default argument to `%T'"
 msgid "invalid memory model argument to builtin"
 msgstr "ugyldig type '%T' for standardparameter til '%T'"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ugyldig tilstand for gen_tst_reg"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19520,7 +19627,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -19527,12 +19634,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_longjmp second argument must be 1"
 msgid "%<__builtin_longjmp%> second argument must be 1"
@@ -19540,70 +19647,70 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "målprocessoren understøtter ikke uendelig"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "målprocessoren understøtter ikke uendelig"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed args"
 msgstr "`va_start' benyttet i en funktion med fast antal parametre"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "for mange parametre til funktionen 'va_start'"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "forkert antal parametre angivet til egenskaben '%s'"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of `va_start' not last named argument"
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "den anden parameter til 'va_start' er ikke den sidste navngivne parameter"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -20869,40 +20976,40 @@
 msgid "conversion to incomplete type"
 msgstr "konvertering til en ufuldstændig type"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "kan ikke konvertere vektorværdier af forskellige størrelser"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "en værdi af en sammensat type er angivet hvor der forventedes et heltal"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "en henvisningsværdi er angivet hvor der forventedes et komplekst tal"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "en værdi af en sammensat type er angivet hvor der forventedes et komplekst tal"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "kan ikke konvertere vektorværdier af forskellige størrelser"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert value to a vector"
 msgid "can%'t convert value to a vector"
 msgstr "kan ikke konvertere værdi til en vektor"
 
-#: convert.c:1168
+#: convert.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate value used where a float was expected"
 msgid "aggregate value used where a fixed-point was expected"
@@ -21065,12 +21172,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -21186,12 +21293,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: expr.c:10986
+#: expr.c:10992
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
@@ -21208,13 +21315,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "%Jstørrelsen af '%D' er større end %d byte"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "kunne ikke åbne dumpningsfilen '%s'"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not close final insn dump file %qs: %m"
@@ -21226,45 +21333,45 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "stort heltal forkortes underforstået til type uden fortegn"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "sammenligning er altid %d"
 
 # RETMIG: det giver ikke mening
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, fuzzy, gcc-internal-format
 #| msgid "`or' of unmatched not-equal tests is always 1"
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "'or' af uafbalancerede sammenligninger med forskellig fra er altid 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, fuzzy, gcc-internal-format
 #| msgid "`and' of mutually exclusive equal-tests is always 0"
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "'and' af udtryk der hver for sig udelukker hinanden, er altid 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -21835,29 +21942,29 @@
 msgid "can%'t write PCH file"
 msgstr "kan ikke skrive i uddatafil"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments for spec function"
 msgid "%qD source argument is the same as destination"
 msgstr "ingen parametre til specifikationsfunktion"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -21873,12 +21980,13 @@
 msgid "null pointer dereference"
 msgstr "henvisning"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared here"
@@ -22414,10 +22522,10 @@
 msgstr "tabelindeks er ikke et heltal"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -22451,7 +22559,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 #, fuzzy
 #| msgid "no arguments for spec function"
 msgid "%G%qD source argument is the same as destination"
@@ -22820,273 +22928,278 @@
 msgid "function cannot be instrumented"
 msgstr "funktion kan ikke indbygges"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "contains additional virtual method %qD"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, fuzzy, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "tidligere definition her"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "a different type is defined in another translation unit"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "the incompatible type defined in another translation unit"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "type name %qs should match type name %qs"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in %s"
 msgid "the incompatible type is defined here"
 msgstr "uforenelige typer i %s"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "forming reference to void"
 msgid "array types have different bounds"
 msgstr "danner reference til void"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "return value type mismatch"
 msgstr "typen af startværdien for feltet passer ikke"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in parameter %i"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "different type"
 msgid "types have different parameter counts"
 msgstr "anden type"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, fuzzy, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "tidligere definition her"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "type %qT should match type %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "a type defined in another translation unit is polymorphic"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "a type with different bases is defined in another translation unit"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "no file specified with -fdump-translation-unit"
 msgid "fields have different layout in another translation unit"
 msgstr "ingen filer angivet med -fdump-translation-unit"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -23108,7 +23221,7 @@
 msgid "the extra base is defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -23115,7 +23228,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23122,7 +23235,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -23129,7 +23242,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -23136,7 +23249,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23143,7 +23256,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23442,32 +23555,38 @@
 #: multiple_target.c:91
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "versionsattribut er ikke en streng"
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "versionsattribut er ikke en streng"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default target was not set"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
+#: multiple_target.c:379
+#, fuzzy, gcc-internal-format
+#| msgid "bad value (%s) for -march= switch"
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr "ugyldig værdi (%s) til tilvalget -march="
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -23790,13 +23909,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s"
@@ -24419,22 +24538,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "uddataoperand %d skal bruge %<&%>-begrænsningen"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Ugyldig next_regno til tom kæde (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Løkke i registertalskæde (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Ugyldig oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Ikke-tomt register i kæde (%s %u %i)"
@@ -24478,7 +24597,7 @@
 msgstr "register for %qD brugt til flere globale registervariabler"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "er i konflikt med %qD"
@@ -24720,161 +24839,161 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D omdøbt efter at være refereret i maskinkode"
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "funktionsymbol er ikke en funktion"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "variabelsymbol er ikke en variabel"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "node har ukendt type"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "node blev ikke fundet node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "node er forskellig fra node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "maskinekodenavn på hashliste er ødelagt"
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "node blev ikke fundet i symtabs maskinkodehash"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "dobbelt lænket liste på maskinekodenavne er ødelagt"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "node har body_removed men er en definition"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "node is analyzed byt it is not a definition"
 msgid "node is analyzed but it is not a definition"
 msgstr "node er analyseret byt, det er ikke en definition"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "node er alias men ikke implicit alias"
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "node er alias men ikke definition"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, fuzzy, gcc-internal-format
 #| msgid "node is weakref but not an alias"
 msgid "node is weakref but not an transparent_alias"
 msgstr "node er weakref men ikke et alias"
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, fuzzy, gcc-internal-format
 #| msgid "node is weakref but not an alias"
 msgid "node is transparent_alias but not an alias"
 msgstr "node er weakref men ikke et alias"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "node er i same_comdat_grooup-liste men har ingen comdat_group"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group-liste over forskellige grupper"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "blanding af forskellige symboltyper i samme comdata-gruppe er ikke understøttet"
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "node er alene i en comdat-gruppe"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group er ikke en cirkulær liste"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "comdat-local-symbol refereret ti laf %s uden for dets comdat"
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "implicit_section-flag er angivet men sektion er ikke"
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Både sektion og comdat-gruppe er angivet"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Alias og måls sektion er forskellige"
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Alias og måls comdat-grupper er forskellige"
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's section differs"
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Alias og måls sektion er forskellige"
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify mislykkedes"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "To symboler med samme comdat_group er ikke lænket af same_comdat_group-listen."
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "funktion %q+D del af aliascyklus"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabel %q+D del af aliascyklus"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "sektion for alias %q+D skal matche sektion for dens målarkitektur"
@@ -26133,13 +26252,13 @@
 msgid "control reaches end of non-void function"
 msgstr "kontrol når til slutningen af ikke-void funktion"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -26666,7 +26785,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -26711,92 +26830,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "en tabel af funktioner giver ikke mening"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "en funktions returtype kan ikke være en funktion"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: %s, har %s i %s, ved %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: forventede ingen af %s, har %s i %s, ved %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede klasse %qs, har %qs (%s) i %s, ved %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede ikke klasse %qs, har %qs (%s) i %s, ved %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: forventede omp_clause %s, har %s i %s, ved %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "træ-kontrol: forventede træ som indeholder %qs-struktur, har %qs i %s, ved %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "trækontrol: tilgik udtrykstræ %d af tree_int_cst med %d udtrykstræer i %s, ved %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "trækontrol: tilgik udtrykstræ %d af tree_vec med %d udtrykstræer i %s, ved %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af %s med %d operander i %s, ved %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af omp_clause %s med %d operander i %s, ved %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD er forældet: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD  er forældet"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE er forældet: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE er forældet"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "type er forældet: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "type er forældet"
@@ -26821,242 +26940,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr "og felt"
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "types TREE_TYPE"
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "type er ikke forenelig med dens variant"
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "Hovedvariant er ikke defineret"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "Tabellen TYPE_DOMAIN er ikke af en heltalstype"
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS er defineret i en ufuldstændig type"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Forkert træ i TYPE_FIELDS-liste"
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type mislykkedes"
@@ -27081,12 +27200,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -28049,7 +28168,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "foreslår paranteser omkring tildeling der er benyttet som boolsk værdi"
@@ -28333,7 +28452,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array is too large"
@@ -29002,7 +29121,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -29020,25 +29139,25 @@
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
 msgstr "manglende ')' i udtryk"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -29634,8 +29753,8 @@
 msgid "wrong type argument to %s"
 msgstr "forkert parametertype til %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overløb i konstant udtryk"
@@ -30345,7 +30464,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "comparison between types %qT and %qT"
@@ -30428,7 +30547,7 @@
 msgstr[0] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 msgstr[1] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, fuzzy, gcc-internal-format
 #| msgid "the conditional began here"
 msgid "this condition has identical branches"
@@ -30563,49 +30682,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops er forældet, benyt -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d er ikke mellem 0 og %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps er forældet, benyt -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-jumps=%d is not between 1 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d er ikke mellem 1 og %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions er forældet, benyt -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-functions=%d is not between 1 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d er ikke mellem 1 og %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d er ikke mellem 0 og 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -30633,13 +30752,13 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "ukendt tilvalg -mdebug-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown switch -mlong-double-%s"
 msgid "unknown switch -mlong-double-%s"
@@ -30646,19 +30765,19 @@
 msgstr "Ukendt tilvalg -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -31183,8 +31302,8 @@
 msgstr "\"%s\" er ikke defineret"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
@@ -31276,8 +31395,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "ugyldig værdi '%s' for -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31394,11 +31513,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31409,140 +31528,129 @@
 msgid "%qE attribute only applies to functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arg to `__builtin_frame_address'"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "ugyldig parameter til '__builtin_frame_address'"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
-
-#: config/arc/arc.c:6597
-#, fuzzy, gcc-internal-format
-#| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "long long constant not a valid immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "long long-konstant er ikke en gyldig umiddelbar operand"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 #| msgid "pre-increment address is not a register"
 msgid "insn addresses not freed"
 msgstr "præfiks forøgelsesadresse er ikke et register"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute is missing"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
@@ -31549,27 +31657,27 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute ignored"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
@@ -31597,153 +31705,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "vælger skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32595,13 +32703,13 @@
 msgid "invalid IACC argument"
 msgstr "ugyldig IACC-parameter"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' expects a constant argument"
 msgid "%qs expects a constant argument"
 msgstr "'%s' forventer en konstant parameter"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument out of range for %qs"
@@ -32710,596 +32818,578 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "kan ikke angive position i PCH-filen: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "forkert parameter %qs for tilvalget %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "forkert strateginavn %qs er angivet for tilvalget %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "ukendt justering %qs angivet for tilvalget %qs"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "intet klassenavn angivet med '-%s'"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressetilstanden %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodemodellen %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s understøtter ikke PIC-tilstand"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel understøttes ikke af denne konfiguration"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bit-tilstand er ikke oversat med ind"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "den valgte processor understøtter ikke x86-64-instruktionssættet"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "Intel MPX does not support x32"
 msgstr "målprocessoren understøtter ikke APCS-32"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d er ikke mellem 0 og %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for -mrecip=%s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "-fstack-protector understøttes ikke på denne målarkitektur"
-
-#: config/i386/i386.c:4951
-#, fuzzy, gcc-internal-format
-#| msgid "-fcheck-pointer-bounds is not supported for this target"
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "-fcheck-pointer-bounds er ikke understøttet for denne målarkitektur"
-
-#: config/i386/i386.c:4961
-#, fuzzy, gcc-internal-format
-#| msgid "-fcheck-pointer-bounds is not supported for this target"
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "-fcheck-pointer-bounds er ikke understøttet for denne målarkitektur"
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 understøtter ikke egenskaben ms_abi"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue er ikke forenelig med den indlejrede funktion"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -33306,352 +33396,352 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported size for integer register"
 msgid "'V' modifier on non-integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "udvidede registre har ikke høje halvdele"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ikke-understøttet operandstørrelse for udvidede registre"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No case for %s"
 msgid "No dispatcher found for %s"
 msgstr "Ingen case for %s"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 #| msgid "argument to dss must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "skifteværdi skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown asm flag output %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for asm flag output"
 msgstr "ugyldig type for make-funktion"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown architecture specific memory model"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "versionen er ikke understøttet"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33881,7 +33971,7 @@
 msgstr "interrupt_thread er kun tilgængelig på fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
@@ -34445,9 +34535,39 @@
 msgid "constant argument out of range for %s"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this media function is only available on the fr400"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "denne mediafunktion er kun tilgængelig på fr400"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this media function is only available on the fr400"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "denne mediafunktion er kun tilgængelig på fr400"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "Profiling is not supported on this target."
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "Profilering er ikke understøttet på målarkitekturen."
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
 #| msgid "Generate load/store multiple instructions"
+msgid "don't support performance extension instructions"
+msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate load/store multiple instructions"
+msgid "don't support performance extension version 2 instructions"
+msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
+#| msgid "Generate load/store multiple instructions"
 msgid "don't support string extension instructions"
 msgstr "Generér flere indlæsnings-/lagringsinstruktioner"
 
@@ -34468,11 +34588,11 @@
 msgstr "kan ikke sætte afbrydelsesegenskaben: ingen aktuel funktion"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "a nested function is not supported for reduced registers"
@@ -34479,37 +34599,55 @@
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant out of range"
 msgid "intrinsic register index is out of range"
 msgstr "heltalskonstanten er uden for det gyldige interval"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+#| msgid "integer constant out of range"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "heltalskonstanten er uden for det gyldige interval"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid id value for reset attribute"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "Generér placeringsuafhængig kode, om muligt"
@@ -34738,38 +34876,38 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute requires a void return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34865,12 +35003,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "ragelse i slutningen af #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
@@ -34924,7 +35062,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert accepterer kun 3 parametre"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -35250,7 +35388,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35260,7 +35398,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -35270,12 +35408,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35285,30 +35423,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -35329,13 +35467,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -35361,61 +35499,61 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "#%s med ugyldig parameter"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be in the range 0..15"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -35555,7 +35693,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, fuzzy, gcc-internal-format
 #| msgid "stack frame too big"
 msgid "stack frame too large"
@@ -35567,13 +35705,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC-målarkitektur er ikke understøttet på denne maskine"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
@@ -35583,22 +35721,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -35608,7 +35746,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -36080,22 +36218,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -36167,33 +36305,39 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, fuzzy, gcc-internal-format
+#| msgid "a -ifile option requires a -map option"
+msgid "builtin %qs requires builtin %qs"
+msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
+
+#: config/rs6000/rs6000-c.c:7058
+#, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -36327,46 +36471,46 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%s har ingen %s"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs already processed"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qs must be a constant"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -36373,7 +36517,7 @@
 msgstr "%s accepterer kun 1 parameter"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -36380,140 +36524,140 @@
 msgstr "#%s med ugyldig parameter"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "#%s med ugyldig parameter"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "second argument to %qs must be 0..12"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "third argument to %qs must be 0..12"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %s must be a constant"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "this media function is only available on the fr400"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "denne mediafunktion er kun tilgængelig på fr400"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires the %qs option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "%qs uses register r29"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ugyldig parametertype '%T'"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s%qs%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -37377,7 +37521,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tom værdi er ikke ignoreret som den burde være"
@@ -37643,7 +37787,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "declaration of %qD shadows a global declaration"
@@ -37655,7 +37799,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -37728,7 +37872,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(et kaldenavn der ikke er erklæret, rapporteres kun én gang per funktion)"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, fuzzy, gcc-internal-format
 #| msgid "label %s referenced outside of any function"
 msgid "label %qE referenced outside of any function"
@@ -37763,7 +37907,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "etiketten '%s' er blevet erklæret mere end én gang"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "duplicate label %qD"
@@ -37884,7 +38028,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -38173,7 +38317,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklasse angivet for typenavn"
@@ -38352,7 +38496,7 @@
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
@@ -38492,7 +38636,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable or field %qE declared void"
@@ -38693,7 +38837,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
@@ -38749,7 +38893,7 @@
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
@@ -38788,7 +38932,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "omerklæring af 'enum %s'"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
@@ -38821,7 +38965,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline funktion '%s' givet egenskaben noinline"
@@ -38853,7 +38997,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
@@ -38973,12 +39117,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -39044,7 +39188,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
@@ -39210,38 +39354,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "højreskiftsantal er større end bredden af typen"
@@ -39274,7 +39418,7 @@
 msgid "to match this %qs"
 msgstr "  anden type her"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -39320,7 +39464,7 @@
 msgstr "ukendt registernavn: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -39337,7 +39481,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -39354,8 +39498,8 @@
 msgid "unexpected attribute"
 msgstr "uventet operand"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
@@ -39393,7 +39537,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -39423,7 +39567,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected string literal"
@@ -39495,13 +39639,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutningen af enum-liste"
@@ -39642,7 +39786,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -39677,23 +39821,23 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "uventet operand"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous `else'"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -39716,12 +39860,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ugyldigt register i instruktionen"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -39750,12 +39894,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -40064,7 +40208,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -40129,78 +40273,78 @@
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "en dataområdeegenskab kan ikke angives for lokale variable"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected integer expression before ')'"
@@ -40218,60 +40362,60 @@
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -40294,91 +40438,91 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "forventede %<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%qs expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%qs value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "for mange parametre"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected argument"
 msgstr "uventet operand"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "chunk size value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -40388,12 +40532,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -40413,19 +40557,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -40436,69 +40580,69 @@
 msgid "invalid proc_bind kind"
 msgstr "ugyldig roteringsinstruktion"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -40515,7 +40659,7 @@
 msgid "expected function name"
 msgstr "forventet funktion"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a function"
@@ -40526,47 +40670,47 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -40576,23 +40720,23 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
@@ -40603,73 +40747,73 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -40689,32 +40833,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -40770,47 +40914,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -40827,7 +40971,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "'%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ugyldig brug af void-udtryk"
@@ -40958,7 +41102,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "tabelindeks er ikke et heltal"
@@ -40985,7 +41129,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -41104,19 +41248,19 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%Jsvag erklæring af '%D' efter første brug resulterer i ikke-defineret opførsel"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "sammenligning mellem henvisningsvariabel og heltal"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -41144,7 +41288,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -41406,7 +41550,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typeomtvingelse fra heltal til henvisning af en anden størrelse"
@@ -41584,7 +41728,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
@@ -41664,7 +41808,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
@@ -41747,12 +41891,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionel C forbyder klargøring af auto-variabler af sammensatte typer"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
@@ -41802,7 +41946,7 @@
 msgid "invalid initializer"
 msgstr "ugyldig startværdi"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
@@ -41818,7 +41962,7 @@
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
 # RETMIG: eller er det fleksibel tabel-medlem
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "klargøring af fleksibelt tabelmedlem i en indlejret kontekst"
@@ -41954,7 +42098,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C forbyder 'goto *udtryk;'"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -42001,7 +42145,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
@@ -42012,17 +42156,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "'default'-etiket befinder sig ikke inden i en switch-sætning"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
@@ -42051,24 +42195,24 @@
 msgid "expression statement has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "operandbegrænsninger til 'asm' har forskellige antal alternativer"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "sammenligning af kommatal med == eller != er ikke sikkert"
@@ -42122,7 +42266,7 @@
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
@@ -42156,12 +42300,12 @@
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -42172,28 +42316,28 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -42206,18 +42350,18 @@
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -42224,54 +42368,54 @@
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Intern oversætterfejl i %s ved %s:%d."
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -42295,7 +42439,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "brug af '%D' er tvetydigt"
@@ -42305,17 +42449,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -42330,20 +42474,20 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -42355,34 +42499,34 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -42404,55 +42548,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE er ikke en variable i %<depend%>-klausul"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE er hverken en variabel eller et funktionsnavn i klausul %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -42463,32 +42607,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -42636,7 +42780,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -42719,28 +42863,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "konvertering fra '%T' til '%T' er tvetydigt"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "call of overloaded `%D(%A)' is ambiguous"
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
@@ -42748,229 +42892,229 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "henvisning til medlemsfunktionen %E kan ikke kaldes uden et objekt; overvej at benytte .* eller ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to `(%T) (%A)'"
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen passende fundet for kald til '(%T) (%A)'"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "tvetydig konvertering af tabelindeks"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid " (operand type is %qT)"
 msgstr "operanden er r0"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: %s"
 msgid "ternary %<operator?:%>"
 msgstr "intern fejl: %s"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s for operatoren '%T %s' "
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ forbyder udeladelse af den mellemste del af et ?:-udtryk"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: `%T' vs `%T'"
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "enum-typer passer ikke sammen i betinget udtryk: '%T' og '%T'"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %q#T and %q#T"
 msgstr "sammenligning mellem '%#T' og '%#T'"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passende 'operator delete' for '%T'"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared private here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared protected here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is inaccessible"
 msgid "%q#D is inaccessible within this context"
@@ -42977,445 +43121,445 @@
 msgstr "'%+#D' er ikke tilgængelig"
 
 # %s bliver til returnering eller tildeling eller noget i den retning
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, fuzzy, gcc-internal-format
 #| msgid "passing NULL used for non-pointer %s %P of `%D'"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "overbringelse af NULL benyttet for ikke-henvisnings%s %P af '%D'"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, fuzzy, gcc-internal-format
 #| msgid "%s to non-pointer type `%T' from NULL"
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s til ikke-henvisningstypen '%T' fra NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around initializer for %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %qD"
 msgstr "  ved klargøring af parameteren %P til '%D'"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "kan ikke erklære feltet '%D' til at være af typen '%T'"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type `%#T' through `...'"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan ikke modtage objekter af en ikke-POD type '%#T' gennem '...'"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr "  i kald af '%D'"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "; use value-initialization instead"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use copy-assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "; use copy-initialization instead"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%#qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan ikke kalde destruktionsfunktion '%T::~%T' uden objekt"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "kan ikke kalde medlemsfunktionen '%D' uden et objekt"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "videregivelse af '%T' vælger '%T' frem for '%T'"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "vælger '%D' frem for '%D'"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  fordi konverteringssekvensen for parameteren er bedre"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
@@ -43461,8 +43605,8 @@
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
 # hænger sammen med næste tekst
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
@@ -43510,7 +43654,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qT declared here"
@@ -43601,7 +43745,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
@@ -43917,7 +44061,7 @@
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
@@ -43997,7 +44141,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "ikke tilstrækkelig information om typen"
@@ -44100,371 +44244,371 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "tom erklæring"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to internal function %qE"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' implicitly declared before its definition"
 msgid "%qD used before its definition"
 msgstr "'%s' er underforstået erklæret efter dens definition"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, fuzzy, gcc-internal-format
 #| msgid "protocol `%s' has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokollen '%s' har cirkulær afhængighed"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized array element"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "'%s' er ikke en funktion,"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "'%+#D' er privat"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
 msgstr "uventet type for 'id' (%s)"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -44513,7 +44657,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "casting %qT to %qT does not dereference pointer"
@@ -44525,344 +44669,344 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%#T' to `%#T'"
 msgid "conversion from %q#T to %q#T"
 msgstr "konvertering fra '%#T' til '%#T'"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' used where a `%T' was expected"
 msgid "%q#T used where a %qT was expected"
 msgstr "'%#T' benyttet hvor '%T' var forventet"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' used where a floating point value was expected"
 msgid "%q#T used where a floating point value was expected"
 msgstr "'%#T' benyttet hvor der forventedes en kommatalsværdi"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from `%T' to non-scalar type `%T' requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "konvertering fra '%T' til en ikke-skalartype '%T' udbedt"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "in call to %qD, declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konvertering til en ufuldstændig type"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 #| msgid "cannot allocate an object of type `%T'"
 msgid "conversion to void will not access object of type %qT"
 msgstr "kan ikke allokere et objekt af typen '%T'"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "object `%E' of incomplete type `%T' will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objektet '%E' af den ufuldstændige type '%T' vil ikke blive tilgået i %s"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function `%E'"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s er en reference til og ikke et kald af funktionen '%E'"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement has no effect"
 msgstr "%Hsætning uden nogen virkning"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous default type conversion from `%T'"
 msgid "ambiguous default type conversion from %qT"
 msgstr "tvetydig standardtypekonvertering fra '%T'"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, fuzzy, gcc-internal-format
 #| msgid "  candidate conversions include `%D' and `%D'"
 msgid "  candidate conversions include %qD and %qD"
@@ -44907,19 +45051,19 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "'%s' blev erklæret 'extern' og derefter 'static'"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%F' throws different exceptions"
 msgid "declaration of %qF has a different exception specifier"
 msgstr "erklæring af '%F' kaster forskellige undtagelser"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "than previous declaration `%F'"
 msgid "from previous declaration %qF"
 msgstr "end tidligere erklæring '%F'"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
@@ -44926,211 +45070,211 @@
 msgstr "erklæring af '%D' som %s"
 
 # hænger sammen med næste tekst
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "cannot specialize concept %q#D"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
 # shadowing betyder at en funktion har samme navn og dermed skjuler en anden
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "skygger for den indbyggede funktion '%s'"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing library function `%s'"
 msgid "shadowing library function %q#D"
 msgstr "skygger for biblioteksfunktionen '%s'"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "library function `%#D' redeclared as non-function `%#D'"
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "biblioteksfunktionen '%#D' er omerklæret som '%#D' der ikke er en funktion"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration `%#D'"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "strider mod indbygget erklæring '%#D'"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration `%#D'"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "tidligere ikke-funktionserklæring '%#D'"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration `%#D'"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "strider mod indbygget erklæring '%#D'"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration `%#D'"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "tvetydiggør indbygget erklæring '%#D'"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration `%#D'"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "tvetydiggør indbygget erklæring '%#D'"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "semicolon missing after %s declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "semikolon mangler efter %s-erklæring"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' redeclared as different kind of symbol"
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "conflicting declaration of template %q+#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration `%#D'"
 msgid "ambiguating new declaration %q+#D"
 msgstr "tvetydiggør tidligere erklæring '%#D'"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration `%#D'"
 msgid "old declaration %q#D"
 msgstr "global erklæring '%#D'"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration `%#D'"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "tvetydiggør tidligere erklæring '%#D'"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D'"
 msgid "previous declaration as %q#D"
 msgstr "tidligere erklæring af '%#D'"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q#D previously defined here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously declared here"
 msgid "%q#D previously declared here"
 msgstr "'%#D' tidligere erklæret her"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for `%#D'"
 msgid "prototype specified for %q#D"
 msgstr "prototypen for '%#D'"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "non-prototype definition here"
 msgid "previous non-prototype definition here"
 msgstr "definition uden prototype her"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with new declaration with %L linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "strider mod ny erklæring af med %L-kædning"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "previous declaration with %qL linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "default argument given for parameter %d of %q#D"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in `%#D'"
 msgid "previous specification in %q#D here"
 msgstr "efter tidligere specifikation i '%#D'"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%D' in same scope"
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overflødig omerklæring af '%D' i samme virkefelt"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "deleted definition of %q+D"
@@ -45144,19 +45288,19 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD after first use"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
@@ -45163,24 +45307,24 @@
 msgid "redefinition of %q#D"
 msgstr "omdefinering af '%#T'"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' conflicts with previous using declaration `%#D'"
 msgid "%qD conflicts with used function"
 msgstr "'%#D' strider mod tidligere using-erklæring '%#D'"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%q#D not declared in class"
 msgstr "'%D' ikke erklæret"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -45188,319 +45332,319 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal erklæring af '%s' følger ikke-trådlokal erklæring"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ikke-trådlokal erklæring af '%s' følger trådlokal erklæring"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overflødig omerklæring af '%s' i samme virkefelt"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "en tidligere lokal variabel"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  herfra"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of `%#D'"
 msgid "  crosses initialization of %q#D"
 msgstr "  krydser klargøring af '%#D'"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  går ind i catch-blok"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of `%#D'"
 msgid "  skips initialization of %q#D"
 msgstr "  springer over klargøring af '%#D'"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr "uventet operand"
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "%qD used without template parameters"
 msgstr "'%D' benyttet uden skabelonsparametre"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a template"
 msgid "%q#T is not a class"
 msgstr "'%#T' er ikke en skabelon"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named `%#T' in `%#T'"
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klasseskabelon ved navn '%#T' i '%#T'"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "no type named `%#T' in `%#T'"
 msgid "no type named %q#T in %q#T"
 msgstr "ingen type ved navn '%#T' i '%#T'"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameters do not match template %qD"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "'%s' er forældet"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "'%s' er forældet"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-falign-labels=%d understøttes ikke"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med konstruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med destruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med kopitildelingsoperator er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flere typer i én erklæring"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omerklæring af indbygget type i C++ '%T'"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "manglende typenavn i typedef-erklæring"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ forbyder anonyme strukturer"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "'%D' kan kun angives for konstruktionsfunktioner"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "tom erklæring"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -45507,393 +45651,393 @@
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
 # init dækker over værditildeling her - samme for de næste mange
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef '%D' bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillader ikke '%T::%D' at blive defineret som '%T::%D'"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variablen '%#D' bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "den sammensatte type '%#D' er af en ufuldstændig type og kan ikke defineres"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ikke-trivielle udpegede startværdier er ikke understøttet"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "startværdien giver ikke størrelsen af %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "tabelstørrelsen mangler i %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nulstørrelsestabel %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstørrelsen af %qD er ikke kendt"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  du kan arbejde dig rundt om dette ved at fjerne startværdien"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized const %qD"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "typen '%T' har ingen destruktionsfunktion"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "startværdi for '%T' skal være indesluttet i krøllede paranteser"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "ugyldig startværdi"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C89 forbyder sammensatte konstanter"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "'%D' skal klargøres af en konstruktionsfunktion, ikke af '{...}'"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktionsfunktion"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en klargøring uden for klassens erklæring er nødvendig)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "medlem '%D' med konstante felter uden startværdi"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillader ikke %<register%>-lagerklasseangivelse"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "%<register%> storage class specifier used"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skygger for tidligere typeerklæring af '%#D'"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%u name provided for structured binding"
@@ -45901,7 +46045,7 @@
 msgstr[0] "lagringsklasse angivet for strukturfelt '%s'"
 msgstr[1] "lagringsklasse angivet for strukturfelt '%s'"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -45908,7 +46052,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -45915,98 +46059,104 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "in initialization of structured binding variable %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose union type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "dereferencing pointer to incomplete type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
@@ -46013,37 +46163,37 @@
 msgstr "'%D' erklæret som 'virtual' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
@@ -46050,19 +46200,19 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
@@ -46069,60 +46219,60 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method '%D' has non-Java return type `%T'"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java-metoden '%D' har har en returtype '%T' som ikke er fra Java"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not definition"
 msgid "concept %qD has no definition"
 msgstr "node er alias men ikke definition"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
@@ -46129,792 +46279,797 @@
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ugyldig brug af skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a template"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be inline"
 msgstr "kan ikke erklære '::main' som indlejret"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "kan ikke erklære '::main' som indlejret"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%qD has invalid argument list"
 msgstr "#%s med ugyldig parameter"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "'main' skal returnere typen 'int'"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion '%#D' erklæret i klassen '%T'"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ forbyder tildeling af startværdi til medlemskonstant '%D' af en ikke-heltallig type"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "størrelsen af tabellen '%D' er ikke af en heltalstype"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "størrelsen af tabellen '%D' er negativ"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med størrelsen nul"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med variabel størrelse"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tabeldimension for stor"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "angivelse af returneringstypen til konstruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "returtype angivet for 'operator %T'"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unavngiven variabel eller felt erklæret void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-member"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ forbyder erklæring af '%s' uden en type"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "short, signed eller unsigned er ugyldig for '%s'"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "signed og unsigned er begge angivet for '%s'"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "long, short, signed og unsigned er ugyldige for '%s'"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for `%s'"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "long eller short angivet samtidig med char for '%s'"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "long og short er begge angivet for '%s'"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "short, signed eller unsigned er ugyldig for '%s'"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned used invalidly for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed og unsigned er benyttet på ugyldig vis for '%s'"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-erklæringer er ugyldig i parametererklæringer"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `typedef'"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "'typedef' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "structured binding declaration cannot be %qs"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "requires-clause on return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
+#| msgid "type qualifiers ignored on function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "typemodifikationer ignoreret i funktionsreturtypen"
+
+#: cp/decl.c:11156
+#, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11099
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
-msgstr "typemodifikationer ignoreret i funktionsreturtypen"
-
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -46921,63 +47076,63 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "constructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -46984,277 +47139,277 @@
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referencen %qs kan ikke erklæres %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type %qD med samme navn som den omgivende klasse"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet for friend class-erklæring"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen %qT til ven af det globale virkningsfelt"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -47261,187 +47416,187 @@
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a constructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static data member %qE declared %<concept%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
@@ -47449,90 +47604,90 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -47553,36 +47708,36 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a nonstatic member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
@@ -47589,160 +47744,160 @@
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -47754,103 +47909,103 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in the class %T"
 msgid "%qT defined with multiple direct bases"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "%qT defined with direct virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -47860,86 +48015,86 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -47984,7 +48139,7 @@
 msgid "deleting %qT is undefined"
 msgstr "benyttelse af delete på '%T' er ikke defineret"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -47999,7 +48154,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
@@ -48128,45 +48283,45 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonym struct er ikke inden i en navngiven type"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member `%#D' in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "privat medlem '%#D' i en anonym union"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonyme variabler af sammensatte typer i navnerumsvirkefelt skal erklæres static"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, fuzzy, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must return type `%T'"
 msgid "%<operator new%> must return type %qT"
@@ -48176,70 +48331,70 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' takes type `size_t' (`%T') as first parameter"
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "den første parameter til 'operator new' skal være af typen 'size_t' ('%T')"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' must return type `%T'"
 msgid "%<operator delete%> must return type %qT"
 msgstr "'operator delete' skal returnere typen '%T'"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' takes type `%T' as first parameter"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "den første parameter til 'operator delete' skal være af typen '%T'"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -48249,70 +48404,70 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "'%#D' refererer ikke til den ikkemodificerede type, so den bruges ikke til sammenkædning"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "strider mod tidligere erklæring '%#D'"
 
 # hænger sammen med næste tekst
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous mangling %q#D"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of `%+#D'"
 msgid "default argument missing for parameter %P of %q+#D"
@@ -48320,19 +48475,19 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "use of template qualifier outside template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -48343,114 +48498,114 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "ingen parametre"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, fuzzy, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "%qD is not a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -48615,78 +48770,78 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(hvis dette er hvad du ønsker, så sikr dig at funktionsskabelonen allerede er blevet erklæret og tilføj <> efter funktionsnavnet her) -Wno-non-template-friend deaktiverer denne advarsel"
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "value-initialization of incomplete type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "value-initialization of function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "value-initialization of reference type %qT"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "'%D' bør blive klargjort i medlemsklargøringslisten"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "klassen '%T' er underforstået ven med sig selv"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid initializer for array member %q#D"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %q#T"
 msgstr "konstant medlem '%D' uden startværdi"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
@@ -48693,317 +48848,317 @@
 msgid "%q#D should be initialized"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, fuzzy, gcc-internal-format
 #| msgid "base `%T' will be initialized after"
 msgid "base %qT will be initialized after"
 msgstr "stamklasse '%T' vil blive klargjort efter"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, fuzzy, gcc-internal-format
 #| msgid "  base `%T'"
 msgid "  base %qT"
 msgstr "  stamklasse '%T'"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for `%D'"
 msgid "multiple initializations given for %qD"
 msgstr "flere startværdier angivet for '%D'"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for base `%T'"
 msgid "multiple initializations given for base %qT"
 msgstr "flere startværdier angivet for stamklassen '%T'"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 #| msgid "initializations for multiple members of `%T'"
 msgid "initializations for multiple members of %qT"
 msgstr "startværdier for flere medlemmer af '%T'"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "stamklassen '%#T' bør eksplicit blive klargjort i kopikonstruktionsfunktionen"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "class %qT does not have any field named %qD"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "feltet '%#D' er statisk; det eneste sted det kan klargøres er ved dets definition"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which has no base classes"
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which uses multiple inheritance"
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unavngiven klargøring af '%T' som benytter multipel nedarvning"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, fuzzy, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qT is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "heltalsoverløb i udtryk"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "strenge med dobbelte anførselstegn er ikke tilladte i #if-udtryk"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `void' for new"
 msgid "invalid type %<void%> for new"
 msgstr "ugyldig type 'void' til new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "feltet '%s' blev ikke fundet i klassen"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous"
 msgid "request for member %qD is ambiguous"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "startværdien slutter for tidligt"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukendt tabelstørrelse i delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
@@ -49015,7 +49170,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -49103,71 +49258,71 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
@@ -49297,46 +49452,46 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "strider mod tidligere erklæring '%#D'"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' hides constructor for `%#T'"
 msgid "%q#D hides constructor for %q#D"
 msgstr "'%#D' skjuler konstruktionsfunktion for '%#T'"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration `%#D'"
 msgid "local external declaration %q#D"
 msgstr "global erklæring '%#D'"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "does not match previous declaration %q#D"
@@ -49345,64 +49500,64 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "name lookup of `%D' changed"
 msgid "name lookup of %qD changed"
 msgstr "navneopslag for '%D' ændret"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this `%D' under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  passer med '%D' under ISO-standardreglerne"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this `%D' under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  passer med '%D' under tidligere regler"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "name lookup of `%D' changed for new ISO `for' scoping"
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "navneopslaget af '%D' er ændret til ISO 'for'-virkefelt"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at `%D'"
 msgid "using obsolete binding %qD"
 msgstr "  bruger forældet binding til '%D'"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -49410,13 +49565,13 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, fuzzy, gcc-internal-format
 #| msgid "a using-declaration cannot specify a template-id.  Try `using %D'"
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "en using-erklæring kan ikke angive en skabelons-id; prøv 'using %D'"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%D' not allowed in using-declaration"
 msgid "namespace %qD not allowed in using-declaration"
@@ -49424,7 +49579,7 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "%qT is not a namespace"
@@ -49431,108 +49586,108 @@
 msgstr "'%T' er ikke et navnerum"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already declared in this scope"
 msgid "%qD is already declared in this scope"
 msgstr "'%D' er allerede erklæret i dette navnerum"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD not declared"
 msgstr "'%D' ikke erklæret"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T::%D%> names destructor"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 #| msgid "no members matching `%D' in `%#T'"
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "ingen medlemmer passer til '%D' i '%#T'"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate type qualifiers in %s declaration"
 msgid "explicit qualification in declaration of %qD"
 msgstr "dobbelte typemodifikationer i %s-erklæring"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should have been declared inside `%D'"
 msgid "%qD should have been declared inside %qD"
 msgstr "'%D' skulle have været erklæret inden i '%D'"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -49539,57 +49694,63 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "`%s' is not a valid class name"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "'%s' er et ugyldigt klassenavn"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "it was later defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, fuzzy, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, fuzzy, gcc-internal-format
 #| msgid "namespace alias `%D' not allowed here, assuming `%D'"
 msgid "namespace alias %qD not allowed here, assuming %qD"
@@ -49596,29 +49757,29 @@
 msgstr "navnerumsalias '%D' er ikke tilladt her, antager '%D'"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "cannot nest more than %d namespaces"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -49638,7 +49799,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -49665,7 +49826,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -49757,7 +49918,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -49988,7 +50149,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -50076,7 +50237,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -50092,534 +50253,524 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ forbyder sammensatte konstanter"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
 msgstr "ugyldig brug af '%D"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a class member"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tillader ikke %<alignof%> med en ikke-type"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer kan ikke defineres i et nyt udtryk"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, fuzzy, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected expression-list or type-id"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "brug af ældre type typeomtvingning"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "foreslår paranteser omkring && inden i ||"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tillader ikke ?: med udeladt midter operand"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "new kan ikke bruges på en referencetype"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid expression statement"
 msgid "lambda-expression in template-argument"
 msgstr "Ugyldig udtrykssætning"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only variable `%s'"
 msgid "capture of non-variable %qE"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "default argument specified for lambda parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<mutable%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, fuzzy, gcc-internal-format
 #| msgid "case label `%E' not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "case-etiket '%E' befinder sig ikke inden i en switch-sætning"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 #| msgid "In statement function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "I sætningsfunktion"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flere erklæringer '%T' og '%T'"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "tom erklæring"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "ugyldig startværdi til bitstreng"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "decl-specifier invalid in condition"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' invalid in `%#T'"
 msgid "%qD invalid in lambda"
 msgstr "'%D' ugyldig i '%#T'"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "cannot expand initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "forældet stamklasseklargøring"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expected suffix identifier"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type modifier within pointer declarator"
 msgid "invalid encoding prefix in literal operator"
 msgstr "ugyldig typemodifikation i erklæring af henvisning"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -50626,391 +50777,391 @@
 msgstr "uventet operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `export' not implemented, and will be ignored"
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "uventet operand"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "uventet operand"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "uventet operand"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 #| msgid "sigof type specifier"
 msgid "expected type specifier"
 msgstr "sigof-typeangivelse"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "expected template-id for type"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ekstra modifikation '%T::' af medlemmet '%D' ignoreret"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, fuzzy, gcc-internal-format
 #| msgid "multiple definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af '%#T'"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a namespace-name"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "uventet operand"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace name required"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "function with nested functions cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "funktion med indlejrede funktioner kan ikke indbygges"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace %qD entered"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: funktionsdefinitionen er ikke omdannet\n"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 #| msgid "empty scalar initializer"
 msgid "expected initializer"
 msgstr "tom skalarstartværdi"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array bound is not an integer constant"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<%T::%E%> is not a type"
@@ -51020,17 +51171,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ugyldig erklærer"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -51037,407 +51188,407 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "tom erklæring"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is a namespace"
 msgid "%qD is a namespace"
 msgstr "'%D' er et navnerum"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate cv-qualifier"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource påkræver -o"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "ugyldig brug af '%T'"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "kan ikke finde filen for klassen %s"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "tidligere definition af '%#T'"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected attribute before %<...%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -51446,427 +51597,427 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Aktiver multiply-instruktioner"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching concept for template-introduction"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "'%s' tidligere erklæret her"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -51873,84 +52024,84 @@
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "data member %qD cannot be a member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid member template declaration %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope `%D'"
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "eksplicit specialisering i virkefeltet '%D' der ikke er et navnerum"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, fuzzy, gcc-internal-format
 #| msgid "specializing `%#T' in different namespace"
 msgid "specialization of %qD in different namespace"
@@ -51957,42 +52108,42 @@
 msgstr "specialiserer '%#T' i andet navnerum"
 
 # hænger sammen med foregående tekst, derfor ikke 'fra'
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of `%#D'"
 msgid "  from definition of %q#D"
 msgstr "  i forhold til definition af '%#D'"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of non-template %qT"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%T' after instantiation"
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering af '%T' efter instantiering"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, fuzzy, gcc-internal-format
 #| msgid "specializing `%#T' in different namespace"
 msgid "specializing %q#T in different namespace"
@@ -52000,76 +52151,76 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "specialization `%T' after instantiation `%T'"
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering af '%T' efter instantiering '%T'"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "template specialization with C linkage"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a variable template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -52076,24 +52227,24 @@
 msgstr "eksplicit specialisering af %D efter første brug"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "skabelonsparameter er påkrævet for '%T'"
@@ -52100,62 +52251,62 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' in declaration of primary template"
 msgid "template-id %qD in declaration of primary template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition angivet for eksplicit instantiering"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of `%D'"
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization declared %<concept%>"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "partiel specialisering '%D' af funktionsskabelon"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a template function"
@@ -52169,150 +52320,150 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "no member function `%D' declared in `%T'"
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion '%D' erklæret i '%T'"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "friend declaration here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of function concept %qD"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
 msgstr "        '%D'"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anonym %s>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type `%T' declared `friend'"
 msgid "template parameter %qD declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "primary template %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "template argument %qE involves template parameter(s)"
@@ -52319,7 +52470,7 @@
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
 # flertalsform unødvendig
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -52327,19 +52478,19 @@
 msgstr[0] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 msgstr[1] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -52348,52 +52499,52 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "template %qD declared"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "skabelonsklasse uden et navn"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -52403,66 +52554,66 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "skabelonsdefinition af ikke-skabelon '%#D'"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "forvented %d niveauer af skabelonsparametre for '%#D', modtog %d"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "modtog %d skabelonsparametre for '%#T'"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d påkrævet"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -52470,7 +52621,7 @@
 msgstr[0] "'%D' benyttet uden skabelonsparametre"
 msgstr[1] "'%D' benyttet uden skabelonsparametre"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %qD used %d template parameter"
@@ -52478,13 +52629,13 @@
 msgstr[0] "tidligere erklæring af '%#D' her"
 msgstr[1] "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "skabelonsparameter '%#D'"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
@@ -52494,130 +52645,130 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "den skal være en henvisning til medlem på formen '&X::Y'"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "because it is a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -52624,326 +52775,331 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qE"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attributes in template argument %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected %qD but got %qD"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %qD"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure"
 msgstr "intern GCC-afbrydelse"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr "fleksibelt tabelmedlem i union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %qD"
@@ -52962,317 +53118,317 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "'%#T' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "exception specification of %qD depends on itself"
@@ -53285,118 +53441,123 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "ugyldig standardparameter i skabelon"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -53628,7 +53789,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualified type %qT does not match destructor name ~%qT"
@@ -53684,7 +53845,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
@@ -53765,303 +53926,303 @@
 msgstr "'%T' er ikke en skabelonstype"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "ugyldig brug af ikke-statisk felt '%D'"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has const type for %<reduction%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> static expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<gang%> static value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<vector%> length expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<worker%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "%<worker%> num value must be positive"
 msgstr "venstre parameter skal være en skive"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "for mange inddatafiler"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<grainsize%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<priority%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<tile%> argument needs integral type"
 msgstr "skive-slutning skal være heltal"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed"
 msgstr "verifikationsfejl ved PC=%d"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to decltype must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
@@ -54068,18 +54229,18 @@
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -54222,13 +54383,13 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "zero as null pointer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontrol: mislykkedes i %s, ved %s:%d"
@@ -54296,399 +54457,399 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of `%s' to a member function"
 msgid "invalid application of %qs to a member function"
 msgstr "ugyldig brug af '%s' på en medlemsfunktion"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-aggregate type `%T'"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-sammensat type '%T'"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-class type `%T'"
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member `%D' of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ugyldig tilgang til ikke-statisk datamedlem '%D' af NULL-objekt"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a member template function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qT is not a pointer-to-object type"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared `register'"
 msgid "subscripting array declared %<register%>"
 msgstr "indeksering af tabel som er erklæret 'register'"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, fuzzy, gcc-internal-format
 #| msgid "object missing in use of `%E'"
 msgid "object missing in use of %qE"
 msgstr "objekt mangler i brug af '%E'"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function `%s'"
 msgid "cannot call function %qD"
 msgstr "kan ikke deaktivere den indbyggede funktion '%s'"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids calling `::main' from within program"
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ forbyder kald af '::main' inde fra programmet"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, fuzzy, gcc-internal-format
 #| msgid "must use .* or ->* to call pointer-to-member function in `%E (...)'"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "brug .* eller ->* i kald af henvisning til medlemsfunktion i '%E (...)'"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qE cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to constructor %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to constructor %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to method %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to method %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "assuming cast to type `%T' from overloaded function"
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antager typeomtvingning til typen '%T' fra flertydig funktion"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL benyttet i udregning"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "%s-roteringsantal >= bredden af typen"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "%s-roteringsantal >= bredden af typen"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ forbyder sammenligning mellem henvisningsvariabel og heltal"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "uordnet sammenligning af ikke-kommatalsparameter"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types `%T' and `%T' to binary `%O'"
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ugyldige operander af typerne '%T' og '%T' til binær '%O'"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer of type `void *' in subtraction"
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning af typen 'void *' i fratrækning"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til funktion i fratrækning"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til medlemsfunktion i fratrækning"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ugyldig brug af en henvisning til en ufuldstændig type i henvisningsberegning"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of constructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of destructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' to form a pointer-to-member-function.  Use a qualified-id."
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ugyldig brug af '%E' til at danne en henvisning til medlemsfunktion; benyt et kaldenavn med klassepræfiks"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around '%E' cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
@@ -54695,12 +54856,12 @@
 msgstr "paranteser omkring '%E' kan ikke bruges til at danne en henvisning til medlemsfunktion"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en ikke-modificeret, ikke-statisk medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
@@ -54707,423 +54868,417 @@
 msgstr "ISO C++ forbyder at tage adressen på en bundet medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking address of function `::main'"
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ forbyder at tage adressen på funktionen '::main'"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan ikke oprette henvisning til reference medlemmet '%D'"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "attempt to take address of bit-field"
 msgstr "kan ikke finde adressen af bitfeltet '%s'"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type bool"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of explicit register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, fuzzy, gcc-internal-format
 #| msgid "address requested for `%D', which is declared `register'"
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse forespurgt for '%D' som er erklæret 'register'"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' casts away const (or volatile)"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast fra '%T' til '%T' fjerner const (eller volatile)"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "skabelonsparameter '%T' benytter lokal type '%T'"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type `%T' to type `%T'"
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ugyldig static_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "konvertering fra '%T' til '%T'"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "reinterpret_cast from `%T' to `%T' loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "reinterpret_cast fra '%T' til '%T' mister præcision"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from `%T' to `%T' increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typeomtvingning fra '%T' til '%T' forøger den påkrævede justering af målets type"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ forbyder sammenligninger mellem henvisning til funktion og henvisning til objekt"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ugyldig brug af const_cast med typen '%T' som ikke er en henvisnings-, reference- eller en henvisning til datamedlem-type"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is a pointer or reference to a function type"
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "ugyldig brug af const_cast med typen '%T' som er en henvisning eller reference til funktion"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type `%T' to type `%T'"
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type `%T'"
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ forbyder omtvingelse af typen til en tabeltype '%T'"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "invalid cast to function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, fuzzy, gcc-internal-format
 #| msgid "  in evaluation of `%Q(%#T, %#T)'"
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i evaluering af '%Q(%#T, %#T)'"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "ugyldig tildeling af startværdi til tabel"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i henvisning til medlemsfunktion-omdannelse"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "henvisning til medlem-omdannelse via den virtuelle stamklasse '%T' af '%T'"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i henvisning til medlem-omdannelse"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
+#| msgid "cannot convert `%T' to `%T' in %s"
+msgid "cannot convert %qH to %qI"
+msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
-msgid "cannot convert %qH to %qI"
-msgstr "kan ikke konvertere '%T' til '%T' i %s"
-
-#: cp/typeck.c:8804
-#, fuzzy
-#| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %qD"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "reference til ikke-venstreværdi returneret"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %qD returned"
 msgstr "reference til den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
@@ -55130,45 +55285,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "kan ikke returnere fra en håndtering af en funktions-try-blok i en konstruktionsfunktion"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "manglende startværdi"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
@@ -55175,12 +55330,12 @@
 msgstr "'operator new' må ikke returnere NULL medmindre den er erklæret 'throw()' (eller -fcheck-new er benyttet)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -55435,163 +55590,163 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "konstruktionsfunktionsyntaks benyttet, men ingen konstruktionsfunktion er erklæret for typen '%T'"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-tabel får tildelt startværdi fra en ikke-bred streng"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-tabel får tildelt startværdi fra en ikke-bred streng"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "startværdistrengen til char-tabellen er for lang"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -56037,29 +56192,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Null element at %0 for array reference at %1"
 msgid "Bad array dimension at %L"
 msgstr "Nulelement ved %0 for tabelreference ved %1"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
@@ -56066,22 +56221,22 @@
 msgid "Simplification error"
 msgstr "omerklæring af '%#D'"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -57108,7 +57263,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -57292,7 +57447,7 @@
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -57562,470 +57717,470 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Old-style initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected an initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%Jsvag erklæring af '%D' ikke understøttet"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nested extern declaration of `%s'"
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "indlejret extern-erklæring af '%s'"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing right parenthesis at %C"
 msgstr "Manglende formel parameterterm"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected scalar initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "ugyldig typeparameter"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "IMPORT statement at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Missing codimension specification at %C"
 msgstr "Modstridende I/O-kontrolangivelser ved %0 og %1"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing dimension specification at %C"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -58032,353 +58187,353 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "Missing term"
 msgid "Missing symbol"
 msgstr "Manglende term"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Alternate-return argument at %C"
 msgstr "forkert parametertype til %s"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Planlæg ikke begyndelsen og slutningen af proceduren"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't specify array dimension in a declaration"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Kan ikke angive tabeldimension i en erklæring"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicts with function declaration `%#D'"
 msgid "Unexpected junk after function declaration at %C"
 msgstr "strider mod funktionserklæring '%#D'"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-sætning ved %C kan ikke fremgå i en STRUCTURE-blok"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing first operand for binary operator at %0"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Manglende første operand for binær operator ved %0"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected END statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "END statement instead of %s statement at %L"
@@ -58385,169 +58540,169 @@
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-udtryk forventet ved %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting %s statement at %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "Cray pointer at %C must be an integer"
 msgstr "udsagn skal være et kaldenavn"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksfejl i PROTECTED-udtryk ved %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Mystisk fortegn i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializing array with parameter list"
 msgid "Initializing already initialized variable at %C"
@@ -58554,476 +58709,476 @@
 msgstr "klargør tabel med en parameterliste"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VALUE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VOLATILE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "forhåndserklæring af '%#T'"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after MAP statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after UNION statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing structure name for outer structure definition at %0"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Manglende strukturnavn for ydre strukturdefinition ved %0"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type name expected before `*'"
 msgid "ENUM definition statement expected before %C"
 msgstr "der forventedes et typenavn før '*'"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Duplicate access-specifier at %C"
 msgstr "mere end én tilgangsangivelse"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Forventede tilgangsangivere ved %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Forventede bindingattribut ved %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE og DEFERRED kan ikke begge vises ved %C"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> forventet ved %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-liste ved %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> er ugyldig for DEFERRED-binding ved %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Forventede %<::%> ved %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Forventede generisk navn elelr operatordeskriptor ved %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Forkert udformet GENERIC-udtryk ved %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Forventede %<=>%> ved %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
@@ -59368,27 +59523,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -59720,7 +59875,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of `%T'"
 msgid "Creating array temporary at %L"
@@ -59732,64 +59887,64 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Ingen kald i funktionen %s\n"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "bad expression"
 msgstr "uventet adresseudtryk"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad operand"
 msgid "bad op"
 msgstr "ugyldig operand"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -59912,12 +60067,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -61164,7 +61319,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -62680,12 +62835,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -62926,8 +63081,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -62969,7 +63124,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -63313,186 +63468,186 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  conflict with `%D'"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "  konflikt med '%D'"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  conflict with `%D'"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "  konflikt med '%D'"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overflow in constant expression"
 msgid "TILE requires constant expression at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -64894,7 +65049,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
@@ -65010,7 +65165,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -65393,234 +65548,234 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -65629,238 +65784,238 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Selector at %L cannot be NULL()"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "Selector at %L has no type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -65867,12 +66022,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -65880,109 +66035,109 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -65989,69 +66144,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Pointer procedure assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid NULL at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -66058,7 +66213,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -66066,58 +66221,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -66124,898 +66279,898 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fejl ved egenskabsundersøgelse af filen %s"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -67462,7 +67617,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -68128,18 +68283,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -68328,186 +68483,186 @@
 msgid "previously defined here as %s"
 msgstr "'%s' tidligere defineret her"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr ""
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has already been declared in `%T'"
 msgid "%qD has already been defined"
 msgstr "'%D' er allerede blevet erklæret i '%T'"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "previously defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, fuzzy, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "tidligere definition her"
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "type of %qD does not match original declaration"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "%qD was previously declared here"
 msgstr "'%s' tidligere erklæret her"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "variable %qD redeclared as function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared here"
 msgstr "'%s' tidligere erklæret her"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "kunne ikke fortolke hex-tal"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "kunne ikke fortolke filforskydning"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "uventet forskydning"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ugyldig linje i løsningsfilen"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ugyldig løsning i løsningsfilen"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr ""
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Kan ikke åbne %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Kan ikke oversætte %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Kan ikke læse %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() mislykkedes"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid mislykkedes"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "åbner LTRANS-uddatalisten %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "skriver til LTRANS-uddatalisten til %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "lukker LTRANS-uddatalisten %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "kunne ikke åbne symbolløsningsfilen: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing resolution data for %s"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -69504,6 +69659,16 @@
 msgstr "opretter vælger for ikke-eksisterende metode '%s'"
 
 #, fuzzy
+#~| msgid "Support MMX and SSE built-in functions and code generation"
+#~ msgid "Support Control-flow  Enforcment Technology (CET) built-in functions and code generation."
+#~ msgstr "Understøt indbyggede MMX- og SSE-funktioner og kodegenerering"
+
+#, fuzzy
+#~| msgid "Specify yes/no if isel instructions should be generated"
+#~ msgid "builtin operand should be an unsigned 6-bit value"
+#~ msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
+
+#, fuzzy
 #~| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 #~ msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 #~ msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
@@ -69555,6 +69720,11 @@
 #~ msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
 #, fuzzy
+#~| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
+#~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#~ msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
+
+#, fuzzy
 #~ msgid "Function name %qs not allowed at %C"
 #~ msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
Index: gcc/po/tr.po
===================================================================
--- gcc/po/tr.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/tr.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -165,40 +165,40 @@
 msgid "negative insn length"
 msgstr "negatif komut uzunluğu"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "komut çatallanamadı"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "geçersiz 'asm': "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "iç içe çevirici aksan alternatifleri"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "sonlandırılmamış çevirici aksan alternatifi"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "%%-harf'ten sonraki terim numarası eksik"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "terim numarası aralık dışında"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "%% kodu geçersiz"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "'%%l' terimi bir yafta değil"
@@ -209,13 +209,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "gerçel sayı sabit yanlış kullanılmış"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1292,21 +1292,21 @@
 msgid "At top level:"
 msgstr "Üst düzeyde:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "%qs üye işlevinde"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "%qs işlevinde"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr ""
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 #| msgid "    Included at %s:%d\n"
 msgid "    inlined from %qs at %r%s:%d%R"
@@ -1314,7 +1314,7 @@
 "Sırayla bir altındaki dosyada içerilerek:\n"
 "\t\t%s:%d\n"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, fuzzy, c-format
 #| msgid "complex invalid for %qs"
 msgid "    inlined from %qs"
@@ -3252,9 +3252,9 @@
 msgid "invalid address mode"
 msgstr "adres geçersiz"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3270,7 +3270,7 @@
 msgstr "%%r değeri geçersiz"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3277,13 +3277,13 @@
 msgstr "%%R değeri geçersiz"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
@@ -3314,7 +3314,7 @@
 msgstr "%%U değeri geçersiz"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
@@ -3325,7 +3325,7 @@
 msgstr "%%C değeri geçersiz"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
@@ -3336,7 +3336,7 @@
 msgstr "bilinmeyen yerdeğişim unspec"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3348,61 +3348,61 @@
 msgid "invalid operand address"
 msgstr "adres geçersiz"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p kodu için terim geçersiz"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s kodu için terim geçersiz"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L kodu için terim geçersiz"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U kodu için terim geçersiz"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V kodu için terim geçersiz"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3410,19 +3410,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "geçersiz terim çıktı kodu"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "tanınmayan tahmini sabit"
 
@@ -3459,7 +3459,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
@@ -3600,8 +3600,8 @@
 msgstr "const_double terim geçersiz"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3820,112 +3820,112 @@
 msgid "bad output_condmove_single operand"
 msgstr "output_condmove_single terimi hatalı"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid conditional operand"
 msgid "invalid vector immediate"
 msgstr "koşullu terim geçersiz"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "bilinmeyen komut kipi"
 
@@ -3965,7 +3965,7 @@
 msgstr "%%P terimi geçersiz"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -4023,7 +4023,7 @@
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -4208,150 +4208,150 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "%2$qT mutlak sınıf türündeki %1$qE ifadesi throw ifadesi içinde kullanılamaz"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4493,43 +4493,43 @@
 msgid "created and used with different endianness"
 msgstr "farklı bayt sıralaması ile oluşturulup kullanılmış"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "geçersiz %%Y terimi"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "geçersiz %%A terimi"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "geçersiz %%B terimi"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "geçersiz %%C terimi"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "geçersiz %%D terimi"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "geçersiz %%s terimi"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4767,14 +4767,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4790,7 +4790,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4799,7 +4799,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4816,7 +4816,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
@@ -4824,7 +4824,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -4834,14 +4834,14 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4853,20 +4853,20 @@
 msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4875,25 +4875,25 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4905,7 +4905,7 @@
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4918,47 +4918,47 @@
 msgid "expected label"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "1. aday:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "2. aday:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "%qD yaftasına jump"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "case yaftasına jump"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  catch blokuna giriyor"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters OpenMP structured block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters synchronized or atomic statement"
 msgstr "deyim umuluyordu"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -5071,7 +5071,7 @@
 msgid "<statement>"
 msgstr "deyim umuluyordu"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown src"
 msgid "<unknown>"
@@ -5093,129 +5093,129 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr ""
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 #, fuzzy
 #| msgid "Bad operator"
 msgid "<unknown operator>"
 msgstr "Hatalı işleç"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 #| msgid "In member function %qs:"
 msgid "In static member function %qs"
 msgstr "%qs üye işlevinde:"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In constructor %qs"
 msgstr "%qs işlevinde:"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In destructor %qs"
 msgstr "%qs işlevinde:"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 #| msgid "In member function %qs:"
 msgid "In lambda function"
 msgstr "%qs üye işlevinde:"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 #| msgid "explicit instantiation of %q#D"
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 #| msgid "provided for %q+D"
 msgid "required from %q#D\n"
 msgstr "%q+D için sağlanmış"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 #| msgid "called from here"
 msgid "recursively required from here\n"
 msgstr "buradan çağrıldı"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "called from here"
 msgid "required from here\n"
 msgstr "buradan çağrıldı"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "adaylar:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5277,50 +5277,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tek terimli eksiye yanlış türde argüman"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs'a yanlış türde argüman"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "mantıksal çarpım için yanlış türde argüman"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5613,11 +5613,11 @@
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
@@ -5813,59 +5813,59 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5907,13 +5907,13 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 #| msgid "Argument of SQRT at %L has a negative value"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "%L'de SQRT'nin argümanı negatif değer içeriyor"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -6185,6 +6185,7 @@
 msgstr "-Xbind-now ile -Xbind-lazy uyumsuz"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -9704,7 +9705,7 @@
 msgstr "Değişkenler 32 bitlik sınıra hizalanır"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 #| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
@@ -10279,7 +10280,7 @@
 msgstr "Sabitlemek için yazmaç aralığı belirtilir"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -11161,7 +11162,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Verilen ABI'ye uyumlu kod üretilir"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -11709,7 +11710,7 @@
 msgstr "MMX ve SSE2 yerleşik işlevleri ve kod üretimi desteklenir"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use given stack-protector guard."
@@ -11720,7 +11721,7 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use the given base register for addressing the stack-protector guard."
@@ -11727,7 +11728,7 @@
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use the given offset for addressing the stack-protector guard."
@@ -11744,47 +11745,49 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "MMX ve SSE2 yerleşik işlevleri ve kod üretimi desteklenir"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Warn about implicit function declarations"
 msgid "Make all function calls indirect."
 msgstr "İşlevlerin örtük bildirimlerinde uyarır"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "işlevin dönüş türü işlev olamaz"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "MMX ve SSE2 yerleşik işlevleri ve kod üretimi desteklenir"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support MMX and SSE built-in functions and code generation"
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "MMX ve SSE2 yerleşik işlevleri ve kod üretimi desteklenir"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -12329,7 +12332,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Önerilmeyen seçenek. Yerine -mvrsave/-mno-vrsave kullanın"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -12337,7 +12340,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -12461,7 +12464,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "Verilen işlemci için kodu zamanlar"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -12503,7 +12506,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "-mfloat-gprs için seçenek geçersiz: '%s'"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -12603,27 +12606,27 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 #| msgid "Use hardware quad FP instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Donanım bazlı quad fp komutları kullanılır"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Yükleme/saklama çoklu komutları üretilir"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12643,19 +12646,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -12671,15 +12674,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12689,17 +12692,17 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Enable fused multiply/add instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Birleşik çarpma/toplama komutları etkinleştirilir"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12709,7 +12712,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Yazmaçlardaki küçük kümeler döndürülür"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 #| msgid "invalid option for -mfloat-gprs: '%s'"
 msgid "Valid arguments to -mstack-protector-guard=:"
@@ -12750,14 +12753,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Bir işlevin önbilgisinden önce profilleme için mcount çağrılır"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "ABI çağrı uzlaşımı seçilir"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -13618,7 +13620,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -13871,14 +13873,26 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare with loops."
+msgstr "Bir switch'siz döngüdeki azami komut sayısı"
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop"
+msgid "Max number of pairs of load insns for compare."
+msgstr "Tek bir döngüdeki azami soyulma sayısı"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
@@ -13891,10 +13905,49 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "Select full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "Ya full veya part seçilir ya da hiçbir traceback tablosu seçilmez"
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "Specify size of long double (64 or 128 bits)"
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "long double boyutu belirtilir (64 ya da 128 bit)"
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+#| msgid "%qs is deprecated"
+msgid "%qs is deprecated"
+msgstr "%qs önerilmiyor"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "ABI çağrı uzlaşımı seçilir"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "sdata eldesi için yöntem seçilir"
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Dolaysız TLS konumlarının bit genişliği belirtilir"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -15450,114 +15503,176 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Birleşik çarpma/toplama komutları üretilmez"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "Kıymetli baytın başta olduğu kod üretilir"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "Yazmaç tahsisinden önce komutları yeniden zamanlar"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "Yazmaç tahsisinden önce komutları yeniden zamanlar"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate conditional move instructions."
 msgstr "isel komutları üretilir"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate performance extension instructions."
 msgstr "Yükleme/saklama çoklu komutları üretilir"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate performance extension version 2 instructions."
 msgstr "Yükleme/saklama çoklu komutları üretilir"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate string extension instructions."
 msgstr "Yükleme/saklama çoklu komutları üretilir"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "isel komutları üretilir"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate 16-bit instructions."
 msgstr "isel komutları üretilir"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Specify if floating point hardware should be used"
 msgid "Enable Virtual Hosting support."
 msgstr "Eğer kayan nokta donanımı kulanılmalıysa belirtilir"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the register allocation order"
 msgid "Specify the cpu for pipeline model."
 msgstr "Yazmaç ayırma sırası belirtilir"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "Tüm kurucu ve yıkıcılar private olduğunda uyarır"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "isel komutları üretilir"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Kayan noktalı çarpma/toplama komutları üretilir"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "Eşleştirilmiş tekil kayan nokta komutları kullanılır"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "68881 kayan nokta komutlarını kullanan kod üretilir"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -16680,14 +16795,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Yükleme/saklama çoklu komutları üretilir"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-#| msgid "%qs is deprecated"
-msgid "%qs is deprecated"
-msgstr "%qs önerilmiyor"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate fused multiply/add instructions"
@@ -19645,8 +19752,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "hesaplanan değer kullanılmadı"
@@ -19682,7 +19789,7 @@
 msgstr "İfade türü umuluyordu"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20219,7 +20326,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -20249,13 +20356,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -20307,9 +20414,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -20322,8 +20429,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -20460,83 +20567,77 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid argument to %qD"
 msgstr "IACC argümanı geçersiz"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument to %qD"
@@ -20544,78 +20645,78 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for static member function %qD"
 msgid "trampoline generated for nested function %qD"
 msgstr "statik üye işlev %qD için ilklendirici belirtilmiş"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid memory model argument to builtin"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -20623,7 +20724,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -20631,13 +20732,13 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>'in ikinci argümanı 1 olmalı"
@@ -20644,67 +20745,67 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> işlev içinde sabit sayıda argümanla kullanılmış"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%H%D için son argüman 0 .. 3 arasında bir tamsayı sabit değil"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -21952,40 +22053,40 @@
 msgid "conversion to incomplete type"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "farklı boyuttaki vektör değerleri arasında dönüşüm yapılamaz"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "bir tamsayı umulurken küme değeri kullanılmış"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "karmaşık sayı umulan yerde gösterici değeri kullanılmış"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "karmaşık sayı umulan yerde küme değeri kullanılmış"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "farklı boyuttaki vektör değerleri arasında dönüşüm yapılamaz"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert value to a vector"
 msgid "can%'t convert value to a vector"
 msgstr "değer bir vektöre dönüştürülemez"
 
-#: convert.c:1168
+#: convert.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate value used where a float was expected"
 msgid "aggregate value used where a fixed-point was expected"
@@ -22149,12 +22250,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -22269,13 +22370,13 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%q+D işlevinin yeniden bildirimi inline öznitelikli değil"
 
-#: expr.c:10986
+#: expr.c:10992
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute warning: %s"
@@ -22293,13 +22394,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "%q+D boyutu %wd bayttan fazla"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "döküm dosyası %qs açılamadı: %s"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close final insn dump file %qs: %m"
@@ -22311,42 +22412,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "büyük tamsayı örtük olarak unsigned türe indirgendi"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "karşılaştırma sonucu daima %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "eşleşmeyenlerin farklılık sınamalarının %<or%> sonucu daima 1 dir"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold sınaması: özgün ağac fold tarafından değiştirildi"
@@ -22944,29 +23045,29 @@
 msgid "can%'t write PCH file"
 msgstr "PCH dosyasına yazılamıyor"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qD source argument is the same as destination"
 msgstr "cleanup argümanı bir işlev değil"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -22982,12 +23083,13 @@
 msgid "null pointer dereference"
 msgstr "PRINT_OPERAND boş gösterici"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -23521,10 +23623,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -23558,7 +23660,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 #, fuzzy
 #| msgid "cleanup argument not a function"
 msgid "%G%qD source argument is the same as destination"
@@ -23925,268 +24027,273 @@
 msgid "function cannot be instrumented"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "sanal olmayan yöntem %q+D için ilklendirici belirtilmiş"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr "ilklendirmede uyumsuz türler"
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "%Jönceden burada tanımlı"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "a different type is defined in another translation unit"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "the incompatible type defined in another translation unit"
 msgstr "ilklendirmede uyumsuz türler"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type name %qs should match type name %qs"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in return"
 msgid "the incompatible type is defined here"
 msgstr "dönüş değerinde uyumsuz türler"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "array types have different bounds"
 msgstr "?: için terimler farklı türde"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "return value type mismatch"
 msgstr "alan ilklendirici türü uyumsuzluğu"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "type mismatch in parameter %i"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "types have different parameter counts"
 msgstr "?: için terimler farklı türde"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "%Jönceden burada tanımlı"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type %qT should match type %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "has different parameters in another translation unit"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "fields have different layout in another translation unit"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -24208,7 +24315,7 @@
 msgid "the extra base is defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -24215,7 +24322,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24222,7 +24329,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -24229,7 +24336,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -24236,7 +24343,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24243,7 +24350,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24543,34 +24650,38 @@
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
 #: multiple_target.c:91
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qs attribute is not a string constant"
-msgid "default target_clones attribute was not set"
-msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
+#, gcc-internal-format
+msgid "default %<target_clones%> attribute was not set"
+msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
-#| msgid "%qs incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
-msgstr "%qs uyumsuz özniteliği yoksayıldı"
+#| msgid "%qs attribute directive ignored"
+msgid "single %<target_clones%> attribute is ignored"
+msgstr "%qs öznitelik yönergesi yoksayıldı"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it receives a non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "%q+F işlevi yerel olmayan goto içerdiğinden satıriçine alınamaz"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default target was not set"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -24893,13 +25004,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -25542,22 +25653,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "çıktı terimi %d %<&%> kısıtını kullanmalı"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Boş zincir için next_regno hatalı (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: regno zinciri içinde döngü (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] oldest_regno hatalı (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] zincir içinde boş olmayan yazmaç (%s %u %i)"
@@ -25606,7 +25717,7 @@
 msgstr "yazmaç iki genel yazmaç değişkeni için kullanılmış"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25853,165 +25964,165 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "makina dilinde referanslandıktan sonra %D yeniden isimlendirilmiş."
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
 msgstr "bir işlev döndüren işlev"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "çağrılan nesne %qE bir işlev değil"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is transparent_alias but not an alias"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa başarısız"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D part of alias cycle"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -27300,13 +27411,13 @@
 msgid "control reaches end of non-void function"
 msgstr "%Hdenetim void olmayan işlevin sonunu aşıyor"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute warn_unused_result"
@@ -27837,7 +27948,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -27882,97 +27993,97 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "işlev dizileri anlamlı değil"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "işlevin dönüş türü işlev olamaz"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.c:9359
+#: tree.c:9364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s umulmuyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.c:9372
+#: tree.c:9377
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: tree.c:9421
+#: tree.c:9426
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: tree.c:9434
+#: tree.c:9439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s umulmuyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.c:9494
+#: tree.c:9499
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs yapısını içeren ağaç umuluyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$qs var"
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "ağaç denetimi: %4$s dosyasının %5$d. satırında %3$s işlevinde %2$d öğelik ağaç vektörünün %1$d. öğesine erişildi"
 
-#: tree.c:9520
+#: tree.c:9525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "ağaç denetimi: %4$s dosyasının %5$d. satırında %3$s işlevinde %2$d öğelik ağaç vektörünün %1$d. öğesine erişildi"
 
-#: tree.c:9533
+#: tree.c:9538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.c:9546
+#: tree.c:9551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tür önerilmiyor"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tür önerilmiyor"
@@ -27997,247 +28108,247 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with graph file\n"
 msgid "first mismatch is field"
 msgstr "%s: zaman damgası çizge dosyası ile çelişiyor\n"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "type is not compatible with its variant"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "Main variant is not defined"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "%qs alanı tamamlanmamış türde"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "verify_type failed"
@@ -28265,12 +28376,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "%HBozuk değer profili: %s profilcinin ne sayısı varsa (%d) BB sayısı (%d) ile uyuşmuyor"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -29224,7 +29335,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "atamayı sarmalayan parantezler muhtemelen doğruluk değeri olarak kullanılmış"
@@ -29494,7 +29605,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array is too large"
@@ -30137,7 +30248,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -30155,24 +30266,24 @@
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
 msgstr "atama engelleme"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -30754,8 +30865,8 @@
 msgid "wrong type argument to %s"
 msgstr "abs'a yanlış türde argüman"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "sabit ifadesinde taşma"
@@ -31461,7 +31572,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
@@ -31547,7 +31658,7 @@
 msgstr[0] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 msgstr[1] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -31687,49 +31798,49 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops artık kullanılmıyor yerine -falign-loops kullanın"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malıgn-jumps artık atıl, yerine -falign-jumps kullanın"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions artık atıl, yerine -falign-functions kullanın"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d, 0 ile 5 arasında değil"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -31756,13 +31867,13 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "-mdebug-%s seçeneği bilinmiyor"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown switch -mlong-double-%s"
 msgid "unknown switch -mlong-double-%s"
@@ -31769,19 +31880,19 @@
 msgstr "-mlong-double-%s seçeneği bilinmiyor"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -32299,8 +32410,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -32383,8 +32494,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency için değer %qs hatalı"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32503,11 +32614,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32518,134 +32629,124 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: config/arc/arc.c:6556
-#, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-frepo, -c ile kullanilmalı"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "long long constant not a valid immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "long long sabit geçerli bir anlık terim değil"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 #| msgid "pre-increment address is not a register"
 msgid "insn addresses not freed"
 msgstr "ön arttırımlı adres bir yazmaç değil"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -32652,27 +32753,27 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
@@ -32700,153 +32801,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "seçici bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33723,12 +33824,12 @@
 msgid "invalid IACC argument"
 msgstr "IACC argümanı geçersiz"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs için bir sabit argüman beklenir"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "sabit argüman %qs için aralık dışında"
@@ -33839,18 +33940,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "PCH dosyası içinde konum belirlenemiyor: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "'%s' spec işlevi için argümanlar hatalı"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33857,609 +33958,594 @@
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "static is not supported on TPF-OS"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bitlik kip bunun içinde derlenmiş değil:"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Seçtiginiz işlemci  x86-64 komutlarını desteklemiyor."
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s %s desteği vermiyor"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d, 0 ile %d arasında değil"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "\"%s\" önişlemci için geçerli bir seçenek değil"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qT çağrısı"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib desteklenmiyor"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç argümanı"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "SSE register return with SSE disabled"
 msgid "x87 register return with x87 disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -34466,266 +34552,266 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "ek yazmaçların yüksek yarıları yok"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap seçeneğinin argümanı geçersiz: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "shift bir anlık değer olmalı"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -34732,86 +34818,86 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown asm flag output %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for asm flag output"
 msgstr "tür argümanı geçersiz"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "unknown architecture specific memory model"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -35058,7 +35144,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
@@ -35627,8 +35713,38 @@
 msgid "constant argument out of range for %s"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "global destructors not supported on this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "bu hedefte global yıkıcılar desteklenmiyor"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "Generate load/store multiple instructions"
+msgid "don't support performance extension instructions"
+msgstr "Yükleme/saklama çoklu komutları üretilir"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate load/store multiple instructions"
+msgid "don't support performance extension version 2 instructions"
+msgstr "Yükleme/saklama çoklu komutları üretilir"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 #| msgid "Enable use of DB instruction"
 msgid "don't support string extension instructions"
 msgstr "DB komutunun kullanımı etkin olur"
@@ -35652,11 +35768,11 @@
 msgstr "sistem kesmesi özniteliği ayarlanamıyor: böyle bir işlev yok"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35663,37 +35779,55 @@
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+#| msgid "invalid register in the instruction"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "komuttaki yazmaç geçersiz"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -35921,39 +36055,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ özniteliğine özdevinimli saklatım sınıfında izin verilmez"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -36047,12 +36181,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "'#pragma longcall' sonunda karışıklik"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -36109,7 +36243,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanın aktarımı gösterici hedef türündeki niteleyicileri iptal ediyor"
@@ -36436,7 +36570,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından döndürüldü: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
@@ -36446,7 +36580,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -36456,12 +36590,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından aktarıldı: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
@@ -36472,30 +36606,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36516,13 +36650,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36548,60 +36682,60 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%L'deki ATANH argümanı -1 .. 1 aralığının içinde kalmalı"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "Altivec yerleşiği %qF için çözümlenmemiş aşırı yükleme"
@@ -36740,7 +36874,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "yığıt çerçevesi çok büyük"
@@ -36751,13 +36885,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma extern_prefix not supported on this target"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix bu hedefte desteklenmiyor"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
@@ -36767,22 +36901,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating point types in AltiVec types is invalid"
@@ -36794,7 +36928,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
@@ -37270,22 +37404,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -37357,34 +37491,40 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, fuzzy, gcc-internal-format
+#| msgid "Function '%s' requires an argument list at %C"
+msgid "builtin %qs requires builtin %qs"
+msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
+
+#: config/rs6000/rs6000-c.c:7058
+#, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -37523,48 +37663,48 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts a string argument"
@@ -37571,7 +37711,7 @@
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37578,141 +37718,141 @@
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "second argument to %qs must be 0..12"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "third argument to %qs must be 0..12"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "iç hata: yan etkili komut main etkisi oluşturuyor"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "iç hata: yan etkili komut main etkisi oluşturuyor"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qs uses register r29"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38574,7 +38714,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void değer yoksayılması gerekirken yoksayılmadı"
@@ -38835,7 +38975,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
@@ -38845,7 +38985,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD bildirimi önceki yereli gölgeliyor"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -38913,7 +39053,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Bildirilmemiş her betimleyici görüldüğü her işlev"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qE yaftası işlev dışına başvuruyor"
@@ -38945,7 +39085,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "%qE yaftası bildirimi yinelenmiş"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "yinelenmiş %qD yaftası"
@@ -39071,7 +39211,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39346,7 +39486,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
@@ -39531,7 +39671,7 @@
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
@@ -39676,7 +39816,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "void bildirimli değişken ya da alan %qE"
@@ -39871,7 +40011,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
@@ -39923,7 +40063,7 @@
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -39963,7 +40103,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> yeniden bildirilmiş"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "belirtilen kip sırali sayısal değerler için çok küçük"
@@ -39994,7 +40134,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
@@ -40028,7 +40168,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -40159,12 +40299,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -40233,7 +40373,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
@@ -40394,38 +40534,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "sağa kaydırma sayısı tür genişliğinden büyük ya da eşit"
@@ -40458,7 +40598,7 @@
 msgid "to match this %qs"
 msgstr "%J  diğer tür burada"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -40503,7 +40643,7 @@
 msgstr "bilinmeyen yazmaç ismi: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -40520,7 +40660,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -40538,8 +40678,8 @@
 msgid "unexpected attribute"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -40581,7 +40721,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
@@ -40611,7 +40751,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "dizge sabiti umuluyordu"
@@ -40683,13 +40823,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "sembolik sabitler listesinin sonunda virgul"
@@ -40823,7 +40963,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -40858,24 +40998,24 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "deyim umuluyordu"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hif deyiminin gövdesi boş"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%Helse gövdesi boş"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -40897,12 +41037,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -40931,12 +41071,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -41248,7 +41388,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -41312,85 +41452,85 @@
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jadres alanı özelliği işlevler için belirtilemez"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression before ')'"
@@ -41408,61 +41548,61 @@
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41486,93 +41626,93 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<grainsize%> value must be positive"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "%qs expression must be integral"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%qs value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many %<static%> arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "unexpected argument"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "chunk size value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -41583,12 +41723,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -41608,19 +41748,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -41632,74 +41772,74 @@
 msgid "invalid proc_bind kind"
 msgstr "geçersiz döngü komutu"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "invalid OpenACC clause at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41716,7 +41856,7 @@
 msgid "expected function name"
 msgstr "umulmadık düğüm"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -41728,47 +41868,47 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41779,23 +41919,23 @@
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
@@ -41806,76 +41946,76 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41896,34 +42036,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -41980,51 +42120,51 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -42040,7 +42180,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void ifade kullanımı geçersiz"
@@ -42168,7 +42308,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "dizi indisi bir tamsayı değil"
@@ -42193,7 +42333,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42302,19 +42442,19 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%q+D zayıf bildirimi ilk kullanımdan sonra belirsiz davranışla sonuçlanıyor"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "gösterici ile tamsayı arasında karşılaştırma"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -42341,7 +42481,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -42591,7 +42731,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "farklı boyuttaki tamsayı türden göstericiye dönüşüm"
@@ -42763,7 +42903,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
@@ -42835,7 +42975,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
@@ -42912,12 +43052,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "geleneksel C özdevinimli ortak değer ilklendirmesini reddeder"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "karakter dizisinin ilklendiricisi olarak geniş dizge kullanılmış"
@@ -42966,7 +43106,7 @@
 msgid "invalid initializer"
 msgstr "geçersiz ilklendirici"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
@@ -42981,7 +43121,7 @@
 msgid "braces around scalar initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "iç içe bağlam içinde esnek dizi üyesi ilklendirmesi"
@@ -43114,7 +43254,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
@@ -43157,7 +43297,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
@@ -43167,17 +43307,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
@@ -43205,23 +43345,23 @@
 msgid "expression statement has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "== veya != ile karşılaştırma gerçel sayılarda güvenli değil"
@@ -43274,7 +43414,7 @@
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
@@ -43306,12 +43446,12 @@
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -43322,28 +43462,28 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -43356,19 +43496,19 @@
 msgstr "girdi dosyası sayısı çok fazla"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -43375,56 +43515,56 @@
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "zero length array section in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -43447,7 +43587,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction not found for %qE"
@@ -43458,17 +43598,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -43483,20 +43623,20 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -43508,34 +43648,34 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -43558,60 +43698,60 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -43622,32 +43762,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -43797,7 +43937,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43882,28 +44022,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%D(%A)%> çağrısı belirsiz"
@@ -43910,672 +44050,672 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "üye göstericisi işlevi %E nesnesiz çağrılamaz; .* or ->* kullanımı önerilir"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> çağrısı için eşleşme yok"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> çağrısı belirsiz"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "dizi indisi için dönüşüm belirsiz"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types %qT and %qT to binary %qO"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Kullanıcı işleçleri:\n"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%2$E ? %3$E : %4$E%> içindeki %<?: üç terimlisi%> için %1$s"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<%3$E%4$s%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Hatalı işleç"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%2$E[%3$E]%> içindeki %<[] işleci%> için %1$s"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%<%3$s %4$E%> içindeki %2$qs için %1$s"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%3$E %4$s %5$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<%3$s%4$E%> içindeki %<%2$s işleci%> için %1$s"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ bir ?: üç terimlisinde ikinci terimin eksikliğine izin vermez"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "koşullu ifade içinde enum uyumsuzluğu: %qT vs %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ile %q#T arasında karşılaştırma"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%2$qT için uygun bir %<%1$s işleci%> yok"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D erişilebilir değil"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "%2$qD işlevinin gösterici olmayan %1$P argümanına NULL aktarılması"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL'dan gösterici olmayan %qT türüne dönüşüm"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 #| msgid "converting to %qT from %qT"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "%qT türüne %qT türünden dönüşüm"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  %2$qD işlevinin %1$P argümanının ilklendirilmesi"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "%qE bitalanı %qT türüne bağlanamaz"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "%qE paketli alanı %qT türüne bağlanamaz"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "sağ taraf değeri %qE, %qT türüne bağlanamaz"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden aktarılamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD işlevinin %1$d. parametresi için öntanımlı argüman henüz çözümlenmedi"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  %qD çağrısında"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "; use value-initialization instead"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Ek:`%s' için (%L'de) yeniden ilklendirme"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%s(%A)%> çağrısı belirsiz"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from constructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from destructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "üye işlev %qD nesne olmaksızın çağrılamaz"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qT aktarımı %qT türünü %qT türü üzerinden seçiyor"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD %qD üzerinden,"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  çünkü argüman için dönüşüm süreci daha iyi"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE %qT türüne dönüştürülemedi"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -44623,8 +44763,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D,"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
@@ -44670,7 +44810,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
@@ -44756,7 +44896,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -45061,7 +45201,7 @@
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
@@ -45135,7 +45275,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tür bilgisi yetersiz"
@@ -45239,383 +45379,383 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs döngüsel bağımlılık içeriyor"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "no field %qD found in union being initialized"
 msgid "%qD used in its own initializer"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%q#D is not const"
 msgstr "%q+D bir işlev değil,"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D private'dir"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
 msgstr "'%s' de umulmadık dosya sonu"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45668,7 +45808,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "%qT türünden %qT türüne dönüşüm gösterici başvurusunu kaldırmaz"
@@ -45679,335 +45819,335 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "%q#T türünden %q#T türüne dönüşüm"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, fuzzy, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%2$qT umulan yerde %1$q#T kullanılmış"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "%qE %qT türüne dönüştürülemedi"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "bir gerçel sayı değer umulan yerde %q#T kullanılmış"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "%qT türünden skalar olmayan %qT türüne dönüşüm istendi"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "in call to %qD, declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "sözde yıkıcılar çağrılmaz"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "%2$qT tamamlanmamış türüne %1$qs uygulanması geçersiz"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "tamamlanmamış türe dönüşüm"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "içi boş %2$qT türündeki %1$E nesnesi, %3$s içinde erişimli olmayacak"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s %qE işlevine çağrı değil bir atıftır"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "deyim etkisiz"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT tünüden öntanımlı türe dönüşüm belirsiz"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  aday dönüşümler %qD ve %qD içeriyor"
@@ -46052,228 +46192,228 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD önce %<extern%> sonra da %<static%> bildirilmiş"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of %qF has a different exception specifier"
 msgstr "%qF bildirimi"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "önceki %q+F bildirimindeki farklı olağandışılıkları yakalıyor"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "%q+D'nin önceki tanımı buradaydı"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "%qD'nin önceki bildirimi buradaydı"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "shadowing built-in function %q#D"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "shadowing library function %q#D"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "kütüphane işlevi %q#D işlev olmayan %q#D olarak yeniden bildirildi"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "%q#D yerleşik bildirimiyle çelişiyor"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration %q+#D"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "önceden işlev olmayan bildirim %q+#D"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "%q#D yerleşik bildirimiyle çelişiyor"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "%q#D yerleşik bildirimini belirsizleştiriyor"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "%q#D yerleşik bildirimini belirsizleştiriyor"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "derived type declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "türetilmiş tür bildirimi"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D farklı bir simge çeşidi olarak tekrar bildirilmiş"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "eski %q+#D bildirimini belirsizleştiriyor"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "old declaration %q#D"
 msgstr "%q+#D genel bildirimi"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "eski %q+#D bildirimini belirsizleştiriyor"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D"
 msgid "previous declaration as %q#D"
 msgstr "önceki %q+#D bildirimi"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "%q+#D için prototip"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfollows non-prototype definition here"
 msgid "previous non-prototype definition here"
 msgstr "%Jburadaki prototip olmayan tanımı izliyor"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with new declaration with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "%qL ilintili yeni bildirim ile çelişiyor"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, fuzzy, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in %q+#D"
 msgid "previous specification in %q#D here"
 msgstr "%q+#D bildirimindeki önceki belirtimden sonra verilmiş"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %q+D"
@@ -46287,12 +46427,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -46299,7 +46439,7 @@
 msgstr "%q+D: görünürlük özniteliği yoksayıldı çünkü"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
@@ -46306,25 +46446,25 @@
 msgid "redefinition of %q#D"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%q#D not declared in class"
 msgstr "%qD bildirilmemiş"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
@@ -46333,315 +46473,315 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q+D'nin yerel-evreli bildirimi yerel-olmayan-evreli bildirimi izliyor"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q+D'nin yerel-olmayan-evreli bildirimi yerel-evreli bildirimi izliyor"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous label"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  buradan"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  %q+#D ilklendirmesini kesiyor"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  catch blokuna giriyor"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a type"
 msgstr "%qD bir şablon değil"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a template"
 msgid "%q#T is not a class"
 msgstr "%q#T bir şablon değil"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde sınıf şablonu yok"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "trampolines not supported"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "trampolines desteklenmiyor"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kuruculu üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde yıkıcılı üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kopya atama isleçli üye %q+#D kullanılamaz"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T için öznitelik %qs anahtar sözcüğünü izlemeli"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "bir bildirimde birden fazla tür"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++ yerleşik türü %qT için yeniden bildirim"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef bildiriminde tür ismi eksik"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ anonim yapıları (struct) yasaklar"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sadece kurucular için belirtilebilir"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
@@ -46648,383 +46788,383 @@
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ %<%T::%D%>nin %<%T::%D%> olarak tanımlanmasına izin vermez"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "%qD ilklendirmesi yinelenmiş"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "%q#D değişkeni ilklendirilmiş ama içi boş türde"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "küme %q#D içi boş türde olup tanımlı olamaz"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "alelade olmayan ilklendiriciler desteklenmiyor"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  ilklendiriciyi kaldırarak bunun olurunu bulabilirsiniz"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "%qs türü bir kullanıcı tanımlı yapıcıya sahip"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "%2$qT türündeki bir vektör için ilklendirici olarak %1$qT türü geçersiz"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "geçersiz ilklendirici"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 bileşik sabitlere izin vermez"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD bir kurucu ile ilklendirilmeli, %<{...}%> ile değil"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "parantezli dizge sabiti %2$qE ile ilklendirilmiş %1$qD dizgesi"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "kuruculu statik üye için ilklendirici geçersiz"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(bir sınıf dışı ilklendirme gerekli)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "önceki %q#D tür bildirimini gölgeliyor"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
-#| msgid "creating pointer to member of non-class type %qT"
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
+#| msgid "%qT is an inaccessible base of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "içi boş ture gösterici ilişkilendirme"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%u name provided for structured binding"
@@ -47032,7 +47172,7 @@
 msgstr[0] "%qs yapı alan için saklama sınıfı belirtilmiş"
 msgstr[1] "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -47039,7 +47179,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -47046,1024 +47186,1035 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "in initialization of structured binding variable %qD"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot decompose union type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "adres çözümlenemez"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "return type is an incomplete type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "dönüş türü, bir içi boş tür"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java yöntemi %qD Java olmayan %qT dönüş türünü içeriyor"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%qD doğrudan özelleştirmesinin kardeş bildirimde tanımı"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde %qD şablon kimliğinin kullanımı geçersiz"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> %<int%> döndürmeli"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "sınıf %2$qT içinde bildirilmiş %1$q#D diye bir üye işlev yok"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ tümlemeyen %2$qT türündeki %1$qD üye sabitinin ilklendirilmesine izin vermez"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "%qD dizisinin boyutu negatif"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "dizi boyutu negatif"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ değişken boyutlu %qD dizisine izin vermez"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++  değişken boyutlu diziye izin vermez"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "dizi boyutunda taşma"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "kurucu için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "%<operator %T%> için dönüş türü belirtilmiş"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "void bildirimli adsız değişken ya da alan"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "üye olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ türsüz %qs bildirimine izin verilmez"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for %qs"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%qs için short, signed veya unsigned geçersiz"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%qs için signed ve unsigned birlikte verilmiş"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<long long%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<long%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<short%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for %qs"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for %qs"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%qs için char ile long veya short belirtilmiş"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for %qs"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%qs için long ve short birlikte belirtilmiş"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for %qs"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%qs için short, signed veya unsigned geçersiz"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz olarak kullanılmış"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%qs için tepe-seviye bildirim %<auto%> belirtiyor"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirimli"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "saklatım sınıfı belirteçleri kardeş işlev bildirimlerinde geçersiz"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "requires-clause on return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
-#, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
-msgstr ""
-
-#: cp/decl.c:11099
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/decl.c:11111
+#: cp/decl.c:11156
 #, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.c:11169
+#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -48070,265 +48221,265 @@
 msgstr "kurucular virtual olarak bildirilemez"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -48335,177 +48486,177 @@
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
@@ -48512,82 +48663,82 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
@@ -48607,184 +48758,184 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -48796,97 +48947,97 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in the class %qT"
 msgid "%qT defined with multiple direct bases"
 msgstr "%qD zaten sınıf %qT içinde tanımlı"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
@@ -48895,84 +49046,84 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "geçersiz üye işlev bildirimi"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -49013,7 +49164,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%qT silinmesi tanımsız"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D şablon bildirimi"
@@ -49027,7 +49178,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "yıkıcı %qD üye şablon olarak bildirilmiş"
@@ -49147,45 +49298,45 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonim yapı isimli türün içinde değil"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "anonim union içinde private üye %q+#D"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "isim alanı bağlamındaki anonim kümeler static olmalıdır"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "üyesiz anonim union"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> %qT türünde dönmeli"
@@ -49194,68 +49345,68 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> ilk parametreyi %<size_t%> (%qT) türünde alir"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> %qT türünde dönmeli"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> ilk parametreyi %qT türünde alır"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -49265,67 +49416,67 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D niteliksiz türe başvurmuyor, dolasıyla ilintileme için kullanılmaz"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "satıriçi işlev %q+D tanımlanmadan kullanılmış"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D'nin %1$P. parametresi için öntanımlı argüman eksik"
@@ -49332,19 +49483,19 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -49354,113 +49505,113 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "argüman yok"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "%<%T::%D%> ile ilişkilendirme belirsiz"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD, %qD nin bir üyesi değil"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> bildirilmemişti"
@@ -49615,76 +49766,76 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(eğer istediğiniz bu değilse, işlev şablonunun zaten bildirilmiş olduğundan emin olduktan sonra burada işlev isminden sonra bir <> ekleyin)-Wno-non-template-friend bu UYARIyı iptal eder"
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "%2$qT tamamlanmamış türüne %1$qs uygulanması geçersiz"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "value-initialization of function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "value-initialization of reference type %qT"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "initializer for flexible array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD üye ilklendirme listesinde ilklendirilmiş olmalı"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "sınıf %T kendisiyle dolaylı kardeş"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
@@ -49691,311 +49842,311 @@
 msgid "%q#D should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "taban %qT sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  taban %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  burada ilklendirildiğinde"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J%qD için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jtaban %qT için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J%qT'nin çok sayıda üyesi için ilklendirmeler"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D bir static veri üyesidir; sadece tanımında ilklendirilebilir"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "taban sınıfı olmayan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "çoklu miras kullanan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD  hem doğrudan hem de dolaylı sanal taban"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qT is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "içi boş tür %qT üye %qD'yi içermiyor"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "%qD bit alanına gösterici geçersiz"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "ifadede tamsayı taşması"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "new için %<void%> türü geçersiz"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "%2$qT sınıfında uygun bir %1$qD yok"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "üye %qD için istek belirsiz"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new bir referans türe uygulanamaz"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "ilklendirici erken sonlanıyor"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete içindeki dizi boyutu bilinmiyor"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
@@ -50007,7 +50158,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -50094,71 +50245,71 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(%<-fpermissive%> kullanırsaniz, G++ kodunuzu kabul edecek ama bildirilmemiş isim kullanımına izin vermek artık önerilmiyor)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "%<?:%> için ortadaki terim olmadığından yorumlanamadı"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
@@ -50289,47 +50440,47 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D %q#T kurucusunu gizliyor"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "due to different exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "%q+#D genel bildirimi"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -50338,64 +50489,64 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%q+D bildirimi kullanımı önceki bildirimlerden biri ile çelişiyor"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "%qD isim araması değişti"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  bu %q+D ISO standardının kuralları altında eşleşir"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  bu %q+D eski kurallar altında eşleşir"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "name lookup of %qD changed for new ISO %<for%> scoping"
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "%qD isim araması yeni ISO %<for%> etki alanında değişti"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "  %qD'de atıl bağlantı kullanımı"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -50403,12 +50554,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "bir using bildirimi bir şablon kimliği belirtemez. %<using %D%> deneyin"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "using bildiriminde isim alanı %qD kullanılamaz"
@@ -50415,106 +50566,106 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT bir isim alanı değil"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD zaten bu bağlamda bildirilmiş"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> yıkıcı isimlendiriyor"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "%3$q#T içinde %<%1$T::%2$D%> ile eşleşen bir üye yok"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD bildirimi %qD'yi kuşatan isim alanında değil"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD bildiriminde doğrudan niteleme"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD %qD içinde bildirilmeliydi"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%qD öznitelik yönergesi yoksayıldı"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -50521,86 +50672,92 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%<this%> is unavailable for static member functions"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "statik üye işlevlerde %<this%> kullanılmaz"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%q+#D bildirilemez"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "it was later defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on local using directive"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "burada isim alanı rumuzu %qD kullanılamaz, %qD varsayılıyor"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX, pop_everything () işlevine giriyor\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX, pop_everything () işlevini bırakıyor\n"
@@ -50621,7 +50778,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50648,7 +50805,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "sınıf olmayan %2$qT türündeki %1$qD üyesi için istek"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -50740,7 +50897,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -50988,7 +51145,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -51080,7 +51237,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -51095,550 +51252,541 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef ismi %qD yıkıcı bildiricisi olarak kullanılmış"
 
-#: cp/parser.c:6110
-#, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "belirteç niteleyici listesi umuluyordu"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bir şablon değil"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ birleşik sabitlere izin vermez"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "parantezli tür kimliğinden sonra dizi sınırı yasak"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "eski tarz tür dönüşümü"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| içindeki && çevresinde parantezler önerilir"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "new types may not be defined in a return type"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "lambda-expression in template-argument"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Beklenmeyen modül sonu"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case etiketi %qE bir switch deyimi içinde değil"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "fazladan %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "karışık bildirimler ve işlev tanımları yasaktır"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "boş bildirim"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for structured binding declaration"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D %q#T içinde geçersiz"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "temel ilklendiricileri sadece kurucular alır"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "artık tarih olmuş eski tarz temel sınıf ilklendiricisi"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (bir nitelikli üye ilklendirici örtük olarak bir tür olduğundan)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "koşullu terim geçersiz"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -51645,75 +51793,75 @@
 msgstr "beklenmeyen terim"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> bir şablon argüman listesi başlatamaz"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ile %<[%> aynı şeyi gösterir. %<<%> ile %<::%> arasında boşluk bırakın"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -51720,325 +51868,325 @@
 msgstr "deyim umuluyordu"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "bir şablon olduğunu belirtmek için %<%T::template %D%> kullanın"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "C ilintileme ile şablon özelleştirmesi"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Umulmadık isim"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "fazladan niteleme yoksayıldı"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "nested namespace name required"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function %qs"
 msgid "initializer provided for function"
 msgstr "kardeş işlev %qs ilklendirilemiyor"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -52048,18 +52196,18 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -52066,427 +52214,427 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD bir isim alanıdır"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "missing template arguments after %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "öntanımlı argümanlara sadece işlev parametresi olarak izin verilir"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD bildirimindeki sınıf ismi geçersiz"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "bir doğrudan özelleştirme %<template <>%> ile öncelenmeli"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T türünde önceden tanım"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "bir kardeş bildirilirken bir sınıf anahtarı kullanılmalıdır"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "expected %<;%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (taban sınıfı örtük olarak bir türdür)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -52495,459 +52643,459 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable fused multiply/add instructions"
 msgid "empty introduction-list"
 msgstr "Birleşik çarpma/toplama komutları etkinleştirilir"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52954,119 +53102,119 @@
 msgstr "%qD bir üye şablon işlevi değil"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma pack%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma pack%> sonunda döküntü"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  %q+#D tanımından"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "name of class shadows template template parameter %qD"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "örneklenim sonrası %qT özelleştirmesi"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "%q#T farklı isim alanında özelleştiriliyor"
@@ -53073,71 +53221,71 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "örneklenim %2$qT sonrası %1$qT özelleştirmesi"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -53144,24 +53292,24 @@
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "Code özniteliği eksik"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
@@ -53169,60 +53317,60 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde şablon kimliği %qD"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "şablon parametre listesi doğrudan örneklenimde kullanılmış"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "tanım doğrudan örneklenim için sağlanmış"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok az şablon parametresi listeleniyor"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD doğrudan özelleştirmesi %<template <>%> tarafından vurgulanmalı"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bir şablon işlevi değildir"
@@ -53235,152 +53383,152 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%2$qT türünde bildirimli %1$qD isminde üye işlev yok"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %q#D declares a non-template function"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend bildirimi %q#D bir şablon olmayan işlev bildiriyor"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "friend declaration here"
 msgstr "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<anonim>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "şablon parametre türü %qT %<friend%> bildirimli"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of variable concept %q#D"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -53387,19 +53535,19 @@
 msgstr[0] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 msgstr[1] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD için öntanımlı argüman yok"
@@ -53407,53 +53555,53 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "bir isim olmaksızın şablon sınıfı"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -53464,59 +53612,59 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "şablon olmayan %q#D için şablon tanımı"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d seviye umulurken %q#D için şablon parametresi seviyesi olarak %d seviye alındı"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d şablon parametresi %q#T için alındı"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  ama %d gerekiyordu"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD bildiriminde şablon belirteçleri belirtilmemiş"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -53524,7 +53672,7 @@
 msgstr[0] "%qD şablon parametreleri olmaksızın kullanılmış"
 msgstr[1] "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -53532,12 +53680,12 @@
 msgstr[0] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 msgstr[1] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "şablon parametresi %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
@@ -53546,132 +53694,132 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration %q#D with different constraints"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53678,318 +53826,324 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü bu bağlamda dizge sabitler kullanılamaz"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "in template argument for type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes in template argument %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  %qD türünde bir şablon umulurken %qD alındı"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "dahili tutarlılık hatası"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "%Jflexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "%Junion içinde esnek dizi üye"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -54008,294 +54162,294 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -54308,119 +54462,125 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of %<virtual%> in template declaration of %q#D"
+msgid "invalid use of %qT in template argument"
+msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -54643,7 +54803,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "sözde yıkıcı isminde niteleyen etki alanı geçersiz"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
@@ -54695,7 +54855,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
@@ -54772,325 +54932,327 @@
 msgstr "%qT bir şablon türü değil"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
-msgstr ""
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
+msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> static expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> static value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<vector%> length expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<worker%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> num value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<grainsize%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<priority%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -55231,13 +55393,13 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* denetimi: %2$s dosyasının %3$d. satırındaki %1$s içinde başarısız"
@@ -55308,394 +55470,394 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "bir üye işleve %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "dizge sabitten %qT'ye dönüşüm artik önerilmiyor"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "static olmayan veri üyesi %qE kullanımı geçersiz"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "iptal edilen tür %qT iken yıkıcı %qT ile ilişkili"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bir nesne göstericisi türü değil"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE kullanimında nesne eksik"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "%qs yerleşik işlevi iptal edilemez"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ program içinden %<::main%> çağrısına izin vermez"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<%E (...)%> içinde üye gösterici işlevi çağrısı için %<.*%> veya %<->*%> kullanılmalı"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "işlev için çok fazla argüman belirtildi"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "işlev için çok az argüman belirtildi"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%P parametresi %qD içinde tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametre %P tamamlanmamış %qT türünde"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "aşırı yüklü işlevden %qT türüne dönüşüm yapildigi varsayılıyor"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "aritmetik içinde NULL kullanımı"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "left rotate count is negative"
 msgstr "%s döngü sayısı negatif"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "right rotate count is negative"
 msgstr "%s döngü sayısı negatif"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "left rotate count >= width of type"
 msgstr "%s döngü sayısı >= tür genişligi"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count >= width of type"
 msgid "right rotate count >= width of type"
 msgstr "%s döngü sayısı >= tür genişligi"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ da gösterici ile tamsayı arasında karşılaştırmaya izin verilmez"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ bir çıkarma içinde %<void *%> türde gösterici kullanımına izin vermez"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içindeki bir işlev göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içinde bir yöntem göstericisi kullanımına izin vermez"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "gösterici aritmetiginde tamamlanmamış ture gösterici kullanımı geçersiz"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "%qE kullanımı üye işleve gösterici biçiminde geçersiz"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  bir nitelemeli kimlik gerekli"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around %qE cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
@@ -55702,421 +55864,416 @@
 msgstr "parantez icene alınmis %qE üye işleve gösterici biçiminde kullanilamaz"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir niteliksiz ya da parantezli statik olmayan üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir."
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir sınır üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ %<::main%> işlevinin adresinin alınmasına izin vermez"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "referans üye %qD için gösterici oluşturulamaz"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "%qD bit-alanının adresi alınamaz"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type bool"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "%qD doğrudan yazmaç değişkeninin adresi istendi"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr " %qD için adres istegi (%<register%> olarak bildirilmiş olan)"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT yerel tür %qT kullanıyor"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "%qT'den %qT'ye dönüşüm"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "%qT'den %qT'ye tür dönüşümü hassasiyet kaybi oluşturuyor"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "%qT türünden %qT türüne dönüşüm hedef türün hizalama gereksinimini arttiriyor"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ işlev ve nesne göstericileri arasında dönüşüme izin vermez"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ne bir gösterici türü ne de bir veri üyesine gösterici türü olan %qT ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "bir gösterici ya da bir işlev türüne referans olan %qT türü ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  %<%Q(%#T, %#T)%> nin gelisiminde"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "dizi ilklendirici hatalı"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   üye işleve gösterici dönüşümünde"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "sanal taban %qT üzerinden üye göstericisine dönüşüm"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   üyeye gösterici dönüşümünde"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
+#| msgid "cannot convert %qT to %qT in %s"
+msgid "cannot convert %qH to %qI"
+msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
-msgid "cannot convert %qH to %qI"
-msgstr "%qT %qT'ye %s içinde dönüştürülemez"
-
-#: cp/typeck.c:8804
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "%2$q+D işlevinin %1$P. argümanına aktarımda"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "sag yansiz dönüşluye referans"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "yerel değişken %q+D'ye referans donduruldu"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "bir yıkıcıdan değer donuyor"
@@ -56123,59 +56280,59 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "bir kurucunun bir işlev deneme blokunun bir tutamagından dondurulemez"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "kurucudan bir değer dondurulemez"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "ilklendirici yok"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%>', %<throw()%> olarak bildirilmedikce (ya da -fcheck-new etkinken) NULL donmemeli"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -56423,155 +56580,155 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "kurucu sözdizimi kullanılmış ama %qT türü için kurucu bildirilmemiş"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "tamsayı dizisinin ilklendiricisi olarak geniş-olmayan dizge kullanılmış"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "int-array initialized from incompatible wide string"
 msgstr "tamsayı dizisinin ilklendiricisi olarak geniş-olmayan dizge kullanılmış"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "karakter dizisi için dizge ilklendirici çok uzun"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -57026,29 +57183,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element in %s array constructor at %L is %s"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "%s dizi kurucudaki öğe (%L'deki) %s"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -57055,22 +57212,22 @@
 msgid "Simplification error"
 msgstr "gimpleme başarısız"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -58187,7 +58344,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -58378,7 +58535,7 @@
 msgid "deferred type parameter at %C"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -58653,490 +58810,490 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Cray göstericileri için dizi belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Eski tarz tür bildirimi %s*%d %C'de desteklenmiyor"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%s*%d %C'de standartdısı tür bildirimi"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C'de ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C'deki ilklendirme ifadesinin değişmez olması umuluyordu"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Structure name expected after RECORD at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "%L'deki ifade INTEGER türünde olmalı"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter '%s' at %L has not been declared or is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Bir sabit ifadesine indirgenmeyen '%s' parametresi %L'de ya bildirilmemiş ya da değişken değil"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Genişletme: %C'de BYTE türü"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C'de hedef makinede desteklenmeyen BYTE türü kullanılmış"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tür ismi '%s' %C'de belirsiz"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C'de IMPLICIT NONE deyimi yinelenmiş"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C'deki IMPLICIT içinde karakter aralığı eksik"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyiminde harfler alfabetik sırada olmalı"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s özniteliği ('%L'de) bir MODULE dışında kullanılamaz"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "%C'deki satır kırpıldı"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -59144,367 +59301,367 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C'deki USE deyiminde soysal belirtim eksik"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "sayı eksik"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C'deki türetilmiş tür evvelce tanımlanmış olmamalıydı, bu durumda bir türetilmiş tür tanımı içinde görünemez"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "MODULE prefix at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C'de diğer return yaftası umuluyordu"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template argument required for %<%s %T%>"
 msgid "A parameter name is required at %C"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C'deki dizi bildiriminde farklı bir boyut umuluyordu"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Sembol '%s' %C'deki biçimsel argüman listesinde yinelenmiş"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C'deki RESULT değişkeninin ismi işlev isminden farklı olmalı"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C'deki yapı kurucuda söz dizimi hatası"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "%C'deki işlev tanımında biçimsel argüman listesi umuluyordu"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C'deki ENTRY deyimi bir PROGRAM içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C'deki ENTRY deyimi bir BLOCK DATA içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C'deki ENTRY deyimi bir DERIVED TYPE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C'deki ENTRY deyimi bir IF-THEN bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C'deki ENTRY deyimi bir DO bloku içinde görünemez"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C'deki ENTRY deyimi bir FORALL bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C'deki ENTRY deyimi bir WHERE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş altyordamın içinde görünemez"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş işlevde görünemez"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C'de biçim yaftası eksik"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "'%s' işlev ismi olarak %C'de kullanılamaz"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -59511,176 +59668,176 @@
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "'%s' etiketi umuluyordu (%s deyiminde, %C'de)"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Dizi belirtimi %L'de ertelenmiş olmalı"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C'deki değişken listesinde umulmadık karakter"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C'deki Cray göstericisi %d baytlık hassasiyete sahip ancak bellek adresi %d bayt gerektiriyor"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "%C'de \")\" umuluyordu"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C'de \",\" veya deyim sonu umuluyordu"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "%C'deki Cray göstericisi bildirimi -fcray-pointer seçeneğini gerektiriyor"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%s işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ".%s. işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C'de PARAMETER deyiminde değişken ismi umuluyordu"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde = işareti umuluyordu"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C'deki PARAMETER deyiminde ifade umuluyordu"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
@@ -59687,502 +59844,502 @@
 msgstr "COMMON değişkeni `%s' için %C'de ilklendirme yapılamaz"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde umulmayan karakterler"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C'deki kapsamlı SAVE deyiminden önce bir SAVE deyimi var"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "'%s' simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD evreye yerel olamaz çünkü POD olmayan %qT türünde"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PRIVATE olabilir"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PUBLIC olabilir"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C'deki Cray göstericileri tahmini biçimli dizi olamaz"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM AND ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003'te yeni: %C'de ENUM AND ENUMERATOR"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Sayısal sabitler %C'de C tamsayı türünü aşıyor"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "bir tamsayı ifadesi ile ilklendirilmemiş ENUMERATOR %L"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C öncesinde ENUM tanım deyimi umuluyordu"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C'deki ENUMERATOR tanımında sözdizimi hatası"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "%C'de isimsiz bir arayüz umuluyordu"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C'de dizi indisi umuluyordu"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected module procedure name at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RESULT attribute required in ENTRY statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki ENTRY deyimi bir RESULT özniteliği gerektirir"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -60555,27 +60712,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -60927,7 +61084,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
 msgid "Creating array temporary at %L"
@@ -60939,70 +61096,70 @@
 msgid "Removing call to function %qs at %L"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "ifade umuluyordu"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad test"
 msgid "bad op"
 msgstr "hatalı test"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -61134,12 +61291,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -62461,7 +62618,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -64036,12 +64193,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -64307,8 +64464,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
@@ -64355,7 +64512,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -64713,189 +64870,189 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOGICAL operands are required in expression at %L"
 msgid "TILE requires constant expression at %L"
 msgstr "%L'deki ifadede LOGICAL terimler gerekiyor"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -66377,7 +66534,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
@@ -66501,7 +66658,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66907,23 +67064,23 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -66930,219 +67087,219 @@
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki UNIT belirtimi ya bir INTEGER ifadesi ya da bir CHARACTER değişkeni olmalıdır"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67151,258 +67308,258 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -67410,12 +67567,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67423,113 +67580,113 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -67536,75 +67693,75 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -67612,7 +67769,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -67621,63 +67778,63 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -67685,971 +67842,971 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s işlevinde (%s dosyasının %d. satırı)"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -69114,7 +69271,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): geçersiz tür: %s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -69817,19 +69974,19 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Yerleşik işlev %qs (%d) tanınmiyor"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "The event variable at %L shall not be coindexed"
@@ -70035,203 +70192,203 @@
 msgid "previously defined here as %s"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "multiple prevailing defs for %qE"
 msgstr "%qs için complex geçersiz"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in %qT"
 msgid "%qD has already been defined"
 msgstr "%qD zaten %qT içinde tanımlı"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "previously defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "%Jönceden burada tanımlı"
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "type of %qD does not match original declaration"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%qD was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "variable %qD redeclared as function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %qD redeclared as variable"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "could not find specs file %s\n"
 msgid "could not parse file offset"
 msgstr "belirtim dosyası %s bulunamadı\n"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected node"
 msgid "unexpected offset"
 msgstr "umulmadık düğüm"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid line in the resolution file"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid resolution in the resolution file"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot read LTO decls from %s"
 msgstr "sınıf %qs bulunamıyor"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init başarısız"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr "rpo dosyasının ismi değiştiriliyor"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "opening LTRANS output list %s: %m"
 msgstr "`%s' çıktı dosyasının açılması: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, fuzzy, gcc-internal-format
 #| msgid "when writing output to %s: %m"
 msgid "writing to LTRANS output list %s: %m"
 msgstr "çıktı %s e yazılırken: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "closing LTRANS output list %s: %m"
 msgstr "`%s' çıktı dosyasının açılması: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "%s: çıktı dosyası '%s' açılamadı\n"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -72600,6 +72757,10 @@
 #~ msgid "invalid use of Boolean expression as operand to %<operator--%>"
 #~ msgstr "terim olarak ifade geçersiz"
 
+#, fuzzy
+#~ msgid "cannot convert %qT to %qT for argument %qP to %qD"
+#~ msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
+
 #~ msgid "return-statement with a value, in function returning 'void'"
 #~ msgstr "'void' dönüşlu işlevde değer içeren `return' deyimi"
 
Index: gcc/po/be.po
===================================================================
--- gcc/po/be.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/be.po	(.../branches/gcc-8-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -147,42 +147,42 @@
 msgid "negative insn length"
 msgstr ""
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr ""
 
-#: final.c:3615
+#: final.c:3618
 #, fuzzy
 #| msgid "invalid mask"
 msgid "invalid 'asm': "
 msgstr "нерэчаісная маска"
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr ""
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr ""
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr ""
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr ""
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "нерэчаісны %%-код"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr ""
@@ -193,13 +193,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1154,28 +1154,28 @@
 msgid "At top level:"
 msgstr ""
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, fuzzy, c-format
 msgid "In member function %qs"
 msgstr "у функцыі \"%s\":"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, fuzzy, c-format
 #| msgid "In function `%s':"
 msgid "In function %qs"
 msgstr "у функцыі \"%s\":"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr ""
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 #| msgid "In file included from %s:%d"
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "У файле уключаным з %s:%d"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, fuzzy, c-format
 #| msgid "In file included from %s:%d"
 msgid "    inlined from %qs"
@@ -2975,9 +2975,9 @@
 msgid "invalid address mode"
 msgstr "нерэчаісны адрас"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2993,7 +2993,7 @@
 msgstr "нерэчаіснае значэньне %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3000,13 +3000,13 @@
 msgstr "нерэчаіснае значэньне %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
@@ -3037,7 +3037,7 @@
 msgstr "нерэчаіснае значэньне %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
@@ -3048,7 +3048,7 @@
 msgstr "нерэчаіснае значэньне %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
@@ -3059,7 +3059,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3071,57 +3071,57 @@
 msgid "invalid operand address"
 msgstr "нерэчаісны адрас"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 msgid "invalid operand to %%Z code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 msgid "invalid operand to %%z code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 msgid "invalid operands to %%c code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 msgid "invalid operand to %%M code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, fuzzy, c-format
 msgid "invalid operand to %%p code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, fuzzy, c-format
 msgid "invalid operand to %%s code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, fuzzy, c-format
 msgid "invalid operand to %%R code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, fuzzy, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, fuzzy, c-format
 msgid "invalid operand to %%U code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, fuzzy, c-format
 msgid "invalid operand to %%V code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 msgid "invalid operand to %%O code"
 msgstr "нерэчаісны %%-код"
@@ -3128,18 +3128,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 #, fuzzy
 msgid "unrecognized supposed constant"
 msgstr "нераспазнаны выбар \"-%s\""
@@ -3176,7 +3176,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, fuzzy, c-format
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
@@ -3306,8 +3306,8 @@
 msgstr "нерэчаісны %%c аперанд"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3526,100 +3526,100 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of register '%s'"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of asm flag output"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid constraints for operand"
 msgstr "нерэчаісны %%c аперанд"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "невядомы рэжым машыны \"%s\""
@@ -3663,7 +3663,7 @@
 msgstr "нерэчаісны %%-код"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3719,7 +3719,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -3890,83 +3890,83 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
@@ -3973,63 +3973,63 @@
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4157,43 +4157,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "нерэчаісны %%Y аперанд"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "нерэчаісны %%A аперанд"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "нерэчаісны %%B аперанд"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "нерэчаісны %%C аперанд"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "нерэчаісны %%D аперанд"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, fuzzy, c-format
 msgid "invalid %%s operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4414,14 +4414,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -4436,7 +4436,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -4444,7 +4444,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -4458,7 +4458,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
@@ -4465,7 +4465,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -4475,13 +4475,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -4490,18 +4490,18 @@
 msgid "expected %<.%>"
 msgstr ""
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4509,23 +4509,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
@@ -4534,7 +4534,7 @@
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -4545,40 +4545,40 @@
 msgid "expected label"
 msgstr ""
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr ""
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr ""
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr ""
 
@@ -4676,7 +4676,7 @@
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4695,124 +4695,124 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 #, fuzzy
 #| msgid "parse error"
 msgid "<expression error>"
 msgstr "граматычная памылка"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr ""
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 msgid "In static member function %qs"
 msgstr "у функцыі \"%s\":"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, fuzzy, c-format
 #| msgid "In construct"
 msgid "In copy constructor %qs"
 msgstr "У канструкцыі"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 #| msgid "In construct"
 msgid "In constructor %qs"
 msgstr "У канструкцыі"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 #| msgid "In construct"
 msgid "In destructor %qs"
 msgstr "У канструкцыі"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 #| msgid "In function"
 msgid "In lambda function"
 msgstr "У функцыі"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "ініцыялізацыя"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr ""
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "called from here"
 msgid "required from here\n"
 msgstr "выклікана адсюль"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4863,50 +4863,50 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "in argument to unary !"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5187,11 +5187,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr ""
 
@@ -5366,47 +5366,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5448,12 +5448,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5706,6 +5706,7 @@
 msgstr ""
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -8456,7 +8457,7 @@
 msgstr ""
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr ""
 
@@ -8922,7 +8923,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr ""
 
@@ -9648,7 +9649,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Генерыраваць код для дадзенага ЦП"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -10065,7 +10066,7 @@
 msgstr ""
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -10074,12 +10075,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -10092,41 +10093,41 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
 msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 msgid "Make all function calls indirect."
 msgstr ""
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr ""
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1057
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr ""
@@ -10546,7 +10547,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -10554,7 +10555,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10645,7 +10646,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "Генерыраваць код для дадзенага ЦП"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr ""
 
@@ -10673,7 +10674,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr ""
 
@@ -10751,23 +10752,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -10787,19 +10788,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -10815,15 +10816,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 msgid "Generate the integer modulo instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
@@ -10832,15 +10833,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -10848,7 +10849,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
@@ -10877,12 +10878,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr ""
 
@@ -11567,7 +11567,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -11771,14 +11771,22 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+msgid "Max number of pairs of load insns for compare."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr ""
@@ -11787,10 +11795,38 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:410
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr ""
+
+#: config/rs6000/sysv4.opt:24
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:28
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use 64-bit FP registers"
@@ -12989,97 +13025,153 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code for given CPU"
 msgid "Generate code in big-endian mode."
 msgstr "Генерыраваць код для дадзенага ЦП"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code for Intel ld"
 msgid "Generate code in little-endian mode."
 msgstr "Генерыраваць код для Intel ld"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 msgid "Generate conditional move instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 msgid "Generate string extension instructions."
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Generate 16-bit instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr ""
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr ""
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr ""
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 msgid "Guide linker to relax instructions."
 msgstr "нявернае выкарыстанне \"restict\""
 
+#: config/nds32/nds32.opt:314
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:318
+msgid "Generate single-precision floating-point instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:322
+msgid "Generate double-precision floating-point instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr ""
@@ -13975,13 +14067,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr ""
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate char instructions"
@@ -16282,8 +16367,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -16311,7 +16396,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr ""
@@ -16764,7 +16849,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -16792,13 +16877,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -16847,9 +16932,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16863,8 +16948,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %qD"
@@ -16997,84 +17082,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "too few arguments to function %<va_start%>"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid argument to %qD"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -17081,75 +17160,75 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' must be constant"
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr ""
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -17157,7 +17236,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -17164,12 +17243,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -17176,17 +17255,17 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, fuzzy, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed args"
@@ -17194,50 +17273,50 @@
 "`va_start' выкарыстоўвываецца ў функцыі з нязьменнай\n"
 "           колькасьцю аргументаў"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -18438,38 +18517,38 @@
 msgid "conversion to incomplete type"
 msgstr ""
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr ""
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr ""
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 #| msgid "can't get current directory"
 msgid "can%'t convert value to a vector"
 msgstr "не магу атрымаць бягучую дырэкторыю"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -18628,12 +18707,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18744,12 +18823,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18765,12 +18844,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "не магу знайсці крыніцу %s\n"
@@ -18780,42 +18859,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -19374,28 +19453,28 @@
 msgid "can%'t write PCH file"
 msgstr "не магу запісаць ў %s"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -19409,12 +19488,13 @@
 msgid "null pointer dereference"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared here"
@@ -19933,10 +20013,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -19965,7 +20045,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -20308,252 +20388,257 @@
 msgid "function cannot be instrumented"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr ""
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr ""
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, fuzzy, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr ""
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -20574,7 +20659,7 @@
 msgid "the extra base is defined here"
 msgstr ""
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -20581,7 +20666,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20588,7 +20673,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -20595,7 +20680,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -20602,7 +20687,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20609,7 +20694,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20889,30 +20974,34 @@
 
 #: multiple_target.c:91
 #, gcc-internal-format
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr ""
 
-#: multiple_target.c:324
-#, fuzzy, gcc-internal-format
-#| msgid "`%s' attribute ignored"
-msgid "single target_clones attribute is ignored"
-msgstr "\"%s\" атрыбут ігнарыруецца"
+#: multiple_target.c:343
+#, gcc-internal-format
+msgid "single %<target_clones%> attribute is ignored"
+msgstr ""
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr ""
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -21228,12 +21317,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -21840,22 +21929,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21899,7 +21988,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -22142,159 +22231,159 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function symbol is not function"
 msgstr "функцыя не вяртае тып string"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "node is alias but not definition"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -23476,12 +23565,12 @@
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23989,7 +24078,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -24029,92 +24118,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -24139,243 +24228,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr ""
@@ -24400,12 +24489,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -25298,7 +25387,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -25557,7 +25646,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array is too large"
@@ -26179,7 +26268,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -26195,22 +26284,22 @@
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -26765,8 +26854,8 @@
 msgid "wrong type argument to %s"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -27407,7 +27496,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -27486,7 +27575,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -27618,47 +27707,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -27685,13 +27774,13 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown switch -mlong-double-%s"
@@ -27698,19 +27787,19 @@
 msgstr "невядомы рэжым машыны \"%s\""
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -28193,8 +28282,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -28274,8 +28363,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28384,11 +28473,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -28398,147 +28487,137 @@
 msgid "%qE attribute only applies to functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `-%s' is missing"
 msgid "argument of %qE attribute is missing"
 msgstr "аргумент для \"-%s\" прапушчан"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -28564,157 +28643,157 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 7"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 3"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 1"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of mask should be in 0 to 255"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -29526,12 +29605,12 @@
 msgid "invalid IACC argument"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr ""
@@ -29632,571 +29711,556 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "немагчыма зачыніць уваходзячы файл %s"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "X32 does not support ms_abi attribute"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -30203,313 +30267,313 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "непадтрымліваемая версія"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30738,7 +30802,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -31274,7 +31338,32 @@
 msgid "constant argument out of range for %s"
 msgstr ""
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:702
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:717
+#, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:736
+#, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:748
+#, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:760
 #, fuzzy, gcc-internal-format
 #| msgid "Don't use AltiVec instructions"
 msgid "don't support string extension instructions"
@@ -31296,42 +31385,59 @@
 msgstr ""
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr ""
+
+#: config/nds32/nds32.c:3508
+#, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "position-independent code not supported"
@@ -31544,37 +31650,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -31671,12 +31777,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -31726,7 +31832,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -32029,7 +32135,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32039,7 +32145,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -32049,12 +32155,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32064,28 +32170,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
@@ -32105,12 +32211,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
@@ -32132,53 +32238,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -32303,7 +32409,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "stack frame too large"
@@ -32314,12 +32420,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -32329,22 +32435,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -32354,7 +32460,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -32820,22 +32926,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr ""
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr ""
@@ -32898,30 +33004,35 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
+#, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
@@ -33046,175 +33157,175 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of `%s' should be `char **'"
 msgid "second argument to %qs must be 0..12"
 msgstr "другім аргументам \"%s\" павінен быць \"char **\""
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "third argument to %qs must be 0..12"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use register sb"
 msgid "%qs uses register r29"
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%s=%s is too large"
 msgid "%s%qs%s is not allowed"
 msgstr "%s=%s вельмі вялікі"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -34020,7 +34131,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -34278,7 +34389,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -34288,7 +34399,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -34351,7 +34462,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Аб кожным неабвешчаным ідэнтыфікатары паведамляецца"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -34383,7 +34494,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "паўтарэнне \"%s\""
@@ -34504,7 +34615,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -34768,7 +34879,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -34933,7 +35044,7 @@
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -35062,7 +35173,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
@@ -35246,7 +35357,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -35298,7 +35409,7 @@
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
@@ -35336,7 +35447,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
@@ -35366,7 +35477,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -35398,7 +35509,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
@@ -35518,12 +35629,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -35588,7 +35699,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
@@ -35747,37 +35858,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -35807,7 +35918,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -35850,7 +35961,7 @@
 msgstr "невядомая назва рэгістра: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -35867,7 +35978,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -35883,8 +35994,8 @@
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -35922,7 +36033,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -35952,7 +36063,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -36018,13 +36129,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -36157,7 +36268,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -36191,24 +36302,24 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -36228,12 +36339,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -36260,12 +36371,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -36546,7 +36657,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -36608,77 +36719,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -36693,54 +36804,54 @@
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr ""
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -36762,84 +36873,84 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr ""
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr ""
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many %<static%> arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "unexpected argument"
 msgstr "няма аргументаў"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -36850,12 +36961,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -36875,19 +36986,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -36897,68 +37008,68 @@
 msgid "invalid proc_bind kind"
 msgstr "Нерэчаісны выбар %s"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -36973,7 +37084,7 @@
 msgid "expected function name"
 msgstr ""
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD does not refer to a function"
@@ -36984,42 +37095,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -37029,22 +37140,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -37054,72 +37165,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -37139,32 +37250,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr ""
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -37219,47 +37330,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -37275,7 +37386,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -37396,7 +37507,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -37421,7 +37532,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -37525,17 +37636,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr ""
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -37560,7 +37671,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -37795,7 +37906,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -37948,7 +38059,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -38015,7 +38126,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -38085,12 +38196,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -38136,7 +38247,7 @@
 msgid "invalid initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -38151,7 +38262,7 @@
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -38282,7 +38393,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C не падтрымлівае \"goto *expr;\""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -38323,7 +38434,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -38333,17 +38444,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -38368,22 +38479,22 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -38434,7 +38545,7 @@
 msgstr ""
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -38464,12 +38575,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -38479,25 +38590,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -38508,70 +38619,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -38591,7 +38702,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -38601,17 +38712,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -38626,18 +38737,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -38649,32 +38760,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -38694,55 +38805,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -38752,32 +38863,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -38911,7 +39022,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38989,24 +39100,24 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr ""
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr ""
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr ""
@@ -39013,613 +39124,613 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr ""
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr ""
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr ""
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "Унутраная памылка: %s"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s\n"
 msgid "%qs"
 msgstr "%s\n"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "немагчымы апэратар '%s'"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared protected here"
 msgstr "выклікана адсюль"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 msgid "could not convert %qE from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
@@ -39658,8 +39769,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
@@ -39701,7 +39812,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr ""
@@ -39781,7 +39892,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -40060,7 +40171,7 @@
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
@@ -40132,7 +40243,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
@@ -40228,336 +40339,336 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "call to internal function %qE"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "%qD used in its own initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40599,7 +40710,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -40608,307 +40719,307 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr ""
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "conversion from %q#T to %q#T"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr ""
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr ""
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr ""
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr ""
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr ""
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -40950,204 +41061,204 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr ""
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr ""
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "from previous declaration %qF"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr ""
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "previous definition of %qD was here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "у функцыі \"%s\":"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "у функцыі \"%s\":"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr ""
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr ""
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr ""
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "conflicting declaration of template %q+#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "%q#D previously defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "няма папярэдняга прататыпа для \"%s\""
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "previous non-prototype definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, fuzzy, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "deleted definition of %q+D"
@@ -41161,12 +41272,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -41173,7 +41284,7 @@
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
@@ -41180,22 +41291,22 @@
 msgid "redefinition of %q#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -41203,634 +41314,634 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr " адсюль"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr ""
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr ""
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -41837,7 +41948,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -41844,7 +41955,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -41851,892 +41962,902 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr ""
+
+#: cp/decl.c:7774
+#, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "ініцыялізацыя"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' павінна вяртаць `int'"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "памер масіва `%D' - адмоўны"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "адмоўны памер масіва "
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as array of void"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as non-member"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
+msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:11099
+#: cp/decl.c:11156
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
+msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42743,463 +42864,463 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -43206,77 +43327,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -43296,172 +43417,172 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "%qD must have no arguments"
 msgstr "няма аргументаў"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qT has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -43473,95 +43594,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -43570,78 +43691,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid function declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43681,7 +43802,7 @@
 msgid "deleting %qT is undefined"
 msgstr "метка \"%s\" ужываецца, але не вызначана"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "пустое абвяшчэнне"
@@ -43694,7 +43815,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -43805,42 +43926,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -43849,67 +43970,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -43918,65 +44039,65 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous mangling %q#D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "inline function %qD used but never defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -43983,17 +44104,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -44003,113 +44124,113 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "няма аргументаў"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -44255,360 +44376,360 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr ""
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "  when initialized here"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "поле \"%s\" не знойдзена ў класе"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44620,7 +44741,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -44703,67 +44824,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -44882,44 +45003,44 @@
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "does not match previous declaration %q#D"
@@ -44928,57 +45049,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr ""
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr ""
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr ""
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr ""
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr ""
@@ -44985,12 +45106,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
@@ -44997,104 +45118,104 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, fuzzy, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, fuzzy, gcc-internal-format
 msgid "%qD not declared"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qD attribute directive ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -45101,78 +45222,83 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr ""
+
+#: cp/name-lookup.c:5929
+#, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr ""
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -45192,7 +45318,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45217,7 +45343,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -45297,7 +45423,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45520,7 +45646,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -45602,7 +45728,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -45617,512 +45743,502 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr ""
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
 #, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr ""
+
+#: cp/parser.c:10119
+#, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "default argument specified for lambda parameter"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "неаднолькавае абвяшчэньне `%T' і `%T'"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected operator"
@@ -46129,364 +46245,364 @@
 msgstr "нераспазнаны аператар %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a namespace-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "expected initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -46495,17 +46611,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "нерэчаісны абвяшчальнік"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -46512,389 +46628,389 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate cv-qualifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate virt-specifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "нерэчаіснае выкарыстаньне `%T'"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr ""
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -46903,529 +47019,529 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty introduction-list"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "  from definition of %q#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -47432,88 +47548,88 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
@@ -47520,57 +47636,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a template function"
@@ -47584,139 +47700,139 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "у функцыі \"%s\":"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "friend declaration here"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47723,17 +47839,17 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -47741,47 +47857,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -47791,58 +47907,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -47849,7 +47965,7 @@
 msgstr[0] "нявернае выкарыстанне \"restict\""
 msgstr[1] "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -47856,12 +47972,12 @@
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -47870,118 +47986,118 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "original definition appeared here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -47988,289 +48104,294 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "in template argument for type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
 #, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr ""
+
+#: cp/pt.c:11691
+#, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -48288,280 +48409,280 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -48573,106 +48694,111 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "нявернае выкарыстанне \"restict\""
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -48878,7 +49004,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -48928,7 +49054,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -49000,294 +49126,294 @@
 msgstr "\"%s\" мае незавершаны тып"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4071
+#: cp/semantics.c:4056
 #, gcc-internal-format
-msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -49412,12 +49538,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -49477,735 +49603,731 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a member template function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "left rotate count is negative"
 msgstr "адмоўны памер масіва "
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr ""
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, fuzzy, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8786
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#: cp/typeck.c:8812 cp/typeck.c:8829
+msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8800
-msgid "cannot convert %qH to %qI"
-msgstr ""
-
-#: cp/typeck.c:8804
+#: cp/typeck.c:8833
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -50212,56 +50334,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -50488,141 +50610,141 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr ""
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr ""
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -51047,48 +51169,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -52085,7 +52207,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -52257,7 +52379,7 @@
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -52508,450 +52630,450 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization"
 msgid "Old-style initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -52958,953 +53080,953 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Прапушчана назва"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "невядомая назва рэгістра: %s"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -54241,27 +54363,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -54587,7 +54709,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr ""
@@ -54597,63 +54719,63 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "bad header version"
 msgid "bad expression"
 msgstr "дрэнная версія загалоўка"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -54773,12 +54895,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -55972,7 +56094,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -57418,12 +57540,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -57663,8 +57785,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -57706,7 +57828,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -58047,182 +58169,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -59576,7 +59698,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -59686,7 +59808,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -60062,228 +60184,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -60292,232 +60414,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60524,12 +60646,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60537,107 +60659,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60644,67 +60766,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -60711,7 +60833,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -60719,58 +60841,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -60777,889 +60899,889 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -62103,7 +62225,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -62745,18 +62867,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -62945,181 +63067,181 @@
 msgid "previously defined here as %s"
 msgstr "папярэдняе вызначэньне"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr ""
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr ""
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "previously defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "type of %qD does not match original declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 msgid "previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr ""
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't open %s"
 msgid "Cannot open %s"
 msgstr "немагчыма адчыніць %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "не магу зачыніць %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "не магу прачытаць з %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr ""
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 #| msgid "Could not open data file %s.\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "Немагчыма адчыніць файл з дадзенымі %s.\n"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/ru.po
===================================================================
--- gcc/po/ru.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/ru.po	(.../branches/gcc-8-branch)
@@ -12,7 +12,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1-b20180128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2018-01-30 10:25+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
@@ -164,40 +164,40 @@
 msgid "negative insn length"
 msgstr "отрицательная длина RTL-инструкции"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "разбиение RTL-инструкции невозможно"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "некорректная директива 'asm': "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "вложенные альтернативы диалектов ассемблера"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "незавершённая альтернатива диалекта ассемблера"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "не задан номер операнда после %%-буква"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "номер операнда вне диапазона"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "некорректный модификатор после %%"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "операнд '%%l' не является меткой"
@@ -208,13 +208,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "некорректное использование плавающей константы"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1308,29 +1308,29 @@
 msgid "At top level:"
 msgstr "На верхнем уровне:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "В функции-члене %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "В функции %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 #, fuzzy
 #| msgid "    inlined from %qs at %s:%d:%d"
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    включённом из %qs в %s:%d:%d"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 #| msgid "    inlined from %qs at %s:%d"
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    включённом из %qs в %s:%d"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    включённом из %qs"
@@ -3245,9 +3245,9 @@
 msgid "invalid address mode"
 msgstr "некорректный режим адресации"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' использовано без локальной динамической TLS ссылки"
@@ -3263,7 +3263,7 @@
 msgstr "некорректное значение %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3270,13 +3270,13 @@
 msgstr "некорректное значение %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
@@ -3307,7 +3307,7 @@
 msgstr "некорректное значение %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
@@ -3318,7 +3318,7 @@
 msgstr "некорректное значение %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
@@ -3329,7 +3329,7 @@
 msgstr "некорректное unspec-перемещение"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3341,61 +3341,61 @@
 msgid "invalid operand address"
 msgstr "некорректный адрес"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%Z code"
 msgstr "некорректный операнд для кода %%s"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%z code"
 msgstr "некорректный операнд для кода %%s"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operands to %%c code"
 msgstr "некорректный операнд для кода %%s"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%M code"
 msgstr "некорректный операнд для кода %%s"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "некорректный операнд для кода %%p"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "некорректный операнд для кода %%s"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "некорректный операнд для кода %%R"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "некорректный операнд для кода %%H/%%L"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "некорректный операнд для кода %%U"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "некорректный операнд для кода %%V"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%O code"
@@ -3403,19 +3403,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "неверный код выходного операнда"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "неопознанная константа"
 
@@ -3450,7 +3450,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
@@ -3585,8 +3585,8 @@
 msgstr "некорректный операнд const_double"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3803,109 +3803,109 @@
 msgid "bad output_condmove_single operand"
 msgstr "некорректный операнд для output_condmove_single"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid type for make function"
 msgid "invalid use of asm flag output"
 msgstr "некорректный тип для make функции"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "недопустимый размер операнда для кода '%c'"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "недопустимый размер операнда для кода '%c'"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "недопустимый тип операнда для кода '%c'"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "недопустимый размер операнда для кода '%c'"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд не является кодом условия, неверный код операнда 'D'"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд не является кодом условия, неверный код операнда 'D'"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд не является ссылкой на память со смещением, неверный код операнда 'H'"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "некорректные ограничения для операнда"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid vector immediate"
 msgstr "недопустимая инструкция:"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "некорректный режим инструкции"
 
@@ -3944,7 +3944,7 @@
 msgstr "неверный операнд для кода %%P"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -3998,7 +3998,7 @@
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -4169,146 +4169,146 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "некорректное %%H значение"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не генерировать одну выходную точку для каждой функции"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "ошибка при генерации загрузок операндов на регистры для:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4439,43 +4439,43 @@
 msgid "created and used with different endianness"
 msgstr "создан с одним значением endianness, а используется с другим"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "некорректный операнд для %%Y"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "некорректный операнд для %%A"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "некорректный операнд для %%B"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "некорректный %%C операнд"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "некорректный %%D операнд"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "некорректный операнд для %%f"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "некорректный операнд для %%s"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4701,14 +4701,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалась %<,%>"
@@ -4723,7 +4723,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалась %<)%>"
@@ -4731,7 +4731,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалась %<]%>"
@@ -4745,7 +4745,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалась %<(%>"
@@ -4752,7 +4752,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалась %<{%>"
@@ -4762,13 +4762,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
@@ -4777,18 +4777,18 @@
 msgid "expected %<.%>"
 msgstr "ожидалась %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалась %<,%> или %<)%>"
@@ -4796,23 +4796,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалась %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<[%>"
@@ -4821,7 +4821,7 @@
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<<%>"
@@ -4833,47 +4833,47 @@
 msgid "expected label"
 msgstr "ожидался канал"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "переход по метке %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "переход по case-метке"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  входит в try-блок"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  входит в catch-блок"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 #| msgid "  enters OpenMP structured block"
 msgid "enters OpenMP structured block"
 msgstr "  входит в OpenMP структурный блок"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 #| msgid "Generate code for huge switch statements"
 msgid "enters synchronized or atomic statement"
 msgstr "Генерировать код для больших переключателей"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -4967,7 +4967,7 @@
 msgid "<statement>"
 msgstr "<оператор>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<неизвестный>"
@@ -4986,132 +4986,132 @@
 msgid "<unparsed>"
 msgstr "<unparsed>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 #, fuzzy
 #| msgid "<lambda"
 msgid "<lambda>"
 msgstr "<lambda"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<ошибка выражения>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<Неизвестный оператор>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "На глобальном уровне:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "В статической функции-члене %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "В конструкторе копирования %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "В конструкторе %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "В деструкторе %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "В lambda функции"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: В подстановке %qS:\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: В конкретизации %q#D:\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 #, fuzzy
 #| msgid "%s:%d:%d:   "
 msgid "%r%s:%d:%d:%R   "
 msgstr "%s:%d:%d"
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 #, fuzzy
 #| msgid "%s:%d:   "
 msgid "%r%s:%d:%R   "
 msgstr "%s:%d:   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "рекурсивно требуемый при подстановке %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr "требуемый при подстановке %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr "рекурсивно требуемый из %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr "требуемый из %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 #| msgid "recursively required from here"
 msgid "recursively required from here\n"
 msgstr "рекурсивно требуемый отсюда"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "required from here"
 msgid "required from here\n"
 msgstr "требуемый отсюда"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 #, fuzzy
 #| msgid "%s:%d:%d:   [ skipping %d instantiation contexts ]\n"
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%s:%d:%d:   [ пропуск %d контекстов конкретизации ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 #, fuzzy
 #| msgid "%s:%d:%d:   [ skipping %d instantiation contexts ]\n"
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%s:%d:%d:   [ пропуск %d контекстов конкретизации ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 #, fuzzy
 #| msgid "%s:%d:%d:   in constexpr expansion of %qs"
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d:%d:   в раскрытии константного выражения %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 #, fuzzy
 #| msgid "%s:%d:   in constexpr expansion of %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d:   в раскрытии константного выражения %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "претенденты:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
@@ -5158,48 +5158,48 @@
 msgid "source type is not polymorphic"
 msgstr "тип источника не является полиморфным"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неверный тип аргумента для унарного минуса"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неверный тип аргумента для побитового дополнения"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неверный тип аргумента для abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неверный тип аргумента для сопряжения"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "в аргументе унарного !"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "нет преинкрементного оператора для типа"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "нет постинкрементного оператора для типа"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "нет предекрементного оператора для типа"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "нет постдекрементного оператора для типа"
 
@@ -5485,11 +5485,11 @@
 msgid "implied END DO"
 msgstr "предписанный END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "присваивание указателя"
 
@@ -5682,47 +5682,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Противоречивые ранги для оператора в %%L и %%L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Переменная цикла"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr "Переменная итератора"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "Начальное выражение в DO цикле"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "Конечное выражение в DO цикле"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "Шаговое выражение в DO цикле"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE объект"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "ALLOCATE объект"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "STAT переменная"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "ERRMSG переменная"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr "элемент в READ"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK переменная"
 
@@ -5764,12 +5764,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Неравные character длины (%ld/%ld) в %s"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES от REPEAT встроенной функции отрицателен (его значение равно %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Аргумент NCOPIES от REPEAT встроенной функции слишком велик"
 
@@ -6037,6 +6037,7 @@
 msgstr "ключи -Xbind-now и -Xbind-lazy несовместимы"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 #, fuzzy
 #| msgid "consider using `-pg' instead of `-p' with gprof(1)"
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
@@ -9691,7 +9692,7 @@
 msgstr "Выравнивать переменные по границе 32 бит"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 #| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
@@ -10288,7 +10289,7 @@
 msgstr "Диапазон регистров с фиксированным назначением"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -11214,7 +11215,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Генерировать код в соответствии с заданным ABI"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "Допустимые ABI (возможные аргументы ключа -mabi=):"
 
@@ -11768,7 +11769,7 @@
 msgstr "Включить поддержку внутренних функций и генерацию команд PCLMUL"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -11779,12 +11780,12 @@
 msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -11797,49 +11798,51 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд MMX и SSE"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
 msgstr "Использовать call и rtc для вызовов функций и возвратов"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "результат функции не может иметь тип функции"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 #, fuzzy
 #| msgid "Known TLS dialects (for use with the -mtls-dialect= option):"
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Диалекты TLS (возможные аргументы ключа -mtls-dialect=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation"
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation"
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -12388,7 +12391,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Устаревший ключ.  Используйте -mvrsave взамен"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 #, fuzzy
 #| msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
@@ -12398,7 +12401,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -12515,7 +12518,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\tПланировать код для указанного процессора"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -12555,7 +12558,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Корректные аргументы ключа -mfloat-gprs=:"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -12659,27 +12662,27 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Использовать vector/scalar (VSX) инструкции"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Генерировать команды множественного чтения/записи"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12699,21 +12702,21 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 #, fuzzy
 #| msgid "Use pattern compare instructions"
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Использовать инструкции сравнения шаблонов"
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector instructions added in ISA 3.0."
@@ -12731,17 +12734,17 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 #, fuzzy
 #| msgid "Enable min/max instructions"
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Включить инструкции min/max"
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12751,19 +12754,19 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "Использовать инструкции десятичных плавающих"
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Использовать инструкции десятичных плавающих"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12773,7 +12776,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Возвращать короткие агрегатные значения в регистрах"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 #| msgid "Valid arguments to -mfloat-gprs=:"
 msgid "Valid arguments to -mstack-protector-guard=:"
@@ -12816,14 +12819,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Вызывать mcount для профилирования перед прологом функции"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "Использовать соглашения о вызовах для ABI"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -13701,7 +13703,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Избегать перекрытия целевых и адресных регистров в LDRD инструкциях"
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "Включить невыровненные словные и полусловные обращения к упакованным данным."
 
@@ -13964,14 +13966,28 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "Ключ %<-mfused-madd%> устарел; используйте %<-ffp-contract=%>."
 
-#: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:338
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare without loops."
+msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле"
+
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare with loops."
+msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле"
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop"
+msgid "Max number of pairs of load insns for compare."
+msgstr "Максимальный коэффициент раскатки цикла"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
@@ -13984,10 +14000,49 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "ключ %<-mcpu=%> устарел; используйте %<-mtune=%> или %<-march=%>"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tВывод traceback-таблицы: full (полная), part (частичная), no (не выводить таблицу)"
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\tЗадать размер long double (64 или 128 бит)"
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+#| msgid "%qE is deprecated"
+msgid "%qs is deprecated"
+msgstr "имя %qE будет исключено в будущих версиях"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Использовать соглашения о вызовах для ABI"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Метод обработки sdata"
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Битовый размер смещений для непосредственных TLS"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -15434,120 +15489,186 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Разрешить использование команд SETLB и Lcc"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "Генерировать код для прямого (big endian) порядка байт"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "Генерировать код для обратного (little endian) порядка байт"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "Планировать код перед распределением регистров"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "Планировать код перед распределением регистров"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
 #, fuzzy
+#| msgid "Align code and data to 32 bits"
+msgid "Align function entry to 4 byte."
+msgstr "Выравнивать код и данные по границе 32 бит"
+
+#: config/nds32/nds32.opt:91
+#, fuzzy
 #| msgid "enable conditional move instruction usage."
 msgid "Generate conditional move instructions."
 msgstr "включить использование инструкции условного перемещения."
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate performance extension instructions."
 msgstr "Генерировать битовые инструкции"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate performance extension version 2 instructions."
 msgstr "Генерировать битовые инструкции"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate string extension instructions."
 msgstr "Генерировать битовые инструкции"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Генерировать команды isel"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate 16-bit instructions."
 msgstr "Генерировать битовые инструкции"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
 msgstr "Включить поддержку многоядерности"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 #, fuzzy
 #| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known arch types (for use with the -march= option):"
 msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 #, fuzzy
 #| msgid "Known code models (for use with the -mcmodel= option):"
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "Известные модели кода (значения ключа -mcmodel= ):"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Select code model"
 msgid "Specify the cpu for pipeline model."
 msgstr "Выбрать модель кода"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 #, fuzzy
 #| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
 #, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "Известные плавающие ABIs (для использования с -mfloat-abi= опцией):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
+#, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "Предупреждать о классах, в которых все конструкторы и деструкторы private"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "Генерировать команды isel"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Генерировать код для плавающей арифметики используя заданный набор команд"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "Использовать команды плавающей арифметики формата paired-single (над парами значений одинарной точности)"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "Генерировать код с использованием плавающих инструкций 68881"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -16700,14 +16821,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Генерировать команды множественного чтения/записи"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-#| msgid "%qE is deprecated"
-msgid "%qs is deprecated"
-msgstr "имя %qE будет исключено в будущих версиях"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate fused multiply/add instructions"
@@ -19767,8 +19880,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "вычисленное значение не используется"
@@ -19794,7 +19907,7 @@
 msgstr "ожидался булевый тип"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20236,7 +20349,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "атрибут %qE конфликтует с атрибутом %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -20264,13 +20377,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "атрибут %qE проигнорирован"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -20319,9 +20432,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -20335,8 +20448,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "отсутствует %<=%> (после атрибута %<getter%>) перед %qE"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -20473,83 +20586,79 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "слишком мало аргументов в вызове функции %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid argument to %qD"
 msgstr "некорректное использование %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument to %qD"
@@ -20557,73 +20666,73 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "оба аргумента %<__builtin___clear_cache%> должны быть указателями"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "сгенерирован трамплин для вложенной функции %qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "семантика %qD изменилась в GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "некорректный аргумент модели памяти в вызове встроенной функции"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "модель памяти для случая отказа не может быть сильнее, чем для случая успеха в вызове %<__atomic_compare_exchange%>"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "задан некорректный аргумент модели памяти для случая отказа в вызове %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "недопустимая модель памяти в вызове %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "недопустимая модель памяти в вызове %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "неконстантный аргумент 1 в вызове __atomic_always_lock_free"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "нецелочисленный аргумент 1 в вызове __atomic_is_lock_free"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return не поддерживается для этой платформы"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -20631,7 +20740,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack ()%>"
@@ -20638,12 +20747,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "второй аргумент %<__builtin_longjmp%> должен быть 1"
@@ -20650,66 +20759,66 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "целевой формат не поддерживает бесконечные значения"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "целевой формат не поддерживает бесконечные значения"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> в функции с фиксированным числом аргументов"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "неверное число аргументов в вызове функции %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "неверное число аргументов в вызове функции %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "второй аргумент %<va_start%> не является последним явным аргументом"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "неопределенное поведение, т.к. второй параметр %<va_start%> продекларирован с классом памяти %<register%>"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kпервый аргумент %D должен быть указателем, второй - целой константой"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kпоследний аргумент %D не является целой константой от 0 до 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kпопытка освобождения объекта %qD, не находящегося в динамической памяти"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kпопытка освобождения объекта, не находящегося в динамической памяти"
@@ -21931,39 +22040,39 @@
 msgid "conversion to incomplete type"
 msgstr "преобразование к неполному типу"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert between vector values of different size"
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "невозможно преобразовать векторное значение в векторное значение другого размера"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "агрегатное значение вместо ожидаемого целого"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "указатель вместо ожидаемого комплексного значения"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "агрегатное значение вместо ожидаемого комплексного"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert between vector values of different size"
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "невозможно преобразовать векторное значение в векторное значение другого размера"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "невозможно преобразовать значение в вектор"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "агрегатное значение использовано вместо ожидаемого значения с фиксированной точкой"
@@ -22122,12 +22231,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "множественные программы индивидуальности для EH поддерживаются только если ассемблер поддерживает директиву .cfi_personality"
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) найден в расположении переменной"
@@ -22237,12 +22346,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом error: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом warning: %s"
@@ -22258,12 +22367,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "размер кадра %wd байт больше чем %wd байт"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "ошибка открытия дамп-файла прохода final %qs: %m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "ошибка закрытия дамп-файла прохода final %qs: %m"
@@ -22273,42 +22382,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "большая константа с фиксированной точкой неявно урезана к типу с фиксированной точкой"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "предполагается что при упрощении проверки диапазона не произошло переполнение"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "результат сравнения - всегда %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<или%> от двух сравнений на неравенство с разными величинами - всегда 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<или%> от двух взаимно исключающих сравнений на равенство - всегда 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "предполагается что при редукции константы в сравнении не произошло переполнение"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "предполагается, что при комбинировании констант вокруг сравнения не произошло переполнение"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "проверка fold: исходное дерево изменено функцией fold"
@@ -22866,29 +22975,29 @@
 msgid "can%'t write PCH file"
 msgstr "ошибка записи PCH файла"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qD source argument is the same as destination"
 msgstr "аргумент атрибута cleanup - не функция"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -22904,12 +23013,13 @@
 msgid "null pointer dereference"
 msgstr "нулевой указатель"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "объявлено здесь"
@@ -23463,10 +23573,10 @@
 msgstr "индекс массива вне диапазона границ массива"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -23499,7 +23609,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 #, fuzzy
 #| msgid "cleanup argument not a function"
 msgid "%G%qD source argument is the same as destination"
@@ -23864,129 +23974,129 @@
 msgid "function cannot be instrumented"
 msgstr "%qs функция не может иметь аргументы"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "инициализатор задан для невиртуального метода %q+D"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, fuzzy, gcc-internal-format
 #| msgid "virtual function %q+D"
 msgid "virtual method %qD"
 msgstr "виртуальная функция %q+D"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "a different type is defined in another translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in binary expression"
 msgid "the incompatible type defined in another translation unit"
 msgstr "несовместимые типы в бинарном выражении"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type name %qs should match type name %qs"
 msgstr "тип %qT не является производным от %qT"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in send"
 msgid "the incompatible type is defined here"
 msgstr "несовместимые типы в send"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
@@ -23993,7 +24103,7 @@
 msgstr "Ссылка на массив выходит за границы"
 
 #
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "return value type mismatch"
@@ -24000,134 +24110,139 @@
 msgstr "несоответствие типа инициализатора поля"
 
 #
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "implicit this pointer type mismatch"
 msgstr "несоответствие типа инициализатора поля"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type mismatch in nontype parameter pack"
 msgid "type mismatch in parameter %i"
 msgstr "несоответствие типов в нетиповом parameter pack"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "different parameter types"
 msgid "types have different parameter counts"
 msgstr "разные типы параметров"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type %qT should match type %qT"
 msgstr "тип %qT не является производным от %qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "has different return value in another translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "has different parameters in another translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "a field with different name is defined in another translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "fields have different layout in another translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -24149,7 +24264,7 @@
 msgid "the extra base is defined here"
 msgstr "метка %qD определена здесь"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -24157,7 +24272,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24165,7 +24280,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -24173,7 +24288,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -24181,7 +24296,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24189,7 +24304,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24490,33 +24605,39 @@
 #: multiple_target.c:91
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "атрибут версии не строка"
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "атрибут версии не строка"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be copied because it receives a non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "функция %q+F не может быть скопирована, поскольку имеют нелокальные переходы в эту функцию"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses %qD"
 msgid "default target was not set"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
+#: multiple_target.c:379
+#, fuzzy, gcc-internal-format
+#| msgid "missing %<=%> (after %<getter%> attribute)"
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -24848,13 +24969,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "некорректный аргумент ключа %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "допустимые аргументы %qs: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "допустимые аргументы %qs: %s"
@@ -25488,22 +25609,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "выходной операнд %d должен содержать ограничитель %<&%>"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Некорректный next_regno для пустого списка (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: цикл в списке номеров регистров (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: : [%u] Некорректный oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Непустой регистр в списке (%s %u %i)"
@@ -25547,7 +25668,7 @@
 msgstr "регистр %qD назначен для нескольких глобальных регистровых переменных"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "конфликтует с %qD"
@@ -25791,7 +25912,7 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "переименование %D после ссылки в ассемблерном коде"
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
@@ -25798,163 +25919,163 @@
 msgstr "функция возвращает функцию"
 
 #
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 #| msgid "array is not addressable"
 msgid "variable symbol is not variable"
 msgstr "массив неадресуем"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, fuzzy, gcc-internal-format
 #| msgid "node has wrong clone list"
 msgid "node has unknown type"
 msgstr "узел имеет некорректный список клонов"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "не найден узел в cgraph_hash"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 #| msgid "double linked list of clones corrupted"
 msgid "double linked list of assembler names corrupted"
 msgstr "испорчен двусвязный список клонов"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used before its definition"
 msgid "node has body_removed but is definition"
 msgstr "%qD использована до своего определения"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "node is in clone list but it is not clone"
 msgid "node is analyzed but it is not a definition"
 msgstr "узел в списке клонов, но не является клоном"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "node is in clone list but it is not clone"
 msgid "node is alias but not definition"
 msgstr "узел в списке клонов, но не является клоном"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, fuzzy, gcc-internal-format
 #| msgid "node is in clone list but it is not clone"
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "узел в списке клонов, но не является клоном"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, fuzzy, gcc-internal-format
 #| msgid "same_comdat_group is not a circular list"
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group не является циклическим списком"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "только один узел в comdat группе"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group не является циклическим списком"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, fuzzy, gcc-internal-format
 #| msgid "node is alone in a comdat group"
 msgid "Both section and comdat group is set"
 msgstr "только один узел в comdat группе"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "процедура verify_ssa выявила ошибки"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "функция %q+D является частью цикла алиасов"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "переменная %q+D входит в цикл алиасов"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -27158,12 +27279,12 @@
 msgid "control reaches end of non-void function"
 msgstr "управление достигает конца не-void функции"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "результат функции, декларированной с атрибутом warn_unused_result, игнорируется"
@@ -27680,7 +27801,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "векторная операция перемешивания будет выполнена по частям"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -27725,95 +27846,95 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "массивы функций не имеют осмысленной интерпретации"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "результат функции не может иметь тип функции"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "дерево: %s, имеется %s в %s, на %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "дерево: не ожидалось ничего из %s, обнаружено %s в %s, на %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "дерево: ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "дерево: не ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "дерево: ожидалось omp_clause %s, обнаружено %s в %s, на %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "дерево: ожидалось дерево, содержащее структуру %qs, обнаружено %qs в %s, на %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "дерево: доступ к элементу %d вектора tree_vec с %d элементами в %s, на %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "дерево: доступ к элементу %d вектора tree_vec с %d элементами в %s, на %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции %s с %d операндами в %s, в %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции omp_clause %s с %d операндами в %s, в %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE устаревшее: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "имя %qE будет исключено в будущих версиях"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE устаревшее: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "имя %qE будет исключено в будущих версиях"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "поддержка данного типа будет исключена в будущих версиях: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "поддержка данного типа будет исключена в будущих версиях"
@@ -27838,246 +27959,246 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not compatible with %qD"
 msgid "type is not compatible with its variant"
 msgstr "%qD не совместим с %qD"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "Main variant is not defined"
 msgstr "переменная окружения %qs не определена"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "размер массива %qE имеет не целочисленный тип"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "поле %qE имеет неполный тип"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -28103,12 +28224,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "Испорчен профиль значений: общий счётчик профиля %s (%d из %d) не соответствует счетчику блока (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "лимит памяти для отслеживания переменных превышен с -fvar-tracking-assignments, повторная попытка без этого ключа"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "лимит памяти для отслеживания переменных превышен"
@@ -29028,7 +29149,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "адрес %qD всегда будет иметь значение %<истина%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "присваивание, используемое как логическое выражение, рекомендуется "
@@ -29290,7 +29411,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "индекс %E обозначает смещение, превышающее размер %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "размер массива слишком велик"
@@ -29913,7 +30034,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "в %<#pragma omp atomic capture%> используются две различные переменные для памяти"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "некорректный тип итерационной переменной %qE"
@@ -29929,22 +30050,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE не инициализирован"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "отсутствует управляющий предикат"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный управляющий предикат"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "отсутствует инкрементальное выражение"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "некорректное инкрементальное выражение"
@@ -30503,8 +30624,8 @@
 msgid "wrong type argument to %s"
 msgstr "неверный аргумент типа для %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "переполнение при вычислении константного выражения"
@@ -31162,7 +31283,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "сравнение между типами %qT и %qT"
@@ -31248,7 +31369,7 @@
 msgstr[1] "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 msgstr[2] "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -31389,47 +31510,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s имеет некорректную кремниевую версию"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops устарело, используйте -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps устаревший ключ, используйте -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions устаревший ключ, используйте -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-loops=%d не между 0 и %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d не между 0 и 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> в настоящее время поддерживается только на GNU/Linux"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
@@ -31457,31 +31578,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "некорректный ключ -mdebug-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "неизвестный ключ -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "опция -msingle-float эквивалентна -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "опция -msimple-fpu игнорируется"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
@@ -31996,8 +32117,8 @@
 msgstr "attribute(target(\"%s\")) неизвестен"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -32080,8 +32201,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "некорректное значение %qs для -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32200,11 +32321,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32214,120 +32335,110 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE атрибут применим только к функциям"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "неверный аргумент для %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6556
-#, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea следует использовать с -mmulticore"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "symbol used as immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "символ использован как непосредственный операнд"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 #| msgid "Bad address, not register:"
 msgid "insn addresses not freed"
 msgstr "некорректный адрес, не register:"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
@@ -32334,25 +32445,25 @@
 msgstr "атрибут %qE допустим только для 32 бит"
 
 #
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute is missing"
 msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "аргументом атрибута %qE должна быть целая константа"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "атрибут %qE допустим только для функций"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
@@ -32359,15 +32470,15 @@
 msgstr "атрибут %qE допустим только для функций"
 
 #
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute ignored"
 msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE атрибут применим только к переменным"
@@ -32394,154 +32505,154 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор должен быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "аргумент атрибута %qE должен быть между 0 и 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33388,12 +33499,12 @@
 msgid "invalid IACC argument"
 msgstr "некорректный IACC аргумент"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "для %qs требуется константный аргумент"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "константный аргумент для %qs вне диапазона"
@@ -33502,18 +33613,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "невозможно установить позицию в PCH файле: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 #| msgid "-Werror=%s: no option -%s"
 msgid "wrong argument %qs to option %qs"
 msgstr "-Werror=%s: ключа -%s не существует"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33520,48 +33631,48 @@
 msgstr "не задано имя регистра для %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for function %qE"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "выравнивание задано для функции %qE"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "too many size ranges specified in option %qs"
 msgstr "некорректный диапазон %s для ключа %s"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Неизвестная функция списка аргументов в %L"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-битный ABI в режиме ESA/390 не поддерживается"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s устарело; используйте вместо этого соответственно %stune=k8%s или %stune=generic%s"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -33568,554 +33679,536 @@
 msgstr "%stune=x86-64%s устарело; используйте вместо этого соответственно %stune=k8%s или %stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "%<__int128%> не поддерживается этой целевой платформой"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кода %s не поддерживает PIC режим"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel не поддерживается в этой конфигурации"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битный режим не компилируется в"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "заданный процессор не поддерживает набор команд x86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не поддерживает %s"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "некорректное значение (%s) для ключа -march"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "некорректное значение (%s) для %sarch=%s %s"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "некорректное значение (%s) для ключа -mtune="
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "некорректное значение (%s) для %stune=%s %s"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "допустимые аргументы %qs: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d не между 0 и %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary не поддерживается для этой целевой платформы"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d не между %d и 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s используется без SSE включения"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s используется без SSE включения"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry не поддерживается для 32 бит в комбинации с -fpic"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "неизвестная опция для -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "неверный ключ препроцессора %qs"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
-
-#: config/i386/i386.c:4951
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
-
-#: config/i386/i386.c:4961
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") уже было задано"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "инструкции с 2-байтным кодом операции не допускаются в 64-битном VLIW режиме"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Использовать защиту стека для каждой функции"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE используется не для метода класса"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qT с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не поддерживает мультибиблиотеку"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue несовместим с вложенной функцией"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE векторный аргумент без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "результат - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "возврат вектора MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом flexible array изменен в GCC 4.4"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI для передачи объединения с long double изменен в GCC 4.4"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE регистровый возврат с выключенным SSE"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE регистровый аргумент с выключенным SSE"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 регистровый возврат с выключенным x87"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert: %s совместима по присваиванию с %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "атрибут ms_hook_prologue несовместим с -mfentry для 32 бит"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack не поддерживает fastcall с вложенной функцией"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register  parameters for a nested function"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -34123,254 +34216,254 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "расширенные регистры не имеют верхних половин"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 #| msgid "non-integer operand used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "нецелый операнд использован с кодом операнда '%c'"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
 #
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "статическая компоновка не поддерживается"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Аргумент для -ffpe-trap некорректен: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "последний аргумент должен быть 2-битным непосредственным"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "пятый аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "третий аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "следующий за последним аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "аргумент должен быть константой"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "некорректная инструкция:"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "недопустимое разделение узлов дерева"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE требует неизвестную isa опцию"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE требует isa опцию %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "последний аргумент должен быть непосредственным"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "последний аргумент должен быть степенью 1, 2, 4, 8"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "последний аргумент должен быть степенью 1, 2, 4, 8"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "некорректная инструкция:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
@@ -34377,86 +34470,86 @@
 msgstr "аргументом атрибута %qE должна быть строковая константа"
 
 #
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Аргумент по значению в %L не допускается в этом контексте"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown IRA algorithm %qs"
 msgid "unknown asm flag output %qs"
 msgstr "неизвестный алгоритм раскраски %qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for asm flag output"
 msgstr "некорректный тип для make функции"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "unknown architecture specific memory model"
 msgstr "неизвестная архитектура '%s'"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподдерживаемая комбинация: %s"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported return type %qT for simd"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -34684,7 +34777,7 @@
 msgstr "interrupt_thread доступен только на fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "выражение для границы стека не поддерживается"
@@ -35244,9 +35337,39 @@
 msgid "constant argument out of range for %s"
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "эта встроенная функция доступна только на fr450"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "эта встроенная функция доступна только на fr450"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "nested functions not supported on this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "вложенные функции не поддерживаются для этой платформы"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
 #| msgid "Generate bit instructions"
+msgid "don't support performance extension instructions"
+msgstr "Генерировать битовые инструкции"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate bit instructions"
+msgid "don't support performance extension version 2 instructions"
+msgstr "Генерировать битовые инструкции"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
+#| msgid "Generate bit instructions"
 msgid "don't support string extension instructions"
 msgstr "Генерировать битовые инструкции"
 
@@ -35269,11 +35392,11 @@
 msgstr "несколько атрибутов прерываний не допускаются"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35280,37 +35403,55 @@
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "некорректный регистр в инструкции"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+#| msgid "invalid register in the instruction"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "некорректный регистр в инструкции"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "некорректный тип итерационной переменной %qE"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "некорректный аргумент атрибута %qs"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "некорректный аргумент атрибута %qs"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "некорректный аргумент атрибута %qs"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "Disable position-independent code (PIC) for use in OS kernel code"
 msgid "position-independent code not supported"
@@ -35544,39 +35685,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "атрибут %qE для типов игнорируется"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "атрибут __BELOW100__ не допускается для класса памяти auto"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -35670,12 +35811,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "мусор в конце #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -35729,7 +35870,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert принимает только 3 аргумента"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -36046,7 +36187,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, возвращенный по ссылке: нестандартное расширение ABI без гарантий совместимости"
@@ -36056,7 +36197,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "возврат значения в векторном регистре невозможен, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
@@ -36067,13 +36208,13 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "передача аргумента в векторном регистре невозможна, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, переданный по ссылке: нестандартное расширение ABI без гарантий совместимости"
@@ -36083,30 +36224,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "внутренняя ошибка: встроенная функция %s уже обработана"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36128,13 +36269,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s игнорируется в 64-битном режиме"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36160,58 +36301,58 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs некорректный аргумент для -mcpu="
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 должен быть 4-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 должен быть 2-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент 1 должен быть отображением"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "число должно быть 0 или 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "аргумент %d от %qE должен быть в диапазоне %d...%d"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешенная перегрузка Altivec builtin %qF"
@@ -36348,7 +36489,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "внутренняя ошибка: встроенная функция %s, аргумент %d имел неожиданный тип аргумента %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "кадр стека слишком велик"
@@ -36359,13 +36500,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target для этой машины не поддерживается"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
@@ -36375,22 +36516,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Вы не можете брать адрес вложенной функции, если Вы используете опцию -mno-pointers-to-nested-functions."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
@@ -36400,7 +36541,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "использование %<long%> в типах AltiVec некорректно для 64-битного кода без -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
@@ -36870,22 +37011,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "неизвестное значение %s для ключа -mfpu"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -36957,34 +37098,40 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s принимает только 1 аргумент"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s принимает только 1 аргумент"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s принимает только 1 аргумент"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mvsx option"
+msgid "builtin %qs requires builtin %qs"
+msgstr "Встроенная функция %s требует опцию -mvsx"
+
+#: config/rs6000/rs6000-c.c:7058
+#, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "ifunc в данной конфигурации не поддерживается"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -37125,49 +37272,49 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Устаревший ключ. Игнорируется."
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "возврат значения в векторном регистре невозможен, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "передача аргумента в векторном регистре невозможна, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s already processed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "внутренняя ошибка: встроенная функция %s уже обработана"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer type"
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 __builtin_spe_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s игнорируется в 64-битном режиме"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -37174,7 +37321,7 @@
 msgstr "%s принимает только 1 аргумент"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37181,143 +37328,143 @@
 msgstr "%qs некорректный аргумент для -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs некорректный аргумент для -mcpu="
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "second argument to %qs must be 0..12"
 msgstr "аргумент 1 должен быть отображением"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "third argument to %qs must be 0..12"
 msgstr "аргумент 1 должен быть отображением"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d of %qE must be a pointer type"
 msgid "argument 1 of %s must be a constant"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s is only valid for the cell processor"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "Встроенная функция %s допустима только для процессора cell"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "builtin function %qs requires the %qs option"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s is not supported with the current options"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "Встроенная функция %s не поддерживается с текущими опциями"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "внутренняя ошибка: встроенная функция %s имела неожиданный тип результата %s"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "внутренняя ошибка: встроенная функция %s, аргумент %d имел неожиданный тип аргумента %s"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 3 register parameters"
 msgid "%qs uses register r29"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 #| msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Вы не можете брать адрес вложенной функции, если Вы используете опцию -mno-pointers-to-nested-functions."
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "использование %<long%> в типах AltiVec некорректно для 64-битного кода без -mvsx"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "использование %<long long%> в типах AltiVec некорректно без -mvsx"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "использование %<double%> в типах AltiVec некорректно без -mvsx"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "некорректный процессор \"%s\" для %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s не допускается"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s некорректно"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38146,7 +38293,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "использование пустого (void) значения"
@@ -38399,7 +38546,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларация %q+D перекрывает параметр"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларация %qD перекрывает глобальную декларацию"
@@ -38409,7 +38556,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "декларация %qD перекрывает декларированную ранее локальную переменную"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "перекрытая декларация находится здесь"
@@ -38473,7 +38620,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "сообщение о каждом неописанном идентификаторе выдается один раз в каждой функции, где он встречается"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ссылка на метку %qE вне функции"
@@ -38503,7 +38650,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "повторная декларация метки %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "дублирование метки %qD"
@@ -38622,7 +38769,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> не допускается нигде кроме прототипа функции"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -38880,7 +39027,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "класс хранения задан для неименованного параметра"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "класс хранения задан для имени типа"
@@ -39045,7 +39192,7 @@
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
@@ -39175,7 +39322,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "элемент структуры или объединения не может иметь переменно модифицируемый тип"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "переменная или поле %qE объявлено void"
@@ -39355,7 +39502,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "определение типа в выражении %qs некорректно в C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
@@ -39405,7 +39552,7 @@
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "регулируемый элемент-массив в объединении"
@@ -39443,7 +39590,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "повторная декларация %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "заданный режим слишком мал для значений перечислимого типа"
@@ -39473,7 +39620,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline функция %qD с атрибутом noinline"
@@ -39504,7 +39651,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD использована без прототипа, до её определению"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %qD"
@@ -39619,12 +39766,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметру %qD присвоено значение, но он не использован"
@@ -39690,7 +39837,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
@@ -39844,38 +39991,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "величина сдвига влево больше или равна ширине данного типа"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "величина сдвига вправо больше или равна ширине данного типа"
@@ -39909,7 +40056,7 @@
 msgid "to match this %qs"
 msgstr "%J  другой тип здесь"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -39951,7 +40098,7 @@
 msgstr "неизвестное имя типа %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
@@ -39967,7 +40114,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидалось %<;%>, идентификатор или %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префиксные атрибуты для методов игнорируются"
@@ -39982,8 +40129,8 @@
 msgid "unexpected attribute"
 msgstr "неожиданный атрибут"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -40026,7 +40173,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "ожидалось %<,%> или %<;%>"
@@ -40054,7 +40201,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 не поддерживает %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "ожидался строковый литерал"
@@ -40122,13 +40269,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "запятая в конце списка значений перечислимого типа"
@@ -40258,7 +40405,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "ожидалось %<}%> перед %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> без предшествующего %<if%>"
@@ -40293,22 +40440,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "ожидался оператор"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<else%>"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "используйте фигурные скобки во избежание неоднозначной трактовки %<else%>"
@@ -40328,12 +40475,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "некорректная переменная-итератор в быстром перечислении"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -40360,12 +40507,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -40675,7 +40822,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "операнды %<__builtin_complex%> имеют разные типы"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "неверное число аргументов в вызове аргументов в вызове %<__builtin_shuffle%>"
@@ -40736,79 +40883,79 @@
 msgid "no type or storage class may be specified here,"
 msgstr "в этом месте не может указываться ни тип, ни класс хранения,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "атрибут %<setter%> может быть задан только один раз"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "имя setter должно заканчиваться %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "атрибут %<getter%> может быть задан только один раз"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC option%> не является строковым литералом"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression before %s'%c'"
 msgid "expected integer expression before ')'"
@@ -40825,59 +40972,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "ожидалось %<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -40900,95 +41047,95 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%<priority%> value must be non-negative"
 msgstr "'%s' в %L должен быть неотрицательным"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "ожидалось %<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
 msgstr "ожидалось %<class%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "слишком много аргументов"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute"
 msgid "unexpected argument"
 msgstr "неожиданный атрибут"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qE не целая константа"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> или %<max%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "в декларации заданы спецификаторы %<long%> и %<void%>"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<runtime%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<auto%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный тип планирования"
@@ -40999,13 +41146,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
@@ -41029,19 +41176,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "некорректный тип планирования"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "некорректная маска"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -41053,34 +41200,34 @@
 msgid "invalid proc_bind kind"
 msgstr "некорректный тип планирования"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным для %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs следует использовать вместе с %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "array section in %<#pragma acc declare%>"
@@ -41087,19 +41234,19 @@
 msgstr "Секция массива в '%s' вызове в %L"
 
 #
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "некорректное использование %<--%> на булевой переменной %qD"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "invalid OpenACC clause at file scope"
 msgstr "некорректный тип в декларации"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
@@ -41106,24 +41253,24 @@
 msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
 
 #
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<--%> на булевой переменной %qD"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%> before %<#pragma%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ожидалось %<@end%> перед %<#pragma%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -41140,7 +41287,7 @@
 msgid "expected function name"
 msgstr "ожидалась функция"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -41152,46 +41299,46 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
@@ -41202,22 +41349,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация итерации или инициализация"
@@ -41227,76 +41374,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "недостаточно аккуратно вложенные циклы"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "сливаемые циклы не являются идеально вложенными"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>, как единственный параметры не может содержать квалификаторы"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> before %qE"
 msgid "expected %<for%> after %qs"
 msgstr "ожидалось %<;%> перед %qE"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "ожидалось %<using%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41317,34 +41464,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "ожидалось %<try%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "ожидалось %<decltype%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -41405,48 +41552,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE объявлена %<threadprivate%> после первого использования"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE имеет неполный тип"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без включения транзакционной памяти"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "внешний %<__transaction_cancel%> не внутри внешнего %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  либо %<transaction_may_cancel_outer%> функция"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не внутри %<__transaction_atomic%>"
@@ -41463,7 +41610,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD имеет неполный тип"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неправильное использование void-выражения"
@@ -41589,7 +41736,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексируемый объект не является ни массивом, ни указателем, ни вектором"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс массива не является целым значением"
@@ -41614,7 +41761,7 @@
 msgid "enum constant defined here"
 msgstr "константа перечислимого типа определена здесь"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -41720,18 +41867,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "неявная конверсия из %qT в %qT при передаче аргумента функции"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "сравнение со строковым литералом приводит к неопределенному поведению"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "сравнение указателя и целого"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -41757,7 +41904,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -42002,7 +42149,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведение к типу указателя от целого другого размера"
@@ -42159,7 +42306,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
@@ -42232,7 +42379,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "некорректное использование массива, не являющегося левой частью присваивания"
@@ -42308,12 +42455,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "в традиционном C инициализация автоматических агрегатных переменных запрещена"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "инициализация регулируемого элемента-массива"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "инициализация символьного массива строкой широких символов"
@@ -42359,7 +42506,7 @@
 msgid "invalid initializer"
 msgstr "неверный инициализатор"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
@@ -42374,7 +42521,7 @@
 msgid "braces around scalar initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "инициализация элемента регулируемого элемента-массива во вложенном контексте"
@@ -42505,7 +42652,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
@@ -42546,7 +42693,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case-метка не является целочисленным константным выражением"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-метка вне оператора switch"
@@ -42556,17 +42703,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "метка %<default%> вне оператора switch"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "оператор continue вне цикла"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "оператор break использован с OpenMP для цикла"
@@ -42593,23 +42740,23 @@
 msgid "expression statement has incomplete type"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "сравнение векторов с разными типами элементов"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "сравнение векторов с разным числом элементов"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 #| msgid "could not find interface for class %qE"
 msgid "could not find an integer type of the same size as %qT"
 msgstr "невозможно найти интерфейс для класса %qE"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "сравнение плавающих значений при помощи == или != не надежно"
@@ -42660,7 +42807,7 @@
 msgstr "упорядоченное сравнение указателя с нулевым указателем"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
@@ -42690,12 +42837,12 @@
 msgid "used vector type where scalar is required"
 msgstr "векторный тип использован в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -42706,27 +42853,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD не является шаблонным элементом-функцией"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -42739,19 +42886,19 @@
 msgstr "слишком много конструкций %qs"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -42758,58 +42905,58 @@
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "zero length array section in %qs clause"
 msgstr "Секция массива в '%s' вызове в %L"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "используется массив переменного размера"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "for инкрементное выражение не имеет эффекта"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "При входе в процедуру копировать секции массивов в последовательный блок"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qE does not have pointer or array type"
@@ -42831,7 +42978,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE имеет недопустимый тип для %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -42842,17 +42989,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "используется массив переменного размера"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE должно быть %<threadprivate%> для %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -42867,18 +43014,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -42891,33 +43038,33 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE не является переменной в конструкции %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE не является переменной в конструкции %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -42941,64 +43088,64 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Секция массива не разрешена в '%s' вызове в %L"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -43010,32 +43157,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE является предопределенным %qs для %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -43187,7 +43334,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  нет известных преобразований для аргумента %d из %qT в %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43274,28 +43421,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "преобразование из %qT в %qT неоднозначно"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим операндом бинарного выражения"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "вызов перегруженной функции %<%D(%A)%> неоднозначен"
@@ -43302,597 +43449,597 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "указатель на элемент-функцию %E нельзя вызвать без задания объекта; рекомендуется использовать конструкцию .* или ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "не найден метод для преобразования в %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "вызов %<(%T) (%A)%> неоднозначен"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "неоднозначная перегрузка для %qs в %<%s %E%>"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "нет соответствия для %qs в %<%s %E%>"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "неверные операнды бинарной операции %s (%qT и %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "неверные операнды бинарной операции %s (%qT и %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "нет соответствия для трехместного %<operator?:%> в %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "нет соответствия для %<operator%s%> в %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "нет соответствия для %<operator[]%> в %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "нет соответствия для %qs в %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "нет соответствия для %<operator%s%> в %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "нет соответствия для %<operator%s%> в %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ запрещает опускать средний операнд выражения ?:"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 #, fuzzy
 #| msgid "conversion of scalar to vector involves truncation"
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "преобразование скаляра в вектор приводит к усечению значения"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "второй операнд условного оператора имеет тип %<void%>, но третий операнд не является ни throw-expression, ни элементом типа %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "третий операнд условного оператора имеет тип %<void%>, но второй операнд не является ни throw-expression, ни элементом типа %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "операнды для ?: имеют разные типы %qT и %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим результатом условного выражения"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs, пробуем применить префиксный оператор"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "сравнение между %q#T и %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "неразмещенная функция освобождения %q+D"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "нет соответствующей функции освобождения для %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нет подходящего operator %s%> для %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "в данном контексте"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "объявлено здесь"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "в данном контексте"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "объявлено здесь"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D недоступен"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "передача NULL в неуказательный аргумент %P в %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "преобразование в неуказательный тип %qT из NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "преобразование %<false%> в указательный тип для аргумента %P в %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "преобразование %<false%> в указательный тип %qT"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "слишком много фигурных скобок вокруг инициализатора для %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "ошибка преобразования %qT в %qT в инициализации"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid user-defined conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "некорректное определенное пользователем преобразование из %qT в %qT"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  при инициализации %P -го аргумента %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "некорректное преобразование из %qT в %qT"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "преобразование в %qT из списка инициализации будет использовать явный конструктор %qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "только декларации конструкторов могут быть %<explicit%>"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "преобразование к volatile ссылке типа %qT из rvalue типа %qT"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "некорректная инициализация неконстантной ссылки типа %qT из rvalue типа %qT"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "передача %qT как аргумент %<this%> %q#D отменяет квалификаторы"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "недопустимое связывание битового поля %qE с %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "недопустимое связывание упакованного  поля %qE с %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "неявная конверсия из %qT в %qT при передаче аргумента функции"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "невозможно передать объекты нетривиально копируемого типа %q#T через %<...%>"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "рекурсивное вычисление подразумеваемого аргумента для %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "вызов %qD использует подразумеваемый аргумент для параметра %P, который еще не определен"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент вызова функции мог быть кандидатом для атрибута формата"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted function %q+D with default argument"
 msgid "use of multiversioned function without a default"
 msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как аргумент %<this%> %q#D отменяет квалификаторы"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в вызове %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "вывод %qT как %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (вы можете отключить это посредством -fno-deduce-init-list)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "слишком много аргументов для конструктора %q#D"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD не может быть локально-поточным, поскольку имеет нетривиальный тип %qT"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "используйте директиву #include"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "; use value-initialization instead"
 msgstr "инициализация значения функционального типа %qT"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD не может быть локально-поточным, поскольку имеет нетривиальный тип %qT"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "используйте директиву #include"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Расширение: повторная инициализация '%s' в %L"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "преобразование к void не даст доступ к объекту нетривиально копируемого типа %qT"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD объявлено здесь"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "константа ссылается на себя"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  для приведения типов в функциональном стиле удалите лишние %<::%D%>"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "вызов перегруженной %<%s(%A)%> имеет неоднозначную трактовку"
 
 #
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
@@ -43899,7 +44046,7 @@
 msgstr "инициализаторы нестатических элементов данных"
 
 #
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from constructor"
@@ -43906,78 +44053,78 @@
 msgstr "инициализаторы нестатических элементов данных"
 
 #
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from destructor"
 msgstr "инициализаторы нестатических элементов данных"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "некорректный вызов элемента-функции %qD без объекта"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "при передаче %qT предпочтение отдается %qT, а не %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "предпочтение отдается %qD (а не %qD)"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  при преобразовании из %qT в %qT,"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  поскольку это дает лучшую последовательность преобразований аргумента"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "несоответствие подразумеваемого аргумента при разрешении перегрузки"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "ошибка преобразования %qE из %qT в %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "временная граница %qD сохраняется, пока существует конструктор"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "некорректная инициализация неконстантной ссылки типа %qT из rvalue типа %qT"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -44025,8 +44172,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D не может быть перегружено"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %q#D"
@@ -44072,7 +44219,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qT declared here"
@@ -44159,7 +44306,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D некорректно; анонимное объединение может иметь только нестатические элементы данных"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -44463,7 +44610,7 @@
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларировано здесь"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
@@ -44535,7 +44682,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "недостаточная информация о типе"
@@ -44641,371 +44788,371 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D не может использоваться как constexpr функция поскольку:"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E не есть константное выражение"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "внутренняя функция"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE does not designate a constexpr function"
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "выражение %qE не обозначает constexpr функцию"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-constexpr function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "вызов non-constexpr функции %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD called in a constant expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD вызвана в константном выражении"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD вызвана в константном выражении"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD использована до своего определения"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "вызов имеет циклическую зависимость"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "глубина обработки constexpr превышает максимум %d (задайте -fconstexpr-depth= чтобы увеличить максимум)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "индекс массива вне диапазона границ массива"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "индекс массива вне диапазона границ массива"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "индекс массива вне диапазона границ массива"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "индекс массива вне диапазона границ массива"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "доступ по указателю %<void *%>"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "mutable %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "обращение к элементу %qD вместо инициализированного элемента %qD в константном выражении"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "доступ по указателю %<void *%>"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "обращение к значению %qE через %qT glvalue в константном выражении"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD использована в своем собственном инициализаторе"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D не есть const"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D переменная"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD не была инициализирована константным выражением"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD не была декларирована %<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "глубина обработки constexpr превышает максимум %d (задайте -fconstexpr-depth= чтобы увеличить максимум)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неожиданное выражение %qE вида %s"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT не может быть типом полного константного выражения поскольку он имеет mutable sub-objects"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT не может быть типом полного константного выражения поскольку он имеет mutable sub-objects"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в constant-expression"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "выражение %qE имеет побочные эффекты"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression не есть константное выражение поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE не описан здесь (не в функции)"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантная инициализация массива"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45054,7 +45201,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "преобразование из %qT в %qT отменяет квалификаторы"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "преобразование %qT в %qT не снимает указатель"
@@ -45065,313 +45212,313 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "некорректное преобразование от типа %qT к типу %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "преобразование из %q#T в %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "результат преобразования не определен, поскольку %qE  вне диапазона типа %qT"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T использовано там, где ожидалось %qT"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "ошибка преобразования %qE из %qT в %qT"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T использовано там, где ожидалось плавающее значение"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "запрошено преобразование от %qT к нескалярному типу %qT"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD объявлено здесь"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "псевдо-деструктор не вызывается"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "преобразование к void не даст доступ к объекту неполного типа %qT"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT во втором операнде условного выражения"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в третьем операнде условного выражения"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в правом операнде оператора запятая"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в левом операнде оператора запятая"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в операторе"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "косвенность не даст доступ к объекту неполного типа %qT в for инкрементном выражении"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "преобразование к void не даст доступ к объекту типа %qT"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT во втором операнде условного выражения"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в третьем операнде условного выражения"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в правом операнде оператора запятая"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в левом операнде оператора запятая"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в операторе"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "неявный переход по указателю не даст доступ к объекту типа %qT в for инкрементном выражении"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "преобразование к void не даст доступ к объекту нетривиально копируемого типа %qT"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT во втором операнде условного выражения"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в третьем операнде условного выражения"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в правом операнде оператора запятая"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в левом операнде оператора запятая"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в операторе"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "косвенность не даст доступ к объекту нетривиально копируемого типа %qT в for инкрементном выражении"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "преобразование к void не даст доступ к объекту %qE неполного типа %qT"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "переменная %qE неполного типа %qT не будет доступна во втором операнде условного выражения"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "переменная %qE неполного типа %qT не будет доступна в третьем операнде условного выражения"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "переменная %qE неполного типа %qT не будет доступна в правом операнде оператора запятая"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "переменная %qE неполного типа %qT не будет доступна в левом операнде оператора запятая"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "переменная %qE неполного типа %qT не будет доступна в операторе"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "переменная %qE неполного типа %qT не будет доступна в for инкрементном выражении"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "преобразование к void не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "второй операнд условного выражения не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "третий операнд условного выражения не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "правый операнд оператора запятая не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "левый операнд оператора запятая не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "оператор не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "for инкрементное выражение не может разрешить адрес перегруженной функции"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "второй операнд условного выражения ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "третий операнд условного выражения ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "правый операнд оператора запятая ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "левый операнд оператора запятая ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "оператор ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "for инкрементное выражение ссылка, а не вызов функции %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "второй операнд условного выражения ссылка не имеет эффекта"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "третий операнд условного выражения ссылка не имеет эффекта"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "правый операнд оператора запятая не имеет эффекта"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "левый операнд оператора запятая не имеет эффекта"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "оператор не имеет эффекта"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for инкрементное выражение не имеет эффекта"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "преобразование NULL к неуказательному типу"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "  невозможно вывести параметр шаблона %qD"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "неоднозначное преобразование из типа %qT по умолчанию"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  возможные преобразования - %qD и %qD"
@@ -45415,226 +45562,226 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD продекларирован как %<extern%>, а позже как %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "декларация %qF имеет другой спецификатор исключений"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "предыдущая декларация %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "редекларация %qD отличается в %<constexpr%>"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
 msgstr "предыдущая декларация %q+#D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of friend %q#D may not have default template arguments"
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "редекларация friend %q#D не может иметь подразумеваемые аргументы шаблона"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "шаблон литерального оператора %q+D противоречит сырому литеральному оператору %qD"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "сырой литеральный оператор %q+D противоречит шаблону литерального оператора %qD"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "здесь было предыдущее определение %q+D"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "здесь была предыдущая декларация %q+D"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "внутренняя функция %q+D декларирована как не функция"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "перекрытие встроенной функции %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "перекрытие библиотечной функции %q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "библиотечная функция %q#D декларирована повторно как не функция %q#D"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "противоречит встроенной декларации %q#D"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "декларация %qD перекрывает глобальную декларацию"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration %q+#D"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "предыдущая декларация не-функции %q+#D"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "противоречит встроенной декларации %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "делает неоднозначной встроенную декларацию %#D"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "делает неоднозначной встроенную декларацию %#D"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "derived type declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "декларация производного типа"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D редекларирован как другой вид символа"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "декларация шаблона %q#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "делает неоднозначной старую декларацию %q+#D"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "old declaration %q#D"
 msgstr "глобальная декларация %q+#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "противоречивая декларация %q#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "делает неоднозначной старую декларацию %q+#D"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "противоречивая декларация %q#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration as %q#D"
 msgstr "предыдущая декларация %q+#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D ранее определено здесь"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
 msgstr "%q+#D ранее декларировано здесь"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "прототип для %q+#D"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "follows non-prototype definition here"
 msgid "previous non-prototype definition here"
 msgstr "следует непрототипное определение здесь"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "предыдущая декларация %q+#D с %qL привязкой"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "previous declaration with %qL linkage"
 msgstr "предыдущая декларация %q+#D с %qL привязкой"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "подразумеваемый аргумент задан для параметра %d %q#D"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in %q+#D"
 msgid "previous specification in %q#D here"
 msgstr "после предыдущей спецификации в %q+#D"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "избыточная повторная декларация %qD в той же области видимости"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %q+D"
@@ -45648,12 +45795,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "явная специализация %qD после первого использования"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "'setter' attribute of property %qD conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -45660,28 +45807,28 @@
 msgstr "'setter' атрибут свойства %qD конфликтует с предшествующей декларацией"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "переопределение %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD противоречит использованной функции"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D не декларировано в классе"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline с %<gnu_inline%> атрибутом"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline без %<gnu_inline%> атрибута"
@@ -45689,671 +45836,671 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "редекларация friend %q#D не может иметь подразумеваемые аргументы шаблона"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "локальная для потока декларация %q#D следует за не локальной для потока декларацией"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не локальная для потока декларация %q#D следует за локальной для потока декларацией"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "редекларация %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "избыточная повторная декларация %qD в той же области видимости"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "предыдущая декларация"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  отсюда"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  покидает OpenMP структурный блок"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  пересекает инициализацию %q+#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  входит в область действия %q+#D имеющего нетривиальный деструктор"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  входит в catch-блок"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  пропускает инициализацию %q+#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  входит в область действия %q+#D имеющего нетривиальный деструктор"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  входит в try-блок"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  входит в OpenMP структурный блок"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "некорректный выход из OpenMP структурного блока"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD не является типом"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "использование %qD без параметров шаблона"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T не является классом"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "шаблон класса с именем %q#T' отсутствует в %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нет имени типа %q#T в %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "просмотр %qT в %qT неоднозначен"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именует %q#T, который не является шаблоном класса"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> именует %q#T, который не является типом"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "параметры не подходят шаблону"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qE is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "протокол %qE устарел"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qE is deprecated"
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "протокол %qE устарел"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-falign-labels=%d не поддерживается"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с конструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с деструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с операцией присваивания-копирования недопустим в анонимном агрегатном типе"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q#T должен следовать за %qs ключевым словом"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "несколько типов в одной декларации"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторная декларация внутреннего типа C++ %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "отсутствует имя типа в typedef-декларации"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "в ISO C++ анонимные структуры запрещены"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs допустим только для функций"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs допустим только для функций"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> может быть задан только для конструкторов"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "квалификаторы могут быть заданы только для объектов и функций"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "квалификаторы могут быть заданы только для объектов и функций"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "квалификаторы могут быть заданы только для объектов и функций"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> в этой декларации отброшен"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибуты игнорируются для конкретизации шаблона"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE атрибут может применяться только к определениям классов"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "игнорирование атрибутов примененных к классу %qT вне определения"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "игнорирование атрибутов примененных к зависимому типу %qT без ассоциированной декларации"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD инициализирован (используйте decltype взамен)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларация %q#D содержит %<extern%> и инициализирована"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D не есть нестатический элемент данных %qT"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "шаблонная декларация %q#D"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "некорректная декларация элемента-шаблона %qD"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не разрешает определять %<%T::%D%> как %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "повторная инициализация %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE не описан здесь (не в функции)"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "переменная %q#D инициализирована, хотя имеет неполный тип"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегатный тип %q#D неполон и не может быть определён"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "переменная %qD декларирована как ссылка, но не инициализирована"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "имя использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривиально определенные инициализаторы не поддерживаются"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "массив %qD имеет нулевой размер"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "размер памяти %qD неизвестен"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "размер памяти %qD не константа"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: ошибочная семантика статических данных %q+#D inline-функции (запутаетесь с несколькими копиями)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: ошибочная семантика статических данных %q+#D inline-функции (запутаетесь с несколькими копиями)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  это можно обойти, удалив инициализатор"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T не имеет предоставленный пользователем подразумеваемый конструктор"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "конструктор не является предоставленным пользователем, поскольку он явно подразумевался в теле класса"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, fuzzy, gcc-internal-format
 #| msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "и неявно определенный конструктор не инициализирует %q+#D"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "некорректный тип %qT является инициализатором для вектора типа %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> использовано в определенном в GNU-стиле инициализаторе для класса %qT"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 обозначение %qE вне инициализатора агрегата"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "элементы массива %q#T имеют неполный тип"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "составной литерал переменного размера"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D имеет неполный тип"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "в инициализаторе скалярного объекта %qD должен быть только один элемент"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "в C++98 %qD следует инициализировать при помощи конструктора, а не %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "массив %qD инициализируется строковой константой %qE, заключённой в скобки"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "инициализатор недопустим для статического элемента с конструктором"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant in-class initialization invalid for static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(запрошена инициализация вне класса)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD инициализируется самим собой"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ не поддерживает назначенные инициализаторы"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "некорректное использование функции-элемента (вы забыли %<()%> ?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "объект переменного размера нельзя инициализировать"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "перекрытие предыдущей декларации %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  нельзя использовать устаревшую привязку в %q+D, потому что имеется деструктор"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "невозможно сформировать указатель на элемент не класса %q#T"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "доступ по указателю на неполный тип"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 не поддерживает массив %qE переменного размера"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -46362,7 +46509,7 @@
 msgstr[1] "%qs задано для поля структуры"
 msgstr[2] "%qs задано для поля структуры"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46370,7 +46517,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46378,920 +46525,931 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "некорректный тип итерационной переменной %qE"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "ошибка при декомпозиции адреса"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "dereferencing pointer to incomplete type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "доступ по указателю на неполный тип"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "недопустимое применение %<offsetof%> к статическому элементу данных %qD"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qT"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива в %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "нулевой размер массива %qT"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирована как %<virtual%> переменная"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации переменной"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> параметр"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> параметр"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации параметра"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> тип"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> тип"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации типа"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> поле"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> поле"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации поля"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключений"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD декларирован как не параметр"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметр %qD объявлен с типом void"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java-метод %qD имеет тип результата %qT, не поддерживаемый Java"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "определение явной специализации %qD в friend-декларации"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "некорректное использование идентификатора шаблона %qD в декларации первичного шаблона"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "специализация %qD должна появляться в пределах пространства имен"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "литеральный оператор с C-привязкой"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD имеет некорректный список аргументов"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, fuzzy, gcc-internal-format
 #| msgid "integer suffix %<%s%> shadowed by implementation"
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "целый суффикс %<%s%> затенен реализацией"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %<%s%> shadowed by implementation"
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "плавающий суффикс %<%s%> затенен реализацией"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> должна возвращать %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "определение явно подразумеваемого %q+D"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D explicitly defaulted here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D явно подразумевается здесь"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "нет элемента-функции %q#D в классе %qT"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "инициализация внутри класса статического элемента данных %q#D неполного типа"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> требуется для инициализации внутри класса статического элемента данных %q#D нецелого типа"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "инициализация внутри класса статического элемента данных %q#D нелитерального типа"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ запрещает инициализацию элемента-константы %qD нецелочисленного типа %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "размер массива %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "размер массива %qD отрицательный"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "размер массива отрицательный"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ запрещает массив переменного размера %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ запрещает массивы переменного размера"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "используется массив переменного размера %qD"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переполнение в размерности массива"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "декларация %qD как массива void"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "создание массива void"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "декларация %qD как массива функций"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "создание массива функций"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "декларация %qD как массива ссылок"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "создание массива ссылок"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "декларация %qD как массива элементов-функций"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "создание массива элементов-функций"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "в многомерном массиве должны быть определены границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в конструкторе"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "тип результата задан для %<operator %T%>"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "конфликтующие спецификаторы в декларации %qs"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "конфликтующие спецификаторы в декларации %qs"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "декларация безымянной переменной или поля с типом void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "декларация переменной или поля с типом void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T не является классом или пространством имен"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "декларация %qD как не-элемента"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "декларатор отсутствует; используется зарезервированное слово %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларация %qD как %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "декларация %qD как параметра"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> не может встречаться в typedef декларации"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> не может встречаться в typedef декларации"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или более типа в декларации имени %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "конфликтующие спецификаторы в декларации %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ запрещает декларации %qs без типа"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%> не поддерживается этой целевой платформой"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не поддерживает %<__int128%> для %qs"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> или %<unsigned%> некорректны для %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> и %<unsigned%> одновременно заданы для %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "недопустимо использовать %<long long%> для %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "недопустимо использовать %<long%> для %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "недопустимо использовать %<short%> для %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> или %<short%> некорректны для %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> или %<char%> некорректны для %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> или %<short%> заданы в описании %qs с типом char"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> и %<short%> одновременно заданы для %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> или %<long%> некорректны для %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "неверное употребление long, short, signed или unsigned в описании %s"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "спецификатор complex для %qs недопустим"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "элемент %qD не может быть декларирован как virtual и static"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "элемент %qD не может быть декларирован как virtual и static"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-декларация не допускается в декларации параметров"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "класс хранения задан для параметра шаблона %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "спецификаторы класса хранения не допускаются в декларациях параметров"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> вне декларации класса"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "индексируемый массив объявлен как %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qE declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "вложенная функция %qE объявлена %<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "имя %qs описано на верхнем уровне с классом хранения %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "класс хранения не допускается в декларации friend-функции"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs функция использует %<auto%> спецификатор типа без завершающего типа возврата"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
+#| msgid "type qualifiers ignored on function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "квалификаторы в описании типа возвращаемого значения функции "
+
+#: cp/decl.c:11156
+#, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs функция не может иметь аргументы"
 
-#: cp/decl.c:11099
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
-msgstr "квалификаторы в описании типа возвращаемого значения функции "
-
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -47298,59 +47456,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs функция с завершающим типом возврата не декларирована с %<auto%> спецификатором типа"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -47357,257 +47515,257 @@
 msgstr "конструкторы нельзя декларировать как virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "невозможно определить friend-функцию %qs в определении локального класса"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs функция не может иметь аргументы"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента-функции %<%T::%s%> внутри %<%T%>"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "невозможно декларировать элемент-функцию %<%T::%s%> внутри %<%T%>"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> вне декларации класса"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> в пустой декларации"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "только декларации конструкторов могут быть %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "ссылка %qs не может быть декларирована %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef декларирован %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "инициализация значения функционального типа %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> недопустим в данном контексте"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "нестатический элемент данных декларирован %<auto%>"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -47614,170 +47772,170 @@
 msgstr "ISO C90 не поддерживает регулируемые элементы-массивы"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация функции %qD в неверном контексте"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функция %qD объявлена виртуальной внутри объединения"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не может быть объявлена виртуальной, поскольку она всегда статическая"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для деструктора %qD"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для конструктора %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "переменная %qD повторно декларирована как функция"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "исходный тип объявлен здесь"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr статический элемент данных %qD должен иметь инициализатор"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-спецификаторы в %qs не допускаются вне определения класса"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<static%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs определен не в контексте класса"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs декларирован не в контексте класса"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
@@ -47784,59 +47942,59 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларация constexpr переменной %qD не является определением"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D не имеет инициализатора"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
 #
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
@@ -47843,23 +48001,23 @@
 msgstr "некорректное использование %<virtual%> в декларации шаблона %q#D"
 
 #
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "некорректное использование %<virtual%> в декларации шаблона %q#D"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает указатель на массив с неизвестной границей %qT"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает ссылку на массив с неизвестной границей %qT"
@@ -47879,177 +48037,177 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD должен иметь не более одного аргумента"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD должен иметь один или два аргумента"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксный %qD должен иметь аргумент типа %<int%>"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксный %qD должен иметь второй аргумент типа %<int%>"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD должен иметь ровно два аргумента"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD должен иметь ровно один аргумент"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD должен иметь ровно два аргумента"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "преобразование к ссылке на void никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "преобразование к void никогда не использует операцию преобразования типа"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к ссылке на тот же тип никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "преобразование к тому же типу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "преобразование к ссылке на базовый класс никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "преобразование к базовому классу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "использование синонима специализации шаблона %qT после %qs"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD ранее декларирован здесь"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T ранее декларирован здесь"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -48061,95 +48219,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT не является непосредственной или виртуальной базой %qT"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "рассогласование основного типа в enum %q#T"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "отличающийся основной тип в enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -48159,82 +48317,82 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "значение перечисления %qE слишком велико для основного типа %<%T%>"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "некорректная декларация функции"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "типы возвращаемых значений функции несовместимы из-за %<volatile%>"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "некорректная декларация элемента-функции"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -48276,7 +48434,7 @@
 msgid "deleting %qT is undefined"
 msgstr "удаление %qT не определено"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонная декларация %q#D"
@@ -48289,7 +48447,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD объявлен как шаблон элемента"
@@ -48406,46 +48564,46 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "ширина битового поля %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "анонимная структура не внутри именованного типа"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D некорректно; анонимное объединение может иметь только нестатические элементы данных"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "private-элемент %q+#D в анонимном объединении"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "protected-элемент %q+#D в анонимном объединении"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "анонимные агрегатные данные в области видимости пространства имён должны быть статическими"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "безымянное объединение без элементов"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> должен возвращать тип %qT"
@@ -48454,71 +48612,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "первый аргумент %<operator new%> не может иметь значение по умолчанию"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> имеет %<size_t%> (%qT) в качестве первого параметра"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> должен иметь результат типа %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> имеет первый параметр типа %qT"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT объявлен с большей областью видимости, чем тип его поля %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -48528,70 +48686,70 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "анонимный тип без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "анонимный тип без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не ссылается на неквалифицированный тип, поэтому не используется для связывания"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, декларированное посредством локального типа %qT, используется, но не определяется"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D конфликтует с предыдущей декларацией"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous mangling %q#D"
 msgstr "предыдущая декларация %q+#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (или =0) избегает этой ошибки изменением в разборке"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "inline функция %q+D использована, но нигде не определена"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "отсутствует аргумент по умолчанию для параметра %P функции %q+#D"
@@ -48598,18 +48756,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "преобразование lambda, использующей %<...%>, к указателю на функцию"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "использование удаленной функции %qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -48620,117 +48778,117 @@
 msgid "with"
 msgstr "с"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "отсутствуют аргументы"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "явные операции преобразования доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "scoped enums доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "override controls (override/final) доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "инициализаторы нестатических элементов данных доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "определенные пользователем литералы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "определенные пользователем литералы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "неполный тип %qT использован во вложенном спецификаторе имени"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "ссылка на %<%T::%D%> неоднозначна"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD не является элементом %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD не является элементом %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> не был декларирован"
@@ -48881,71 +49039,71 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(если это не то, что вы имели в виду, убедитесь, что шаблон функции уже был декларирован и добавьте <> после имени функции здесь) "
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "инициализация значения неполного типа %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "невозможно инициализировать значение массива с неизвестной границей %qT"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "инициализация значения функционального типа %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "инициализация значения ссылочного типа %qT"
 
 #
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "инициализаторы нестатических элементов данных"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "объединение определено здесь"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "initializer for flexible array member %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD следует инициализировать в списке инициализации элементов"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD инициализируется самим собой"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "неинициализированный const элемент в %q#T"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
@@ -48952,307 +49110,307 @@
 msgid "%q#D should be initialized"
 msgstr "%qD должен быть инициализирован"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "неинициализированный ссылочный элемент в %q#T"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D будет инициализирован после"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "базовый класс %qT будет инициализирован после"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  базового класса %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  если инициализирован здесь"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "повторные инициализации заданы для %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "повторные инициализации заданы для базового класса %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "инициализации для нескольких элементов %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "базовый класс %q#T должен быть явно инициализирован в копирующем конструкторе"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "в классе %qT нет поля с именем %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D есть статический элемент данных; он может быть инициализирован только при своем определении"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D не есть нестатический элемент данных %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "безымянный инициализатор для %qT, не имеющего базовых классов"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "безымянный инициализатор для %qT, имеющего множественное наследование"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD - непосредственный базовый тип, а также косвенный виртуальный базовый тип"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT не является непосредственной или виртуальной базой %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "неполный тип %qT не имеет элемента %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "некорректный указатель на битовое поле %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "некорректное использование нестатического элемента %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в %q#T использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный ссылочный элемент в %q#T использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "неинициализированный ссылочный элемент в %q#T"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный const элемент в %q#T использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "неинициализированный const элемент в %q#T использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неинициализированный const элемент в %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "переполнение при вычислении целочисленного выражения"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "variably modified type not allowed in new-expression"
 msgstr "переменно модифицированное поле на уровне файла"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "попробуйте убрать скобки вокруг идентификатора типа"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "некорректный тип %<void%> задан для new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "непроинициализированная константа в %<new%> от %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "не найдено подходящего %qD в классе %qT"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "запрос элемента %qD неоднозначен"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "в классе %qT нет поля с именем %qD"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "инициализатор со скобками в new массива"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new нельзя применять к ссылочному типу"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new нельзя применять к типу функции"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "преждевременное завершение инициализатора"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "неизвестный размер массива в операторе delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "удаление объекта абстрактного класса типа %qT, имеющего нетривиальный деструктор, вызовет неопределенное поведение"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "удаление объекта полиморфного класса типа %qT, имеющего нетривиальный деструктор, вызовет неопределенное поведение"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
@@ -49264,7 +49422,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -49349,71 +49507,71 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(с ключом %<-fpermissive%>, G++ примет данный код, но разрешение использовать недекларированные имена будет отменено в дальнейших версиях)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "разборка typeof, используйте decltype взамен"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "разборка __underlying_type"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "разборка неизвестного типа с фиксированной точкой"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "разборка %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "опущен средний операнд %<?:%> операнд не может быть разобран"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "строковый литерал в сигнатуре шаблона функции"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
@@ -49545,46 +49703,46 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D конфликтует с предыдущей декларацией"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D скрывает конструктор для %q#T"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "противоречивая декларация %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "из-за различных спецификаций исключений"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларация %q#D перекрывает параметр"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "глобальная декларация %q+#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -49593,63 +49751,63 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend декларация %qD в локальном классе без предшествующей декларации"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "поиск имени %qD изменен"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  соответствует декларации %q+D по правилам стандарта ISO"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  соответствует декларации %q+D по старым правилам"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "поиск имени %qD приведен в соответствие с правилами видимости ISO %<for%>"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  нельзя использовать устаревшую привязку в %q+D, потому что имеется деструктор"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "  используется устаревшая привязка в %q+D"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -49657,12 +49815,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "в using-декларации нельзя задавать идентификатор шаблона. Попробуйте %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "пространство имён %qD не допускается в using-декларации"
@@ -49669,107 +49827,107 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT не является пространством имён"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "в этой области видимости уже есть декларация %qD"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "отсутствует декларация %qD"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> обозначает деструктор"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> обозначает конструктор в %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "нет элементов, соответствующих %<%T::%D%>, в %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларация %qD вне пространства имён, объемлющего %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "явные квалификаторы в декларации %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE не был декларирован"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D декларировано как friend"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD следовало объявить внутри %qD"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD атрибут требует единственный NTBS аргумент"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD атрибут не имеет смысла поскольку элементы анонимного пространства имен получают локальные символы"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибут %qD игнорируется"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "максимальное число %d пространств имен просмотрено для %qE"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -49777,12 +49935,12 @@
 msgstr[1] "предлагаемые варианты:"
 msgstr[2] "предлагаемые варианты:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -49789,76 +49947,82 @@
 msgid "suggested alternative: %qs"
 msgstr "предлагаемый вариант:"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%qD is not a variable in clause %qs"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%qD не есть переменная в клаузуле %qs"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D не может быть определено %qE"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "структура определена здесь"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "ключ %qs больше не поддерживается"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "атрибуты игнорируются для неконкретизированного типа"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "использование пространства имён %qD здесь недопустимо; предполагается %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "атрибуты методов задаются только в конце"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "метка %qD определена здесь"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX вход в pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX выход из pop_everything ()\n"
@@ -49878,7 +50042,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -49903,7 +50067,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "запрос элемента %qE в неклассовом типе %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> не был декларирован"
@@ -49985,7 +50149,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "плавающий литерал не может появляться в константном выражении"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "приведение к типу, отличному от целого или перечисления, не может появляться в константном выражении"
@@ -50218,7 +50382,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "невозможно найти оператор строкового литерала %qD с аргументами %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "ожидалась декларация"
@@ -50304,7 +50468,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "область видимости %qT до %<~%> не является именем класса"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
@@ -50320,342 +50484,333 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-имя %qD использовано как декларатор деструктора"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ожидался unqualified-id"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "найдено %<:%> во вложенном спецификаторе имени, ожидалось %<::%>"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype обработано до %qT, что не является классом или перечислимым типом"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "неполный тип %qT использован во вложенном спецификаторе имени"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не является шаблоном"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "типы нельзя определять в приведении типов"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "типы нельзя определять в %<typeid%> выражении"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неверное число аргументов в вызове аргументов в вызове %<__builtin_shuffle%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неверное число аргументов в вызове %<__builtin_complex%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "в ISO C++ составные литеральные конструкции запрещены"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "некорректное использование %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> не является элементом класса"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "нескалярный тип"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ не допускает %<alignof%> с не-типом"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "типы не могут быть определены в %<noexcept%> выражениях"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "типы не могут быть определены в new-выражении"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница массива не допускается после идентификатора типа в скобках"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "попробуйте убрать скобки вокруг идентификатора типа"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Ожидался тип выражения"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "типы не могут быть определены в new-type-id"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "использование устаревшей конструкции для приведения типа"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "оператор %<>>%> трактуется в C++11 как две правые угловые скобки"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "рекомендуется окружать скобками выражение %<>>%>"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ не допускает ?: с опущенным средним операндом"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in conditions"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "типы нельзя определять в условиях"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "lambda-expression в необрабатываемом контексте"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in unevaluated context"
 msgid "lambda-expression in template-argument"
 msgstr "lambda-expression в необрабатываемом контексте"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ожидался конец capture-list"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "явное by-copy capture %<this%> избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "capture of non-variable %qD "
 msgid "capture of non-variable %qE"
 msgstr "capture непеременной %qD "
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
 msgstr "%q+#D декларировано здесь"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture переменной  %qD с неавтоматическим сроком хранения"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "явное by-copy capture %qD избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "явное by-reference capture %qD избыточно с by-reference capture умолчанием"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "задан аргумент по умолчанию для lambda-параметра"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "повторное употребление %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ожидался помеченный оператор"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-метка %qE вне оператора switch"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "требуется %<typename%> перед %qE поскольку %qT зависимый контекст"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> обозначает конструктор, а не тип"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "compound-statement in %<constexpr%> function"
 msgstr "составной оператор в constexpr функции"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 #| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидался selection-statement"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> выражение типа %qT имеет неполный тип"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "range-based %<for%> выражение типа %qT имеет %<end%> элемент без %<begin%>"
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "range-based %<for%> выражение типа %qT имеет %<begin%> элемент без %<end%>"
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "противоречивые begin/end типы в range-based %<for%> операторе: %qT и %qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидался iteration-statement"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
@@ -50662,204 +50817,204 @@
 msgstr "составной оператор в constexpr функции"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор перехода"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "избыточная %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> не в начале блока"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "смешивание деклараций и определений функций запрещено"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration"
 msgid "empty structured binding declaration"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "некорректный инициализатор для элемента-функции %qD"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> использовано вне класса"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> меняет смысл в C++11; пожалуйста удалите его"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D некорректно в %q#T"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "определение класса не должно содержать friend"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "некорректная linkage-specification"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "типы нельзя определять в %<decltype%> выражениях"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "типы не могут быть определены в new-type-id"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "только конструкторы берут инициализаторы элементов"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "невозможно расширить инициализатор для элемента %<%D%>"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "устаревший стиль инициализатора базового класса"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (инициализатор квалифицированного элемента неявно является типом)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "отсутствует пробел между %<\"\"%> и суффикс-идентификатором"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ожидался суффикс-идентификатор"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "ожидалась пустая строка после ключевого слова %<operator%>"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неверные операнды тернарной операции"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "ожидался оператор"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
@@ -50866,371 +51021,371 @@
 msgstr "некорректный нетиповый параметр шаблона"
 
 #
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "некорректный catch параметр"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template template parameter %qT"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "некорректное использование шаблона параметра шаблона %qT"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "pack параметр шаблона %qD не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "pack параметры шаблона не могут иметь аргументы по умолчанию"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "ожидался template-id"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "список аргументов шаблона не должен начинаться с %<<::%>"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> - альтернативное написание %<[%>. Вставьте пробел между %<<%> и %<::%>"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(если вы используете %<-fpermissive%> G++ примет ваш код)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "ошибка разбора в списке аргументов шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "ожидалось template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "используйте нотацию %<%T::template %D%> для указания о том, что это шаблон"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ожидался pack параметр перед %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "явная конкретизация не должна использовать %<inline%> спецификатор"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "ожидался спецификатор типа"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "ожидался template-id для типа"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "ожидалось имя типа"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, fuzzy, gcc-internal-format
 #| msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier для scoped enum не должен использовать ключевое слово %<%D%>"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "декларация %qD ничего не декларирует"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибуты игнорируются для неконкретизированного типа"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибуты игнорируются для конкретизации шаблона"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибуты игнорируются для elaborated-type-specifier который не является forward декларацией"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD является шаблоном перечисления"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ожидалось %<;%> или %<{%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "невозможно добавить enumerator список к конкретизации шаблона"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларация %qD в пространстве имен %qD, которое не включает %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "избыточная квалификация не допускается"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ запрещает инкрементирование enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier без имени"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier должен использовать простой идентификатор"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD не есть namespace-name"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ожидалось namespace-name"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "ожидалось namespace-name"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace name required"
 msgstr "использование пространства имён %qD в качестве выражения"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "использование пространства имён %qD в качестве выражения"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "декларациям доступа следует предпочесть using-declarations; предлагается: добавьте ключевое слово %<using%>"
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "типы нельзя определять в алиасных декларациях шаблонов"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "составной оператор в constexpr функции"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition здесь не допускается"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "ожидался конструктор, деструктор или преобразование типа"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "ожидался инициализатор"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "инициализатор задан для функции"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функция %q+D повторно декларирована как inline"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница массива не является целой константой"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "невозможно определить элемент зависимого typedef %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не является типом"
@@ -51239,17 +51394,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "некорректная декларация"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "некорректное использование конструктора как шаблона"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "используйте %<%T::%D%> вместо %<%T::%D%> для именования конструктора в имени с квалификатором"
@@ -51256,336 +51411,336 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "некорректный тип в декларации"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD является пространством имён"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "невозможно сформировать указатель на элемент не класса %q#T"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ожидался ptr-operator"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "повторный virt-specifier"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "в аргументе шаблона для типа %qT "
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "некорректное использование %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "типы нельзя определять в аргументах шаблона"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-type template argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ожидался type-specifier"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ожидалось %<,%> или %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "аргументы по умолчанию разрешены только для параметров функций"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameter pack %qD не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "pack параметр шаблона не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameter pack не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ не поддерживает назначенные инициализаторы"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ не поддерживает C99 назначенные инициализаторы"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ не поддерживает назначенные инициализаторы"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "ожидалось class-name"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "ожидалось %<;%> после определения класса"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "ожидалось %<;%> после определения структуры"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ожидалось %<{%> или %<:%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "невозможно задать %<override%> для класса"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "global квалификация имени класса некорректна"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "квалифицированное имя не именует класс"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "некорректное имя класса в декларации %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "перед явной специализацией должно быть %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "невозможно разрешить typename type"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "предыдущее определение %q+#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "в C++03 class-key должен использоваться при декларировании friend"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for unnamed bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "выравнивание задано для безымянного битового поля"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "спецификатор pure в определении функции"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "ожидалось %<;%> после определения класса"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "некорректный спецификатор pure (только %<= 0%> допускается)"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "инициализатор в фигурных скобках здесь не допускается"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> задано более одного раза в base-specified"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, fuzzy, gcc-internal-format
 #| msgid "more than one access specifier in base-specified"
 msgid "more than one access specifier in base-specifier"
 msgstr "более одного спецификатора access в base-specified"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (базовый класс неявно является типом)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "из-за различных спецификаций исключений"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "динамические спецификации исключений не рекомендуются в C++0x; использийте вместо этого %<noexcept%>"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
@@ -51592,74 +51747,74 @@
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
 #
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD не есть %<constexpr%>"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "атрибут %qE конфликтует с атрибутом %s"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier before string constant"
 msgid "expected an identifier for the attribute name"
 msgstr "ожидался идентификатор перед строковой константой"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute before %qE"
 msgid "expected attribute before %<...%>"
 msgstr "неожиданный атрибут перед %qE"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%> недоступно в Objective-C 1.0"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 #| msgid "a transaction expression cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "транзакционное выражение не может присутствовать в константном выражении"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "специализация элемента %<%T::%E%> требует %<template<>%> синтаксис"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -51668,423 +51823,423 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "шаблон литерального оператора %qD имеет некорректный список параметров. Ожидался нетиповый pack аргумент шаблона <char...>"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "шаблон литерального оператора %qD имеет некорректный список параметров. Ожидался нетиповый pack аргумент шаблона <char...>"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Включить инструкции умножения"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона элемента в локальном классе"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная явная специализация"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларация ничего не описывает"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация шаблона не может иметь класс хранения"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректное использование %qD в спецификации привязки"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не поддерживает %<long long%>"
 
 #
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "в спецификаторах декларации заданы и %<_Sat%> и %<char%>"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "дублирование %qE"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидалось %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидалось %<__transaction_atomic%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидалось %<__transaction_relaxed%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag использован в именовании %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD редекларирован с другим доступом"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "слово %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "некорректное Objective-C++ имя селектора"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидалась objective-c++ декларация метода"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибуты метода должны задаваться в конце"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "случайное %qs между Objective-C++ методами"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "некорректный тип для instance переменной"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "ожидался идентификатор после %<@protocol%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибуты нельзя задавать до %<@%D%> Objective-C++ ключевого слова"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "префиксные атрибуты игнорируются до %<@%D%>"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип для property"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неверный инициализатор"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неверный инициализатор"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "ожидалось id-выражение"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause before %<decltype%>"
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "ожидалась конструкция %<#pragma omp%> перед %<decltype%>"
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52091,117 +52246,117 @@
 msgstr "%qD не является шаблонным элементом-функцией"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "мусор в конце директивы %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "элемент данных %qD не должен быть членом шаблона"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "некорректная декларация элемента-шаблона %qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "явная специализация в не-namespace области %qD"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "объемлющие шаблоны классов не были явно специализированы"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специализация %qD должна появляться в пределах пространства имен"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специализация %qD в другой namespace-области"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  из определения %q+#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "явная конкретизация %qD в пространстве имен %qD (которое не включает пространство имен %qD)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "имя класса затеняет шаблон параметра шаблона %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of alias template %qD"
 msgstr "частичная специализация алиасного шаблона %qD"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специализация %qT после конкретизации"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "специализация %q#T в другой namespace-области"
@@ -52208,71 +52363,71 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специализация %qT после конкретизации %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "специализация шаблона %qD не допускается ISO C++"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специализация %qD после конкретизации"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD не переменная"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "идентификатор шаблона %qD для %q+D не соответствует никакой декларации шаблона"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "разбор %d %<template<>%>, требуется %d для специализации шаблона элемента-функции"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "неоднозначная конкретизация шаблона %qD для %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -52279,25 +52434,25 @@
 msgstr "явная специализация %qD после первого использования"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явная конкретизация %qD в пространстве имен %qD (которое не включает пространство имен %qD)"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "явная специализация %qD после первого использования"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing primary template attributes %s"
 msgstr "несовпадающие аргументы"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing primary template attribute %s"
@@ -52305,60 +52460,60 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id %qD в декларации первичного шаблона"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "список параметров шаблона использован в явной конкретизации"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "определение представленное для явной конкретизации"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "слишком много списков параметров шаблона в декларации %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "слишком мало списков параметров шаблона в декларации %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "перед явной специализацией %qD должно быть %<template <>%>"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "частичная специализация шаблона функции %qD не допускается"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "частичная специализация шаблона функции %qD не допускается"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "задан подразумеваемый аргумент в явной специализации"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD не является функцией шаблоном"
@@ -52371,154 +52526,154 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специализация неявно декларированного специального элемента-функции"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "никакая элемент-функция %qD не декларирована в %qT"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %q#D declares a non-template function"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend декларация %q#D декларирует нешаблонную функцию"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "friend declaration here"
 msgstr "предыдущей декларации %q+#D здесь"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Аргумент ACOS в %L должен быть между -1 и 1"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "расширение базового инициализатора %<%T%> не содержит packs параметров"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "образец расширения %<%T%> не содержит packs аргументов"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "образец расширения %<%E%> не содержит packs аргументов"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "packs параметров не расширены с %<...%>:"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларация %q+D перекрывает параметр"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларация %q+D перекрывает параметр"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "тип параметра шаблона %qT декларирован %<friend%>"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of variable concept %q#D"
 msgstr "частичная специализация алиасного шаблона %qD"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "параметры шаблона не используются в частичной специализации:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "предыдущая декларация здесь"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template %qD"
 msgstr "предыдущая декларация здесь"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qE должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qT должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -52526,19 +52681,19 @@
 msgstr[1] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 msgstr[2] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "частичная специализация %qT после конкретизации %qT"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нет подразумеваемого аргумента для %qD"
@@ -52546,50 +52701,50 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE должен быть в конце списка параметров шаблона"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в редекларации friend шаблона функции"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в декларации friend шаблона функции"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в шаблонах функций без -std=c++11 или -std=gnu++11"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в частичных специализациях"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "параметр %qD декларирован void"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблон класса без имени"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -52600,58 +52755,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "определение шаблона для не-шаблона %q#D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "ожидалось %d уровней параметров шаблона для %q#D, дано %d"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "дано %d параметров шаблона для %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "дано %d параметров шаблона для %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  вместо требуемых %d"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "аргументы шаблона для %qD не соответствуют первоначальному шаблону %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "используйте template<> для явной специализации"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не является шаблонным типом"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "спецификаторы шаблона не заданы в декларации %qD"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -52659,7 +52814,7 @@
 msgstr[1] "редекларировано с %d параметрами шаблона"
 msgstr[2] "редекларировано с %d параметрами шаблона"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -52669,12 +52824,12 @@
 msgstr[1] "предыдущая декларация %q+D использовала %d параметров шаблона"
 msgstr[2] "предыдущая декларация %q+D использовала %d параметров шаблона"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблона %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "редекларирован здесь как %q#D"
@@ -52683,121 +52838,121 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "редекларация аргумента по умолчанию для %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "исходное определение находится здесь"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "редекларация %qD отличается в %<constexpr%>"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "исходное определение находится здесь"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%E не является корректным аргументом шаблона для типа %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "это должно быть адресом функции с внешней привязкой"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "это должно быть адресом функции с внешней привязкой"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "это должно быть указателем на элемент вида %<&X::Y%>"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD не является элементом %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  невозможно вывести параметр шаблона %qD"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  несоответствие типов %qT и %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  параметр шаблона %qD не есть parameter pack, но аргумент %qD таковым является"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE не эквивалентно %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  противоречивый вывод parameter pack с %qT и %qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  выведены конфликтующие типы для параметра %qT (%qT и %qT)"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  выведены конфликтующие значения для нетипового параметра %qE (%qE и %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  тип элемента-функции %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -52807,309 +52962,315 @@
 msgstr[1] "  кандидат ожидает %d аргумента, %d предоставлено"
 msgstr[2] "  кандидат ожидает %d аргументов, %d предоставлено"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  невозможно преобразовать %qE (типа %qT) к типу %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT является неоднозначным базовым классом %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT не является производным от %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  параметры шаблона для шаблона аргумента шаблона несовместимы с другими выведенными аргументами шаблона"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  невозможно вывести шаблон для %qT из нешаблонного типа %qT"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match %qD"
 msgid "  template argument %qE does not match %qE"
 msgstr "  аргумент шаблона %qE не соответствует %qD"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку строковые литералы не могут быть использованы в этом контексте"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "in template argument for type %qT"
 msgstr "в аргументе шаблона для типа %qT "
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "в аргументе шаблона для типа %qT "
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD не есть корректный аргумент шаблона поскольку %qD переменная, а не адрес переменной"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD не есть корректный аргумент шаблона поскольку %qD переменная, а не адрес переменной"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qE не переменная"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT из-за конфликтов в cv-qualification"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он не есть lvalue"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D не есть корректный аргумент шаблона для типа %qT поскольку ссылочная переменная не имеет постоянного адреса"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он не является объектом с внешней привязкой"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку объект %qD не имеет внешней привязки"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он является указателем"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он имеет тип %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD использовано как шаблон аргумента шаблона"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qE в качестве типа"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "ошибка при преобразовании аргумента шаблона %qE в %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "задано для %q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумеваемый аргумент задан для параметра %d %q#D"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не является шаблоном функции"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "обнаружена несогласованность внутреннего представления gcc"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "use of invalid variable template %qE"
 msgstr "%qD не переменная"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (задайте -ftemplate-depth= чтобы увеличить максимум) при подстановке %qS"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "регулируемый элемент-массив в объединении"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "несоответствие длин argument pack при расширении %<%T%>"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "несоответствие длин argument pack при расширении %<%E%>"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -53128,285 +53289,285 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qD имеет тип функции"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает массив"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow initializers in lambda expression capture lists"
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++ не допускает инициализаторы в списках lambda expression capture"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT есть/использует анонимный тип"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -53419,116 +53580,122 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth= чтобы увеличить максимум)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет привязки"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  вывод/подстановка аргумента шаблона неудачна:"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функция не подлежит inline-подстановке"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid non-type template argument"
+msgid "invalid use of %qT in template argument"
+msgstr "некорректный нетиповый аргумент шаблона"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -53745,7 +53912,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "некорректный квалифицированный контекст в имени псевдодеструктора"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
@@ -53796,7 +53963,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "protected-элемент %q+#D в анонимном объединении"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
@@ -53871,327 +54038,329 @@
 msgstr "%qT не имеет перечислимый тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameter pack __bases допустим только в декларации шаблона"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "невозможно применить %<offsetof%> к деструктору %<~%T%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
-msgstr ""
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
+msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE имеет неверный тип для %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "конец вырезки должен быть целым"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "слишком много конструкций %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не есть переменная файла, пространства имен или контекста блока"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE директива не в %qT определении"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "разность между %qE и %qD не имеет целый тип"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "в %<#pragma omp atomic update%> используются две различные переменные для памяти"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "в %<#pragma omp atomic update%> используются две различные переменные для памяти"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "не выполнено статическое утверждение: %E"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "неудача static assertion: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантное условие для static assertion"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "аргумент decltype должен быть выражением"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype не может разрешить адрес перегруженной функции"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "третий операнд условного выражения ссылка не имеет эффекта"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -54334,12 +54503,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s атрибут применен к %s %s в %L"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "ноль как константа пустой указатель"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: ошибка в %s, в %s:%d"
@@ -54401,774 +54570,768 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "общий узел канонического типа для различных типов %T и %T"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "некорректное применение %qs к элементу-функции"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "недопустимое применение %<sizeof%> к битовому полю"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<sizeof%> к выражению функционального типа"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "недопустимое применение %<__alignof%> к битовому полю"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<__alignof%> к выражению функционального типа"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "взятие адреса от временного массива"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "устаревшее преобразование из строковой константы в %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "устаревшее преобразование из строковой константы в %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "запрос на элемент %qD в %qE, который имеет указательный тип %qT (возможно вы хотели использовать %<->%> ?)"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "запрос элемента %qD в %qE, имеющего не классовый тип %qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "некорректное использование нестатического элемента данных %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "некорректный доступ к нестатическому элементу данных %qD NULL объекта"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "объектный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "разрушаемый тип %qT, а деструктор относится к %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> не является элементом %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT не содержит элемента с именем %qE"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT не содержит элемента с именем %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD не является шаблонным элементом-функцией"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT не является типом указателя на объект"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "некорректное использование индексирования массива к указателю на элемент"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "некорректное использование унарной %<*%> к указателю на элемент"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "некорректное использование неявного преобразования к указателю на элемент"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "отсутствует индекс массива"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексируемый массив объявлен как %<register%>"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексируемый объект не является ни массивом, ни указателем"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "не задан объект при использовании %qE"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "невозможно отменить внутреннюю функцию %s"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ запрещает использование %<::main%> из программы"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "необходимо использовать %<.*%> или %<->*%> для вызова pointer-to-member функции в %<%E (...)%>, например %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "слишком много аргументов для конструктора %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "слишком мало аргументов для элемента-функции %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "слишком много аргументов для функции %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "слишком мало аргументов для функции %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "слишком много аргументов для метода %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "слишком мало аргументов для метода %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "для функции задано слишком много аргументов"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "слишком мало аргументов функции"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметр %P %qD имеет неполный тип %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметр %P имеет неполный тип %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адрес %qD никогда не будет NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "результат сравнения всегда %<true%>, поскольку адрес %qD не может быть NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "предполагается приведение к типу %qT из перегруженной функции"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL в арифметическом выражении"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "счетчик циклического сдвига влево отрицателен"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "счетчик циклического сдвига вправо отрицателен"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "счетчик циклического сдвига влево >= ширины типа"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "счетчик циклического сдвига вправо >= ширины типа"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ не поддерживает сравнение между указателем и целым"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "нет имени типа %q#T в %q#T"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим операндом бинарного выражения"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "некорректные операнды типов %qT и %qT для бинарной операции %qO"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя %<void *%> в вычитании"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на функцию в вычитании"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на метод в вычитании"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "некорректное использование указателя на неполный тип в вычислениях с указателями"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "взятие адреса от конструктора %qE"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "взятие адреса от деструктора %qE"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "некорректное использование %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  qualified-id требуется"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "нельзя использовать скобки вокруг %qE для образования указателя на элемент-функцию"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ не поддерживает взятие адреса от неквалифицированного элемента-функции или элемента в скобках для формирования указателя на элемент-функцию.Используйте синтаксис %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++  не поддерживает взятие адреса от bound-элемента-функции для формирования указателя на элемент-функцию. Используйте синтаксис %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "взятие адреса от xvalue (rvalue ссылка)"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ не поддерживает взятие адреса от функции %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "некорректная попытка взять адрес битового поля %qD"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type bool"
 msgstr "взятие адреса от выражения типа %<void%>"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ запрещает инкрементирование enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ запрещает декрементирование enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "невозможно инкрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "невозможно декрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает инкрементирование указателя типа %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает декрементирование указателя типа %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "нельзя взять адрес от %<this%>, поскольку это rvalue-выражение"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "запрошен адрес явной регистровой переменной %qD"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "запрошен адрес для %qD, которая декларирована как %<register%>"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer для неклассового типа не должен быть заключен в скобки"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "список выражений рассматривается как составное выражение в инициализаторе"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "список выражений рассматривается как составное выражение в mem-initializer"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "список выражений рассматривается как составное выражение в функциональном приведении типов"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "нет контекста для разрешения типа %qE"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "приведение от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
 #
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT использует локальный тип %qT"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "преобразование из %qT в %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "приведение из типа %qT к типу %qT теряет точность"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "сравнение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "приведение от %qT к %qT увеличивает размер выравнивания для указуемого типа"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ не поддерживает приведение типа указателя на функцию к указателю на объект"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "некорректное приведение из типа %qT к типу %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "некорректное применение const_cast с типом %qT, не являющимся ни указателем, ни ссылкой, ни  указателем на элемент данных"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "некорректное применение const_cast с типом %qT, являющимся указателем или ссылкой на функцию"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "некорректное применение const_cast от rvalue-выражения типа %qT к типу %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "некорректное применение const_cast от типа %qT к типу %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ не поддерживает приведение к типу массива %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "некорректное приведение к типу функции %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  в вычислении %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "присваивание массиву из списка инициализатора"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несовместимые типы в присваивании %qT -> %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "массив использован как инициализатор"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "некорректное присваивание массива"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   в преобразовании указателя на элемент-функцию"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "преобразование указателя к элементу через виртуальную базу %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   в преобразовании указателя на элемент"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "ошибка преобразования %qT в %qT для аргумента %qP функции %qD"
+#| msgid "cannot convert %qT to %qT"
+msgid "cannot convert %qH to %qI"
+msgstr "ошибка преобразования %qT в %qT"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ошибка преобразования %qT в %qT в подразумеваемом аргументе"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ошибка преобразования %qT в %qT при передаче аргументов"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-#| msgid "cannot convert %qT to %qT"
-msgid "cannot convert %qH to %qI"
-msgstr "ошибка преобразования %qT в %qT"
-
-#: cp/typeck.c:8804
-#, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ошибка преобразования %qT в %qT в инициализации"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "ошибка преобразования %qT в %qT при возврате"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ошибка преобразования %qT в %qT в присваивании"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "параметр %qP %qD мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "параметр мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "цель преобразования могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "цель инициализации могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "левая часть присваивания могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "при передаче аргумента %P функции %q+D"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "возвращена ссылка на не-lvalue-выражение"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "возвращена ссылка на локальную переменную %q+D"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "возвращен адрес локальной переменной %q+D"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "возвращен адрес локальной переменной %q+D"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "возвращен результат деструктора"
@@ -55175,58 +55338,58 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "возврат в обработчике try-блока конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "возврат результата конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<инициализатор в фигурных скобках>"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "противоречивые типы %qT и %qT выведены для возвращаемого типа lambda"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> не должен возвращать NULL, если только он не декларирован %<throw()%> (или задан ключ -fcheck-new)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "использование временного как lvalue"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "использование xvalue (rvalue ссылка) как lvalue"
@@ -55461,151 +55624,151 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "использован синтаксис конструктора для типа %qT, который не имеет конструкторов"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "сужающее преобразование %qE из %qT в %qT внутри { } считается неверно оформленным в C++11"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "сужающее преобразование %qE из %qT в %qT внутри { }"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "выражение в статическом утверждении не является целочисленным константным выражением"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "инициализация массива int строкой не широких символов"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "инициализация массива int строкой несовместимой ширины"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "слишком длинная строка инициализации для символьного массива"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "невозможно инициализировать агрегат типа %qT составным литералом"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "тип %qD не соответствует исходной декларации"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поле %qD не найдено в инициализируемом объединении"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд %<->%> имеет неуказательный тип %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "невозможно применить элементный указатель %qE к %qE, который имеет неклассовый тип %qT"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "в арифметическом выражении использован указатель на элемент-функцию"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "в арифметическом выражении использован указатель на элемент-функцию"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "в арифметическом выражении использован указатель на элемент-функцию"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функциональное приведение к массивному типу %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "в аргументе шаблона для типа %qT "
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа %q#T"
@@ -56063,29 +56226,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Разные CHARACTER длины (%d/%d) в конструкторе массива в %L"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Некорректная ссылка на массив в %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -56092,22 +56255,22 @@
 msgid "Simplification error"
 msgstr "преобразование в gimple завершилось неуспешно"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -57239,7 +57402,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
@@ -57432,7 +57595,7 @@
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: отложенный параметр типа в %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -57715,494 +57878,494 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Формальный параметр '%s' в %L не может иметь инициализатор"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Повторная спецификация массива для Cray указателя в %C"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Расширение: Старомодная инициализация в %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference type"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in pointer initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Ошибка в инициализации указателя в %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Инициализация в %C не для указательной переменной"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Инициализация указателя в %C требует '=>', а не '='"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ожидалось инициализационное выражение в %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Инициализация переменной в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Инициализация размещаемого компонента в %C не допускается"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Компонент указатель '%s' от '%s' в %L есть тип который не был декларирован"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старомодная декларация типа %s*%d не поддерживается в %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандартная декларация типа %s*%d в %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Отсутствует правая скобка в %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Явное инициализационное выражение в %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ожидалось скалярное инициализационное выражение в %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Вид %d не поддерживается для типа %s в %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C вид параметра типа задан для типа %s но тип в %L есть %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Отсутствует правая скобка или запятая в %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Вид %d не поддерживается для CHARACTER в %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксическая ошибка в CHARACTER декларации в %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Interface-name ожидалось после '(' в %C"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Вид параметра типа для сущности в %L отличается от вида параметра типа из typespec"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "первый аргумент %<operator new%> не может иметь значение по умолчанию"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Выражение в %L должно быть INTEGER типа, найдено %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Массив '%s' в %L является переменной, которая не сводится к константному выражению"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Расширение: BYTE тип в %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE тип использованный в %C не доступен на целевой машине"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Аргумент по значению в %L не допускается в этом контексте"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: TYPE with intrinsic-type-spec at %C"
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008: TYPE с intrinsic-type-spec в %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: DOUBLE COMPLEX at %C"
 msgid "DOUBLE COMPLEX at %C"
 msgstr "Расширение: DOUBLE COMPLEX в %C"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Имя типа '%s' в %C неоднозначно"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: CLASS statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003: CLASS оператор в %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Имя типа '%s' в %C конфликтует с ранее декларированной сущностью в %L, которая имеет то же имя"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Повторный IMPLICIT NONE оператор в %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Отсутствует символьный диапазон в IMPLICIT в %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Буквы должны быть в алфавитном порядке в IMPLICIT операторе в %C"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "SAVE оператор в %C следует за общим SAVE оператором"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Пустой IMPLICIT оператор в %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT оператор в %C допустим только в INTERFACE теле"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "IMPORT оператор в %C допустим только в INTERFACE теле"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Пустой IMPLICIT оператор в %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Невозможно IMPORT '%s' из единицы компиляции уровня хоста в %C - не существует."
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' уже IMPORTed из единицы компиляции уровня хоста в %C."
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксическая ошибка в IMPORT операторе в %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Отсутствует спецификатор коизмерения в %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Отсутствует спецификатор измерения в %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Повторный %s атрибут в %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: ALLOCATABLE атрибут в %C в TYPE определении"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Атрибут %s в %L в TYPE определении"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: ALLOCATABLE атрибут в %C в TYPE определении"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Компонент '%s' с CLASS в %L должен быть размещаемым или указателем"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Атрибут %s в %L в TYPE определении"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s атрибут в %L не допускается вне спецификационной части модуля"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS attribute at %C"
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003: ASYNCHRONOUS атрибут в %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS attribute at %C"
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008: CONTIGUOUS атрибут в %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED в %C допускается только в спецификационной части модуля"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: PROTECTED атрибут в %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: VALUE атрибут в %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: VOLATILE атрибут в %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Несколько идентификаторов задано с одним NAME= спецификатором в %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Неявно декларированная BIND(C) функция '%s' в %L может не быть C совместимой"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Переменная '%s' в common блоке '%s' в %L может не быть C совместимого вида хотя common блок '%s' есть BIND(C)"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Декларация типа '%s' at %L не является C совместимой но входит в BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Переменная '%s' в %L может не быть C совместимого вида но входит в bind(c)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Переменная '%s' в common блоке '%s' в %L не может быть декларирована с BIND(C) поскольку она не является глобальной"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Возвращаемый тип BIND(C) функции '%s' в %L не может быть массивом"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -58210,363 +58373,363 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Символ '%s' в %L помечен как PRIVATE но получил связывающую метку '%s'"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Требуется имя либо сущности либо common блока для оператора спецификации атрибутов в %C"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Отсутствует имя сущности или common блока для оператора спецификации атрибутов в %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "отсутствует число"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Пустой IMPLICIT оператор в %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Производный тип в %C не был ранее определен и поэтому не может появляться в определении производного типа"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксическая ошибка в декларации данных в %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксическая ошибка в декларации данных в %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: IMPURE procedure at %C"
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008: IMPURE процедура в %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE и IMPURE не должны оба появляться в %C"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Fortran 2008: двойное двоеточие в MODULE PROCEDURE операторе в %L"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Ожидалась метка альтернативного возврата в %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after '*'"
 msgid "A parameter name is required at %C"
 msgstr "Левая скобка требуется после '*'"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Имя '%s' в %C есть имя процедуры"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Ожидается другая размерность массива в определении %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неожиданный мусор в списке формальных аргументов в %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate name '%s' in association at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Повторение имени '%s' в ассоциации в %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Повторяющийся символ '%s' в списке формальных аргументов в %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT переменная в %C должна отличаться от имени функции"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неожиданный мусор после декларации функции в %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: BIND(C) атрибут в %L не может быть специфицирован для внутренней процедуры"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C) атрибут в %C требует интерфейс с BIND(C)"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C) процедура с NAME не может иметь POINTER атрибут в %C"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Формальным процедура в %C не может иметь BIND(C) атрибут с NAME"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Процедура '%s' в %L уже имеет базовый тип %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксическая ошибка в операторе PROCEDURE в %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Ожидалось '::' после атрибутов связывания в %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS или явный интерфейс требуются в %C"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer component at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003: Компонент указателя на процедуру в %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксическая ошибка в компоненте указателя на процедуру в %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE в %C должна быть в generic интерфейсе"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008: двойное двоеточие в MODULE PROCEDURE операторе в %L"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: PROCEDURE оператор в %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Ожидался список формальный аргументов в определении функции в %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C) атрибут в %L может использоваться только для переменных или common блоков"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Пустой IMPLICIT оператор в %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY оператор в %C не может появляться внутри PROGRAM"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY оператор в %C не может появляться внутри MODULE"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY оператор в %C не может появляться внутри MODULE"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY оператор в %C не может появляться внутри BLOCK DATA"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY оператор в %C не может появляться внутри SELECT блока"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY оператор в %C не может появляться внутри DERIVED TYPE блока"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY оператор в %C не может появляться внутри IF-THEN блока"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY оператор в %C не может появляться внутри DO блока"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY оператор в %C не может появляться внутри SELECT блока"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY оператор в %C не может появляться внутри FORALL блока"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY оператор в %C не может появляться внутри WHERE блока"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней подпрограммы"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Неожиданный END оператор в %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней процедуры"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Отсутствуют обязательные скобки перед BIND(C) в %C"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Некорректное C имя в NAME= спецификаторе в %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксическая ошибка в NAME= спецификаторе для связывающей метки в %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= спецификатор в %L должен быть инициализационным выражением"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Отсутствует закрывающая скобка для связывающей метки в %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Связывающее имя не допускается в BIND(C) в %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Для формальной процедуры %s связывающее имя не допускается в BIND(C) в %C"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME не допускается в BIND(C) для ABSTRACT INTERFACE в %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неожиданный END оператор в %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: END statement instead of %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -58573,664 +58736,664 @@
 msgstr "Fortran 2008: END оператор вместо %s оператора в %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s оператор ожидался в %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Ожидается %s оператор в %C"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Ожидалось имя блока от '%s' в %s операторе в %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Ожидалось завершающее имя в %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Ожидалась метка '%s' для %s оператора в %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Отсутствует спецификация массива в %L в DIMENSION операторе"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Измерение специфицировано для %s в %L после его инициализации"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Отсутствует спецификация массива в %L в CODIMENSION операторе"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Спецификация массива должна быть отложенной в %L"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неожиданный символ в списке переменных в %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Ожидалась '(' в %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Ожидалось имя переменной в %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray указатель в %C должен быть целым"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray указатель в %C имеет %d байт точности; адреса памяти требуют %d байт"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Ожидалась \",\" в %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Ожидалась \")\" в %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Ожидалась \",\" или окончание оператора в %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Декларация Cray указателя в %C требует -fcray-pointer флаг"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008: CONTIGUOUS оператор в %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Спецификация доступа %s оператора в %C уже была специфицирована"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Спецификация доступа .%s. оператора в %C уже была специфицирована"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: PROTECTED оператор в %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксическая ошибка в PROTECTED операторе в %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE оператор в %C допустим только в спецификационной части модуля"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC оператор в %C допустим только в спецификационной части модуля"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Ожидалось имя переменной в %C в PARAMETER операторе"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Ожидался = знак в PARAMETER операторе в %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ожидалось выражение в %C в PARAMETER операторе"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Инициализация уже инициализированной переменной в %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неожиданные символы в PARAMETER операторе в %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Ожидалась переменная в READ операторе в %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксическая ошибка в VOLATILE операторе в %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Ожидалась переменная в READ операторе в %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксическая ошибка в SAVE операторе в %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Общий SAVE оператор в %C следует за предыдущим SAVE оператором"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE оператор в %C следует за общим SAVE оператором"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксическая ошибка в SAVE операторе в %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: VALUE оператор в %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксическая ошибка в VALUE операторе в %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: VOLATILE оператор в %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, fuzzy, gcc-internal-format
 #| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Указание VOLATILE для комассивной переменной '%s' в %C, которая является use-/host-associated"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксическая ошибка в VOLATILE операторе в %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003: ASYNCHRONOUS оператор в %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксическая ошибка в ASYNCHRONOUS операторе в %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE в %C должна быть в generic module interface"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Встроенная процедура в %L не может быть MODULE PROCEDURE"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Неоднозначный символ в TYPE определении в %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Символ '%s' в %C уже был host ассоциирован"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' в EXTENDS выражении в %C не есть производный тип"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' не может быть расширено в %C поскольку оно BIND(C)"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' не может быть расширено в %C поскольку оно SEQUENCE тип"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Производный тип в %C может быть только PRIVATE в спецификационной части модуля"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Производный тип в %C может быть только PUBLIC в спецификационной части модуля"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT тип '%s' использован в %L"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close read state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "ошибка закрытия файла состояния файла %s [%s]"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Определение производного типа '%s' at %C уже было определено"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Мусор после ASSOCIATE оператора в %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Мусор после ASSOCIATE оператора в %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' в %C не является членом '%s' структуры"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Неожиданный мусор после декларации функции в %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Мусор после ASSOCIATE оператора в %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Имя типа в '%s' в %C не может быть тем же что у встроенного типа"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Ожидалось :: в TYPE определении в %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Имя типа в '%s' в %C не может быть тем же что у встроенного типа"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Имя производного типа '%s' в %C уже имеет базовый тип в %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Определение производного типа '%s' at %C уже было определено"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Синтаксическая ошибка в CHARACTER декларации в %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray указуемое в %C не может быть массивом предполагаемой формы"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM и ENUMERATOR в %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Перечислитель превосходит целый тип C в %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L не инициализирован целым выражением"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM оператор определения ожидался до %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксическая ошибка в ENUMERATOR определении в %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Повторный спецификатор доступа в %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Связывающие атрибуты уже специфицировали passing, некоректный NOPASS в %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Связывающие атрибуты уже специфицировали passing, некоректный PASS в %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Повторный POINTER атрибут в %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Повторный NON_OVERRIDABLE в %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Повторный DEFERRED в %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Ожидался спецификатор доступа в %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Ожидался связывающий атрибут в %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE и DEFERRED не могут оба появляться в %C"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER атрибут требуется для компонента указателя на процедуру в %C"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Interface-name ожидалось после '(' в %C"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "')' ожидалась в %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Интерфейс должен быть специфицирован для DEFERRED связывания в %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) at %C следует декларировать DEFERRED"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Ожидалось связывающее имя в %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: PROCEDURE list at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008: PROCEDURE список в %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "'=> target' некорректно для DEFERRED связывания в %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "'::' требуется в PROCEDURE связывании с явной целью в %C"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Ожидалась цель связывания после '=>' в %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Тип '%s' содержащий DEFERRED связывание в %C не есть ABSTRACT"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, fuzzy, gcc-internal-format
 #| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Уже есть процедура со связывающим именем '%s' для производного типа '%s' в %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC в %C должно быть внутри производного типа CONTAINS"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Ожидалось '::' в %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Ожидалось generic имя или дескриптор оператора в %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Некорректная форма PROGRAM оператора в %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Ожидалось '=>' в %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Уже есть non-generic процедура со связывающим именем '%s' для производного типа '%s' в %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Связывание в %C должно иметь тот же доступ что и уже определенное связывание '%s'"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Ожидалось конкретное связывающее имя в %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "'%s' уже определено как конкретное связывание для generic '%s' в %C"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Мусор после GENERIC связывания в %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL декларация в %C должна быть внутри секции CONTAINS производного типа"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Декларация производного типа с FINAL в %C должна быть в спецификационной части модуля"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Пустое FINAL в %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Ожидалось имя модульной процедуры в %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Ожидалась \",\" в %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Неизвестное име процедуры \"%s\" в %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%s' в %C уже определена как FINAL процедура!"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неизвестный атрибут в !GCC$ ATTRIBUTES операторе в %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Синтаксическая ошибка в !GCC$ ATTRIBUTES операторе в %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -59597,31 +59760,31 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Расширение: BOZ литерал в %L использован для инициализации нецелой переменной '%s'"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Расширение: BOZ литерал в %L вне DATA оператора и вне INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ литерал в %L есть побитно преобразованный нецелый символ '%s'"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Арифметическая потеря значимости побитно преобразованного BOZ at %L. Эту проверку можно выключить опцией -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Арифметическая переполнение побитно преобразованного BOZ at %L. Эту проверку можно выключить опцией -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -59979,7 +60142,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Создание временного массива в %L"
@@ -59990,71 +60153,71 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Удаление вызова функции '%s' в %L"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "ожидалось выражение"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "некорректная пересылка"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "некорректные операнды в gimple сравнении"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в коизмерении %d"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в коизмерении %d"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -60181,12 +60344,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -61534,7 +61697,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST объект '%s' в списке имен '%s' в %L является полиморфным и требует определенную процедуру ввода/вывода"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -63109,12 +63272,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Неожиданный мусор после $OMP FLUSH оператора в %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -63382,8 +63545,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF клаузула в %L требует скалярное LOGICAL выражение"
@@ -63428,7 +63591,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
@@ -63807,200 +63970,200 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "!$OMP DO сжатые циклы не образуют прямоугольное итерационное пространство в %L"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "сжатые !$OMP DO циклы не вполне вложены в %L"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO не может быть DO WHILE или DO без управления циклом в %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$OMP DO итерационная переменная должна быть типа integer в %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$OMP DO сжатые циклы не образуют прямоугольное итерационное пространство в %L"
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "сжатые !$OMP DO циклы не вполне вложены в %L"
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s)  конфликтует с INTENT(%s) в %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s атрибут конфликтует с %s атрибутом в %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s атрибут конфликтует с %s атрибутом в %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "TILE requires constant expression at %L"
 msgstr "%qE не есть константное выражение"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "POINTER объект '%s' в %s клаузуле в %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Секция массива не разрешена в '%s' вызове в %L"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -65506,7 +65669,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Non-RECURSIVE процедура '%s' в %L возможно вызывает себя рекурсивно.  Декларируйте ее RECURSIVE или используйте -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %d используемая в %L нигде не определяется"
@@ -65632,7 +65795,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функция '%s' в %L не имеет IMPLICIT типа"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66038,239 +66201,239 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коиндексированный объект с полиморфным размещаемым подкомпонентом в %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Передаваемый объект в %L должен быть скаляром"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип '%s'"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип '%s'"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовый объект для вызова NOPASS type-bound процедуры в %L должен быть скаляром"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC '%s' в %L"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' в %L должна быть SUBROUTINE"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Ожидался тип выражения"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "'%s' в %L должна быть скаляром"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' в %L должен быть неотрицательным"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s в %L должна быть INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Шаговое выражение в DO цикле в %L не может быть нулевым"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO цикл в %L будет выполнен ноль раз"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL стартовое выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL конечное выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL шаговое выражение в %L не может быть нулевым"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL индекс '%s' не может появляться в спецификации триплета в %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object в %L должен быть ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коиндексированный размещаемый объект в %L"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг что и allocate-object в %L"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr в %L и allocate-object в %L должны иметь одинаковую форму"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сущности в %L есть тип несовместимый с source-expr в %L"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allocate-object в %L и source-expr в %L должны иметь одинаковый вид параметра типа"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Размещение %s ABSTRACT базового типа в %L требует type-spec или source-expr"
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Размещение %s в %L с type-spec требует того же character-length параметра что и в декларации"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Спецификация комассива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация массива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Ожидалась '*' в спецификации коиндекса в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация комассива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG в %L бесполезно без STAT тега"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Errmsg-variable в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object в %L также появляется в %L"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object в %L есть подобъект объекта в %L"
@@ -66279,249 +66442,249 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Выражение в CASE операторе в %L должно быть типа %s"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Выражение в CASE операторе в %L должно быть вида %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Выражение в CASE операторе в %L должно быть скаляром"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Выражение выбора в вычисляемом GOTO операторе в %L должно быть скалярным integer выражением"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Выражение в CASE операторе в %L не находится в диапазоне %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "За DEFAULT CASE в %L не может следовать второй DEFAULT CASE в %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логический диапазон в CASE операторе в %L не допускается"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константное логическое значение в CASE операторе повторяется в %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Спецификации диапазона в %L невозможно найти соответствие"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логический SELECT CASE блок в %L имеет более двух случаев"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Цель ассоциации в %C не должна быть коиндексирована"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "Цель ассоциации в %C не должна быть коиндексирована"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name '%s' в %L используется как массив"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор должен быть полиморфным в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "Цель ассоциации в %C не должна быть коиндексирована"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Производный тип '%s' в %L должен быть расширяемым"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Производный тип '%s' в %L должен быть расширением '%s'"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неожиданная NULL() встроенная в %L в формальный параметр '%s'"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec в %L не может содержать параметр отложенного типа"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Двойной CLASS IS блок в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Некорректный контекст для NULL() указателя в %%L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "STOP код в %L должен быть скаляром"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может быть полиморфным если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь ALLOCATABLE компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Элемент передачи данных в %L не может быть полной ссылкой на массив предполагаемого размера"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Фактический аргумент для '%s' в %L должен быть комассивом"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Фактический аргумент для '%s' в %L должен быть комассивом"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG= аргумент в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK= аргумент в %L должна быть скалярной LOGICAL переменной"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset аргумент в %L должен быть между 1 и num_images()"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %L не есть корректный оператор цели перехода для оператора перехода в %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Переход в %L может вызвать зацикливание"
@@ -66528,12 +66691,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO оператор в %L покидает CRITICAL конструкцию для метки в %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO оператор в %L покидает DO CONCURRENT конструкцию для метки в %L"
@@ -66541,113 +66704,113 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Метка в %L не находится в том же блоке что GOTO оператор в %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE маска в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE цель присваивания в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL определенное пользователем присваивание в WHERE в %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый оператор внутри WHERE в %L"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL с индексом '%s' не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Внешняя FORALL конструкция уже имеет индекс с этим именем %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE клаузула в %L требует LOGICAL массив"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER выражение будет усечено в присваивании (%d/%d) в %L"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коиндексированное выражение в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Impure переменная в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присваивание коиндексированной переменной в %L в PURE процедуре"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте что имеется соответствующая конкретная подпрограмма для '=' оператора"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коиндексированная переменная не должна иметь размещаемых окончательных компонентов в присваивании в %L"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -66654,73 +66817,73 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Некорректное присваивание указателя на процедуру в %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO оператор в %L требует INTEGER переменной"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Переменной '%s' не присвоили целевую метку в %L"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternate RETURN оператор в %L требует SCALAR-INTEGER спецификатор возврата"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN оператор в %L требует скалярную подразумеваемого INTEGER переменную"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Некорректный вид для %s в %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Оператор арифметического IF в %L требует числовое выражение"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Условие выхода из DO WHILE цикла в %L должно быть скалярным LOGICAL выражением"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL клаузула маски в %L требует скалярное LOGICAL выражение"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Некорректный код оператора"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -66728,7 +66891,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -66737,66 +66900,66 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Связывающая метка '%s' в %L конфликтует с глобальной сущностью '%s' в %L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Длина строки в %L слишком велика"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Размещаемый массив '%s' в %L должен иметь отложенную форму"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скалярный объект '%s' в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Указатель на массив '%s' at %L должен иметь отложенную форму"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Массив '%s' at %L не может иметь отложенную форму"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Тип '%s' CLASS переменной '%s' at %L не является расширяемым"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS переменная '%s' в %L должна быть формальным параметром, размещаемой или указателем"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип '%s' не может быть host ассоциированным в %L поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: Выведенный SAVE для переменной модуля '%s' в %L, необходим в силе подразумеваемой инициализации"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -66804,1018 +66967,1018 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Массив из модуля или главной программы '%s' в %L должен иметь константную форму"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сущность с предполагаемой character длиной в %L должна быть формальным аргументом или PARAMETER"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' в %L должна иметь константную character длину в этом контексте"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON переменная '%s' в %L должна иметь константную character длину"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Размещаемая '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Внешняя '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Формальный параметр '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Встроенная '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Результат функции '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Автоматический массив '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "в %s, в %s:%d"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Оператор функция с character значением '%s' в %L должна иметь константную длину"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' имеет PRIVATE тип и не может быть формальным аргументом '%s', который PUBLIC в %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Процедура '%s' в PUBLIC интерфейсе '%s' в %L берет формальные аргументы '%s' который PRIVATE"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Функция '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Внешний объект '%s' в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL функция '%s' в %L должна иметь скалярный результат"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Оператор функция '%s' в %L не может иметь pointer или allocatable атрибут"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) функция '%s' в %L не может иметь значение массив"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) функция '%s' в %L не может иметь значение указатель"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) функция '%s' в %L не может быть pure"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) функция '%s' в %L не может быть рекурсивной"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) функция '%s' в %L не может быть pure"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Процедура '%s' в %s в %L не имеет явного интерфейса"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Формальная процедура '%s' в %C не может иметь generic интерфейс"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в '%s' в %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в '%s' в %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в '%s' в %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в '%s' в %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Результат указатель на процедуру '%s' в %L оказался без pointer атрибута"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL процедура '%s' в %L не есть SUBROUTINE"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура в %L должна иметь ровно один аргумент"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент FINAL процедуры в %L должен быть типа '%s'"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедуры в %L не должен быть POINTER"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедуры в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедуры в %L не должен быть OPTIONAL"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедуры в %L не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярная FINAL процедура в %L должна иметь аргумент предполагаемой формы"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL процедура '%s' декларированная в %L имеет тот же ранг (%d) что и '%s'"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Только массивные FINAL процедуры декларированные для производного типа '%s' определенного в %L, предлагают также скалярный тип"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' и '%s' не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC '%s' в %L"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' и '%s' для GENERIC '%s' в %L неоднозначны"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Неопределенное конкретное связывание '%s' как цели GENERIC '%s' в %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' в %L должен нацеливаться на конкретное связывание, '%s' также GENERIC"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC '%s' в %L не может перебить конкретное связывание с тем же именем"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Type-bound оператор в %L не может быть NOPASS"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Процедура '%s' с PASS(%s) в %L не имеет аргумента '%s'"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура '%s' с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Неполиморфный passed-object формальный аргумент '%s' в %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L должен быть производного типа '%s'"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object формальный аргумент '%s' в %L должен быть скаляром"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object формальный аргумент '%s' в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object формальный аргумент '%s' в %L не должен быть POINTER"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура '%s' в %L имеет то же имя что и компонент '%s'"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура '%s' в %L имеет то же имя что и унаследованный компонент '%s'"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Производный тип '%s' декларированный в %L должен быть ABSTRACT поскольку '%s' есть DEFERRED и не перебивается"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Комассивный компонент '%s' в %L должен быть размещаемым с отложенной формой"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Компонент '%s' в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Компонент '%s' в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Компонент '%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент ICHAR в %L должен быть длины один"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Компонент указатель на процедуру '%s' с PASS(%s) в %L не имеет аргумента '%s'"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Компонент указатель на процедуру '%s' с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L должна быть производного типа '%s'"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L должна быть скаляром"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L не может иметь POINTER атрибут"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Компонент '%s' от '%s' в %L имеет то же имя что и унаследованная type-bound процедура"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Character длина компонента '%s' должна быть константным спецификационным выражением в %L"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Character компонент '%s' от '%s' в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: компонент '%s' имеет PRIVATE тип и не может быть компонентом '%s', который PUBLIC в %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Полиморфный компонент %s в %L в SEQUENCE или BIND(C) типе %s"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s SEQUENCE типа декларированный в %L не имеет SEQUENCE атрибут"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Компонент указатель '%s' от '%s' в %L есть тип который не был декларирован"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Конфликт в атрибутах аргумента функции в %C"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Поскольку расширяющий тип '%s' в %L имеет комассивный компонент, родительский тип '%s' должен также иметь его"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Нерасширяемый производный тип '%s' в %L не должен быть ABSTRACT"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: Generic имя '%s' функции '%s' в %L то же что и имя производного типа в %L"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Массив предполагаемого размера '%s' в списке имен '%s' в %L не допускается"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: NAMELIST массивный объект '%s' с предполагаемой формой в списке имен '%s' в %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: NAMELIST массивный объект  '%s' с неконстантной формой в списке имен '%s' в %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: NAMELIST объект '%s' с неконстантной character длиной в списке имен '%s' в %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект '%s' был декларирован PRIVATE и не может быть членом PUBLIC списка имен '%s' в %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST объект '%s' имеет use-associated PRIVATE компоненты и не может быть членом списка имен '%s' в %L"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект '%s' имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен '%s' в %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в '%s' в %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter массив '%s' at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно типизированный PARAMETER '%s' в %L не соотвествует более позднему IMPLICIT типу"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON блок '%s' в %L не может иметь EXTERNAL атрибут"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Сущность '%s' в %L имеет параметр отложенного типа и требует либо pointer либо allocatable атрибут"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив или массивом предполагаемой формы"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Некорректная спецификация для массива предполагаемого размера в %C"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' в %L не может иметь VALUE атрибут поскольку он не является формальным аргументом"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Character формальная переменная '%s' в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C совместимая character формальная переменная '%s' в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Производный тип '%s' в %L имеет тип '%s', который не был определен"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив или массивом предполагаемой формы"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Массив предполагаемой формы '%s' в %L не разрешен в инициализационном выражении"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Переменная цикла в %C не может быть комассивом"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Переменная '%s' at %L не может быть BIND(C) поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "COMMON переменная '%s' в %L должна иметь константную character длину"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIC %s '%s' в %L PRIVATE производного типа '%s'"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "The INTENT(OUT) формальный аргумент '%s' в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент '%s' в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент '%s' в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функции '%s' в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Переменная '%s' в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Переменная '%s' в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Переменная '%s' в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комассивная переменная '%s' в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Размещаемая комассивная переменная '%s' в %L должна иметь отложенную форму"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Переменная '%s' в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Список имен %s не может быть переименован путем USE ассоциации в %s"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA элемент '%s' в %L должен быть в COMMON"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA массив '%s' в %L должен быть специфицирован в предшествующей декларации"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA элемент '%s' в %L не может иметь коиндекс"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA элемент '%s' в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Метка %d в %L определена но не используется"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Метка %d в %L определена но не может быть использована"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Переменная производного типа '%s' в %L должна иметь SEQUENCE атрибут чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Переменная производного типа '%s' в %L не может иметь ALLOCATABLE компоненты чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Переменная производного типа '%s' в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Переменная производного типа '%s' в %L с указательными компонентами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Все или никакие объекты в EQUIVALENCE множестве в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Член common блока '%s' в %L не может быть EQUIVALENCE объектом в pure процедуре '%s'"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именованная константа '%s' at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Массив '%s' at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структуры '%s' at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC function '%s' at %L of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003: PUBLIC функция '%s' в %L PRIVATE типа '%s'"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' в %L не имеет IMPLICIT типа"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура пользовательского оператора '%s' в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура пользовательского оператора '%s' в %L не может быть character предполагаемой длины"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура пользовательского оператора '%s' в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -68276,7 +68439,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): некорректный тип: %s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -68988,20 +69151,20 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Встроенная операция %s(%d) не опознана"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'dim' аргумент встроенной функции %s в %L не есть корректный индекс измерения"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deferred-length character component '%s' at %L is not yet supported"
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Character компонент с отложенной длиной '%s' в %L пока не поддерживается"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "The event variable at %L shall not be coindexed"
@@ -69203,183 +69366,183 @@
 msgid "previously defined here as %s"
 msgstr "предыдущее определение здесь"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "несколько превалирующих определений для %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD уже была определена"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "предыдущее определение здесь"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "тип %qD не соответствует исходной декларации"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "выравнивание %qD больше чем в исходной декларации"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "тип %qD не соответствует исходной декларации"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T was previously declared here"
 msgid "%qD was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "переменная %qD повторно декларирована как функция"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "функция %qD повторно декларирована как переменная"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "предыдущая декларация здесь"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "поток байткода: мусор в конце секции символов"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "невозможно разобрать шестнадцатеричное число"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "неожиданное имя файла %s в файле разрешений линкера. Ожидалось %s"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "невозможно разобрать файловое смещение"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "неожиданное смещение"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "некорректная строка в файле разрешений"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "некорректное разрешение в файле разрешений"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, fuzzy, gcc-internal-format
 #| msgid "resolution sub id "
 msgid "resolution sub id %wx not in object file"
 msgstr "разрешения sub id "
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "ошибка чтения LTO деклараций из %s"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Ошибка открытия %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Ошибка отображения %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Ошибка чтения %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "ошибка lto_obj_file_open()"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "atexit failed"
 msgid "waitpid failed"
 msgstr "ошибка в atexit"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file: %m"
 msgid "streaming subprocess failed"
 msgstr "переименование файла .rpo: %m"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "Не задано LTRANS имя файла выходного списка"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "открытие LTRANS выходного списка %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "запись в LTRANS выходной список %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "закрытие LTRANS выходного списка %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "ошибка открытия файла разрешения символов: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "ошибки при слиянии единиц трансляции"
@@ -70323,6 +70486,11 @@
 msgstr "создается селектор для несуществующего метода %qE"
 
 #, fuzzy
+#~| msgid "Support MMX and SSE built-in functions and code generation"
+#~ msgid "Support Control-flow  Enforcment Technology (CET) built-in functions and code generation."
+#~ msgstr "Включить поддержку внутренних функций и генерацию команд MMX и SSE"
+
+#, fuzzy
 #~| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 #~ msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 #~ msgstr "%q+#D некорректно; анонимная структура может иметь только нестатические элементы данных"
@@ -70343,6 +70511,12 @@
 #~ msgid "cannot initialize multi-dimensional array with initializer"
 #~ msgstr "недопустимая инициализация многомерного массива при помощи инициализатора"
 
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "range-based %<for%> выражение типа %qT имеет %<end%> элемент без %<begin%>"
+
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "range-based %<for%> выражение типа %qT имеет %<begin%> элемент без %<end%>"
+
 #, fuzzy
 #~| msgid "ISO C forbids forward parameter declarations"
 #~ msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
@@ -70377,6 +70551,11 @@
 #~ msgstr "перебивание финальной функции %q+D"
 
 #, fuzzy
+#~| msgid "cannot convert %qT to %qT for argument %qP to %qD"
+#~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#~ msgstr "ошибка преобразования %qT в %qT для аргумента %qP функции %qD"
+
+#, fuzzy
 #~| msgid "Function name '%s' not allowed at %C"
 #~ msgid "Function name %qs not allowed at %C"
 #~ msgstr "Имя функции '%s' не допускается в %C"
Index: gcc/po/sv.po
===================================================================
--- gcc/po/sv.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/sv.po	(.../branches/gcc-8-branch)
@@ -23,7 +23,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1-b20180401\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2018-04-15 09:38+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
@@ -166,40 +166,40 @@
 msgid "negative insn length"
 msgstr "negativ instruktionslängd"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "gick inte att dela instruktion"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "ogiltig ”asm”: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "nästade assemblerdialektalternativ"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "oavslutat assemblerdialektalternativ"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "operandnummer saknas efter %%-tecken"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "operandnummer utanför intervall"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "ogiltig %%-kod"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "'%%l'-operand är inte en etikett"
@@ -210,13 +210,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "flyttalskonstant felanvänd"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1184,25 +1184,25 @@
 msgid "At top level:"
 msgstr "På toppnivå:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "I medlemsfunktion %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "I funktion %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    inline:ad från %qs vid %r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    inline:ad från %qs vid %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    inline:ad från %qs"
@@ -2943,9 +2943,9 @@
 msgid "invalid address mode"
 msgstr "ogiltigt adressläge"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
@@ -2961,7 +2961,7 @@
 msgstr "ogiltigt %%r-värde"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2968,13 +2968,13 @@
 msgstr "ogiltigt %%R-värde"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
@@ -3005,7 +3005,7 @@
 msgstr "ogiltigt %%U-värde"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
@@ -3016,7 +3016,7 @@
 msgstr "ogiltigt %%C-värde"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
@@ -3027,7 +3027,7 @@
 msgstr "okänd avspecifikation av omlokalisering"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3038,57 +3038,57 @@
 msgid "invalid operand address"
 msgstr "ogiltig operandadress"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ogiltig operand till %%Z-kod"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ogiltig operand till %%z-kod"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "ogiltig operand till %%c-kod"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ogiltig operand till %%M-kod"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ogiltig operand till %%p-kod"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ogiltig operand till %%s-kod"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ogiltig operand för %%R-kod"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ogiltig operand för %%H/%%L-kod"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ogiltig operand för %%U-kod"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ogiltig operand till %%V-kod"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ogiltig operand till %%O-kod"
@@ -3095,18 +3095,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ogiltig operand i utmatningskod"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ogiltig UNSPEC som operand: %d"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "okänd förmodad konstant"
 
@@ -3141,7 +3141,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
@@ -3264,8 +3264,8 @@
 msgstr "ogiltig const_double-operand"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3482,97 +3482,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "felaktig operand till output_condmove_single"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ogiltig UNSPEC som operand"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "ogiltigt användning av register ”%s”"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "felaktig användning av asm-flaggutdata"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ogiltig operandstorlek för operandkod ”O”"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ogiltig operandstorlek för operandkod ”z”"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ogiltig operandtyp vid operandkod ”Z”"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ogiltig operandstorlek för operandkod ”Z”"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operanden är inte en villkorskod, ogiltig operandkod ”Y”"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”D”"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand är inte en justerbar minnesreferens, ogiltig operandkod ”H”"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”K”"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”r”"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ogiltig begränsning för operand"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ogiltig vektoromedelbar"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "okänt instruktionsläge"
 
@@ -3610,7 +3610,7 @@
 msgstr "ogiltig %%P-operand"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -3664,7 +3664,7 @@
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -3827,141 +3827,141 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion behöver medium/stor kodmodell"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 och __ibm128 kan inte användas i samma uttryck"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 och long double inte användas i samma uttryck"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 och long double kan inte användas i samma uttryck"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, felaktigt register nr. 1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, felaktigt register nr. 2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load inte MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, felaktigt register nr. 1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, felaktigt register nr. 2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store inte MEM"
 
@@ -4087,43 +4087,43 @@
 msgid "created and used with different endianness"
 msgstr "skapad och använd med olika byteordning"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ogiltig %%Y-operand"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ogiltig %%A-operand"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ogiltig %%B-operand"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ogiltig %%C-operand"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ogiltig %%D-operand"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ogiltig %%f-operand"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ogiltig %%s-operand"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "flyttalskonstant inte en giltig omedelbar operand"
@@ -4340,14 +4340,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -4362,7 +4362,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -4370,7 +4370,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -4384,7 +4384,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
@@ -4391,7 +4391,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -4401,13 +4401,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
@@ -4416,18 +4416,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
@@ -4435,23 +4435,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
@@ -4460,7 +4460,7 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -4471,39 +4471,39 @@
 msgid "expected label"
 msgstr "etikett förväntades"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "hopp till etikett %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "hopp till case-etikett"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr "går in i try-block"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr "går in i catch-block"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr "går in i OpenMP-strukturerat block"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr "går in i synkroniserad eller atomär sats"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr "går in constexpr-if-sats"
 
@@ -4592,7 +4592,7 @@
 msgid "<statement>"
 msgstr "<sats>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<okänd>"
@@ -4611,114 +4611,114 @@
 msgid "<unparsed>"
 msgstr "<otolkat>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr "<lambda>"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<uttrycksfel>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<okänd operator>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "I global räckvidd:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "I statisk medlemsfunktion %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "I kopieringskonstruerare %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "I konstruerare %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "I destruerare %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "I lambdafunktion"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: Vid substituering av %qS:\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: Vid instansiering av %q#D:\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr "%r%s:%d:%d:%R   "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr "%r%s:%d:%R   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "krävs rekursivt av substitution av %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr "krävs av substitution av %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr "rekursivt begärd från %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr "begärs från %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr "rekursivt begärd härifrån\n"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr "begärd härifrån\n"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%d:%R   [ hoppar över %d instansieringskontexter, använd -ftemplate-backtrace-limit=0 för att avaktivera ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%R   [ hoppar över %d instansieringskontexter, använd -ftemplate-backtrace-limit=0 för att avaktivera ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%d:%R   i expansion av %<constexpr%> i %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   i expansion av %<constexpr%> i %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "kandidater är:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
@@ -4764,48 +4764,48 @@
 msgid "source type is not polymorphic"
 msgstr "källtypen är inte polymorfisk"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "fel typ på argument till unärt minus"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "fel typ på argument till unärt plus"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "fel typ på argument till bitkomplement"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "fel typ på argument till abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "fel typ på argument till konjunktion"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "i argument till unärt !"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "ingen pre-ökningsoperator för typen"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "ingen post-ökningsoperator för typen"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "ingen pre-minskningsoperator för typen"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "ingen post-minskningsoperator för typen"
 
@@ -5076,11 +5076,11 @@
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
@@ -5235,47 +5235,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Inkonsistenta ordningar för operator vid %%L och %%L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
@@ -5317,12 +5317,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Olika teckenlängder (%ld/%ld) i %s"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argument NCOPIES till inbyggd REPEAT är negativt (dess värde är %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argumentet NCOPIES till inbyggd REPEAT är för stort"
 
@@ -5556,6 +5556,7 @@
 msgstr "-Xbind-now och -Xbind-lazy är inkompatibla"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "överväg att använda ”-pg” istället för ”-p” med gprof (1)"
 
@@ -8216,7 +8217,7 @@
 msgstr "Justera variabler på en 32-bitarsgräns."
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr "Ange namnet på målarkitekturen."
 
@@ -8659,7 +8660,7 @@
 msgstr "Ange intervall av register att fixera."
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr "Ange bitstorlek på omedelbara TLS-avstånd."
 
@@ -9319,7 +9320,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Generera kod som följer det angivna ABI:et."
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "Kända ABI:er (att användas med flaggan -mabi=):"
 
@@ -9723,7 +9724,7 @@
 msgstr "Stöd inbyggda PKU-funktioner och -kodgenerering."
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr "Använd angiven stackskyddsvakt."
 
@@ -9732,12 +9733,12 @@
 msgstr "Kända stackskyddsvakter (att användas med flaggan -mstack-protector-guard=):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Använd angivet basregister för adressering av stackskyddsvakten."
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Använd angivet avstånd för adressering av stackskyddsvakten."
 
@@ -9750,41 +9751,47 @@
 msgstr "Försök undvika att generera instruktionssekvenser som innehåller ret-byte:ar."
 
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Stöd inbyggda funktioner och kodgenerering för Control-flow  Enforcement Technology (CET)."
+#, fuzzy
+#| msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr "Aktiverar specifikt en funktion för stöd för skuggstack från Control-flow Enforcement Technology (CET)."
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
-msgstr "Aktiverar specifikt en funktion för indirekt grenspårning från Control-flow Enforcement Technology (CET)."
-
-#: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr "Aktiverar specifikt en funktion för stöd för skuggstack från Control-flow Enforcement Technology (CET)."
-
-#: config/i386/i386.opt:1026
 msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr "Slå på CET-instrumentering för switch-satser som använder en hopptabell och ett indirekt hopp."
 
-#: config/i386/i386.opt:1031
+#: config/i386/i386.opt:1021
 msgid "Make all function calls indirect."
 msgstr "Gör alla funktionsanrop indirekta."
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr "Konvertera indirekta anrop och hopp till anrop- och retursnuttar."
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr "Konvertera funktionsreturer till anrops- och returstycken."
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Kända indirekta grenval (att användas med flaggan -mindirect-branch=/-mfunction-return=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr "Tvinga indirekta anrop och hopp via register."
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Stöd inbyggda BMI-funktioner och -kodgenerering."
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Stöd inbyggda BMI-funktioner och -kodgenerering."
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr "Anta kod kommer länkas av GNU ld."
@@ -10159,7 +10166,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Undanbedd flagga.  Använd -mvrsave istället."
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr "Ange hur många byte som bör flyttas inline före anrop av memcpy/memmove."
 
@@ -10167,7 +10174,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr "Ange det maximala antalet par av lastningsinstruktioner som skall genereras inline för jämförelsen.  Om antalet som behövs överskrider gränsen kommer istället ett anrop till memcmp genereras."
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr "Ange det maximala antalet par av lastningsinstruktioner som skall genereras inline för jämförelsen.  Om antalet som behövs överskrider gränsen kommer istället ett anrop till strncmp genereras."
 
@@ -10251,7 +10258,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\tSchemalägg kod för en given CPU."
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr "-mtraceback=\tVälj fullständig, partiell, eller ingen bakåtspårningstabell."
 
@@ -10279,7 +10286,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Giltiga argument till -mfloat-gprs=:"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr "-mlong-double-<n>\tAnge storlek på long double (64 eller 128 bitar)."
 
@@ -10355,23 +10362,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Använd ISA 2.07 instruktioner Category:Vector.AES och Category:Vector.SHA2."
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr "Använd ISA 2.07:s direkta förflyttning mellan GPR- och VSX-registerinstruktioner."
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Använd ISA 2.07 transaktionsminnesinstruktioner (HTM)."
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Generera fyrords minnesinstruktioner (lq/stq)."
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr "Generera atomära minnesinstruktioner för quad-ord (lqarx/stqcx)."
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr "Generera kod för att skicka aggregerade parametrar med som mes 64-bitars justering."
 
@@ -10391,19 +10398,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr "Tillåt 64-bitars heltalsvariabler i övre register med -mcpu=power7 eller -mvsx."
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr "Analysera och ta bort dubbelordsbyten från VSX-beräkningar."
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr "Smält samman vissa operationer för bättre prestanda på power9."
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Använd vissa skalära instruktioner som lades till i ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr "Använd vektorinstruktioner som lades till i ISA 3.0."
 
@@ -10419,15 +10426,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr "Använd register+avstånds-minnesinstruktioner som lades till i ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Använd de nya min-/maxinstruktionerna som definierades i ISA 3.0."
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr "Slå samman medium/stor modellers toc-referenser med minnesinstruktionen."
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr "Generera heltalsmoduloinstruktioner."
 
@@ -10435,15 +10442,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr "Tillåt IEEE 128-bitars flyttalstyper utan att kräva nyckelordet __float128."
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "Aktivera IEEE 128-bitars flyttal via nyckelordet __float128."
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Aktivera användning av IEEE 128-bitars flyttalsinstruktioner."
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr "Aktivera standardkonvertering mellan __float128 & long double."
 
@@ -10451,7 +10458,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Aktivera att små heltal får finnas i VSX-register."
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Giltiga argument till -mstack-protector-guard=:"
 
@@ -10480,12 +10487,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Anropa mcount för profilering före en funktionsprolog."
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr "Välj ABI-konvention för anrop."
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr "Välj metod för hantering av sdata."
 
@@ -11141,7 +11147,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Undvik överlappande destinationer och adressregister för LDRD-instruktioner som kan utlösa Cortex-M3-errata."
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "Tillåt ojusterade ord- och halvordsåtkomster till packade data."
 
@@ -11330,14 +11336,30 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mvrsave=yes%> bör undvikas; använd %<-mvrsave%> istället"
 
+#: config/rs6000/rs6000.opt:334
+#, fuzzy
+#| msgid "Max. count of debug markers to expand or inline."
+msgid "Max number of bytes to move inline."
+msgstr "Maximalt antal felsökningsmarkörer att expandera eller inline:a."
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
-msgstr "Ange det maximala antalet byte att jämföra inline med icke-slingkod.  Om detta är satt till 0 är all inline-expansion (icke-slinga och slinga) av memcmp avaktiverad."
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare without loops."
+msgstr "Det maximala antalet instruktioner i en oväxlad slinga."
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr "Ange det maximala antalet byte att jämföra inline med slingkodgenerering.  OM längden inte är känd vid kompileringstillfället kommer memcmp att anropas efter att detta antal byte har jämförts.  Som standard kommer en längd att väljas beroende på trimningsmålet."
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare with loops."
+msgstr "Det maximala antalet instruktioner i en oväxlad slinga."
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop."
+msgid "Max number of pairs of load insns for compare."
+msgstr "Det maximala antalet avskalningar av en enskild slinga."
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr "%<-misel=no%> bör undvikas; använd %<-mno-isel%> istället"
@@ -11346,10 +11368,48 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-misel=yes%> bör undvikas; använd %<-misel%> istället"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table."
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tVälj fullständig, partiell, eller ingen bakåtspårningstabell."
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\tAnge storlek på long double (64 eller 128 bitar)."
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs bör undvikas"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention."
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Välj ABI-konvention för anrop."
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling."
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Välj metod för hantering av sdata."
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr "Tillåt endast läsbar data i sdata."
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets."
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Ange bitstorlek på omedelbara TLS-avstånd."
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr "Använd fp-register."
@@ -12450,86 +12510,152 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Tillåt gcc att generera instruktionerna SETLB och Lcc."
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "Generera kod för rak byteordning."
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "Generera kod för omvänd byteordning."
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr "Använd reducerad mängd av register för registertilldelning."
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr "Använd hela mängden av register för registertilldelning."
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+#, fuzzy
+#| msgid "Patchable function entry > size"
+msgid "Align function entry to 4 byte."
+msgstr "Patchbar funktionsingång > storlek"
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr "Generera villkorliga flyttinstruktioner."
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr "Generera prestandautökningsinstruktioner."
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr "Generera prestandautökningsinstruktioner version 2."
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 msgid "Generate string extension instructions."
 msgstr "Generera strängutökningsinstruktioner."
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Generera v3 push25/pop25-instruktioner."
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr "Generera 16-bitsinstruktioner."
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr "Aktivera stöd för Virtual Hosting."
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr "Ange storleken på varje avbrottsvektor, som måste vara 4 eller 16."
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr "Ange storleken på varje cache-block, som måste vara en exponent av 2 mellan 4 och 512."
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr "Kända arkitekturtyper (att användas med flaggan -march=):"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr "Ange adressgenereringsstrategin för kodmodellen."
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "Kända cmodel-typer (att användas med flaggan -mcmodel=):"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr "Ange cpu:n för pipelinemodellen."
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Kända arkitekturtyper (att användas med flaggan -mcpu=):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+#, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "Kända flyttals-ABI:er (att användas med flaggan -mfloat-abi=):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr "Aktivera funktionen konstruerare/destruerare."
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr "Hjälp länkaren att lätta instruktioner."
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set."
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Generera flyttalsmatematik med den angivna instruktionsuppsättningen."
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions."
+msgid "Generate single-precision floating-point instructions."
+msgstr "Använd parvisa enkla flyttalsinstruktioner."
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Generera kod som använder flyttalsinstruktioner för 68881."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr "Ange CPU för kodgenereringssyften."
@@ -13350,13 +13476,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Generera mul64- och mulu64-instruktioner."
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs bör undvikas"
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr "Generera inte mpy-instruktioner för ARC700."
@@ -15587,8 +15706,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr "Använd anroparens sparregister mellan anrop om möjligt."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "beräknat värde används inte"
@@ -15614,7 +15733,7 @@
 msgstr "boolesk typ förväntades"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "heltal förväntades"
@@ -16029,7 +16148,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "ignorerar attributet %qE eftersom det står i konflikt med attributet %qs"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16055,12 +16174,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attributet ignorerat"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "Ett attribut som gäller en viss typspecificerare ignoreras"
@@ -16109,9 +16228,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16124,8 +16243,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "saknat attribut %<target%> för flerversioners %qD"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidigare deklaration av %qD"
@@ -16255,82 +16374,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: den angivna storleken mellan %E och %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: att skriva %E eller fler byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:3177
-#, gcc-internal-format
+#: builtins.c:3176
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr "%K%qD: att skriva %E byte till en region av storlek %E spiller över destinationen"
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] "%K%qD: att skriva %E byte till en region av storlek %E spiller över destinationen"
+msgstr[1] "%K%qD: att skriva %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr "%K%qD: att skriva %E byte till en region av storlek %E spiller över destinationen"
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD: att skriva mellan %E och %E byte till en region av storlek %E spiller över destinationen"
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD: den angivna gränsen %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD: den angivna gränsen mellan %E och %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD: den angivna gränsen %E överskrider maximal objektstorlek %E"
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr "%K%qD: den angivna gränsen mellan %E och %E överskrider destinationsstorleken %E"
 
-#: builtins.c:3278
-#, gcc-internal-format
+#: builtins.c:3276
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD reading %E byte from a region of size %E"
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr "%K%qD läser %E byte från en region av storlek %E"
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] "%K%qD läser %E byte från en region av storlek %E"
+msgstr[1] "%K%qD läser %E byte från en region av storlek %E"
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr "%K%qD läser %E byte från en region av storlek %E"
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD läser %E eller fler byte till en region av storlek %E"
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD läser mellan %E och %E byte från en region av storlek %E"
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%K%qD den angivna gränsen %E är lika med destinationsstorleken"
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "För många argument till funktionen %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "ogiltiga argument till %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "argument som inte stödjs till %qD"
@@ -16337,72 +16452,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "att anropa %qD med ett nollskilt argument är osäkert"
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "båda argumenten till %<__builtin___clear_cache%> måste vara pekare"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "trampolin genererad för nästad funktion %qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD bytte semantik i GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "okänd arkitekturspecificerare i minnesmodellen till inbyggd"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "ogiltigt minnesmodellargument till inbyggd funktion"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "felminnesmodellen kan inte vara starkare än den lyckade minnesmodellen för %<__atomic_compare_exchange%>"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "ogiltig felminnesmodell för %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ogiltig minnesmodell för %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ogiltigt minnesmodell för %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "argument 1 till __atomic_always_lock_free är inte konstant"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "argument 1 till __atomic_is_lock_free är inte heltal"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer stödjs inte på denna målarkitektur"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer stödjs inte på denna målarkitektur"
@@ -16409,7 +16524,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack ()%>"
@@ -16416,12 +16531,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "andra argumentet till %<__builtin_longjmp%> måste vara 1"
@@ -16428,62 +16543,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Din målplattform stödjer inte -fcheck-pointer-bounds"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "målformatet stödjer inte oändligheten"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> används i en funktion med fixt antal parametrar"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "fel antal argument till funktionen %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> anropad utan argument"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "fel antal argument till funktionen %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "andra parametern till %<va_start%> är inte det sista namngivna argumentet"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "odefinierat beteende när andra parametern till %<va_start%> är deklarerad med lagringsklass %<register%>"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kförsta argumentet till %qD måste vara en pekare, det andra en heltalskonstant"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Ksista argumentet till %qD är inte en heltalskonstant mellan 0 och 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kförsök att frigöra ett icke-heap-objekt %qD"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kförsök att frigöra ett icke-heap-objekt"
@@ -17647,37 +17762,37 @@
 msgid "conversion to incomplete type"
 msgstr "konvertering till ofullständig typ"
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "det går inte att konvertera en vektor av typen %qT till typen %qT som har annan storlekar"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "sammansatt värde användes där ett heltal förväntades"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "pekarvärde använt där ett komplext värde förväntades"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "sammansatt värde använt där ett komplext värde förväntades"
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "det går inte att konvertera ett värde av typen %qT till vektortypen %qT som har annan storlek"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "det går inte att konvertera värden till en vektor"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "sammansatt värde använt där ett fixdecimalvärde förväntades"
@@ -17832,12 +17947,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet .cfi.personality."
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr "-gdwarf-6 matas ut som version 5 med inkompatibiliteter"
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "odelegitimerad UNSPEC %s (%d) funnen på variabelplats"
@@ -17947,12 +18062,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "skrivning av %wu-bitsdata utanför gränsen för destinationsobjektet, data avhuggen till %wu bitar"
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kanrop av %qs deklarerad med attributet error: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K anrop av %qs deklarerad med attributet warning: %s"
@@ -17967,12 +18082,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "ramstorleken på %wd byte är större än %wd byte"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "det gick inte att öppna slutgiltig instruktionsdumpfil %qs: %m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "det gick inte att stänga slutgiltig instruktionsdumpfil %qs: %m"
@@ -17982,42 +18097,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "stor fixdecimalskonstant implicit trunkerad till fixdecimaltyp"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "jämförelsen är alltid %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> mellan omatchade olikhetstester är alltid 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> mellan ömsesidigt uteslutande likhetstester är alltid 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "antar att teckenspill inte förekommer vid reduktion av konstant i jämförelse"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "antar att teckenspill inte förekommer vid kombination av konstanter runt en jämförelse"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vikningskontroll: originalträdet ändrat av vikning"
@@ -18554,28 +18669,28 @@
 msgid "can%'t write PCH file"
 msgstr "kan inte skriva PCH-fil"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr "källargumentet %qD är samma som destinationen"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr "Destinationen för %G%qD är oförändrad efter att inga byte kopierades från en sträng av längden %E"
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "Destinationen för %G%qD är oförändrad efter att inga byte kopierades"
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "%G%qd-angiven gräns %E är lika med destinationsstorleken"
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr "%G%qD-angiven gräns %E överskrider destinationsstorleken %wu"
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr "%G%qD-angiven gräns %E är lika med källängden"
 
@@ -18589,12 +18704,13 @@
 msgid "null pointer dereference"
 msgstr "nollpekardereferens"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "deklarerad här"
@@ -19111,10 +19227,10 @@
 msgstr "%G%qD på avståndet %s är utanför gränserna för objekt %qD med typen %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -19143,7 +19259,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr "%G%qD avstånd %s från objektet vid %qE är utanför gränserna för refererat underobjekt %qD med typen %qT på avståndet %wu"
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr "%G%qD källargumentet är samma som destinationen"
 
@@ -19482,252 +19598,257 @@
 msgid "function cannot be instrumented"
 msgstr "funktionen kan inte instrumenteras"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr "den virtuella tabellen för typen %qD bryter mot endefinitionsregeln"
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr "en variabel med samma assemblernamn som den virtuella tabellen är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr "den virtuella tabellen för typen %qD innehåller RTTI-information"
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr "men övertrumfas av en utan från en annan översättningsenhet"
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr "RTTI kommer inte att fungera för denna typ"
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr "den virtuella tabellen för typen %qD bryter mot endefinitionsregeln  "
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr "typen som står i konflikt och är definierad i en annan översättningsenhet har en virtuell tabell med annan storlek"
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr "typen som står i konflikt och är definierad i en annan översättningsenhet med annan RTTI-information"
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr "typen som står i konflikt är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "innehåller den ytterligare virtuella metoden %qD"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr "typen som står i konflikt är definierad i en annan översättningsenhet och har en virtuell tabell med fler poster"
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "virtuell metod %qD"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr "borde matcha den virtuella metoden %qD men gör det inte"
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr "typen som står i konflikt är definierad i en annan översättningsenhet och har en virtuell tabell med annat innehåll"
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "typen %qT bryter mot C++ endefinitionsregel"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "en annan typ är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr "den första skillnaden mellan motsvarande definitioner är fältet %qD"
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr "den första skillnaden mellan motsvarande definitioner är metoden %qD"
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr "typen %qT definierad i en anonym namnrymd kan inte matcha typen %qT över gränsen för översättningsenheten"
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr "typen %qT definierad i en anonym namnrymd kan inte matcha över gränsen för översättningsenheten"
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "den inkompatibla typen definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr "typnamnet %qs skall matcha typnamnet %qs"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "den inkompatibla typen är definierad här"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr "vektortyper har olika gränser"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "returvärdets typ stämmer inte"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "typen på implicit this-pekare stämmer inte"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "typer stämmer inte i parameter %i"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "typer har olika parameterantal"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "typen %qT själv bryter mot C++ endefinitionsregel"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "typen %qT borde matcha typen %qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr "en typ med andra kvalificerare är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "en typ med andra attribut är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr "en uppräkningstyp med andra värdenamn definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr "en uppräkningstyp med andra värden är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr "en uppräkningstyp med ett inte matchande antal värden är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr "en typ med annan precision är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr "en typ med annan teckenhet är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr "den är definierad som en pekare i en annan adressrymd i en annan översättningsenhet"
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr "den är definierad som en pekare till en annan typ i en annan översättningsenhet"
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr "en vektor med annan storlek är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "har ett annat returvärde i en annan översättningsenhet"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "har andra parametrar i en annan översättningsenhet"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr "en typ definierad i en annan översättningsenhet är inte polymorf"
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr "en typ definierad i en annan översättningsenhet är polymorf"
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr "en typ med en annan virtuell tabellpekare är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr "en typ med andra baser är definierad i en annan översättningsenhet"
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "ett fält med ett annat namn är definierat i en annan översättningsenhet"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr "ett fält med samma namn men annan typ är definierat i en annan översättningsenhet"
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "fält har en annan layout i en annan översättningsenhet"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -19748,7 +19869,7 @@
 msgid "the extra base is defined here"
 msgstr "den andra basen är definierad här"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -19755,7 +19876,7 @@
 msgstr[0] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop"
 msgstr[1] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop"
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19762,7 +19883,7 @@
 msgstr[0] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop utfört %lli gånger"
 msgstr[1] "Deklaration av typen %qD final skulle möjliggöra avvirtualisering av %i anrop utförda %lli gånger"
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -19769,7 +19890,7 @@
 msgstr[0] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop"
 msgstr[1] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop"
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -19776,7 +19897,7 @@
 msgstr[0] "Deklaration av metoden %qD final skulle möjliggöra avvirtualisering av %i anrop"
 msgstr[1] "Deklaration av metoden %qD final skulle möjliggöra avvirtualisering av %i anrop"
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19783,7 +19904,7 @@
 msgstr[0] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop utfört %lli gånger"
 msgstr[1] "Deklaration av den virtuella destrueraren %qD final skulle möjliggöra avvirtualisering av %i anrop utförda %lli gånger"
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20057,30 +20178,38 @@
 msgstr "målet stödjer inte funktionsversionsavsändare"
 
 #: multiple_target.c:91
-#, gcc-internal-format
-msgid "default target_clones attribute was not set"
+#, fuzzy, gcc-internal-format
+#| msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "standard target_clones-attribut var inte satt"
 
-#: multiple_target.c:324
-#, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+#: multiple_target.c:343
+#, fuzzy, gcc-internal-format
+#| msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "ett ensamt target_clones-attribut ignoreras"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "kloner för attributet %<target_clones%> kan inte skapas"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "funktion %q+F kan aldrig kopieras eftersom den har attributet %<noclone%>"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr "standardmålet var inte satt"
 
+#: multiple_target.c:379
+#, fuzzy, gcc-internal-format
+#| msgid "missing value in %<target()%> pragma or attribute"
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr "värde saknas i pragmat eller attributet %<target()%>"
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20392,12 +20521,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "okänt argument till flaggan %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "giltiga argument till %qs är: %s; menade du %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "giltiga argument till %qs är: %s"
@@ -20992,22 +21121,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "utdataoperand %d måste använda %<&%>-begränsning"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Felaktigt next_regno för tom kedja (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Slinga i regno-kedja (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Felaktig oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Ej tomt reg i kedja (%s %u %i)"
@@ -21051,7 +21180,7 @@
 msgstr "register för %qD använt till flera globala registervariabler"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "står i konflikt med %qD"
@@ -21291,157 +21420,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%qD byter namn efter att ha refererats i assembler"
 
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "funktionssymbol som inte är en funktion"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "variabelsymbol är inte en variabel"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "noden har okänd typ"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nod ej funnen found node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "noden skiljer från node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "hashlistan över assemblernamn trasig"
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "nod finns inte i hashen av symboltabellassemblernamn"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "dubbellänkad lista av assemblernamn är trasig"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "noden har body_removed men är en definition"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "noden är analyserad men den är inte en definition"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "noden är ett alias men inte ett implicit alias"
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "noden är ett alias men inte en definition"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "noden är weakref men inte ett transparent_alias"
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "noden är transparent_alias men inte ett alias"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "noden är i same_comdat_group-listan men den har ingen comdat_group"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group-lista över olika grupper"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "blandning av olika typer av symboler i samma comdat-grupper stödjs inte"
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "noden är ensam i en comdat-grupp"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group är inte en cirkulär lista"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "comdat-lokal symbol refererad till av %s utanför dess comdat"
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "flaggan implicit_section är satt men sektionen är inte det"
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "både sektion och comdat-grupp är satt"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Aliasets och målets sektion skiljer"
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Aliasets och målets comdat-grupper skiljer"
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Transparent alias och målets assemblernamn skiljer"
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Kedjade genomskinliga alias"
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify misslyckades"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Två symboler med samma comdat_group är inte länkade av listan same_comdat_group."
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "funktionen %q+D är en del av en aliascykel"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabeln %q+D är del i en aliascykel"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "sektionen för aliaset %q+D måste stämma med sektionen för dess mål"
@@ -22604,12 +22733,12 @@
 msgid "control reaches end of non-void function"
 msgstr "flödet når slutet på en icke-void-funktion"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "ignorerar returvärdet av funktion deklarerad med attributet warn_unused_result"
@@ -23113,7 +23242,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "vektorblandningsoperationen kommer expanderas bitvis"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "vektorisering hände inte för en simd-slinga"
@@ -23153,92 +23282,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "sidoeffektselement i icke sidoeffekts-CONSTRUCTOR"
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "vektorer av funktioner är inte meningsfulla"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "funktionsreturtyp kan inte vara funktion"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: %s, har %s i %s, vid %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: förväntade ingen av %s, har %s i %s, vid %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "trädkontroll: förväntade klass %qs, har %qs (%s) i %s, vid %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "trädkontroll: klass %qs förväntades inte, har %qs (%s) i %s, vid %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: omp_clause %s förväntades, har %s i %s, vid %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "trädkontroll: förväntade träd som innehåller posten %qs, har %qs i %s, vid %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "trädkontroll: använde element %d av tree_int_cst med %d element i %s, vid %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "trädkontroll: använde element %d av tree_vec med %d element i %s, vid %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av %s med %d operander i %s, vid %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av omp_clause %s med %d operander i %s, vid %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD bör undvikas: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD bör undvikas"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE bör undvikas: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE bör undvikas"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "typen bör undvikas: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "typen bör undvikas"
@@ -23263,242 +23392,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "type variant differs by "
+msgid "type variant differs by %s"
 msgstr "typvarianter skiljer i "
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "typvariant har en annan TYPE_SIZE_UNIT"
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "typvariantens TYPE_SIZE_UNIT"
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "typens TYPE_SIZE_UNIT"
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "typvariant med TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "typvariant har en annan TYPE_VFIELD"
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "typvariant har en annan TYPE_BINFO"
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "typvariantens TYPE_BINFO"
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "typens TYPE_BINFO"
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "typvariant har andra TYPE_FIELDS"
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "första som inte stämmer är fält"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr "och fält"
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "typvariant har en annan TREE_TYPE"
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "typvariantens TREE_TYPE"
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "typens TREE_TYPE"
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "typen är inte kompatibel med sin variant"
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "Huvudvariant är inte definierad"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT har en annan TYPE_MAIN_VARIANT"
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL har en annan TYPE_CANONICAL"
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL är inte kompatibla"
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "TYPE_MODE av TYPE_CANONICAL är inte kompatibla"
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr "TYPE_CANONICAL av huvudvarianten är inte en huvudvariant"
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD är varken FIELD_DECL eller TREE_LIST"
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO är inte POINTER_TYPE"
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO är inte REFERENCE_TYPE"
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO är inte TREE_BINFO"
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "TYPE_BINFO-typ är inte TYPE_MAIN_VARIANT"
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE är inte en post eller union"
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE är inte en post eller union"
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE inte INTEGER_CST"
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW icke-NULL"
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "TYPE_LANG_SLOT_1 (binfo) fält är icke-NULL"
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "Enum-värde är inte CONST_DECL eller INTEGER_CST"
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "Enum-värdetyp är varken INTEGER_TYPE eller konvertibel till enum"
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "Enum-värdenamn är inte IDENTIFIER_NODE"
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "Vektorn TYPE_DOMAIN är inte av heltalstyp"
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS definierad i ofullständig typ"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Fel träd i TYPE_FIELDS-lista"
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P är %i medan TYPE_CACHED_VALUES är %p"
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES är inte TREE_VEC"
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "fel TYPE_CACHED_VALUES-post"
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE är icke-NULL i TYPE_ARG_TYPES-lista"
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Fel post i TYPE_ARG_TYPES-lista"
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "TYPE_VALUES_RAW-fält är icke-NULL"
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "TYPE_CACHED_VALUES_P är satt när det inte skulle vara det"
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG är satt på fel typkod"
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE är inte en huvudvariant"
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type misslyckades"
@@ -23523,12 +23653,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "trasig värdeprofil: profileringsräknaren %s (%d av %d) stämmer inte med GB-antal (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "storleksgräns på variabelspårning överskriden med -fvar-tracking-assignments, försöker igen utan"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "storleksgräns på variabelspårning överskriden"
@@ -24408,7 +24538,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "kompilatorn kan anta att adressen till %qD kommer alltid beräknas till %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "föreslår parenteser runt tilldelning som används som sanningsvärde"
@@ -24659,7 +24789,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "index %E anger ett avstånd större än storleken på %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "storleken på vektorn är för stor"
@@ -25267,7 +25397,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika variabler till minne"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -25282,22 +25412,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -25842,8 +25972,8 @@
 msgid "wrong type argument to %s"
 msgstr "fel typ på argument till %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "spill i konstant uttryck"
@@ -26474,7 +26604,7 @@
 msgstr "%<memset%> använt med en längd lika med antalet element utan att multiplicera med elementstorleken"
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "jämförelse mellan typer %qT och %qT"
@@ -26550,7 +26680,7 @@
 msgstr[0] "att skicka argument %i till en restrict-kvalificerad parameter blir alias med argument %Z"
 msgstr[1] "att skicka argument %i till en restrict-kvalificerad parameter blir alias med argumenten %Z"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "detta villkor har identiska grenar"
@@ -26677,47 +26807,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s har ogiltig kiselversion"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops är föråldrat, använd -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps är föråldrat, använd -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions är föråldrat, använd -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d är inte mellan 0 och %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d är inte mellan 0 och 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> stödjs för närvarande bara på GNU/Linux"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> kräver assemblerstöd för CFI-direktiv"
@@ -26743,31 +26873,31 @@
 msgstr "för flaggan -mcache-block-size=X, måste ett giltigt X vara: 4, 8, 16, 32, 64, 128, 256 eller 512"
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "okänd flagga -mdebug-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "okänd flagga -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "flaggan -msingle-float är likvärdig med -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "flaggan -msimple-fpu ignoreras"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "%<-fsplit-stack%> stödjs för närvarande bara på PowerPC64 GNU/Linux med glibc-2.18 eller senare"
@@ -27247,8 +27377,8 @@
 msgstr "pragmat eller attributet %<target(\"%s=%s\")%> är inte giltigt"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
@@ -27328,8 +27458,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "felaktigt värde %qs till flaggan -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27438,11 +27568,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27452,145 +27582,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr "attributet %qE är bara tillämpligt på funktioner"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "__builtin_arc_aligned med icke konstant justering"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "ogiltigt argument till __builtin_arc_aligned"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr "inbyggds operand skall vara ett teckenlöst 6-bitars värde"
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "operand 1 skall vara en teckenlöst 3-bitars omedelbar"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "operand 2 skall vara ett teckenlöst 3-bitars värde (I0-I7)"
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "operand 1 skall vara ett teckenlöst 3-bitars värde (I0-I7)"
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "operand 2 skall vara ett teckenlöst 8-bitars värde"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "operand 3 skall vara ett teckenlöst 8-bitars värde"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "operand 4 skall vara ett teckenlöst 8-bitars värde (0-255)"
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "operand 3 skall vara ett teckenlöst 3-bitars värde (I0-I7)"
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "operand 2 skall vara ett teckenlöst 3-bitars värde (subreg 0-7)"
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "operand 2 skall vara ett jämnt 3-bitars värde (subreg 0,2,4,6)"
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "inbyggd behöver en omedelbar som operand %d"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "operand %d skall vara en teckenlös 6-bitars omedelbar"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "operand %d skall vara en teckenlös 8-bitars omedelbar"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "operand %d skall vara en teckenlös 3-bitars omedelbar"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr "okänd inbyggd omedelbar operandtyp för operand %d"
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "registernummer måste vara en konstant vid kompileringstillfället.  Försök att ange högre optimeringsnivåer"
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr "operanden till sleep-instruktionen måste vara en teckenlös 6-bitars kompileringstillfälleskonstant"
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "Instruktionsadresser sätts inte efter shorten_branches"
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "instruktionsadressen inte frigjord"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "attributet %qE är bara giltigt för arkitekturen ARCv2"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "argumentet till attributet %qE saknas"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "attributet %qE tillåter endast en heltalskonstant som argument"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "attributet %qE är bara giltigt för arkitekturen ARC EM"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "attributet %qE är bara tillämpligt på typer"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "argumentet till attributet %qE ignoreras"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "attributet %qE är bara tillämpligt på variabler"
@@ -27616,153 +27736,153 @@
 msgstr "Du måste aktivera kryptoinstruktioner (t.ex. inkludera -mfloat-abi=softfp -mfpu=crypto-neon …) för att använda dessa inbyggda."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "en väljare måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "intervallet för väljaren skall vara inom 0 till 7"
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "intervallet för väljaren skall vara inom 0 till 3"
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "intervallet för väljaren skall vara inom 0 till 1"
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "intervallet för masken skall vara i 0 till 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_rori_si64 i koden."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_ror_si64 i koden."
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_si64 i koden."
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_si64 i koden."
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_si64 i koden."
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_si64 i koden."
@@ -28564,12 +28684,12 @@
 msgid "invalid IACC argument"
 msgstr "ogiltigt IACC-argument"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs förväntar sig ett konstant argument"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "konstant argument utanför intervallet för %qs"
@@ -28669,570 +28789,555 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "det går inte att sätta position i PCH-fil: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "felaktigt argument %qs till flaggan %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "storleksintervall till flaggan %qs skall vara ökande"
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "felaktigt strateginamn %qs angivet till flaggan %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginamn %qs angivet till flaggan %qs stödjs inte i 32-bitars kod"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "okänd justering %qs angiven till flaggan %qs"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "maxvärdet för det sista storleksintervallet skall vara -1 för flaggan %qs"
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "för många storleksintervall angivna i flaggan %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "okänd parameter till flaggan -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI stödjs inte i %s-läge"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> bör undvikas.  Använd istället det som passar av %<-mtune=k8%> och %<-mtune=generic%>"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> bör undvikas.  Använd istället det som passar av %<target(\"tune=k8\")%> och %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte stödjs inte för 32-bitarskod"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressläget %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mabi=ms stödjs inte med X32 ABI"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodmodellen %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel stödjs inte i denna konfiguration"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bitsläge inte inkompilerat"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<generic%> kan användas endast till flaggan %<-mtune=%>"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<generic%> kan användas endast till attributet %<target(\"tune=\")%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<intel%> kan användas endast till flaggan %<-mtune=%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<intel%> kan användas endast till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU:n du valde stödjer inte instruktionsuppsättningen x86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX stödjer inte x32"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "felaktigt värde (%qs) till flaggan %<-march=%>"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "felaktigt värde (%qs) till attributet %<target(\"arch=\")%>"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "felaktigt värde (%qs) till flaggan %<-mtune=%>"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "felaktigt värde (%qs) till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm ignoreras för Intel MCU psABI"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d är inte mellan 0 och %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary stödjs inte för denna målarkitektur"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d är inte mellan %d och %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d är inte mellan %d och 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount är inte implementerat för -fPIC"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> använd utan SSE aktiverat"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> använt utan SSE aktiverat"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stackavkänning kräver %<-maccumulate-outgoing-args%> för att bli korrekt"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stackavkänning kräver %<target(\"accumulate-outgoing-args\")%> för att bli korrekt"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "fasta ebp-register kräver %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "fasta ebp-register kräver %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry stödjs inte för 32 bitar i kombination med -fpic"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry är inte kompatibelt med SEH"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues stödjs inte för närvarande med SEH"
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "okänt alternativ till -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs är inte ett giltigt tal i -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs är inte ett giltigt avstånd i -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs är inte ett giltigt basregister i -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "%<-fcf-protection=branch%> kräver stöd för Intel CET.  Använd flaggan -mcet eller -mibt att aktivera CET"
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "%<-fcf-protection=return%> kräver stöd för Intel CET.  Använd flaggan -mcet eller -mshstk för att aktivera CET"
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "%<-fcf-protection=full%> kräver stöd för Intel CET.  Använd flaggan -mcet eller båda flaggorna -mibt och -mshstk för att aktivera CET"
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) är okänt"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(”%s”) var redan angivet"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attributen interrupt och naked är inte kompatibla"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Endast felsökningsformatet DWARF stödjs för avbrottshanteringsrutiner."
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> och %<--fcheck-pointer-bounds%> är inte kompatibla"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-instruktioner är inte tillåtna i en %s-hanteringsrutin"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion utan något attribut no_caller_saved_registers"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qD med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qT med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 stödjer inte attributet ms_abi"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue är inte kompatibelt med nästade funktioner"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorargument utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorretur utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-vektorargument utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-vektorretur utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-vektorargument utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-vektorretur utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-vektorargument utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-vektorretur utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med en flexibel vektormedlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI:et för att skicka unioner med long double har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med complex float medlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-registerretur med SSE avaktiverat"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-registerargument med SSE avaktiverat"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-registerretur med x87 avaktiverat"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "detta är ett fel i GCC som kan gås runt genom att lägga till attributet used till den anropade funktionen"
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI:et för att skicka parametrar med %d-bytejustering har ändrats i GCC 4.6"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues är inte kompatibel med %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "attributet ms_hook_prologue är inte kompatibelt med -mfentry i 32-bitsläge"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) stödjs inte i avbrottshanteringsrutiner.  Detta kan gås runt genom att undvika funktioner med sammansatta returvärden."
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack stödjer inte fastcall med nästade funktioner"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack stödjer inte 2 registerparametrar för en nästad funktion"
@@ -29239,312 +29344,312 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack stödjer inte 3 registerparametrar"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "modifieraren ”V” på ett register som inte är heltal"
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "ej stödd storlek för heltalsregister"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "utökade register har inga höga halvor"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ej stödd operandstorlek för utökat register"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "operand som inte är heltal använt med operandkod ”z”"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "avbrottshanteringsrutiner kan inte anropas direkt"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr "den tomma klassen %qT parameterskickande ABI ändras i -fabi-version=12 (GCC 8)"
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Ingen avsändare funnen för versionsattributen"
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Ingen avsändare funnen för %s"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Ingen avsändare funnen för versionsattributen: %s"
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversioner kan inte markeras som gnu_inline, kropparna måste vara genererade"
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "multiversionering behöver ifunc som inte stödjs på detta mål"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter till inbyggd måste vara en strängkonstant eller -litteral"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter till inbyggd är inte giltig: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "det sista argumentet måste vara en 2-bitars omedelbar"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "det femte argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "det tredje argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "det sista argumentet måste vara en 3-bitars omedelbar"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "det sista argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "det sista argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "det näst sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "det sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "det tredje argumentet måste vara en jämförelsekonstant"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "felaktigt jämförelsesätt"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "felaktig avrundningsoperand"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "det sista argumentet måste vara en 32-bitars omedelbar"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "väljaren måste vara en heltalskonstant i intervallet 0..%wi"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE behöver en okänd isa-flagga"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE behöver isa-flaggan %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "sista argumentet måste vara en omedelbar"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "det sista argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "det fjärde argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "felaktig tipsoperand"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumentet till xabort måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "attributen ms_abi och sysv_abi är inte kompatibla"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha unsigned %sint som andra argument"
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "avbrottshanteringsrutiner kan inte ha ett annat returvärde än void"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "alternativ är inte tillåtna i asm-flaggutdata"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "okänd asm-flaggutdata %qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ogiltigt typ för asm-flaggutdata"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "okänd arkitekturspecifik minnesmodell"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE används inte med ACQUIRE eller starkare minnesmodell"
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE används inte med RELEASE eller starkare minnesmodell"
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "ej stödd simdlen: %d"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "returtyp %qT stödjs ej för simd"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "argumenttyp %qT som inte stödjs till simd"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Pekarkontrolleraren kräver stöd för MPX på detta mål.  Använd flaggan -mmpx för att aktivera MPX."
@@ -29765,7 +29870,7 @@
 msgstr "interrupt_thread är tillgängligt endast för fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stackgränsuttryck stödjs inte"
@@ -30297,7 +30402,37 @@
 msgid "constant argument out of range for %s"
 msgstr "konstant argument utanför intervallet för %s"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "denna inbyggda funktion är endast tillgänglig i fr450"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "denna inbyggda funktion är endast tillgänglig i fr450"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin is not supported for this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "denna inbyggda stödjs inte på denna målarkitektur"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "don't support string extension instructions"
+msgid "don't support performance extension instructions"
+msgstr "stödjer inte strängutökningsinstruktioner"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate performance extension version 2 instructions."
+msgid "don't support performance extension version 2 instructions"
+msgstr "Generera prestandautökningsinstruktioner version 2."
+
+#: config/nds32/nds32-intrinsic.c:760
 #, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr "stödjer inte strängutökningsinstruktioner"
@@ -30318,43 +30453,61 @@
 msgstr "flera avbrottsattribut till funktionen %qD"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "en nästad funktion stödjs inte för reducerade register"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "inbyggt registerindex är utanför sitt intervall"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
+#, fuzzy, gcc-internal-format
+#| msgid "intrinsic register index is out of range"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "inbyggt registerindex är utanför sitt intervall"
+
+#: config/nds32/nds32.c:3508
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "ogiltigt id-värde för avbrotts-/undantagsattribut"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "ogiltigt id-värde för återställningsattribut"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "ogiltig nmi-funktion för återställningsattribut"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "ogiltig warm-funktion för återställningsattribut"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
 #, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
+#, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "positionsoberoende kod stödjs inte"
 
@@ -30563,37 +30716,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr "statisk initiering av variabeln %q+D i %<.shared%>-minne stödjs inte"
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr "kan inte skicka ut ojusterade pekare i ptx-assembler"
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX stödjer inte svaga deklarationer (endast svaga definitioner)"
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "attributet %qE kräver returtypen void"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "attributet %qE är inte tillåtet med lagringsklassen auto"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "använder vector_length (%d), ignorerar %d"
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "använder vector_length (%d), ignorerar körtidsinställningen"
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "använder num_workers (%d), ignorerar %d"
@@ -30687,12 +30840,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "skräp vid slutet av #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
@@ -30742,7 +30895,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert tar endast 3 argument"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "att skicka argument %d till %qE kastar kvalificerare från pekarmåltyp"
@@ -31044,7 +31197,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor returnerad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
@@ -31054,7 +31207,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI:et för att skicka aggregat med %d-bytejustering har ändrats i GCC 5"
@@ -31064,12 +31217,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI:et för att skicka homogena flyttalsaggregat har ändrats i GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor skickad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
@@ -31079,28 +31232,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "internt fel: den inbyggda funktionen %s redan bearbetad"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argument 1 måste vara ett 8-bitars fältvärde"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argument 1 måste vara en 5-bitars litteral med tecken"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argument 2 måste vara en 5-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argument 1 måste vara en 6-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argument 2 måste vara en 7-bitars litteral utan tecken"
@@ -31120,12 +31273,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "inbyggd %s är endast giltigt i 64-bitsläge"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "argument %d måste vara en litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument %d är en litteral utan tecken som är utanför sitt intervall"
@@ -31147,53 +31300,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "hwcap %s är ett ogiltigt argument till den inbyggda %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argument 3 måste vara en 4-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argument 3 måste vara en 2-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argument 3 måste vara en 1-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argument 1 måste vara 0 eller 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argument 1 måste vara en 1-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argument 2 måste vara en 6-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argument 2 måste vara 0 eller 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "argument 3 måste vara i intervallet 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argument till %qs måste vara en 2-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ej upplöst överlagring för inbyggd Altivec %qF"
@@ -31318,7 +31471,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internt fel: inbyggd funktion %s, argument %d har en oväntad argumenttyp %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "för stor stackram"
@@ -31328,12 +31481,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack använder register r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Stackramar större än 2 G stödjs inte med -fsplit-stack"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
@@ -31343,22 +31496,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Du kan inte ta adressen till en nästad funktion om du använder flaggan -mno-pointers-to-nested-functions"
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
@@ -31368,7 +31521,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
@@ -31832,22 +31985,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "okänt cpu %qs till -mtune"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr "-mdiv kräver -march för att innefatta utökningen %<M%>"
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr "begärt ABI kräver -march för att innefatta utökningen %qc"
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr "ABI:et kräver -march=rv%d"
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d måste vara mellan %d och %d"
@@ -31912,30 +32065,36 @@
 "Ej stött cpu-namn returnerat från kärnan till -mcpu=native: %s\n"
 "Ange ett explicit cpu-namn.  Giltiga cpu-namn är: %s"
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "den inbyggda %qs tar endast 2 argument"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "den inbyggda %qs tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "den inbyggda %qs tar endast 1 argument"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, fuzzy, gcc-internal-format
+#| msgid "builtin function %qs requires the %qs option"
+msgid "builtin %qs requires builtin %qs"
+msgstr "den inbyggda funktionen %qs behöver flaggan %qs"
+
+#: config/rs6000/rs6000-c.c:7058
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "den inbyggda funktionen %qs stödjs inte i denna kompilatorkonfiguration"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ogiltigt parameterkombination för inbyggd %qs i AltiVec"
@@ -32058,169 +32217,169 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs bör undvikas och rekommenderas inte under några omständigheter"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd %qs för att aktivera dem"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd %qs för att aktivera dem"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "internt fel: den inbyggda funktionen %qs redan bearbetad"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argument 2 måste vara en 1-bits litteral utan tecken"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "argument 1 till %qs måste vara en konstant"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "argument 1 till %qs är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "inbyggd %qs är endast giltigt i 64-bitsläge"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "den inbyggda %qs tar endast ett strängargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "cpu %qs är ett ogiltigt argument till den inbyggda %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs är ett ogiltigt argument till den inbyggda %qs"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "den inbyggda %qs behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "andra argumentet till %qs måste vara 0..12"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "tredje argumentet till %qs måste vara 0..12"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "argument 1 till %s måste vara en en konstant"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "den inbyggda funktionen %qs är endast giltig för cell-processorn"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "den inbyggda funktionen %qs behöver flaggan %qs"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "den inbyggda funktionen %qs behöver flaggorna %qs och %qs"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "den inbyggda funktionen %qs behöver 128-bitars flyttal enligt ISA 3.0 IEEE"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "den inbyggda funktionen %qs behöver flaggorna %qs (eller senare), och %qs eller %qs"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "den inbyggda funktionen %qs stödjs inte med de aktuella flaggorna"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "internt fel: inbyggd funktion %qs hade en oväntad returtyp %qs"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "internt fel: inbyggd funktion %qs, argument %d har en oväntad argumenttyp %qs"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs använder register r29"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "du kan inte ta adressen till en nästad funktion om du använder flaggan %qs"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan %qs"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "felaktig cpu %qs för %s%qs%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s är inte tillåtet"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s är ogiltigt"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> slår av %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "attributet target_clones behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
@@ -33018,7 +33177,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "värdet av typen void ignoreras inte vilket bör göras"
@@ -33270,7 +33429,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklaration av %qD skuggar en parameter"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklaration av %qD skuggar en global deklaration"
@@ -33281,7 +33440,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "deklaration av %qD skuggar en tidigare lokal deklaration"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "skuggad deklaration är här"
@@ -33341,7 +33500,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "varje odeklarerad identifierare rapporteras bara en gång för varje funktion den förekommer i"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "etikett %qE är refererad till utanför någon funktion"
@@ -33371,7 +33530,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "dubbel deklaration av etikett %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "dubblerad etikett %qD"
@@ -33489,7 +33648,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> är inte tillåtet annat än inom en funktionsprototyp"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
@@ -33744,7 +33903,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklass angiven för namnlös parameter"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklass angiven för typnamn"
@@ -33903,7 +34062,7 @@
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
@@ -34030,7 +34189,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "en medlem av an post eller union får inte ha variabel typ"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel eller fält %qE deklarerad void"
@@ -34210,7 +34369,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
@@ -34260,7 +34419,7 @@
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
@@ -34296,7 +34455,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "omdeklaration av %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "angiven sort för liten för uppräkningvärden"
@@ -34326,7 +34485,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline-funktionen %qD har fått attributet noinline"
@@ -34356,7 +34515,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
@@ -34471,12 +34630,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
@@ -34539,7 +34698,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
@@ -34684,37 +34843,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "vänsterskift med negativt värde"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vänstershiftoperanden är negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "högershiftoperanden är negativ"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vänstershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "högershiftoperanden ≥ storleken på typen"
@@ -34744,7 +34903,7 @@
 msgid "to match this %qs"
 msgstr "för att matcha denna %qs"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -34785,7 +34944,7 @@
 msgstr "okänt typnamn %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -34800,7 +34959,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -34815,8 +34974,8 @@
 msgid "unexpected attribute"
 msgstr "oväntat attribut"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "attributet %<fallthrough%> följs inte av %<;%>"
@@ -34854,7 +35013,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kan endast användas med en ensam deklarerare"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> eller %<;%> förväntades"
@@ -34882,7 +35041,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 stödjer inte %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "strängkonstant förväntades"
@@ -34946,13 +35105,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutet av uppräkningslista"
@@ -35082,7 +35241,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> förväntades före %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> utan ett föregående %<if%>"
@@ -35116,22 +35275,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "sats förväntades"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<if%>-sats"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<else%>-sats"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "föreslår uttryckliga klamrar för att undvika tvetydighet i %<else%>"
@@ -35151,12 +35310,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ogiltigt iterationsvariabel i snabb uppräkning"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC ivdep%>-pragma"
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC unroll%>-pragma"
@@ -35183,12 +35342,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "divisionen %<sizeof (%T) / sizeof (%T)%> beräknar inte antalet vektorelement"
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "första %<sizeof%>-operanden deklarerades här"
@@ -35464,7 +35623,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "operander till %<__builtin_complex%> av olika typer"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "fel antal argument till %<__builtin_shuffle%>"
@@ -35524,76 +35683,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "attributet %<setter%> kan bara anges en gång"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter-namn måste avslutas med %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attributet %<getter%> kan bara anges en gång"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> kräver ett tilldelningsuttryck som beräknas till en icke-negativ heltalskonstant mindre än %u"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "heltalsuttryck förväntades före ”)”"
@@ -35608,53 +35767,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> eller %<present%> förväntades"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> eller %<shared%> förväntades"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> eller %<exit%> förväntades"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> förväntades"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "för många %<if%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "för många %<if%>-klausuler"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "för många %<if%>-klausuler utan modifierare"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "om någon %<if%>-klausul har en modifierare måste alla %<if%>-klausuler använda modifierare"
@@ -35676,82 +35835,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> förväntades"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> förväntades"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-uttrycket måste vara ett heltal"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs-värdet måste vara positivt"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "för många %<static%>-argument"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "oväntat argument"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumentet till %<tile%> behöver en positiv heltalskonstant"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "både %<monotonic%>- och %<nonmonotonic%>-modifierare angivna"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "värdet på styckesstorleken måste vara positivt"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -35761,12 +35920,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%>-klausulens justeringsuttryck måste vara ett positivt konstant heltalsuttryck"
@@ -35786,17 +35945,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -35806,67 +35965,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ogiltig proc_bind-sort"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma acc%>-klausul förväntades"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%>-klausul förväntades"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "inga giltiga klausuler angivna i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "vektorsektionen i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD måste vara en global variabel i %<#pragma acc declare link%>"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ogiltig OpenACC-klausul vid filräckvidd"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<extern%>-variabel %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<global%>-variabeln %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variabeln %qD använd mer än en gång med %<#pragma acc declare%>"
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> förväntades efter %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> har ingen dataflyttningsklausul"
@@ -35881,7 +36040,7 @@
 msgid "expected function name"
 msgstr "ett funktionsnamn förväntades"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD refererar inte till en funktion"
@@ -35891,42 +36050,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> redan använd på %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före användning"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före definitionen"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host%>- eller %<self%>-klausul"
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
@@ -35936,22 +36095,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-klausulparameter är mindre än %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "en %<linear%>-klausul får inte anges tillsammans med en %<ordered%>-klausul med en parameter"
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
@@ -35961,72 +36120,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "inte tillräckligt med perfekt nästade slingor"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "en %<ordered%>-klausul med parameter får inte anges på en %qs-konstruktion"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> med %<depend%>-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> med en annan map-typ än %<to%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> med en annan map-typ än %<from%>-, %<release%>- eller %<delete%> på %<map%>-klausul"
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
@@ -36046,32 +36205,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> med klausuler mellan %<#pragma omp declare target%> utan klausuler och %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %<to%>-klausuler"
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> förväntades"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%>"
@@ -36126,47 +36285,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> eller %<reduction%> eller %<target%> förväntades"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
@@ -36181,7 +36340,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD har en ofullständig typ %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ogiltig användning av void-uttryck"
@@ -36302,7 +36461,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "fältindex är inte ett heltal"
@@ -36327,7 +36486,7 @@
 msgid "enum constant defined here"
 msgstr "uppräkningskonstant definierad här"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> på vektorfunktionsparametern %qE kommer returnera storleken på %qT"
@@ -36430,17 +36589,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "implicit konvertering från %qT till %qT när argument skickas till en funktion"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "jämförelse med stränglitteral resulterar i odefinierat beteende"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "jämförelse mellan pekare och teckenkonstanten noll"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "tänkte du dereferera pekaren?"
@@ -36465,7 +36624,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik på pekare till ofullständig typ"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik på pekare till ett tomt aggregat"
@@ -36698,7 +36857,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "typkonvertering från funktionsanrop av typ %qT till typ %qT matchar inte"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typkonvertering till pekare från heltal med annan storlek"
@@ -36850,7 +37009,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
@@ -36917,7 +37076,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ogiltig användning av icke-l-värde-vektor"
@@ -36987,12 +37146,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionell C tillåter inte aggregatinitiering"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initiering av medlem som är en flexibel vektor"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-vektor initierad från bred sträng"
@@ -37038,7 +37197,7 @@
 msgid "invalid initializer"
 msgstr "ogiltig initierare"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
@@ -37053,7 +37212,7 @@
 msgid "braces around scalar initializer"
 msgstr "klamrar runt skalär initierare"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initiering av medlem som är en flexibel vektor i nästat sammanhang"
@@ -37183,7 +37342,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C förbjuder %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
@@ -37223,7 +37382,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case-etikett är inte ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etikett är inte i en switch-sats"
@@ -37233,17 +37392,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-etikett som inte ligger i en switch-sats"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sats som inte är i en loop eller switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sats som inte är i en loop"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sats använd med OpenMP-for-slinga"
@@ -37268,22 +37427,22 @@
 msgid "expression statement has incomplete type"
 msgstr "uttryckssats har ofullständig typ"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "jämför vektorer med skilda elementtyper"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "jämför vektorer med olika antal element"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "det går inte att hitta en heltalstyp med samma storlek som %qT"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "jämföra flyttal med == eller != är osäkert"
@@ -37334,7 +37493,7 @@
 msgstr "ordningsjämförelse av pekare med nollpekare"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordningsjämförelse av pekare med heltalet noll"
@@ -37364,12 +37523,12 @@
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
@@ -37379,25 +37538,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE i %qs-klausul"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfältet %qE i %qs-klausul"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE är en medlem i en union"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
@@ -37408,70 +37567,70 @@
 msgstr "%<_Atomic%> %qD i %qs-klausul"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "undre gränsen %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "längden %qE i vektorsektion har inte heltalstyp"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "nollängds vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "för en vektor med okänd gräns måste ett längduttryck anges"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negativ nedre gräns i vektorsektion i %qs-klausul"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "negativ längd i vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "nedre gränsen %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "längden %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "övre gräns %qE ovanför storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "för pekartyper måste ett längduttryck anges"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "vektorsektionen är inte sammanhängande i %qs-klausulen"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE har inte pekar- eller vektortyp"
@@ -37491,7 +37650,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE har ogiltig typ för %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "ingen användardefinierad reduktion funnen för %qE"
@@ -37501,17 +37660,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "elementtyp med variabel längd i vektor-%<reduction%>-klausul"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "modifierare skall inte anges i %<linear%>-klausul på %<simd%>- eller %<for%>-konstruktioner"
@@ -37526,18 +37685,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD i %<linear%>-klausul"
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "%<linear%>-klausulens steg %qE är varken en konstant eller en parameter"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD förekommer mer än en gång i reduktionsklausuler"
@@ -37549,32 +37708,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD förekommer både i data- och map-klausuler"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE är inte en variabel i klausul %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE är inte en variabel i klausul %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE är inte en variabel i %<aligned%>-klausul"
@@ -37594,55 +37753,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE är inte en variabel i en %<depend%>-klausul"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE är varken en variabel eller ett funktionsnamn i klausulen %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE förekommer mer än en gång i samma %<declare target%>-direktiv"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
@@ -37652,32 +37811,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs-variabeln är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "%<nonmonotonic%>-modifierare angiven för schemaläggningssort %qs"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-klausulvärde är större än %<safelen%>-klausulvärde"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-schemaläggningsmodiferare angiven tillsammans med %<ordered%>-klausul"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-klausulsteg är en parameter %qD inte angiven i %<uniform%>-klausul"
@@ -37806,7 +37965,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  ingen känd konvertering för argument %d från %qH till %qI"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -37884,24 +38043,24 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  en ärvd konstruerare är inte en kandidat för initiering från ett uttryck av samma eller en härledd typ"
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "konvertering från %qH till %qI är tvetydig"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "initiering av %qH med %qI i konverterat konstantuttryck binder inte direkt"
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr " konvertering från %qH till %qI i ett konverterat konstantuttryck"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%D(%A)%> är tvetydigt"
@@ -37908,608 +38067,608 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "pekar-på-medlem-funktion %E kan inte anropas utan ett objekt, överväg att använda %<.*%> eller %<->*%>"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "ingen träff för anrop till %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "anrop av %<(%T) (%A)%> är tvetydigt"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "tvetydig överlagring för "
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr "ingen matchning för "
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (operandtyper är %qT, %qT och %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (operandtyper är %qT och %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (operandtyp är %qT)"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "treställig %<operator?:%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "treställig %<operator?:%> i %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> i %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> i %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs i %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> i %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> i %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ förbjuder uteslutande av mittersta termen i ett ?: uttryck"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr "den härledda skalära typen %qT är inte en heltals- eller flyttalstyp av samma storlek som %qT"
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "konvertering av skalären %qH till vektorn %qI innebär avhuggning"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "inkompatibla vektortyper i villkorsuttryck: %qT, %qT och %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "andra operanden till villkorsoperatorn är av typ %<void%>, men den tredje operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "tredje operanden till villkorsoperatorn är av typ %<void%>, men den andra operanden är varken ett throw-uttryck eller av typ %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "operander till ?: har olika typer %qT och %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  och båda typerna kan konverteras till den andra"
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "implicit konvertering från %qH till %qI för att stämma med andra resultat i villkor"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "uppräkningsmissmatch i villkorsuttryck: %qT kontra %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "uppräknings- och inte uppräkningstyp i villkorsuttryck"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs, försöker med prefixoperator istället"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "jämförelse mellan %q#T och %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr "undantagsuppstädning för denna placerande new väljer icke-placeringsoperatorn delete"
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr "%qD är som en vanlig (icke placerande) avallokeringsfunktion i C++14 (eller med -fsized-deallocation)"
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD är en vanlig (utan placering) avallokeringsfunktion"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "ingen motsvarande avallokeringsfunktion för %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passande %<operator %s%> för %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D är privat inom denna kontext"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "deklarerad privat här"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D är skyddad inom denna kontext"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "deklarerad skyddad här"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D är oåtkomlig inom denna kontext"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "skickar NULL till icke-pekarargument %P till %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "konverterar till icke-pekartyp %qT från NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "konverterar %<false%> till pekartyp för argument %P till %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterar %<false%> till pekartyp %qT"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "för många klamrar runt initierare för %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "konvertering till %qH från %qI behöver en direktinitiering"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ogiltig användardefinierad konvertering från %qH till %qI"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initierar argument %P till %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 msgid "invalid conversion from %qH to %qI"
 msgstr "ogiltig konvertering från %qH till %qI"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "att konvertera till %qT från initierarlista skulle använda den explicita konstrueraren %qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "i C++11 och senare kan en standardkonstruerare vara explicit"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "kan inte binda r-värdesreferens av typen %qH till ett l-värde av typ %qI"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "kan inte binda icke-const-l-värde av typen %qH till ett r-värde av typ %qI"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "att binda en referens av typen %qH till %qI kastar kvalificerare"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "det går inte att binda bitfält %qE till %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "det går inte att binda packat fält %qE till %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "det går inte att binda rvalue %qE till %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implicit konvertering från %qH till %qI när argument skickas till en funktion"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr "enum %qT med räckvidd skickad vidare … som %qT före -fabi-version=6, %qT efter"
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "att skicka objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "det går inte att referera typen %qT via %<...%>"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "att ta emot objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursiv beräkning av standardargument till %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "anrop till %qD använder standardargumentet för parameter %P, vilket inte definierats ännu"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argument till funktionsanrop kan vara en kandidat för ett formatattribut"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "användning av multiversionsfunktion utan ett standardfall"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  i anrop till %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT är inte en åtkomlig bas till %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "härleder %qT som %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (du kan avaktivera detta med -fno-deduce-init-list)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "skickar argument till ellips av den ärvda konstrueraren %qD"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning"
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD skriver till ett object av den icke-triviala typen %#qT%s"
 
 # %qs blir "protected" eller "private"
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD skriver till ett objekt av typen %#qT med %qs-medlem %qD"
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som innehåller en pekare till datamedlem%s"
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; använd tilldelning eller värdeinitiering istället"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; använd tilldelning istället"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; använd värdeinitiering istället"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD nollställer ett objekt av typend %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD nollställer ett objeck av den icke-triviala typen %#qT%s"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD nollställer ett objekt av typen %#qT som innehåller en pekare-till-medlem%s"
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; använd kopieringstilldelning eller kopieringsinitiering istället"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; använd kopieringstilldelning istället"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; använd kopieringsinitiering istället"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som inte är trivialt kopierbar%s"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD skriver till ett objekt med en borttagen kopieringskonstruerare"
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD kopierar ett objekt med en icke-trivial typ %#qT från en vektor av %#qT"
 
 # %qs blir "protected" eller "private"
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD kopierar ett objekt av typen %#qT med %qs-medlem %qD från en vektor av %#qT; använd tilldelning eller kopieringsinitiering istället"
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD skriver till ett objekt med en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD skriver till ett objekt av en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av en icke trivialt kopierbar typ %#qT; använd %<new%> och %<delete%> istället"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen kopieringskonstruerare; använd %<new%> och %<delete%> istället"
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen destruerare"
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD flyttar ett objekt av den icke-triviala typen %#qT och storleken %E in i en region av storleken %E"
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT är deklarerad här"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "konstruerare delegerar till sig själv"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "för en typkonvertering i funktionsstil, ta bort det överflödiga %<::%D%>"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%s(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%s(%A)%> är tvetydigt"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtual %q#D anropad från initierare av ickestatisk datamedlem"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtual %q#D anropad från en konstruerare"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtual %q#D anropad från en destruerare"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "det går inte att anropa medlemsfunktion %qD utan ett objekt"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "att skicka %qT väljer %qT framför %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "väljer %qD framför %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 msgid "  for conversion from %qH to %qI"
 msgstr "  för konvertering från %qH till %qI"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  för att konverteringssekvensen för argumentet är bättre"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "standardargument stämmer inte överens i upplösning av överlagring"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ säger att dessa är tvetydiga, trots att den sämsta konverteringen för den första är bättre än den sämsta konverteringen för den andra:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 msgid "could not convert %qE from %qH to %qI"
 msgstr "kunde inte konvertera %qE från %qH till %qI"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "en temporär bunden till %qD består endast tills konstrueraren avslutar"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ogiltig initiering av icke konstant referens av typ %qT från ett r-värde av typ %qI"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ogiltig initiering av referens av typ %qH från uttryck av typ %qI"
 
@@ -38548,8 +38707,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kan inte överlagras med %q#D"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "tidigare deklaration %q#D"
@@ -38590,7 +38749,7 @@
 msgstr "%qD ärver ABI-etiketten %E som %qT (använd i sin returtyp) har"
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT är deklarerad här"
@@ -38670,7 +38829,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha publika ickestatiska datamedlemmar"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "denna flexibilitet bör undvikas och kommer tas bort"
@@ -38947,7 +39106,7 @@
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
@@ -39017,7 +39176,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en pekare på medlem kan bara skapas med %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "inte tillräcklig typinformation"
@@ -39112,334 +39271,334 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD är inte användbar som en %<constexpr%>-funktion eftersom:"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%>-anrop flödar förbi slutet på funktionen"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E är inte ett konstant uttryck"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "anrop av intern funktion %qE"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "uttrycket %qE anger inte en %<constexpr%>-funktion"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "anrop av icke-%<constexpr%>-funktion %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD anropad i ett konstant uttryck före dess definition är komplett"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD anropad i ett konstant uttryck"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD användes före sin definition"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "anrop har cirkulärt beroende"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "beräkning av %<constexpr%> överskrider maxvärdet på %d (använd -fconstexpr-depth= för att öka maxvärdet)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "höger operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "högra operanden av skiftuttrycket %q+E är ≥ precisionen på den vänstra operanden"
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "vänster operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "skiftuttrycket %q+E spiller över"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "aritmetik som innefattar en nollpekare i %qE"
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektorn %qD av typen %qT"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med vektorn %qD av typen %qT med okända gränser"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektortypen %qT"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med en vektor typen %qT med okända gränser"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "använder oinitierat vektorelement"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "derefererar en nollpekare i %qE"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "muterbar %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "använder medlem %qD istället för initierad medlem %qD i ett konstant uttryck"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "använder oinitierad medlem %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "derefererar en nollpekare"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "värdet på %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD använd i sin egen initierare"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D är inte const"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D är volatile"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD initierades inte med ett konstant uttryck"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD deklarerades inte %<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD har inte heltals- eller uppräkningstyp"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "ändring av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "%<constexpr%>-slingiterationsantal överskrider gränsen på %d (använd -fconstexpr-loop-limit= för att öka gränsen)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "värdet %qE av typen %qT är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej litterala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "en reinterpret_cast är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "konvertering av %qT-nullpekare till %qT som inte är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "uttrycket %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "satsen är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar till en ofullständigt initierad variabel"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "uttrycket %qE har sidoeffekter"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "lambdafångst av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "för att det används som ett gl-värde"
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast från heltal till pekare"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "lambdauttryck är inte ett konstant uttryck före C++17"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-uttryck är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD är deklarerad %<static%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD är deklarerad %<thread_local%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "division med noll är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> är inte ett konstant uttryck"
 
 # ast = abstract syntax tree
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr "throw kommer alltid anropa terminate()"
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr "i C++11 är standard för destruerare noexcept"
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr "i C++11 kommer denna throw att avsluta eftersom standard för destruerare är noexcept"
@@ -39480,7 +39639,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering från %qH till %qI kastar kvalificerare"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "typkonvertering av %qT till %qT derefererar inte pekare"
@@ -39489,306 +39648,306 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "det går inte att konvertera typ %qH till typ %qI"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "konvertering från %q#T till %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "resultatet av konverteringen är odefinierad eftersom %qE är utanför intervallet för typen %qT"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T använt där %qT förväntades"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "kunde inte konvertera %qE från %<void%> till %<bool%>"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T använt där ett flyttalsvärde förväntades"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "konvertering från %qH till icke-skalär typ %qI begärd"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet nodiscard"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "ignorerar returnerat värde av typen %qT, deklarerat med attributet nodiscard"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "i anrop av %qD, deklarerad här"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "pseudodestruerare anropas inte"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konvertering till void kommer inte använda objekt av ofullständig typ %qT"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt med ofullständig typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i tredje operand till villkorligt uttryck"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i högeroperanden till kommaoperatorn"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i vänstra operand av kommaoperatorn"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i sats"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "indirektion kommer inte att använda objekt av ofullständig typ %qT i ökningsuttryck"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "konvertering till void kommer inte använda objekt av typ %qT"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i tredje operanden till villkorligt uttryck"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i högeroperanden till kommaoperatorn"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i vänstra operanden av kommaoperatorn"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i satsen"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "implicit avreferens kommer inte att använda objekt av typ %qT i for-ökningsuttryck"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "konvertering till void kommer inte använda objekt av ej trivialt kopierbar typ %qT"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "indirektion kommer inte att använda objekt av icke trivialt kopierbar typ %qT i andra operanden av villkorligt uttryck"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "en indirektion kommer inte att använda ett objekt av ej trivialt kopierbar typ %qT i tredje operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "en indirektion kommer inte att använda ett objekt av ej trivialt kopierbar typ %qT i högra operanden av en kommaoperator"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i vänstra operanden av en kommaoperator"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i sats"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "en indirektion kommer inte använda ett objekt av ej trivialt kopierbar typ %qT i for-ökningsuttryck"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "konvertering till void kommer inte använda objekt %qE av ofullständig typ %qT"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i andra operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i tredje operanden av ett villkorsuttryck"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i högra operanden av en kommaoperator"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i vänstra operanden av en kommaoperator"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i en sats"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "variabeln %qE med ofullständig typ %qT kommer inte användas i for-ökningsuttryck"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "konvertering till void kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "andra operanden i villkorsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "tredje operanden i villkorsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "högra operanden av kommaoperator kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "vänstra operanden av kommaoperator kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "en sats kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "for-ökningsuttryck kan inte lösa upp adress till överlagrad funktion"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "andra operanden av villkorsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "tredje operanden av villkorsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "högra operanden av kommaoperator är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "vänstra operanden av kommaoperator är en referens, inte ett anrop, till funktion %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "sats är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "for-ökningsuttryck är en referens, inte ett anrop, till funktionen %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "andra operanden av villkorsuttryck har ingen effekt"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "tredje operanden av villkorsuttryck har ingen effekt"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "höger operand av kommaoperator har ingen effekt"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "vänster operand av kommaoperator har ingen effekt"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "satsen har ingen effekt"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for-ökningsuttryck har ingen effekt"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "konvertera av NULL till icke-pekartyp"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "standardtypkonvertering kan inte härleda mallargumentet för %qD"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "tvetydig standardtypkonvertering från %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  kandidater till konvertering är %qD och %qD"
@@ -39828,197 +39987,197 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD deklarerades %<extern%> och senare %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "deklaration av %qF har en annan undantagsspecificerare"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "än tidigare deklaration av %qF"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "omdeklaration av %qD skiljer i %<constexpr%> från tidigare deklaration"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "tidigare deklaration %qD"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr "kan inte specialisera konceptet %q#D"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "omdeklaration av %q#D kan inte ha standardargument"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "den litterala operatormallen %q+D står i konflikt med den råa litterala operatorn %qD"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "den råa litterala operatorn %q+D står i konflikt med den litterala operatormallen %qD"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "tidigare definition av %qD var här"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "tidigare deklaration av %qD var här"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "inbyggd funktion %qD deklarerad som icke-funktion"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "skuggar inbyggd funktion %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "skuggar biblioteksfunktion %q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "biblioteksfunktion %q#D omdeklarerad som icke-funktion %q#D"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "deklaration av %q+#D står i konflikt med inbyggd deklaration %q#D"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "omdeklaration av %<pragma omp declare reduction%>"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "tidigare %<pragma omp declare reduction%>-deklaration"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "deklaration av %q#D står i konflikt med inbyggd deklaration %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "definitionen av %q#D gör inbyggd deklaration %q#D tvetydig"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "ny deklaration av %q#D gör inbyggd deklaration %q#D tvetydig"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "ignorerar deklarationen %q#D"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D omdeklarerad som en annan sorts symbol"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "motstridig deklaration av mallen %q+#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "ny deklaration %q+#D som skapar tvetydighet"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "gammal deklaration av %q#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "motstridande deklaration av C-funktionen %q+#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "ny deklaration av %q+#D som skapar tvetydighet"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "motstridande deklaration av %q+#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "tidigare deklaration som %q#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr "%q#D definierades tidigare här"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D tidigare deklarerad här"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "prototyp angiven för %q#D"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "tidigare definition som inte är en prototyp här"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "motstridig deklaration av %q+#D med länkklass %qL"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "tidigare deklaration med länkklass %qL"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "standardargumentet angivet för parameter %d till %q#D"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "tidigare specifikation i %q#D här"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "överflödig omdeklaration av %qD i samma definitionsområde"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "borttagen definition av %q+D"
@@ -40031,39 +40190,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explicit specialisering av %qD efter första användningen"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: synlighetsattributet ignoreras eftersom det står i konflikt med tidigare deklaration"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "omdefinition av %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD står i konflikt med använd funktion"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D inte deklarerad i klassen"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline med attributet %<gnu_inline%>"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline utan attributet %<gnu_inline%>"
@@ -40071,630 +40230,631 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "omdeklaration av vän %q#D kan inte ha standardmallargument"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal deklaration av %q#D följer på icke trådlokal deklaration"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "icke trådlokal deklaration av %q#D följer på trådlokal deklaration"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "omdeklaration av %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "överflödig omdeklaration av statisk %<constexpr%>-datamedlem %qD"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "den lokala etiketten %qE står i konflikt med en befintlig etikett"
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr "tidigare etikett"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  härifrån"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  går ut från OpenMP-strukturerat block"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  passerar initiering av %q#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  går in i räckvidden hos %q#D, som har en icke-trivial destruerare"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr "  %s"
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  går in i catch-block"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  hoppar över initiering av %q#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  går in i räckvidden hos %q#D som har en icke-trivial destruerare"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  går in i try-block"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  går in i synkroniserad eller atomär sats"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr "  går in %<constexpr%>-if-sats"
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  går in i OpenMP-strukturerat block"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ogiltig utgång från OpenMP-strukturerat block"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD är inte en typ"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD använd utan mallparametrar"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T är inte en klass"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klassmall med namnet %q#T i %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "ingen typ med namnet %q#T i %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "uppslagning av %qT i %qT är tvetydig"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en klassmall"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en typ"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "mallparametrar stämmer inte med mallen %qD"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<-fno-for-scope%> bör undvikas"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "%<-ffriend-injection%> bör undvikas"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-faligned-new=%d är inte en exponent av två"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med konstruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med destruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator är inte tillåten i anonymt aggregat"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoreras i deklaration av %q#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "attribut för %q#T måste komma efter nyckelordet %qs"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flera typer i en deklaration"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omdeklaration av inbyggd C++-typ %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kan endast anges för variabler eller funktionsdeklarationer"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typnamn saknas i typedef-deklaration"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ förbjuder anonyma poster"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kan endast anges för funktioner"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kan endast anges för funktioner"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kan endast anges inuti en klass"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kan endast anges för konstruerare"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "en lagringsklass kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> ignorerades i denna deklaration"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> kan inte användas för typdeklarationer"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoreras i explicit instansiering av %q#T"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "inget attribut kan användas på en explicit instansiering"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ignorerar attribut använda på klasstypen %qT utanför dess definition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ignorerar attribut använda på beroende typ %qT utan en associerad deklaration"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD är initierad (använd decltype istället)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarationen av %q#D har %<extern%> och är initierad"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definitionen av %q#D är markerad %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D är inte en statisk datamedlem i %q#T"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "icke-medlemsmalldeklaration av %qD"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "stämmer inte med medlemsmalldeklarationen här"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillåter inte %<%T::%D%> att definieras som %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubblerad initierare av %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklaration av %q#D utanför en klass är inte en definition"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD är deklarerad %<thread_local%> i en %<constexpr%>-funktion"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qDF är deklarerad %<static%> i en %<constexpr%>-funktion"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabeln %q#D har initierare men ofullständig typ"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen i vektorn %q#D har ofullständig typ"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "aggregatet %q#D har ofullständig typ och kan inte definieras"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD är deklarerad som en referens men inte initierad"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "namn använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "namnet %qD använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "icketriviala designerade initierare stödjs inte"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-beteckningen %qE är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "initierare misslyckas med att bestämma storleken på %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "vektorstorlek saknas i %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "vektor med storlek noll %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstorlek på %qD är inte känd"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstorlek på %qD är inte konstant"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-variabeln %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-funktioners statiska data %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "du kan gå runt detta genom att ta bort initieraren"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "oinitierade const %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "oinitierad variabel %qD i %<constexpr%>-kontext"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T har ingen användardefinierad standardkonstruerare"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "konstrueraren är inte användarens egna eftersom den är uttryckligen standarddefinierad i klasskroppen"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "och den implicit definierade konstrueraren initierar inte %q#D"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ogiltig typ %qT som initierare för en vektor med typ %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initierare för %qT måste vara inom klamrar"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> använt i en designerad initierare i GNU-stil för klassen %qT"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT har ingen icke-statisk medlem med namnet %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ogiltig initierare för %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "klamrar saknas runt initierare för %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "element i vektorn %q#T har ofullständig typ"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "sammansatta litteral med variabel storlek"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D har ofullständig typ"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalärt objekt %qD kräver ett element i initieraren"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "i C++98 måste %qD initieras med en konstruerare, inte med %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "vektor %qD initierad från strängkonstant inom parentes %qE"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initierare är ogiltig för statisk medlem med konstruerare"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ej konstant initiering inom klassen av statisk medlem %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ej konstant initiering inom klassen är felaktig för icke inline statisk medlem %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en initiering utanför klassen krävs)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "referensen %qD initieras med sig själv"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillåter inte specificeraren %<register%> av lagringsklass"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "specificeraren %<register%> av lagringsklass angiven"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "initieraren för %<decltype(auto) %D%> har funktionstyp (glömde du %<()%> ?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "variabelkoncept har ingen initierare"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skuggar tidigare typdeklaration av %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "det går inte dekomponera klasstypen %qT för att den har en anonym struct-medlem"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "kan inte dekomponera klasstypen %qT för att den har en anonym unionsmedlem"
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+#| msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "det går inte att dekomponera en icke publik medlem %qD av %qT"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: både den och dess basklass %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: dess basklasser %qT och %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "strukturerad bindning refererar till ofullständig typ %qT"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40701,7 +40861,7 @@
 msgstr[0] "%u namn angivet för strukturerad bindning"
 msgstr[1] "%u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40708,7 +40868,7 @@
 msgstr[0] "endast %u namn angivet för strukturerad bindning"
 msgstr[1] "endast %u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40715,1327 +40875,1339 @@
 msgstr[0] "medans %qT dekomponeras till %wu element"
 msgstr[1] "medans %qT dekomponeras till %wu element"
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "medans %qT dekomponeras till %E element"
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "i initieringen av variabel %qD i strukturerad bindning"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "det går inte att dekomponera unionstypen %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "det går inte att dekomponera typen %qT som inte är en klass eller vektor"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "det går inte att dekomponera lambdahöljestypen %qT"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
+#, fuzzy, gcc-internal-format
+#| msgid "structured binding refers to incomplete type %qT"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "strukturerad bindning refererar till ofullständig typ %qT"
+
+#: cp/decl.c:7774
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "det går inte att dekomponera klasstypen %qT utan icke-statiska datamedlemmar"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "konceptet %q#D deklarerad med funktionsparametrar"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "konceptet %q#D deklarerat med en härledd returtyp"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "koncept %q#D med icke-%<bool%>-returtyp %qT"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "konceptet %qD har ingen definition"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definierar explicit specialisering %qD i vändeklaration"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ogiltig användning av mall-id %qD i deklaration av primär mall"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardargument är inte tillåtna i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "det går inte att deklarera %<::main%> som en mall"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "det går inte att deklarera %<::main%> som inline"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "det går inte att deklarera %<::main%> som %<constexpr%>"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "det går inte att deklarera %<::main%> som static"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "härledningsguiden %qD måste deklareras med namnrymdsräckvidd"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "härledningsguiden %qD får inte ha en funktionskropp"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "litteral operator med C-länkning"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD har en ogiltig argumentlista"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "heltalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "flyttalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "litterala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD måste vara en icke-medlems-funktion"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> måste returnera %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "omdefinition av implicit deklarerad %qD"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition av explicit standarddefinierad %q+D"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicit standarddefinierad här"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion %q#D deklarerad i klassen %qT"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "det går inte att deklarera %<::main%> som en global variabel"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "en icke-mallvariabel variabel kan inte vara %<concept%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "koncept måste ha typen %<bool%>"
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med ofullständig typ"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> behövs för initiering i klassen av statisk datamedlem med icke heltalstyp %q#D"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med icke-litteral typ"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ogiltig initiering i klassen av statisk datamedlem med icke heltalstyp %qT"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ förbjuder initiering inom klassen av icke-konstant statisk medlem %qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ förbjuder initiering av medlemskonstant %qD av icke heltalstyp %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "storlek på vektorn %qD av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "storlek på vektorn av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "storlek på vektorn är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "storleken på vektorn %qD är negativ"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "storleken på vektorn är negativ"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med storlek noll"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ förbjuder vektor med storlek noll"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "storlek på vektorn %qD är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med variabel längd"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ förbjuder vektor med variabel längd"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "vektor %qD med variabel längd används"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "vektor med variabel längd används"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "spill i vektordimension"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD är deklarerad som en vektor av %qT"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "deklaration av %qD som en vektor av void"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "skapar vektor av void"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "deklaration av %qD som en vektor av funktioner"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "skapar vektor av funktioner"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "deklaration av %qD som en vektor av referenser"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "skapar vektor av referenser"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "deklaration av %qD som en vektor av funktionsmedlemmar"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "skapar vektor av funktionsmedlemmar"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qD som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kvalificerare är inte tillåtna vid kontruerardeklaration"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "specifikation av returtyp för destruerare är ogiltigt"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kvalificerare är inte tillåtna vid destruerardeklaration"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "returtyp angiven för %<operator %T%>"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kvalificerare är inte tillåtna på deklaration av %<operator %T%>"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "returtypen angiven för härledningsguiden"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kvalificerare är inte tillåtna på deklaration av härledningsguide"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "mallmallparameter %qT i deklaration av härledningsguide"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "decl-specificerare i deklaration av härledningsguide"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "namnlös variabel eller fält deklarerad void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller fält deklarerad void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "specificeraren %<inline%> är ogiltig för variabeln %qD deklarerad med blockräckvidd"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "inline-variabler är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ogiltigt användning av kvalificerat namn %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T är inte en klass eller namnrymd"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "deklaration av %qD som icke-medlem"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklaration av %qD som %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "deklaration av %qD som en parameter"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<concept%> kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "två eller fler datatyper i deklaration av %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "motstridande specificerare i deklarationen av %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ förbjuder deklaration av %qs utan typ"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> stödjs inte på denna målarkitektur"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ stödjer inte %<__int%d%> för %qs"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> eller %<unsigned%> är ogiltigt för %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> och %<unsigned%> givna tillsammans för %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> ogiltig för %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> ogiltig för %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> ogiltig för %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> eller %<short%> ogiltig för %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> eller %<char%> ogiltig för %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> eller %<short%> angiven med char för %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> och %<short%> angivna tillsammans för %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> eller %<long%> ogiltig för %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed eller unsigned använd felaktigt för %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ogiltig för %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "mallens platshållartyp %qT måste följas av ett enkelt deklarerar-id"
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<static%>"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<constexpr%>"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-deklaration ogiltig i parameterdeklaration"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklass angiven för mallparameter %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "specificerare av lagringsklass ogiltig i parameterdeklarationer"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "en parameter kan inte deklareras %<concept%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "en parameter kan inte deklareras %<constexpr%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> utanför klassdeklaration"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<inline%>"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "deklarationen av strukturerad bindning får inte vara %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "deklaration av strukturerad bindning får inta vara %qs"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<concept%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<static%>"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "deklaration av strukturerad bindning får inte vara C++98 %<auto%>"
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha typen %qT"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "typen måste vara en cv-kvalificerad %<auto%> eller en referens till en cv-kvalificerad %<auto%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flera lagringsklasser i deklaration av %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "lagringsklass angiven för %qs"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklass angiven för parameter %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "nästad funktion %qs är deklarerad %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "toppnivådeklaration av %qs anger %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktionsdefinitionsområde %qs implicit auto och deklarerat %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "ogiltig specificerare av lagringsklass i vänfunktionsdeklarationer"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "onödiga paranteser i deklaration av %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-klausul på returtypen"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "härledd returtyp är endast tillgänglig med -std=c++14 eller -std=gnu++14"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
+#, fuzzy, gcc-internal-format
+#| msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "härledd klasstyp %qT i funktionens returtyp"
+
+#: cp/decl.c:11156
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "härledningsguiden för %qT måste ha en avslutande returtyp"
 
-#: cp/decl.c:11099
+#: cp/decl.c:11169
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
-msgstr "härledd klasstyp %qT i funktionens returtyp"
-
-#: cp/decl.c:11111
-#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "den avslutande returtypen %qT hos deduktionsguiden är inte en specialisering av %qT"
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "avslutande returtyp är endast tillgänglig med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "konstruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruerare kan inte deklareras %<virtual%>"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en konverteringsfunktion kan inte ha en avslutande returtyp"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statiska %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-klausul på typedef"
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-klausul på type-id"
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-klausul vid deklaration av icke-funktionstypen %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ej statisk datamedlem deklarerad med platshållaren %qT"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ förbjuder den flexibla vektormedlemen %qs"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ förbjuder flexibla vektormedlemmar"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltigt användning av %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen %qD deklarerad %<virtual%> inuti en union"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kan inte deklareras %<virtual%>, eftersom den alltid är statisk"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "en destruerare kan inte vara %<concept%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "en destruerare kan inte vara %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "en konstruerare kan inte vara %<concept%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ett koncept kan inte vara en medlemsfunktion"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "statisk datamedlem %qE deklarerad %<concept%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisk %<constexpr%>-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "ickestatisk datamedlem %qE deklarerad %<concept%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "ickestatisk datamedlem %qE deklarerad %<constexpr%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
@@ -42042,77 +42214,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarationen av %<constexpr%>-variabeln %qD är inte en definition"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
@@ -42132,169 +42304,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ förhindrar överlagring av operatorn ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD måste ha antingen noll eller ett argument"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD måste ha antingen ett eller två argument"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD måste ha %<int%> som sitt argument"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD måste ha %<int%> som sitt andra argument"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD får inte ha några argument"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD måste ha exakt ett argument"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD måste ha exakt två argument"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konvertering till en referens till void kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konvertering till void kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konvertering till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konvertering till en referens till en basklass kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konvertering till en basklass kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT har en tidigare deklaration här"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -42306,94 +42478,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT definierad med flera direkta baser"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT definerad med en direkt virtuell bas"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
@@ -42402,77 +42574,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "uppräkningsvärde för %qD är inte en heltalstyp eller uppräkningstyp utan räckviddsbegränsning"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<long%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "uppräkningsvärdet %qE är utanför intervallet för den underliggande typen %qT"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "ogiltig funktionsdeklaration"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ogiltig medlemsfunktionsdeklaration"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -42512,7 +42684,7 @@
 msgid "deleting %qT is undefined"
 msgstr "radera %qT är odefinierat"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malldeklaration av %q#D"
@@ -42525,7 +42697,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destrueraren %qD deklarerad som medlemsmall"
@@ -42635,42 +42807,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bredden på bitfältet %qD har icke-heltalstyp %qT"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "den statiska datamedlemmen %q+D är inuti deklarationsmålsdirektiv"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonym post som inte är inuti en namngiven typ"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha ickestatiska datamedlemmar"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "privat medlem %q#D i anonym union"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "skyddad medlem %q#D i anonym union"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonyma aggregat med namnrymdsräckvidd måste vara statiska"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonym union utan medlemmar"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> måste returnera typ %qT"
@@ -42679,67 +42851,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "första parametern till %<operator new%> kan inte ha standardargument"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> tar typen %<size_t%> (%qT) som första parameter"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> måste returnera typ %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> tar typen %qT som första parameter"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT har ett fält %qD vars typ inte har någon länkklass"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT har ett fält %qD vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT har ett fält %qD vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT är deklarerad med större synlighet än typen för dess fält %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT har en bas %qT vars typ inte har någon länkklass"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT har en bas %qT vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT har en bas %qT vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT är deklarerad med större synlighet än sin bas %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D, deklarerad med en namnlös typ, används men är aldrig definierad"
@@ -42748,62 +42920,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D refererar inte till den okvalificerade typen, så den används int för länkklass"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, deklarerad med en lokal typ %qT, används men är aldrig definierad"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "typen %qT utan länkklass använd för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "typen %qT utan någon länkklass använd för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "mangling av %q#D som %qE står i konflikt med en tidigare mangling"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "tidigare mangling %q#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "en senare -fabi-version= (eller =0) undviker detta fel med en ändring av manglingen"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "programmet borde även definiera %qD"
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-funktion %qD använd men aldrig definierad"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "standardargumentet saknas för parameter %P till %q+#D"
@@ -42810,17 +42982,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "användning av den inbyggda parameterpaketet %qD utanför en mall"
@@ -42830,112 +43002,112 @@
 msgid "with"
 msgstr "med"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(inga argument)"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[…]"
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "utökade initierarlistor är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "explicita konverteringsoperatorer är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "variadiska mallar är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "lambdauttryck är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 auto är endast tillgängligt med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "enum med räckvidd är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "standarddefinierade och borttagna funktioner är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "inline-namnrymder är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "styrning av åsidosättande (override/final) är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "initierare av datamedlemmar som inte är statiska är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "användardefinierade litteraler är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "delegerande konstruerare är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "ärvande konstruerare är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "c++11-attribut är endast tillgängligt med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "ref-kvalificerare är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "ofullständig typ %qT använd i nästad namnspecificerare"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "referens till %<%T::%D%> är tvetydig"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD har inte en medlem av %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD är inte en medlem av %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> har inte deklarerats"
@@ -43081,358 +43253,358 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(om detta inte är vad du avsåg, se till att funktionsmallen redan har deklarerats och lägg till <> efter funktionsnamnet här) "
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "värdeinitiering av ofullständig typ %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "det går inte att värdeinitiera vektorn %qT med okänd gräns"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "värdeinitiering av funktionstypen %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "värdeinitiering av referenstypen %qT"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursiv instansiering av standarddatamedleminitierare för %qD"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "standardmedlemsinitieraren för %qD behövs före slutet på dess omgivande klass"
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, gcc-internal-format
 msgid "defined here"
 msgstr "definierad här"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initierare för flexibel vektormedlem %q#D"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD skall initieras i medlemsinitieringslistan"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD initieras med sig själv"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ogiltig initierare för vektormedlem %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "oinitierad const-medlem i %q#T"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D borde initieras"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "oinitierad referensmedlem i %q#T"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD kommer initieras efter"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "basen %qT kommer initieras efter"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  basen %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  vid initiering här"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "flera initieringar givna för %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "flera initieringar givna för basen %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initiering av flera medlemmar av %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "basklass %q#T skulle varit explicit initierad i kopieringskonstrueraren"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "klass %qT har inget fält med namnet %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D är en statisk datamedlem; den kan endast initieras vid sin definition"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D är inte en icke-statisk datamedlem i %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "namnlös initierare för %qT, som inte har några basklasser"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "namnlös initierare för %qT som använder multipelt arv"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD är både en direkt bas och en indirekt virtuell bas"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typ %qT är inte en direkt eller virtuell bas till %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "typ %qT är inte en direkt bas till %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT är inte en klasstyp"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ofullständig typ %qT har inte medlem %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ogiltigt pekare till bitfält %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion %qD"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ogiltig användning av icke-statisk datamedlem %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %<%T [%wu]%> och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar en vektor av objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "heltalsspill i vektorstorlek"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "vektorstorlek i new-uttryck måste vara en konstant"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variabelt ändrad typ inte tillåten i new-uttryck"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr "en ny längd för en icke-konstant vektor måste anges direkt, inte av en typedef"
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "new-längden för en icke-konstant vektor måste anges utan parenteserna runt typ-id:t"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "ogiltig typ %<void%> för new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "oinitierad const i %<new%> av %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ingen lämplig %qD i klassen %qT"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "begäran av medlem %qD är tvetydig"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> av typ %qT med utökad justering %d"
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "använder %qD, som inte har någon justeringsparameter"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "använd %<-faligned-new%> för att aktivera stöd för C++17 överjusterade new"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initierare inom parentes i vektor-new"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "storlek i vektor-new måste ha heltalstyp"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan inte användas på en referenstyp"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan inte användas på en funktionstyp"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "möjligt problem upptäckt vid anrop av operatorn delete []:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn delete [] kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "initierare tar slut i förtid"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "okänd vektorstorlek i delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "möjligt problem upptäckt vid anrop av operatorn delete:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn delete kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "radering av objekt av den abstrakta klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "radering av objekt av den polymorfa klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "typ till vektor-delete är varken pekar- eller vektortyp"
@@ -43443,8 +43615,9 @@
 msgstr "vektor- och körtidsgränser kan inte fångas av kopiering, endast via referens"
 
 #: cp/lambda.c:557
-#, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+#, fuzzy, gcc-internal-format
+#| msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "fångst av typen %qT med variabel storlek som inte är en N3639-vektor av körtidsgräns"
 
 #: cp/lambda.c:561
@@ -43527,67 +43700,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(om du använder %<-fpermissive%>, kommer G++ acceptera din kod, men man bör undvika att tillåta användning av ett odeklarerat namn)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "manglar typeof, använd decltype istället"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "manglar __underlying_type"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "manglar okänd fixdecimaltyp"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "användning av inbyggd egenskap %qE i funktionssignatur; använd biblioteksegenskaper istället"
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "manglar %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "utelämnad mittenoperand till %<?:%> kan inte manglas"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "stränglitteral i funktionsmallsignatur"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "det manglade namnet för %qD kommer ändras i C++17 eftersom undantagsspecifikationen är en del av funktionstypen"
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det manglade namnet på %qD ändrades mellan %<%s=%d%> (%D) och %<%s=%d%> (%D)"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "det manglade namnet på %qD ändras mellan %<%s=%d%> (%D) och %<%s=%d%> (%D)"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det manglade namnet på en snutt för %qD ändras mellan -fabi-version=%d och -fabi-version=%d"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det manglade namnet på %qD ändras mellan -fabi-version=%d och -fabi-version=%d"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det manglade namnet på initieringsvaktsvariabeln för %qD ändras mellan -fabi-version=%d och -fabi-version=%d"
@@ -43706,42 +43879,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "standarddefinierad funktion %q+D med standardargument"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D står i konflikt med tidigare deklaration"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D döljer konstruerare för %q#D"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "motstridande deklaration av C-länkning av %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "på grund av olika undantagsspecifikationer"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklaration av %q#D skuggar en parameter"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarationen av %qD skuggar en medlem av %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "lokal extern deklaration av %q#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "matchar inte tidigare deklaration %q#D"
@@ -43749,57 +43922,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "vändeklaration %qD i lokal klass utan en tidigare lokal deklaration"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr "inskjuten vän %qD är synlig på grund av %<-ffriend-injection%>"
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "namnuppslagning av %qD ändrades"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr "matchar denna %qD under ISO:s standardregler"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr "  stämmer med denna %qD under gamla regler"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "namnuppslagning av %qD ändrad för räckvidd i %<for%> enligt ISO"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "det går inte att använda föråldrad bindning vid %qD för att den har en destruerare"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr "använder föråldrad bindning %qD"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %<%s(%E)%> %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%qT är inte en namnrymd eller uppräkningstyp utan räckviddsbegränsning"
@@ -43806,12 +43979,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "en using-deklaration kan inte ange ett mall-id.  Försök med %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "namnrymd %qD är inte tillåten i using-deklaration"
@@ -43818,103 +43991,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT är inte en namnrymd"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD är redan deklarerad i detta definitionsområde"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD inte deklarerad"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-deklaration för icke-medlem vid klassräckvidd"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> namnger en destruerare"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> namnger konstruerare i %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "kan inte ärva konstruerare från den indirekta basen %qT"
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "inga medlemmar matchar %<%T::%D%> i %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklaration av %qD inte i namnrymd som omger %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explicit-kvalifikation i deklaration av %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD har inte deklarerats inom %qD"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "endast här som %<friend%>"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD borde ha deklarerats inuti %qD"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "attributet %qD kräver ett ensamt NTBS-argument"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "attributet %qD är meningslöst eftersom medlemmar av den anonyma namnrymden får lokala symboler"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "ignorerar attributet %qD på en anonym namnrymd"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ignorerar attributet %qD på en namnrymd som inte är inline"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attributdirektivet %qD ignorerat"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "maxgräns på %d namnrymder sökta %qE"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -43921,78 +44094,85 @@
 msgstr[0] "föreslaget alternativ:"
 msgstr[1] "föreslagna alternativ:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "föreslaget alternativ: %qs"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> är definierad i huvudet %qs; glömde du %<#include %s%>?"
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
+#, fuzzy, gcc-internal-format
+#| msgid "%s is not available for %s architecture"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%s är inte tillgängligt för arkitekturen %s"
+
+#: cp/name-lookup.c:5929
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "makrot %qs har inte definierats ännu"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "det definierades senare här"
 
-#: cp/name-lookup.c:6476
-#, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+#: cp/name-lookup.c:6687
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "definitionen av std::initializer_list matchar inte #include <initializer_list>, är inte en mall"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "direktivet strong using stödjs inte längre"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "du kan använda inline-namnrymder istället"
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "attributet ignorerat på lokalt using-direktiv"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namnrymdsalias %qD inte tillåtet här, antar %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "det går inte att nästa mer än %d namnrymder"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "inline-namnrymder måste anges vid den ursprungliga definitionen"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD definierades här"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX går in i pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX lämnar pop_everything ()\n"
@@ -44012,7 +44192,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P är inte satt till true"
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -44037,7 +44217,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "begäran av medlem %qE i typ %qT som inte är en klasstyp"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> har inte deklarerats"
@@ -44117,7 +44297,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ förbjuder användning av en flyttalslitteral i ett konstantuttryck"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "en typomvandling till en annan typ än en heltals- eller uppräkningstyp kan inte förekomma i ett konstantuttryck"
@@ -44339,7 +44519,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "kan inte hitta en stränglitteraloperator %qD med argumenten %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "en deklaration förväntades"
@@ -44419,7 +44599,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "räckvidd %qT före %<~%> är inte ett klassnamn"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> är endast tillgängligt med -std=c++14 eller -std=gnu++14"
@@ -44434,862 +44614,853 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-namnet %qD använt som destruerardeklarerare"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "litterala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> hittades i kapslad namnspecifikation, %<::%> förväntades"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype beräknas till %qT, som inte är en klass eller uppräkningstyp"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "funktionsmalls-id %qD i nästad namnspecificerare"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "variabelmall-id %qD  i nästad namnspecificerare"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD är inte en mall"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "nästat namn-specificerare förväntades"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "typer får inte definieras i typkonverteringar"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ förbjuder sammansatta litteraler"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "två på varandra följande %<[%> får bara introducera ett attribut"
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ogiltigt användning av %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> är inte en klassmedlem"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "icke skalär typ"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tillåter inte %<alignof%> med annat än en typ"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "typer får inte definieras i %<noexcept%>-uttryck"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer får inte definieras i en new-uttryck"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "vektorgräns är förbjuden efter typ-id i parenteser"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "försök ta bort parenteserna runt typ-id:t"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "initiering av new-uttryck för typen %<auto%> tar precis ett element"
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "uttryckslista eller typ-id förväntades"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "typer får inte definieras i en new-type-id"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "uttryck i new-deklarerare måste ha heltals- eller uppräkningstyp"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "användning av gammaldags typkonvertering till %q#T"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "operatorn %<>>%> hanteras som två högervinkelparenteser i C++11"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "föreslår parenteser runt %<>>%>-uttryck"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tillåter inte ?: med mellersta operanden utelämnad"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in conditions"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "typer får inte definieras i villkor"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "lambdauttryck i oevaluerat sammanhang"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "lambdauttryck i mallargument"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "slut på fångstlista förväntades"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %<this%> överflödigt med standardfall av fångst via kopiering"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "fångst av %<*this%> är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "lambdafångstinitierare är endast tillgängliga med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "tom initierare för lambdas init-fångst"
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "fångst av en icke-variabel %qE"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D är deklarerad här"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "fångst av variabeln %qD med ej automatisk lagringsvaraktighet"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %qD överflödigt vid standardfångst via kopiering"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "explicit fångst via referens av %qD överflödigt med standardfångst via referens"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "lambdamallar är endast tillgängliga med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "lambdamallar är endast tillgängliga med -std=c++2a eller -std=gnu++2a"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "standardargumentet angivet för lambdaparameter"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "dubblerad %<mutable%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "%<constexpr%> lambda är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attribut vid början av satser ignoreras"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "etikettsats förväntades"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-etikett %qE är inte i en switch-sats"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> behövs före %qE för att %qT är en beroende räckvidd"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> namnger konstrueraren, inte typen"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "sammansatt sats i en %<constexpr%>-funktion"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "%<if constexpr%> är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "init-satsen i valsatser är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "typer får inte definieras i villkor"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "intervallbaserat %<for%>-uttryck av typen %qT har ofullständig typ"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "intervallbaserat %<for%>-uttryck av typen %qT har en %<end%>-medlem men inte någon %<begin%>"
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "intervallbaserat %<for%>-uttryck av typen %qT har en %<begin%>-medlem men inte någon %<end%>"
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserat %<for%>-sats: %qT och %qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "intervallbaserad %<for%>-slinga är endast tillgänglig med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> i %<constexpr%>-funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "extra %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> som inte inleder ett block"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "icke-variabel %qD i deklaration med mer än en deklarerare med platshållartyp"
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "inkonsistent härledning för %qT: %qT och sedan %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "att blanda deklarationer och funktionsdefinitioner är förbjudet"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "typer får inte definieras i en for-range-deklaration"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initierare i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flera deklarationer i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "strukturerade bindningar är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "tom deklaration av strukturerad bindning"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ogiltig initierare för deklaration av strukturerad bindning"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> använd utanför en klass"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> ändrar betydelse i C++11; var god ta bort det"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specificerare är ogiltig i villkor"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD är ogiltigt i lambda"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "klassdefinition kan inte deklareras som en vän"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ogiltig länkklasspecifikation"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "static_assert utan ett meddelande är endast tillgänglig med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "typer får inte definieras i %<decltype%>-uttryck"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "typer får inte definieras i en conversion-type-id"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ogiltig användning av %<auto%> i konverteringsoperator"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "användning av %<auto%> i medlemsmallskonverteringsoperator kan aldrig vara härledd"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "endast konstruerare tar medlemsinitierare"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "det går inte att expandera initierare för medlem %qD"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anakronistisk gammaldags basklassinitierare"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (en kvalificerad medlemsinitierare är implicit en typ)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "oväntat nyckelord; ta bort mellanrum mellan citationstecken och suffixidentifierare"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "suffixidentifierare förväntades"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "en tom sträng förväntades efter nyckelordet %<operator%>"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ogiltigt kodningsprefix i litteral operator"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operator förväntades"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "nyckelordet %<export%> är inte implementerat och kommer ignoreras"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ogiltig begränsad typparameter"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-kvalificerad typparameter"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "variadisk begränsning introducerad utan %<...%>"
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "felaktig användning av %<auto%> i standardmallargument"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "mallparameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "mallparameterpaket kan inte ha standardargument"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "mall-id förväntades"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kan inte inleda en argumentlista till en mall"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> är en alternativ stavning av %<[%>.  Lägg in mellanrum mellan %<<%> och %<::%>"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(om du använder %<-fpermissive%> eller %<-std=c++11%> eller %<-std=gnu++11%> kommer G++ acceptera din kod)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "parsningsfel i mallargumentlista"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "mallnamn förväntades"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "icke-mall %qD använd som mall"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "använd %<%T::template %D%> för att indikera att det är en mall"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "parameterpaket förväntades före %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "mallargument förväntades"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ogiltigt mallargument som inte är en typ"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "en explicit instansiering skall inte använda %<inline%>-specificerare"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "en explicit instansiering skall inte använda %<constexpr%>-specificerare"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "mallspecialisering med C-länkning"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i lambdaparameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med -fconcepts"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "mall-id för typ förväntades"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "typnamn förväntades"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "beräknad typspecifikation för en enum med räckvidd får inte använda nyckelordet %qD"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklaration %qD deklarerar inte något"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributet ignorerat på oinstansierad typ"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attribut ignoreras vid mallinstansiering"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attribut ignoreras för bearbetade typspecificerare som inte är en framåtdeklaration"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD är en uppräkningsmall"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD är inte namnet på en uppräkningstyp i %qT"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "namnlös enum med räckvidd är inte tillåtet"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> eller %<{%> förväntades"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "det går inte att lägga till en uppräkningslista till en mallinstansiering"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "nästad namnspecificerare %qT för enum-deklaration som inte namnger en klass eller namnrymd"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "deklaration av %qD i namnrymd %qD som inte innesluter %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "deklaration av %qD i %qD som inte innesluter %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "extra kvalifikation inte tillåten"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ förbjuder tomma namnlösa enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "ogenomskinlig enum-specifikation utan namn"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "en ogenomskinlig enum-specifikation måste använda en enkel identifierare"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD är inte ett namnrymdsnamn"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "namnrymdsnamn förväntades"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "nästade namnrymdsdefinitioner är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nästat namnrymdsnamn krävs"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "namnrymdsnamn krävs"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "en nästad namnrymdsdefinition kan inte ha attribut"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "en nästad namnrymdsdefinition kan inte inline:as"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "gick in i namnrymden %qD"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-definition är inte tillåten här"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "paketexpansion i using-deklaration är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ett mall-id får inte förekomma i en using-deklaration"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "en kommaseparerad lista i using-deklaration är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "åtkomstdeklarationer bör undvikas till förmån för using-deklarationer; förslag: lägg till nyckelordet %<using%>"
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "typer får inte definieras i aliasmalldeklarationer"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition är inte tillåten här"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "en asm-specifikation är inte tillåten på en funktionsdefinition"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attribut är inte tillåtna vid en funktionsdefinition"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "konstruerare, destruerare eller typkonvertering förväntades"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initierare förväntades"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initierare angiven för funktion"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attribut efter initierare inom parentes ignoreras"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "icke-funktionen %qD deklarerad som implicit mall"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "vektorgräns är inte en heltalskonstant"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "det går inte att definiera medlem av beroende typedef %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> är inte en typ"
@@ -45298,17 +45469,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ogiltig deklarator"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ogiltig användning av konstruerare som en mall"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "använd %<%T::%D%> istället för %<%T::%D%> för att namnge konstrueraren i ett kvalificerat namn"
@@ -45315,382 +45486,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "kvalificerad id i deklaration"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "deklarator förväntades"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD är en namnrymd"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "kan inte skapa en pekare till medlem av %q#T som inte är en klass"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "oväntad pekaroperator"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "upprepade cv-kvalificerare"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "upprepade ref-kvalificerare"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE kräver %<-fgnu-tm%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "upprepade virt-specificerare"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "mallargument saknas efter %qT"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ogiltigt användning av %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "typer får inte definieras i mallargument"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "felaktig användning av %<auto%> i mallargument"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> eller %<...%> förväntades"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "typer får inte definieras i parametertyper"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardargument är endast tillåtna för funktionsparametrar"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "mallparameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "C++ designerade initierare är endast tillgängliga med -std=c++2a eller -std=gnu++2a"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillåter inte GNUs designerade initierare"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillåter inte C99:s designerade initierare"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "antingen skall alla initierarklausuler vara designerade eller så skall ingen av dem var det"
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> är inte tillåtet i en designerad initierarlista"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "designeraren %<.%s%> använd flera gånger i samma intierarlista"
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "klassnamn förväntades"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> förväntades efter klassdefinition"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> förväntades efter postdefinition"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> förväntades efter uniondefinition"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> eller %<:%> förväntades"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "det går inte att ange %<override%> för en klass"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globala kvalificering av klassnamn är ogiltigt"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "kvalificerat namn namnger inte en klass"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "nyckelordet %<template%> är inte tillåtet i klasshuvudnamn"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ogiltigt klassnamn i deklaration av %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "en explicit specialisering måste föregås av %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktionsmall %qD omdeklarerad som en klassmall"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "det gick inte att lösa upp typnamnstyp"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "föregående definition av %q#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr "ISO C++ förbjuder nyckelordet typename i mall-mall-parameter; använd -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> eller %<typename%> förväntades"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "i C++03 måste en klassnyckel användas när en vän deklareras"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "vändeklaration som inte namnger en klass eller funktion"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "en lagringklass på ett anonymt aggregat i klassräckvidd tillåts inte"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "standardmedlemsinitierare för bitfält är endast tillgängliga med -std=c++2a eller -std=gnu++2a"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "standardmedlemsinitierare för namnlöst bitfält"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ tillåter endast bitfältsattribut före symbolen %<:%>"
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-specificerare på funktionsdefinition"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "extra %<;%> efter funktionsdefinition i klassen"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "överblivet %<,%> vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> förväntades vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ogiltig pure-specificerare (endast %<= 0%> är tillåtet)"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "en klammeromsluten initierare är inte tillåten här"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> anges mer än en gång i basspecificerare"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mer än en åtkomstspecifikation i basspecificerare"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "nyckelordet %<typename%> är inte tillåtet utanför mallar"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (basklassen är implicit en typ)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "typer får inte definieras i en undantagsspecifikation"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 tillåter inte dynamiska undantagsspecifikationer"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamiska undantagsspecifikationer undanbedes i C++11"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ogiltig användning av %<auto%> i undantagsspecifikation"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "typer får inte definieras i undantagsdeklarationer"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "attribut som använder prefix använt tillsammans med attributsymboler med räckvidd"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "en identifierare förväntades som attributnamn"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "attributet %<noreturn%> får förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "attributet %<deprecated%> kan förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut förväntades före %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "attribut som använder prefix är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> är endast tillgängligt med -fconcepts"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "ett transaktionsuttryck får inte finnas utanför en mall"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -45699,519 +45870,519 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> eller <typename CharT, CharT...> förväntades"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> förväntades"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "tom introduktionslista"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "det finns inget matchande koncept för mallintroduktionen"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "en klassmallsdeklaration får inte deklarera något annat"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> förväntades"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> förväntades"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-väljarnamn"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltigt typ på egenskap"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "inte tillräckligt med for-slingor att kollapsa"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- eller __restrict-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> namnger en mängd överlagrade"
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD refererar inte till en funktion med namnrymdsräckvidd"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "skräp vid slutet av %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> måste vara inuti en funktion"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> måste vara inuti en funktion"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "intermoduloptimeringar inte implementerade för C++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-länkning startade här"
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "datamedlem %qD kan inte vara en medlemsmall"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ogiltig medlemsmalldeklaration %qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explicit specialisering som inte är i namnrymdsområde %qD"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "inneslutande klassmallar är inte explicit specialiserade"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering av %qD i förekomma i namnrymdsräckvidd"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "specialisering av %qD i en annan namnrymd"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  från definitionen av %q#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explicit instansiering av %qD i namnrymden %qD (som inte omsluter namnrymden %qD)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "namn på klass skuggar mallmallparameter %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "specialisering av aliasmall %qD"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explicit specialisering av icke-mall %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering av %qT efter instansiering"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "specialiserar %q#T i en annan namnrymd"
@@ -46218,88 +46389,88 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering %qT efter instansiering %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "mallspecialisering av %qD är inte tillåten av ISO C++"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering av %qD efter instansiering"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD är inte en funktionsmall"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD är inte en variabelmall"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "mall-id %qD för %q+D stämmer inte med någon malldeklaration"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "såg %d %<template<>%>, behöver %d för specialisering av medlemsfunktionsmall"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig mallspecialisering %qD för %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "variabelmallar är endast tillgängliga med -std=c++14 eller -std=gnu++14"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "fel antal mallhuvuden för %qD (skulle vara %d)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "medlemmar av en explicit specialiserad klass definieras utan ett mallhuvud"
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explicit specialisering av %qD utanför dess namnrymd måste använda en nästat-namn-specificerare"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explicit instansiering av %qD utanför dess namnrymd måste använda en nästat-namn-specificerare"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "explicit specialisering %q#D kan sakna attribut"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "primära mallattribut %s saknas"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "primärt mallattribut %s saknas"
@@ -46306,57 +46477,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "mall-id %qD i deklaration av primär mall"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "mallparameterlista använd i explicit instansiering"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition given för explicit instansiering"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "för många mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "för få mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "explicit specialisering av %qD måste inledas av %<template <>%>"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "explicit specialisering  deklarerad %<concept%>"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "partiell specialisering som inte är en typ av %qD är inte tillåten"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "partiell specialisering som inte är en klass eller variabel av %qD är inte tillåten"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardargument angivet i explicit specialisering"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD är inte en mallfunktion"
@@ -46369,137 +46540,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering av implicit deklarerad specialmedlemsfunktion"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion %qD är deklarerad i %qT"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "vändeklarationen %qD är inte synlig för en explicit specialisering"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "vändeklarationen här"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "explicit specialisering av funktionskonceptet %qD"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "argument till __integer_pack måste vara mellan 0 och %d"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "basinitierarexpansionen %qT innehåller inga parameterpaket"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "expansionsmönster %qT innehåller inga argumentpaket"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "expansionsmönster %qE innehåller inga argumentpaket"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameterpaket expanderas inte med %<...%>:"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonym>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklaration av mallparametern %q+D skuggar en mallparameter"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklaration av %q+#D skuggar en mallparameter"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "mallparametern %qD deklarerad här"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "specialisering av variabelkonceptet %q#D"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "mallparameter är inte härledbara i partiell specialisering:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument och är inte mer begränsad än<; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "huvudmall här"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partiell specialisering är inte mer specialiserad än huvudmallen eftersom den ersätter flera parametrar med en paketexpansion"
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partiell specialisering %qD är inte mer specialiserad än"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "huvudmallen %qD"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameterpaketargument %qE måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameterpaketargument %qT måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "mallargument %qE berör mallparametrar"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46506,17 +46677,17 @@
 msgstr[0] "typ %qT för mallargument %qE beror på en mallparameter"
 msgstr[1] "typ %qT för mallargument %qE beror på mallparametrar"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "deklaration av %qD gör tidigare mallinstansiering av %qD tvetydig"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "partiell specialisering %qD efter instansiering av %qD"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "inget standardargument för %qD"
@@ -46524,47 +46695,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameterpaket %q+D måste vara vid slutet av mallens parameterlista"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardmallargument får inte användas i vänomdeklaration av funktionsmall"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardmallargument får inte användas i vändeklarerade mallar"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "standarmallargument får inte användas i funktionsmallar utan -std=c++11 eller -std=gnu++11"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "standardmallargument får inte användas i partiella specialiseringar"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardargumentet för mallparameter för klass om omsluter %qD"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "mallen %qD deklarerad"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "mallklass utan ett namn"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
@@ -46574,57 +46745,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ogiltig malldeklaration av %qD"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malldefinition av icke-mall %q#D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d nivåer av mallparametrar förväntades till %q#D, %d fanns"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "fick %d mallparametrar till %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "fick %d mallparametrar till %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d behövs"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "mallargument till %qD stämmer inte med originalmallen %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "använd %<template<>%> för en explicit specialisering"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT är inte en malltyp"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "mallspecificerare inte angivna i deklarationen av %qD"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46631,7 +46802,7 @@
 msgstr[0] "omdeklarerad med %d mallparameter"
 msgstr[1] "omdeklarerad med %d mallparametrar"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46638,12 +46809,12 @@
 msgstr[0] "tidigare deklaration av %qD använde %d mallparameter"
 msgstr[1] "tidigare deklaration av %qD använde %d mallparametrar"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "mallparameter %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "omdeklarerad här som %q#D"
@@ -46652,117 +46823,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinition av standardargument till %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprunglig definition fanns här"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "omdeklaration av %q#D med andra begränsningar"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprunglig deklaration fanns här"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "det måste vara adressen till en funktion med extern lagringsklass"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "det måste vara namnet på en funktion med extern lagringsklass"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "det måste vara en pekare-till-medlem på formen %<&X::Y%>"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "för att den int är en medlem av %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  kunde inte härleda mallparametrar %qD"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  typerna %qT och %qT har inkompatibla cv-kvalificerare"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  typerna %qT och %qT stämmer inte överens"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  mallparameter %qD är inte ett parameterpaket, men argument %qD är det"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  mallargument %qE stämmer inte med pekare till medlem-konstanten %qE"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE är inte ekvivalent med %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  inkonsistent härledning av parameterpaket med %qT och %qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  härledda typer i konflikt för parametern %qT (T%qT och %qT)"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  härledda värden i konflikt för icke-typ-parametern %qE (%qE och %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  medlemsfunktionstypen %qT är inte ett giltigt mallargument"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46769,287 +46940,293 @@
 msgstr[0] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  kan inte konvertera %qE (typen %qT) till typ %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT är en tvetydig basklass till %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT är inte härledd från %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  mallparametrarna till ett mallmallargument är inkonsistenta med andra härledda mallargument"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  det går inte att härleda en mall för %qT från typen %qT som inte är en mall"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  mallargument %qE stämmer inte med %qE"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom strängkonstanter aldrig kan användas i detta sammanhang"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "i mallargument för typen %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "mallargumentet %qE för typen %qT är inte ett konstant heltal"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD är inte ett giltigt mallargument för att %qD är en variabel, inte adressen till en variabel"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE är inte ett giltigt mallargument till %qT för det är inte adressen till en variabel"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qE inte är en variabel"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "adressen till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "adressen till underobjektet %qT till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "adressen till %qD är inte ett giltigt mallargument av typ eftersom den inte har statisk lagringsvaraktighet"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det inte är ett objekt med länkklass"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom objekt %qD inte har någon länkklass"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ignorerar attribut i mallargumentet %qE"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "begränsningar stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD förväntades men fick %qD"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunde inte konvertera mallargument %qE från %qT till %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "angivna till %qD"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till konceptet %qD"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "mallbegränsningsfel"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "användning av felaktig variabelmall %qE"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "flexibel vektormedlem i union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "fold över tom expansion över %O"
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qT"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qE"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  vid instansiering av standardargument för anrop av %qD"
@@ -47067,276 +47244,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%>  för att expandera argumentpaket"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansieringar av icke-mall %q#D"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "explicit specifikation av %qD beror på sig själv"
@@ -47348,106 +47525,112 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "nyckelordet %<template%> är inte tillåtet i deklarerar-id"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "härledning från klammeromgiven initierarlista kräver %<#include <initializer_list>%>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "icke-klass-mall %qT använd utan mallargument"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "kan inte härleda mallargument till %qT, eftersom den inte några användbara härledningsguider"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of %<auto%> in template argument"
+msgid "invalid use of %qT in template argument"
+msgstr "felaktig användning av %<auto%> i mallargument"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -47650,7 +47833,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ogiltigt kvalificerande räckvidd i pseudodestruerarnamn"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "kvalificerad typ %qT matchar inte destruerarnamnet ~%qT"
@@ -47700,7 +47883,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
@@ -47772,294 +47955,296 @@
 msgstr "%qT är inte ett uppräkningstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpakets-__bases är endast giltiga i malldeklarationer"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "det går inte att applicera %<offsetof%> på destrueraren %<~%T%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr "andra operanden till %<offsetof%> är varken en ensam identifierare eller en sekvens av medlemsåtkomster och vektorreferenser"
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
+
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "det går inte att använda %<offsetof%> på en uppräknare %qD"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "offsetof inom icke-standardlayouttypen %qT är odefinierat"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> tillåtet i OpenMP endast i %<declare simd%>-klausuler"
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "användardefinierad reduktionsuppslagning är tvetydig"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE har const-typ för %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "användardefinierad reduktion med konstruerarinitierare för basklassen %qT"
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linjär klausul med modifieraren %qs tillämpad på en variabel som inte är en referens med typen %qT"
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte pekare med typen %qT"
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD är inte en variabel i klausul %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD är inte en variabel i klausul %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%>-statiskt uttryck måste vara heltal"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%>-statiskt värde måste vara positivt"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%>-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%>-längdvärdet måste vara positivt"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "uttryck för styckesstorlek för schemaläggning måste vara heltal"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs längduttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-id måste vara ett heltal"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> styckesstorleksuttryck måste vara heltal"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD är inte en variabel i %<aligned%>-klausul"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%>-klausuls justeringsuttryck måste vara heltal"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD är inte en variabel i %<depend%>-klausul"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "mallen %qE i-klausulen %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "överlagrad funktion med namnet %qE i klausulen %qs"
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_tasks%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs-variabeln är varken en pekare, eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%>-argumentet behöver en heltalstyp"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använd med klassiterationsvariabeln %qE"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statisk försäkran misslyckades"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statisk försäkran misslyckades: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argument till decltype måste vara ett uttryck"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kan inte lösa upp adressen till en överlagrad funktion"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
@@ -48184,12 +48369,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attributet %qE tillämpat på extern \"C\"-deklaration %qD"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "noll som en nollpekarkonstant"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontroll: misslyckades i %s, vid %s:%d"
@@ -48249,726 +48434,722 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "samma kanoniska typnod för olika typer %qT och %qT"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ogiltig användning av %qs på en medlemsfunktion"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ogiltig användning av %<sizeof%> på ett bitfält"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<sizeof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ogiltig användning av %<__alignof%> på ett bitfält"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<__alignof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "argumentet till %<alignas%> har typen %qT som inte är en heltalstyp"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion av typen %qT"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "tar adress till temporär vektor"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ förbjuder konvertering av en strängkonstant till %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konvertering från strängkonstant till %qT bör undvikas"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "begäran av medlem %qD i %qE, som är av pekartypen %qT (kanske du hade tänkt använda %<->%> ?)"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "begäran av medlem %qD i %qE, som är av icke-klasstyp %qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ogiltig användning av icke-statisk datamedlem %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ogiltig åtkomst av icke-statisk datamedlem %qD i virtuell bas till NULL-objekt"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objekttyp %qT stämmer inte med destruerarnamnet ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "typen som destrueras är %qT, men destrueraren refererar till %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "fältet %q#D kan kommas åt via %q#D"
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> är inte en medlem av %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT är inte en basklass till %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %qE?"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T har ingen medlem med namnet %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD är inte en medlemsmallfunktion"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT är inte en pekare-på-objekt-typ"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ogiltig användning av vektorindexering på pekare till medlem"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ogiltig användning av unärt %<*%> på pekare till medlem"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ogiltig användning av implicit konvertering av pekare till medlem"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "vänstra operanden till %<->*%> måste vara en pekare på en klass, men är en pekare på en medlem av typen %qT"
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "index saknas i vektorreferens"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "indexering av vektor deklarerad %<register%>"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objekt saknas i användning av %qE"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "det går inte att anropa funktionen %qD"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ förbjuder anrop av %<::main%> inifrån program"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "man måste använda %<.*%> eller %<->*%> för att anropa en pekare-till-medlems-funktion i %<%E (...)%>, t.ex. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kan inte användas som en funktion"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kan inte användas som en funktion"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "uttryck kan inte användas som en funktion"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "för många argument till konstrueraren %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "för få argument till konstrueraren %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "för många argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "för få argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "för många argument till funktionen %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "för få argument till funktionen %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "för många argument till metoden %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "för få argument till metoden %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "för många argument till funktion"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "för få argument till funktion"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P till %qD har ofullständig typ %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametern %P har ofullständig typ %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen till %qD kommer aldrig vara NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kompilatorn kan anta att adressen till %qD aldrig kommer att vara NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antar typkonvertering till %qT från överlagrad funktion"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL använd i aritmetik"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "längd att rotera till vänster är negativ"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "längd att rotera till höger är negativ"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "längd att rotera till vänster ≥ storleken på typen"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "längd att rotera till höger ≥ storleken på typen"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ förbjuder jämförelse mellan pekare och heltal"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operandtyper är %qT och %qT"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "oordnad jämförelse av argument som inte är flyttal"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implicit konvertering från %qH till %qI för att matcha den andra operanden i binärt uttryck"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ogiltiga operander av typ %qT och %qT till binär %qO"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare av typ %<void *%> i subtraktion"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en funktion i subtraktion"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en metod i subtraktion"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ogiltig användning av en pekare till en ofullständig typ i pekararitmetik"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "tar adressen till konstrueraren %qD"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "tar adressen till destrueraren %qD"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ogiltig användning av %qE för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  ett kvalificerat id krävs"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parenteser runt %qE kan inte användas för att skapa en pekare-till-medlem-funktion"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en okvalificerad eller parentetiserad icke-statisk medlemsfunktion för att skapa en pekare till en medlemsfunktion.  Säg %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en bunden medlemsfunktion för att skapa en pekare till medlemsfunktion.  Säg %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "tar adress till något temporärt"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "tar adressen till xvalue (rvalue-referens)"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ förbjuder att ta adressen till funktionen %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan inte skapa pekare till referensmedlem %qD"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "försök att ta adressen till bitfält"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr "%<~%> på ett uttryck av typ bool"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "tänkte du använda logiskt icke (%<!%>)?"
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ förbjuder ökning av enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ förbjuder minskning av enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "det går inte att öka en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "det går inte att minska en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder ökning av pekare på typ %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder minskning av pekare på typ %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "användning av en operand av typen %qT i %<operator--%> är förbjudet"
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "användning av en operand av typen %qT i %<operator++%> är förbjudet i C++17"
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "användning av en operand av typen %qT i %<operator++%> bör undvikas"
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan inte ta adressen till %<this%>, som är ett rvalue-uttryck"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adress till explicit registervariabel %qD begärd"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adress begärd till %qD, som är deklarerad %<register%>"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "listinitierare för en typ som inte är en klass får inte vara inom parenteser"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i initierare"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i medlemsinitierare"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "uttryckslista behandlas som sammansatt uttryck i funktionstypkonvertering"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "uttryckslistan %s behandlas som sammansatt uttryck"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "ingen kontext för att lösa upp typen på %qE"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "konvertering från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "oanvändbar konvertering till typen %q#T"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "typkvalificerare ignoreras för typkonverterings resultattyp"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ogiltig static_cast från typ %qT till typ %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 msgid "converting from %qH to %qI"
 msgstr "konvertering från %qH till %qI"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ogiltig typkonvertering av ett rvärdeuttryck av typ %qT till typ %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr "konvertering från %qH till %qI förlorar precision"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "konvertering mellan inkompatibla funktionstyper från %qH till %qT"
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "typkonvertering mellan inkompatibla pekare till medlemstyper från %qH till %qI"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typkonvertering från %qH till %qI ökar kravet på justering för måltypen"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "typkonvertering mellan pekare-till-funktion och pekare-till-objekt stödjs villkorligt"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ogiltig konvertering från typ %qT till typ %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ogiltig användning av const_cast med typ %qT, som inte är en pekare, referens, eller pekare-till-datamedlem-typ"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "ogiltig användning av const_cast med typ %qT, som är en pekare eller referens till en funktionstyp"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "ogiltig const_cast av ett rvärde av typ %qT till typ %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ogiltig const_cast från typ %qT till typ %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ förbjuder typkonvertering till en vektortyp %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ogiltig konvertering till funktionstyp %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i beräkningen av %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "tilldelning till en vektor från en initierarlista"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "inkompatibla typer i tilldelning av %qT till %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "vektor använd som initierare"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ogiltig vektortilldelning"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i konvertering av pekare till medlemsfunktion"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "konvertering av pekare till medlem via virtuell bas %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i konvertering av pekare till medlem"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ogiltig konvertering till typ %qT från typ %qT"
 
-#: cp/typeck.c:8786
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "kan inte konvertera %qH till %qI för argument %qP till %qD"
+#: cp/typeck.c:8812 cp/typeck.c:8829
+msgid "cannot convert %qH to %qI"
+msgstr "det går inte att konvertera %qH till %qI"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "det går inte att konvertera %qH till %qI i standardargument"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "det går inte att konvertera %qH till %qI när argument skickas"
 
-#: cp/typeck.c:8800
-msgid "cannot convert %qH to %qI"
-msgstr "det går inte att konvertera %qH till %qI"
-
-#: cp/typeck.c:8804
+#: cp/typeck.c:8833
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "det går inte att konvertera %qH till %qI i initiering"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 msgid "cannot convert %qH to %qI in return"
 msgstr "det går inte att konvertera %qH till %qI i retur"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "det går inte att konvertera %qH till %qI i tilldelning"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "returtypen %qT är ofullständig"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "parameter %qP till %qD kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "parameter kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "målet för konvertering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "målet för initialisering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "när argument %P till %qD skickades"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerar referens till en temporär"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "referens till annat än lvärde returnerad"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "referens till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adressen till etiketten %qD returnerad"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adress till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerar ett värde från en destruerare"
@@ -48975,55 +49156,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "det går inte att returnerar från en hanterare i ett funktions-try-block eller en konstruerare"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerar ett värde från en konstruerare"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-sats utan värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "returnerar en initierarlista"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "inkonsistenta typer %qT och %qT härledda för lambda-returtypen"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "inkonsistent härledning för auto-returtyp: %qT och sedan %qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-sats med ett värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> får inte returnera NULL om den inte är deklarerad %<throw()%> (eller -fcheck-new är aktivt)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "använder temporär som lvärde"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "hjälp xvärde (rvärdesreferens) som lvärde"
@@ -49244,140 +49425,140 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "konstruerarsyntax använd, men ingen konstruerare är deklarerad för typ %qT"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "avsmalnande konvertering av %qE från %qH till %qI inuti { } är felaktig i C++11"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "avsmalnande konvertering av %qE från %qH till %qI inuti { }"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " uttrycket har ett konstant värde men är inte ett C++ konstant uttryck"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-vektor initierad från icke-bred sträng"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-vektor initierad från inkompatibel bred sträng"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "initierarsträng för vektor av tecken är för stor"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt litteral"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "ordningen på designeraren för fält %qD stämmer inte med deklarationsordningen i %qT"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde före C++2a"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "kan inte härleda mallargument för %qT från ()"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -49801,48 +49982,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr "Vektorkonstruerarvärde vid %L får inte vara obegränsat polymorft [F2008: C4106]"
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Olika CHARACTER-längder (%ld/%ld) i vektorkonstruerare vid %L"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr "spec_dimen_size(): Felaktig dimension"
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr "gfc_ref_dimen_size(): Felaktig dimension"
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Felaktig vektordimension vid %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr "Förenklingsfel"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr "gfc_ref_dimen_size(): Felaktig dimen_type"
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr "gfc_array_dimen_size(): Felaktig dimension"
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr "gfc_array_dimen_size(): Felaktigt EXPR_ARRAY-uttryck"
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr "gfc_find_array_ref(): Det finns ingen referens"
@@ -50837,7 +51018,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Maximal utökningsnivå nådd med typen %qs vid %L"
@@ -51007,7 +51188,7 @@
 msgid "deferred type parameter at %C"
 msgstr "fördröjd typparameter vid %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalärt INTEGER-uttryck förväntades vid %L"
@@ -51257,449 +51438,449 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Explicit formad vektor med ickekonstanta gränser vid %C"
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs vid %C är en omdefinition av deklarationen i motsvarande gränssnitt för MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Enheten %qs kan inte ha en initierare vid %C"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Dubblerad vektorspecifikation för Cray-utpekad vid %C"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Kunde inte sätta utpekads vektorspecifikation."
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Gammaldags initiering vid %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Felaktig gammaldags initiering av härledd typkomponent vid %C"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Syntaxfel i gammaldags initiering av %s vid %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initieringen vid %C är inte för en pekarvariabel"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Pekarinitiering vid %C kräver %<=>%>, inte %<=%>"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ett initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initiering av variabel vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initiering av allokerbar komponent vid %C är inte tillåtet"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Komponenten med attributet KIND eller LEN vid %C förekommer inte i typparameterlistan vid %L"
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Komponenten vid %C som förekommer i typparameterlistan vid %L har varken attributet KIND eller LEN"
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Pekarkomponenten vid %C som är en typparameter måste vara en skalär"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Gammaldags typdeklaration %s*%d stödjs inte vid %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Typdeklaration ej enligt standard %s*%d vid %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Saknad högerparentes vid %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ett skalärt initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Sorten %d stödjs inte för typen %s vid %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Parameter med sort C är för typ %s men typen vid %L är %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Högerparentes eller komma saknas vid %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Sorten %d stödjs inte för typen CHARACTER vid %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfel i CHARACTER-deklaration vid %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr "RECORD vid %C är en utökning, aktivera den med -fdec-structure"
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Postnamn förväntades efter RECORD vid %C"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "Typparameterspecifikationslistan vid %C får inte innehålla både ASSUMED- och DEFERRED-parametrar"
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Typparameterspecifikationslistan vid %C innehåller inte tillräckligt med parameteruttryck"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Den härledda parametern %qs vid %C har inte ett standardvärde"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Parameteruttrycket vid %C måste vara av typen INTEGER och inte av typen %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "KIND-parametern %qs vid %C kan varken vara ASSUMED eller DEFERRED"
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Värdet på KIND-parametern %qs vid %C reduceras inte till ett konstant uttryck"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "Typparameterspecifikationslitan vid %C innehåller för många parameteruttryck"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Parametriserad härledd typ vid %C är tvetydig"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-typ vid %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE-typ använd vid %C är inte tillgänglig på målmaskinen"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Förmodad typ vid %C är inte tillåtet för komponenter"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Antagen typ vid %C"
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE med inbyggd typspecifikation vid %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX vid %C"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typnamnet %qs vid %C är tvetydigt"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-sats vid %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typnamnet %qs vid %C står i konflikt med tidigare deklarerad enhet vid %L, som har samma namn"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Dubblerad IMPLICIT NONE-sats vid %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE med specifikationslista vid %C"
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Teckenintervall saknas i IMPLICIT vid %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Bokstäver måste vara i alfabetisk ordning i IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-sats vid %C följer en IMPLICIT NONE (type)-sats"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tom IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-sats vid %C endast tillåten inuti en INTERFACE-kropp"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT-sats vid %C är inte tillåten i en moduls procedurgränssnittskropp"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-sats vid %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Lista med namngivna entiteter förväntades vid %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Det går inte att IMPORT:era %qs från värdräckviddsenhet vid %C — finns inte."
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs är redan IMPORT:erad från värdräckviddsenhet vid %C."
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfel i IMPORT-sats vid %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Co-dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Dubblerat %s-attribut vid %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s vid %L är en DEC-utökning, aktivera den med %<-fdec-static%>"
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attributet ALLOCATABLE vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attributet KIND vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Komponent med attributet KIND vid %C måste vara INTEGER"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Komponenten med attributet KIND vid %C måste vara av standardheltalssort (%d)"
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Attributet LEN vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponenten med attributet LEN vid %C måste vara INTEGER"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Komponenten attributet LEN vid %C måste vara av standardheltalssort (%d)"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet i en TYPE-definition"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attributet %s vid %L i en TYPE-definition"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribut vid %L är inte tillåtet utanför specifikationsdelen av en modul"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet utanför en TYPE-definition"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attributet ASYNCHRONOUS vid %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attributet CONTIGUOUS vid %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED vid %C är endast tillåtet i specifikation av en del av en modul"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attributet PROTECTED vid %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attributet VALUE vid %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attributet VOLATILE vid %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Felaktigt attribut"
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Flera identifierare angivna med en ensam NAME=-specificerare vid %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implicit deklarerad BIND(C)-funktion %qs vid %L kan inte vara C-interoperativ"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte vara en sort interoperativ med C men common-blocket %qs är BIND(C)"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs vid %L är inte C-interoperativ men den är BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabeln %qs vid %L får inte ha en C-interoperativ sort men den är BIND(C)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte deklareras med BIND(C) eftersom den inte är en global"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet POINTER och BIND(C)"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet ALLOCATABLE och BIND(C)"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en vektor"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en teckensträng"
@@ -51706,951 +51887,951 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbolen %qs vid %L är markerad PRIVATE men har getts bindningsetiketten %qs"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Det behövs antingen entitet- eller common-blocknamn för attributspecifikationssatsen vid %C"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entitets- eller common-blocknamn saknas till attributspecifikationssats vid %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbol saknas"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-sats vid %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Härledd typ vid %C har inte definierats tidigare och kan därför inte förekomma i en härledd typdefinition"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaxfel i anonym postdeklaration vid %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfel i datadeklaration vid %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE-prefix vid %C"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-procedur vid %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE och IMPURE får inte båda finnas vid %C"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Alternativt returargument vid %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Ett parameternamn krävs vid %C"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Namnet %qs vid %C är namnet på proceduren"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "En parameterlista förväntades i typdeklarationen vid %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Oväntat skräp i formell argumentlista vid %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Dubblerat namn %qs i parameterlistan vid %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Dubblerad symbol %qs i formell argumentlista vid %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Formella argumentnamnen till MODULE PROCEDURE stämmer inte (%s/%s) vid %C"
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Antalet formella MODULE PROCEDURE-argument vid %C stämmer inte"
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-variabel vid %C måste vara skilt från funktionsnamnet"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Oväntat skräp efter funktionsdeklaration vid %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Attributet BIND(C) vid %L kan inte anges för en intern procedur"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "Attribut BIND(C) vid %C kräver ett gränssnitt med BIND(C)"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-procedur med NAME får inte ha attributet POINTER vid %C"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Attrapprocedur vid %C kan inte ha attributet BIND(C) tillsammans med NAME"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proceduren %qs vid %L har redan en grundtyp %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfel i PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> förväntades efter bindningsattribut vid %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS eller explicit gränssnitt krävs vid %C"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfel i procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE vid %C måste vara i ett generiskt gränssnitt"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "dubbelkolon i MODULE PROCEDURE-sats vid %L"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formell argumentlista förväntades i funktionsdefinitionen vid %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "Attribut BIND(C) vid %L kan endast användas för variabler och common-block"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-sats vid %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett PROGRAM"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en MODULE"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en SUBMODULE"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett BLOCK DATA"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett STRUCTURE-block"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en ett DERIVED TYPE-block"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett IF-THEN-block"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett DO-block"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett SELECT-block"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett FORALL-block"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett WHERE-block"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett inneslutet underprogram"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Oväntad ENTRY-sats vid %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-sats vid %C kan inte förekomma i en innesluten procedur"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Nödvändig parentes saknas före BIND(C) vid %C"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ogiltig C-identifierare i NAME=-specificerare vid %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfel i NAME=-specifikation för att binda etikett vid %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "NAME=-specificerare vid %C skall vara ett konstant uttryck"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-specificerare vid %C skall vara en skalär av standardteckensort"
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Slutparentes saknas för att binda etikett vid %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Inget bindningsnamn är tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "För attrapprocedur %s är inget bindningsnamn tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME är inte tillåtet på BIND(C) för ABSTRACT INTERFACE vid %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Oväntad END-sats vid %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-sats istället för %s-sats vid %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamn på %qs i %s-sats förväntades vid %L"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Avslutande namn förväntades vid %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Etikett %qs för %s-sats förväntades vid %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i DIMENSION-sats"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensioner angivna för %s vid %L efter dess initiering"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i CODIMENSION-sats"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Vektorspecifikation måste vara fördröjd vid %L"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Oväntat tecken i variabellista vid %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> förväntades vid %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variabelnamn förväntades vid %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-pekare vid %C måste vara ett heltal"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-pekare vid %C har %d bytes precision, minnesadresser kräver %d byte"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "”,” förväntades vid %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "Kunde inte sätta Cray-utpekad vektorspecifikation."
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "”)” förväntades vid %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> eller slut på sats förväntades vid %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray-pekardeklaration vid %C kräver flaggan -fcray-pointer"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-sats vid %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Åtkomstspecifikation av operatorn %s vid %C har redan angivits"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Åtkomstspecifikation för operatorn .%s. vid %C har redan angivits"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-sats vid %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfel i PROTECTED-sats vid %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variabelnamn förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "=-tecken i PARAMETER-sats förväntades vid %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Uttryck förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initierar redan initierad variabel vid %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER utan ”()” vid %C"
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Oväntade tecken i PARAMETER-sats vid %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s vid %C är en DEC-utökning, aktivera den med %<-fdec-static%>"
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Entitetslista förväntades i AUTOMATIC-sats vid %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaxfel i AUTOMATIC-sats vid %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Entitetslista förväntades i STATIC-sats vid %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaxfel i STATIC-sats vid %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Allmän SAVE-sats vid %C följer tidigare SAVE-sats"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-sats vid %C följer allmän SAVE-sats"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfel i SAVE-sats vid %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-sats vid %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfel i VALUE-sats vid %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-sats vid %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE anges för co-vektorvariabel %qs vid %C, vilket är use-/host-associerat"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfel i VOLATILE-sats vid %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfel i ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE PROCEDURE-deklaration vid %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE vid %C måste vara i ett generiskt modulgränssnitt"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Den inbyggda proceduren vid %L kan inte vara en MODULE PROCEDURE"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Tvetydig symbol i TYPE-definition vid %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbolen %qs vid %C har inte definierats tidigare"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs i EXTENDS-uttryck vid %C är inte en härledd typ"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kan inte utökas vid %C för att den är BIND(C)"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kan inte utökas vid %C eftersom det är en SEQUENCE-typ"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PRIVATE i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PUBLIC i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT typ vid %C"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Misslyckades att skapa en post av typen ”%s” vid %C"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Typdefinitionen av %qs vid %C definierades redan vid %L"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Skräp efter MAP-sats vid %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Skräp efter UNION-sats vid %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s vid %C är en DEC-utökning, aktivera den med %<-fdec-structure%>"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Postnamn förväntades i icke nästad postdeklaration vid %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Skräp efter icke nästad STRUCTURE-sats vid %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Postnamnet %qs vid %C får inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: förväntades i TYPE-definition vid %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typnamnet %qs vid %C kan inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Härlett typnamn %qs vid %C har redan en grundtyp %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Härledd typdefinition %qs vid %C har redan definierats"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Skräp efter PARAMETERIZED TYPE-deklaration vid %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-utpekad vid %C kan inte vara förmodat formad vektor"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM och ENUMERATOR vid %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Uppräkningstypen överskrider C:s heltalstyp vid %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L är inte initierad med ett heltalsuttryck"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-definitionssats förväntades före %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfel i ENUMERATOR-definition vid %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Dubblerad åtkomstspecifikation vid %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten NOPASS vid %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten PASS vid %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Dubblerat POINTER-attribut vid %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Dubblerad NON_OVERRIDABLE vid %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Dubblerad DEFERRED vid %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Åtkomstspecificerare förväntades vid %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindningsattribut förväntades vid %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE och DEFERRED kan inte båda finnas vid %C"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-attribut krävs för procedurpekarkomponenten vid %C"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Gränssnittsnamn förväntades efter %<(%> vid %C"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> förväntades vid %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Gränssnitt måste anges för DEFERRED bindning vid %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) vid %C skulle vara deklarerat DEFERRED"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-lista vid %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> mål%> är ogiltigt för DEFERRED-bindning vid %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> behövs i PROCEDURE-bindning med explicit mål vid %C"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindningsmål förväntades efter %<=>%> vid %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typen %qs som innehåller en DEFERRED-bindning vid %C är inte ABSTRACT"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC vid %C måste vara inuti en härledd typs CONTAINS"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> förväntades vid %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generiskt namn eller operatorbeskrivare förväntades vid %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Felformad GENERIC-sats vid %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> förväntades vid %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en icke-generisk procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindning vid %C måste ha samma åtkomst som den redan definierade bindningen %qs"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Specifikt bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs är redan definierat som en specifik bindning för den generiska %qs vid %C"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Skräp efter GENERIC-bindning vid %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-deklaration vid %C måste vara inuti en härledd typs CONTAINS-sektion"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Härledd typdeklaration med FINAL vid %C måste vara med i specifikationsdelen av en MODULE"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tom FINAL vid %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Modulprocedurnamn förväntades vid %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> förväntades vid %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Okänt procedurnamn %qs vid %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs vid %C är redan definierad som FINAL procedur"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Okänt attribut i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfel i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Direktivet %<GCC unroll%> kräver en icke-negativ heltalskonstant mindre än eller lika med %u vid %C"
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaxfel i direktivet !GCC$ UNROLL vid %C"
@@ -52985,27 +53166,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "BOZ-litteral vid %L används för att initiera icke-heltalsvariabeln %qs"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "BOZ-litteral vid %L utanför en DATA-sats och utanför INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ-litteral vid %L är bitvis överförd icke-heltalssymbol %qs"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetiskt underspill av bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetiskt överspill vid bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetisk NaN vid bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
@@ -53330,7 +53511,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Skapar vektortemporär vid %L"
@@ -53340,62 +53521,62 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Tar bort anrop av funktionen %qs vid %L"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "felaktigt uttryck"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr "felaktig operator"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "otillåten OP i optimize_comparison"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Variabeln %qs vid %L satt till odefinierad inuti en slinga som börjar vid %L är argument INTENT(OUT) till subrutin %qs"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Variabeln %qs vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till subrutin %qs"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i slingan som börjar vid %L"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i slingan som börjar vid %L"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Variabeln %qs vid %L satt till odefinierad inuti slingan som börjar vid %L är argument INTENT(OUT) till funktionen %qs"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabeln %qs vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till funktionen %qs"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Kod för omallokering av den allokerbara vektorn vid %L kommer läggas till"
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr "Skalärisering med DIMEN_RANGE är oimplementerat"
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "Utväxlande slingor vid %L"
@@ -53515,12 +53696,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -54710,7 +54891,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -56144,12 +56325,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Oväntat skräp efter $OMP FLUSH-sats vid %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr "Omdefinition av fördefinierad %s !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr "Omdefinition av fördefinierad !$OMP DECLARE REDUCTION vid %L"
@@ -56389,8 +56570,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-klausulparameter är mindre än COLLAPSE vid %L"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
@@ -56432,7 +56613,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Symbolen %qs finns i flera fall vid %L"
@@ -56774,182 +56955,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "%s-kollapsad slinga formar inte en rektangulär iterationsrymd vid %L"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "kollapsade %s-slingor är inte perfekt nästade vid %L"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "inte tillräckligt med DO-slingor för kollapsad %s vid %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "Direktivet %s kan inte anges inuti en %s-region vid %L"
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$ACC LOOP får inte vara en DO WHILE eller DO utan slingstyrning vid %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$ACC LOOP-iterationsvariabel måste ha typen heltal vid %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$ACC LOOP %s-slingor formar inte en rektangulär iterationsrymd vid %L"
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "%s !$ACC LOOP-slingor är inte perfekt nästade vid %L"
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "inte tillräckligt med DO-slingor för %s !$ACC LOOP vid %L"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr "!$ACC LOOP %s i PARALLEL-region tillåter inte %s-argument vid %L"
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr "Slinga parallelliserad över gang är inte tillåten inuti en annan slinga parallelliserad över gang vid %L"
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr "Slinga parallelliserad över gang är inte tillåten inuti en slinga parallelliserad över worker vid %L"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr "Slinga parallelliserad över worker är inte tillåten inuti en annan slinga parallelliserad över worker vid %L"
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Slinga parallelliserad över worker är inte tillåten inuti en annan slinga parallelliserad över vektorer vid %L"
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Slinga parallelliserad över vektorer är inte tillåten inuti en annan slinga parallelliserad över vektorer vid %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "Klausulen SEQ står i konflikt med INDEPENDENT vid %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "Klausulen SEQ  står i konflikt med GANG vid %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "Klausulen SEQ står i konflikt med WORKER vid %L"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "Klausulen SEQ står i konflikt med VECTOR vid %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "Klausulen SEQ står i konflikt med AUTO vid %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "Klausulen AUTO står i konflikt med GANG vid %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "Klausulen AUTO står i konflikt med WORKER vid %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "Klausulen AUTO står i konflikt med VECTOR vid %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr "Slinga uppdelad i bitar kan inte parallelliseras över gang, worker och vektorer på samma gång vid %L"
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE behöver ett konstant uttryck vid %L"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "PARAMETER-objekt %qs är inte tillåtet vid %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Vektorsektioner: %qs är inte tillåtet i !$ACC DECLARE vid %L"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr "OMP TARGET UPDATE vid %L behöver åtminstone en TO- eller FROM-klausul"
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr "!$OMP DECLARE SIMD skall referera till den inneslutande proceduren %qs vid %L"
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "En annan variabel än OMP_PRIV eller OMP_ORIG använd i INITIALIZER-klausul i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "En annan variabel än OMP_OUT eller OMP_IN använd i kombineraren i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr "Felaktig operator för !$OMP DECLARE REDUCTION %s vid %L"
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr "CHARACTER-längden i !$OMP DECLARE REDUCTION %s är inte konstant vid %L"
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Subrutinanrop med alternativa returer i kombinerare i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Subrutinanrop med alternativa returer i INITIALIZER-klausul i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr "Ett av de aktuella subrutinargumenten i INITIALIZER-klausulen i !$OMP DECLARE REDUCTION måste vara OMP_PRIV vid %L"
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr "INITIALIZER-klausul saknas i !$OMP DECLARE REDUCTION av härledd typ utan standardinitierare vid %L"
@@ -58299,7 +58480,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>."
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
@@ -58409,7 +58590,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
@@ -58783,228 +58964,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller över"
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller under"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på enheten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen EVENT_TYPE eller ha en EVENT_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation eller vektorvärt SOURCE=-uttryck krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "”*” förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Errmsg-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -59013,232 +59194,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektorn vid %L får inte vara NULL()"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektorn vid %L har ingen typ"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS vid %L överlappar med TYPE IS vid %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s-procedur vid %L måste vara rekursiv"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha PRIVATE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Händelsevariabeln vid %L måste vara en skalär av typen EVENT_TYPE"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor eller co-indexerat"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor men inte co-indexerat"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller ordning-1-uttryck"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
@@ -59245,12 +59426,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -59258,107 +59439,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär variabel av heltalstyp"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%ld/%ld) vid %L"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Den orena variabeln vid %L är tilldelad till en härledd typvariabel med en POINTER-komponent i en PURE-procedur (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn ”=”"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
@@ -59365,67 +59546,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Procedurpekartilldelning vid %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en INTEGER-variabel"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ogiltig NULL vid %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett skalärt REAL- eller INTEGER-uttryck"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en enhet vid %L"
@@ -59432,7 +59613,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använder samma globala identifierare som enheten vid %L från modulen %qs"
@@ -59440,57 +59621,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som enheten vid %L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen %qs kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet POINTER eller ALLOCATABLE"
@@ -59497,887 +59678,887 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn %qs vid %L måste ha konstant form"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s vid %L"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionens resultatvariabel %qs vid %L för den elementära funktionen %qs skall inte ha ett attribut ALLOCATABLE eller POINTER"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "ELEMENTAL-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "PURE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "RECURSIVE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s mellan MODULE PROCEDURE-deklarationen i MODULE %qs och deklarationen vid %L i (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Typgränsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponenten %qs med typen BIND(C) vid %L måste ha längden ett"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Pekarkomponenten %qs av %qs vid %L är en typen som inte har deklarerats"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initierare som står i konflikt i unionen vid %L och %L"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Den parameteriserade typen %qs har inte någon komponent som motsvarar parametern %qs vid %L"
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Objektet %qs vid %L har en fördröjd LEN-parameter %qs och är varken ollokerbar eller en pekare"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "AUTOMATIC-objektet %qs vid %L får inte ha attributet SAVE eller vara en variabel deklarerad i huvudprogrammet, en modul eller en submodul(F08/C513)"
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Objektet %qs vid %L med ASSUMED typparametrar måste vara en attrapp eller en SELECT TYPE-selektor(F08/4.2)"
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Felaktig specifikation för vektor med antagen storlek vid %L"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-variabeln %qs vid %L måste ha längden ett"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen EVENT_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Felaktigt uttryck"
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats."
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -60813,7 +60994,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Oväntad typ"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Tecknet %qs i sträng vid %L kan inte konverteras till tecken av sort %d"
@@ -61455,18 +61636,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Inbyggd funktion %qs (%d) känns inte igen"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%<dim%>-argumentet till inbyggd %s vid %L är inte ett giltigt dimensionsindex"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Ledsen, händelsekomponenten hos härledd typ vid %L stödjs inte ännu"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Händelsevariabeln vid %L får inte vara co-indexerad"
@@ -61647,177 +61828,177 @@
 msgid "previously defined here as %s"
 msgstr "tidigare definierad här som %s"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "flera gällande definitioner för %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD är redan definierad"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "tidigare definition här"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "%qD bryter mot C++ endefinitionsregel "
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "typen på %qD stämmer inte med originaldeklarationen"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "justering av %qD är större än originaldeklarationen"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr "storleken på %qD skiljer från storleken på originaldeklarationen"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "%qD deklarerades tidigare här"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr "koden kan feloptimeras om inte -fno-strict-aliasing används"
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "variabeln %qD omdeklarerad som en funktion"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "funktionen %qD omdeklarerad som en variabel"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "tidigare deklarerad här"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "bytekodström: skräp i slutet av symbolsektionen"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "kunde inte tolka hexadecimalt tal"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "oväntat filnamn %s i länkupplösningsfilen.  %s förväntades"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "det gick inte tolka filavstånd"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "oväntat avstånd"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ogiltig rad i upplösningsfilen"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ogiltig upplösning i upplösningsfilen"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "upplösnings-under-id %wx är inte en objektfil"
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "det går inte att läsa LTO-deklarationer från %s"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "Kan inte öppna %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "Kan inte avbilda %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "Kan inte läsa %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() misslyckades"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid misslyckades"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "strömmande underprocess misslyckades"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "strömmande underprocess dödades av en signal"
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "inget filnamn för LTRANS-utdatalista angivet"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "när LTRANS-utdatafil %s öppnades: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "när utdata skrevs till LTRANS-utdatalista %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "när LTRANS-utdatalista %s stängdes: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "det gick inte att öppna symbolupplösningsfilen: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "upplösningsdata saknas för %s"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "fel vid sammanslagning av översättningsenheter"
@@ -62758,3 +62939,48 @@
 #, gcc-internal-format
 msgid "creating selector for nonexistent method %qE"
 msgstr "skapar väljare för icke existerande metod %qE"
+
+#~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+#~ msgstr "Stöd inbyggda funktioner och kodgenerering för Control-flow  Enforcement Technology (CET)."
+
+#~ msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+#~ msgstr "Aktiverar specifikt en funktion för indirekt grenspårning från Control-flow Enforcement Technology (CET)."
+
+#~ msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#~ msgstr "Ange det maximala antalet byte att jämföra inline med icke-slingkod.  Om detta är satt till 0 är all inline-expansion (icke-slinga och slinga) av memcmp avaktiverad."
+
+#~ msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+#~ msgstr "Ange det maximala antalet byte att jämföra inline med slingkodgenerering.  OM längden inte är känd vid kompileringstillfället kommer memcmp att anropas efter att detta antal byte har jämförts.  Som standard kommer en längd att väljas beroende på trimningsmålet."
+
+#~ msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
+#~ msgstr "%K%qD: att skriva %E byte till en region av storlek %E spiller över destinationen"
+
+#~ msgid "%K%qD reading %E bytes from a region of size %E"
+#~ msgstr "%K%qD läser %E byte från en region av storlek %E"
+
+#~ msgid "builtin operand should be an unsigned 6-bit value"
+#~ msgstr "inbyggds operand skall vara ett teckenlöst 6-bitars värde"
+
+#~ msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
+#~ msgstr "operanden till sleep-instruktionen måste vara en teckenlös 6-bitars kompileringstillfälleskonstant"
+
+#~ msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
+#~ msgstr "%<-fcf-protection=branch%> kräver stöd för Intel CET.  Använd flaggan -mcet eller -mibt att aktivera CET"
+
+#~ msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
+#~ msgstr "%<-fcf-protection=return%> kräver stöd för Intel CET.  Använd flaggan -mcet eller -mshstk för att aktivera CET"
+
+#~ msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
+#~ msgstr "%<-fcf-protection=full%> kräver stöd för Intel CET.  Använd flaggan -mcet eller båda flaggorna -mibt och -mshstk för att aktivera CET"
+
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "intervallbaserat %<for%>-uttryck av typen %qT har en %<end%>-medlem men inte någon %<begin%>"
+
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "intervallbaserat %<for%>-uttryck av typen %qT har en %<begin%>-medlem men inte någon %<end%>"
+
+#~ msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+#~ msgstr "andra operanden till %<offsetof%> är varken en ensam identifierare eller en sekvens av medlemsåtkomster och vektorreferenser"
+
+#~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#~ msgstr "kan inte konvertera %qH till %qI för argument %qP till %qD"
Index: gcc/po/de.po
===================================================================
--- gcc/po/de.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/de.po	(.../branches/gcc-8-branch)
@@ -10,7 +10,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1-b20180401\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2018-04-06 22:42+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
@@ -154,40 +154,40 @@
 msgid "negative insn length"
 msgstr "negative Befehlslänge"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "Befehl kann nicht aufgeteilt werden"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "ungültiges »asm«: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "geschachtelte Assemblerdialekt-Alternativen"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "unbeendete Assemblerdialekt-Alternative"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "Operandennummer fehlt hinter %%-Buchstabe"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "Operandennummer außerhalb des Wertebereiches"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "ungültiger %%-Code"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "»%%l«-Operand ist keine Marke"
@@ -198,13 +198,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "Gleitkommakonstante falsch verwendet"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1181,25 +1181,25 @@
 msgid "At top level:"
 msgstr "Auf höchster Ebene:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "In Elementfunktion %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "In Funktion %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    eingefügt von %qs bei%r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    eingefügt von %qs bei %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    eingefügt von %qs"
@@ -2937,9 +2937,9 @@
 msgid "invalid address mode"
 msgstr "ungültiger Adressierungsmodus"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
@@ -2955,7 +2955,7 @@
 msgstr "ungültiger %%r-Wert"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2962,13 +2962,13 @@
 msgstr "ungültiger %%R-Wert"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
@@ -2999,7 +2999,7 @@
 msgstr "ungültiger %%U-Wert"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
@@ -3010,7 +3010,7 @@
 msgstr "ungültiger %%C-Wert"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
@@ -3021,7 +3021,7 @@
 msgstr "Unbekanntes relocation unspec"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3032,57 +3032,57 @@
 msgid "invalid operand address"
 msgstr "ungültige Operandenadresse"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ungültiger Operand für Code %%Z"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ungültiger Operand für Code %%z"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "ungültige Operanden für Code %%c"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ungültiger Operand für Code %%M"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ungültiger Operand für Code %%p"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ungültiger Operand für Code %%s"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ungültiger Operand für %%R-Code"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ungültiger Operand für %%H/%%L-Code"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ungültiger Operand für %%U-Code"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ungültiger Operand für %%V-Code"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ungültiger Operand für Code %%O"
@@ -3089,18 +3089,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ungültiger Operanden-Ausgabecode"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ungültiges UNSPEC als Operand: %d"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "unerkannte vermutete Konstante"
 
@@ -3135,7 +3135,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
@@ -3258,8 +3258,8 @@
 msgstr "ungültiger const_double-Operand"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3476,97 +3476,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "Falscher Operand für output_condmove_single"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ungültiges UNSPEC als Operand"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "Ungültige Verwendung von Register »%s«"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ungültige Verwendung der asm-Schalter-Ausgabe"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ungültige Operandengröße für Operandencode »O«"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ungültige Operandengröße für Operandencode »z«"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ungültiger Operandentyp mit Operandencode »Z« verwendet"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ungültige Operandengröße für Operandencode »Z«"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »Y«"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »D«"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "Operand ist keine ausgleichbare Speicherreferenz, ungültiger Operandencode »H«"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »K«"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »r«"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ungültige Bedingungen für Operand"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ungültiger Vektordirektwert"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "unbekannter Befehlsmodus"
 
@@ -3604,7 +3604,7 @@
 msgstr "ungültiger %%P-Operand"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -3658,7 +3658,7 @@
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -3821,141 +3821,141 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "»-mtoc-fusion« benötigt medium/large-Codemodell"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 und __ibm128 können nicht im selben Ausdruck verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 und long double können nicht im gleichen Ausdruck verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 und long double können nicht im selben Ausdruck verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr "addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, falsches Register #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, falsches Register #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load kein MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, falsches Register #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, falsches Register #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store kein MEM"
 
@@ -4081,43 +4081,43 @@
 msgid "created and used with different endianness"
 msgstr "erzeugt und mit anderer Bytereihenfolge verwendet"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ungültiger %%Y-Operand"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ungültiger %%A-Operand"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ungültiger %%B-Operand"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ungültiger %%C-Operand"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ungültiger %%D-Operand"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ungültiger %%f-Operand"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ungültiger %%s-Operand"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "Gleitkommakonstante ist kein gültiger direkter Operand"
@@ -4332,14 +4332,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -4354,7 +4354,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -4362,7 +4362,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -4376,7 +4376,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
@@ -4383,7 +4383,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -4393,13 +4393,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
@@ -4408,18 +4408,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
@@ -4427,23 +4427,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
@@ -4452,7 +4452,7 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<%> erwartet"
@@ -4463,39 +4463,39 @@
 msgid "expected label"
 msgstr "Sprungmarke erwartet"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "Kandidat 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "Kandidat 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "Sprung zur Marke %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "Sprung zur case-Marke"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr "Betreten von try-Block"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr "Betreten des catch-Blocks"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr "Betreten des OpenMP-strukturierten Blocks"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 msgid "enters synchronized or atomic statement"
 msgstr "Betreten der synchronisierten oder atomaren Anweisung"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 msgid "enters constexpr if statement"
 msgstr "Betreten der if-Anweisung mit constexpr"
 
@@ -4584,7 +4584,7 @@
 msgid "<statement>"
 msgstr "<Anweisung>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<unbekannt>"
@@ -4603,114 +4603,114 @@
 msgid "<unparsed>"
 msgstr "<nicht-analysiert>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr "<lambda>"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<Ausdrucksfehler>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<unbekannter Operator>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "Im globalen Gültigkeitsbereich:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "In statischer Elementfunktion %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "In Kopierkonstruktor %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "In Konstruktor %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "In Destruktor %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "In Lambda-Funktion"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: In Ersetzung von %qS:\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: In Instanziierung von %q#D:\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr "%r%s:%d:%d:%R   "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr "%r%s:%d:%R   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "rekursiv erforderlich durch Ersetzung von %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr "erforderlich durch Ersetzung von %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr "rekursiv erfordert von %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr "erfordert durch %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr "rekursiv erfordert von hier\n"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr "von hier erfordert\n"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%d:%R   [ %d Instanziierungskontexte werden übersprungen, »-ftemplate-backtrace-limit=0« zum Ausschalten verwenden ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%r%s:%d:%R   [ %d Instanziierungskontexte werden übersprungen, »-ftemplate-backtrace-limit=0« zum Ausschalten verwenden ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%d:%R   in %<constexpr%>-Ersetzung von %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   in %<constexpr%>-Ersetzung von %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "Kandidaten sind:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
@@ -4756,48 +4756,48 @@
 msgid "source type is not polymorphic"
 msgstr "Quellentyp ist nicht polymorph"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "Argument falschen Typs für unäres Minus"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "Argument falschen Typs für unäres Plus"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "Argument falschen Typs für Bit-Komplement"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "Argument falschen Typs für abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "Argument falschen Typs für Konjugation"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "in Argument für unäres !"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "kein Präinkrementoperator für Typ"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "kein Postinkrementoperator für Typ"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "kein Prädekrementoperator für Typ"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "kein Postdekrementoperator für Typ"
 
@@ -5068,11 +5068,11 @@
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
@@ -5227,47 +5227,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Ränge für Operator bei %%L und %%L stimmen nicht überein"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
@@ -5309,12 +5309,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Ungleiche Zeichenlängen (%ld/%ld) in %s"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist negativ (sein Wert ist %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist zu groß"
 
@@ -5548,6 +5548,7 @@
 msgstr "»-Xbind-now« und »-Xbind-lazy« sind unverträglich"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "evtl. »-pg« statt »-p« mit gprof(1) verwenden"
 
@@ -8208,7 +8209,7 @@
 msgstr "Variablen auf 32-Bit-Grenzen ausrichten."
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr "Namen der Ziel-Architektur angeben."
 
@@ -8651,7 +8652,7 @@
 msgstr "Bereich der zu fixierenden Register angeben."
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr "Bit-Breite des unmittelbaren TLS-Versatzes angeben."
 
@@ -9310,7 +9311,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Code erzeugen, der zum angegebenen ABI passt."
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "Bekannte ABIs (für Verwendung mit Option -mabi=):"
 
@@ -9712,7 +9713,7 @@
 msgstr "Eingebaute PKU-Funktionen und Codeerzeugung unterstützen."
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr "Angegebenen Stapelschutz-Wächter verwenden."
 
@@ -9721,12 +9722,12 @@
 msgstr "Bekannte Stapelschutz-Wächter (für Verwendung mit Option -mstack-protector-guard=):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "Angegebenes Basisregister zur Adressierung des Stapelschutz-Wächters verwenden."
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "Angegebenen Offset zur Addressierung des Stapelschutz-Wächters verwenden."
 
@@ -9738,43 +9739,48 @@
 msgid "Attempt to avoid generating instruction sequences containing ret bytes."
 msgstr "Möglichst Befehlsfolgen erzeugen, die keine RET-Bytes enthalten."
 
-# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=84807
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Eingebaute Funktionen und Codeerzeugung für Control-flow Enforcement Technology (CET) unterstützen."
+#, fuzzy
+#| msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr "Aktiviert insbesondere die Stapelspeicher-Sicherungskopie im Rahmen der Control-Flow Enforcement Technology (CET)."
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
-msgstr "Aktiviert insbesondere das Nachverfolgen von indirekten Sprüngen im Rahmen der Control-Flow Enforcement Technology (CET)."
-
-#: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr "Aktiviert insbesondere die Stapelspeicher-Sicherungskopie im Rahmen der Control-Flow Enforcement Technology (CET)."
-
-#: config/i386/i386.opt:1026
 msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr "Aktiviert CET-Instrumentierung für solche switch-Anweisungen, die Sprungtabellen und indirekte Sprünge verwenden."
 
-#: config/i386/i386.opt:1031
+#: config/i386/i386.opt:1021
 msgid "Make all function calls indirect."
 msgstr "Alle Funktionsaufrufe indirekt machen."
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr "Indirekte Aufrufe und Sprünge in Aufrufe umwandeln und Thunks zurückgeben."
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr "Funktionsrückkehr in Aufruf umwandeln und Thunk zurückgeben."
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "Bekannte indirekte Sprungauswahlen (für Verwendung mit den Optionen -mindirect-branch=/-mfunction-return=):"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr "Indirekte Aufrufe und Sprünge mittels Register erzwingen."
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Eingebaute Funktionen und Codeerzeugung für BMI unterstützen."
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Eingebaute Funktionen und Codeerzeugung für BMI unterstützen."
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr "Annehmen, dass der Code später mit GNU ld gebunden wird."
@@ -10149,7 +10155,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Veraltete Option. Stattdessen -mvrsave verwenden."
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr "Angabe, wie viele Bytes inline kopiert werden, bevor memcpy/memmove aufgerufen wird."
 
@@ -10157,7 +10163,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr "Die Höchstzahl an Befehlspaaren angeben, die für den Vergleich inline erzeugt wird. Wenn mehr benötigt werden, wird stattdessen die Funktion »memcmp« aufgerufen."
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr "Die Höchstzahl an Befehlspaaren angeben, die für den Vergleich inline erzeugt wird. Wenn mehr benötigt werden, wird stattdessen die Funktion »strncmp« aufgerufen."
 
@@ -10241,7 +10247,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\tCode für die angegebene CPU planen."
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr "-mtraceback=\tVoll-, Teil- oder keine Traceback-Tabelle (full, part, no)."
 
@@ -10269,7 +10275,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Gültige Argumente für -mfloat-gprs=:"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr "-mlong-double-<n>\tGröße von »long double« angeben (64 oder 128 Bits)."
 
@@ -10345,23 +10351,23 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Befehle aus ISA 2.07 Category:Vector.AES und Category:Vector.SHA2 verwenden."
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr "Befehle für direktes Kopieren zwischen GPR- und VSX-Registern verwenden, wie in ISA 2.07 angegeben."
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Befehle aus ISA 2.07 für transaktionalen Speicher (HTM) verwenden."
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Befehle zum Laden/Speichern von Quadwords (lq/stq) erzeugen."
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr "Atomare Quadword-Befehle zum Speicherzugriff verwenden (lqarx/stqcx)."
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr "Code zum Übergeben von Aggregaten mit maximal 64-Bit-Ausrichtung erzeugen."
 
@@ -10381,19 +10387,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr "Mit den Optionen »-mcpu=power7« oder »-mvsx« 64-Bit-Ganzzahlvariablen in oberen Registern erlauben."
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr "Doppelwort-Vertauschungen aus VSX-Berechnungen analysieren und entfernen."
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr "Bestimmte Operationen verschmelzen, um die Performance auf power9 zu steigern."
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Bestimmte skalare Befehle verwenden, die in ISA 3.0 hinzugefügt wurden."
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr "Vektor-Befehle verwenden, die in ISA 3.0 hinzugefügt wurden."
 
@@ -10409,15 +10415,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr "Register+Offset-Speicherzugriffsbefehle verwenden, die in ISA 3.0 hinzugefügt wurden."
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Min-/Max-Befehle verwenden, die in ISA 3.0 hinzugefügt wurden."
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr "Verweise auf das Inhaltsverzeichnis für medium/large-Codemodell mit Speicherzugriffsbefehlen verschmelzen."
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 msgid "Generate the integer modulo instructions."
 msgstr "Ganzzahl-Modulo-Befehle erzeugen."
 
@@ -10425,15 +10431,15 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr "Die IEEE-128-Bit-Typen erlauben, ohne das Schlüsselwort »__float128« zu erfordern."
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "IEEE-128-Bit-Gleitkommazahlen mittels Schlüsselwort »__float128« einschalten."
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "IEEE-128-Bit-Gleitkomma-Befehle einschalten."
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr "Standardumwandlungen zwischen »__float128« und »long double« einschalten."
 
@@ -10441,7 +10447,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Zulassen, dass kleine Ganzzahlen in VSX-Registern gespeichert werden."
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Gültige Argumente für -mstack-protector-guart=:"
 
@@ -10470,12 +10476,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Vor jedem Funktionsprolog mcount für Profiling aufrufen."
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr "ABI-Aufrufkonvention auswählen."
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr "Methode für sdata-Behandlung auswählen."
 
@@ -11131,7 +11136,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Sich überschneidende Ziel- und Adressregister bei solchen LDRD-Befehlen vermeiden, die Cortex-M3-Errata auslösen können."
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "Nicht ausgerichtete Wort- und Halbwortzugriffe auf gepackte Daten einschalten."
 
@@ -11320,14 +11325,30 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mvrsave=yes%> ist veraltet. Verwenden Sie stattdessen %<-mvrsave%>"
 
+#: config/rs6000/rs6000.opt:334
+#, fuzzy
+#| msgid "Max. count of debug markers to expand or inline."
+msgid "Max number of bytes to move inline."
+msgstr "Maximalzahl der Debugmarkierungen, die expandiert oder eingereiht werden."
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
-msgstr "Höchstanzahl von Bytes, um Inline-Code mit schleifenfreiem Code zu vergleichen. Ein Wert von 0 bedeutet, dass memcmp überhaupt nicht geinlinet wird."
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare without loops."
+msgstr "Die Höchstzahl der Befehle einer ungeschalteten Schleife."
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr "Höchstanzahl von Bytes, um Inline-Code mit schleifenbasiertem Code zu vergleichen. Wenn die Länge zur Übersetzungszeit nicht bekannt ist, wird nach dieser Anzahl von Bytes memcmp aufgerufen. Der Vorgabewert für die Länge hängt von der Zielarchitektur ab (-mtune=)."
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop."
+msgid "Max number of bytes to compare with loops."
+msgstr "Die Höchstzahl der Befehle einer ungeschalteten Schleife."
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop."
+msgid "Max number of pairs of load insns for compare."
+msgstr "Die Höchstzahl der Schälvorgänge einer einzelnen Schleife."
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr "%<-misel=no%> ist veraltet. Verwenden Sie stattdessen %<-mno-isel%>"
@@ -11336,10 +11357,48 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-misel=yes%> ist veraltet. Verwenden Sie stattdessen %<-misel%>"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table."
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tVoll-, Teil- oder keine Traceback-Tabelle (full, part, no)."
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\tGröße von »long double« angeben (64 oder 128 Bits)."
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs ist veraltet"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention."
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "ABI-Aufrufkonvention auswählen."
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling."
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Methode für sdata-Behandlung auswählen."
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr "Nur-Lese-Daten in sdata-Abschnitt erlauben."
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets."
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Bit-Breite des unmittelbaren TLS-Versatzes angeben."
+
 #: config/alpha/alpha.opt:27
 msgid "Use fp registers."
 msgstr "FP-Register verwenden."
@@ -12432,86 +12491,152 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "GCC erlauben, SETLB- und Lcc-Befehle zu verwenden."
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "Code im »Big Endian«-Modus erzeugen."
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "Code im »Little Endian«-Modus erzeugen."
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr "Eingeschränkten Registersatz für die Allozierung verwenden."
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 msgid "Use full-set registers for register allocation."
 msgstr "Vollständigen Registersatz für die Allozierung verwenden."
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+#, fuzzy
+#| msgid "Patchable function entry > size"
+msgid "Align function entry to 4 byte."
+msgstr "Eintrag für patchbare Funktion > Größe"
+
+#: config/nds32/nds32.opt:91
 msgid "Generate conditional move instructions."
 msgstr "Verwendung bedingter Kopierbefehle einschalten."
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 msgid "Generate performance extension instructions."
 msgstr "Erweiterungsbefehle für Performance einschalten."
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr "Erweiterungsbefehle für Performance Version 2 einschalten."
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 msgid "Generate string extension instructions."
 msgstr "Erweiterungsbefehle für Zeichenketten einschalten."
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Befehle push25/pop25 für v3 erzeugen."
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr "16-Bit-Befehle erzeugen."
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr "Virtual-Hosting-Unterstützung einschalten."
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr "Die Größe jedes Interrupt-Vektors (muss 4 oder 16 sein)."
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr "Die Größe jedes Cache-Blocks (muss eine Zweierpotenz zwischen 4 und 512 sein)."
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr "Bekannte Architekturen (für Verwendung mit Option -march=):"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr "Strategie zur Adresserzeugung für das Codemodell angeben."
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "Bekannte Codemodelle (für Verwendung mit Option -mcmodel=):"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 msgid "Specify the cpu for pipeline model."
 msgstr "CPU für Pipeline-Modell angeben."
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "Bekannte CPU-Typen (für Verwendung mit Option -mcpu=):"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+#, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "Bekannte Gleitkomma-ABIs (für Verwendung mit Option -mfloat-abi=):"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr "Konstruktor-/Destruktor-Feature einschalten."
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 msgid "Guide linker to relax instructions."
 msgstr "Linker anweisen, Befehle zu lockern."
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set."
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Gleitkommaarithmetik mit gegebenem Befehlssatz erzeugen."
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions."
+msgid "Generate single-precision floating-point instructions."
+msgstr "Paarweise-single Gleitkommabefehle verwenden."
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions."
+msgid "Generate double-precision floating-point instructions."
+msgstr "Code erzeugen, der 68881-Gleitkommabefehle verwendet."
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr "CPU für Codeerzeugungszwecke angeben."
@@ -13332,13 +13457,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "mul64- und mulu64-Befehle erzeugen."
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs ist veraltet"
-
 #: config/arc/arc.opt:174
 msgid "Do not generate mpy instructions for ARC700."
 msgstr "Keine mpy-Befehle für ARC700 erzeugen."
@@ -15569,8 +15687,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr "Vom Aufrufer zu sichernde Register über Aufrufe hinweg verwenden, wenn möglich."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "berechneter Wert ist unbenutzt"
@@ -15596,7 +15714,7 @@
 msgstr "boolescher Typ erwartet"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Ganzzahl erwartet"
@@ -16011,7 +16129,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, gcc-internal-format
 msgid "previous declaration here"
@@ -16037,12 +16155,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "Attribut wird ignoriert"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ein Attribut, das sich auf eine Typspezifizierung bezieht, wird ignoriert"
@@ -16091,9 +16209,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16106,8 +16224,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "Attribut %<target%> fehlt für multiversioniertes %qD"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "vorherige Deklaration von %qD"
@@ -16237,82 +16355,78 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD angegebene Größe zwischen %E und %E überschreitet maximale Objektgröße %E"
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr "%K%qD das Schreiben von %E Bytes in eine Region der Größe %E lässt die Zielregion überlaufen"
 
-#: builtins.c:3177
-#, gcc-internal-format
+#: builtins.c:3176
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr "%K%qD das Schreiben von %E Byte in eine Region der Größe %E lässt die Zielregion überlaufen"
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] "%K%qD das Schreiben von %E Byte in eine Region der Größe %E lässt die Zielregion überlaufen"
+msgstr[1] "%K%qD das Schreiben von %E Byte in eine Region der Größe %E lässt die Zielregion überlaufen"
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr "%K%qD das Schreiben von %E Bytes in eine Region der Größe %E lässt die Zielregion überlaufen"
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr "%K%qD das Schreiben von %E bis %E Bytes in eine Region der Größe %E lässt die Zielregion überlaufen"
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr "%K%qD angegebene Grenze %E überschreitet die maximale Objektgröße %E"
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr "%K%qD angegebene Grenze zwischen %E und %E überschreitet maximale Objektgröße %E"
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr "%K%qD angegebene Grenze %E überschreitet die Größe der Zielregion %E"
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr "%K%qD angegebene Grenze zwischen %E und %E überschreitet die Größe der Zielregion %E"
 
-#: builtins.c:3278
-#, gcc-internal-format
+#: builtins.c:3276
+#, fuzzy, gcc-internal-format
+#| msgid "%K%qD reading %E byte from a region of size %E"
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr "%K%qD Lesen von %E Bytes aus einer Region der Größe %E"
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] "%K%qD Lesen von %E Bytes aus einer Region der Größe %E"
+msgstr[1] "%K%qD Lesen von %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr "%K%qD Lesen von %E Bytes aus einer Region der Größe %E"
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr "%K%qD das Lesen von %E oder mehr Bytes aus einer Region der Größe %E"
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr "%K%qD das Lesen von %E bis %E Bytes aus einer Region der Größe %E"
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr "%K%qD angegebene Grenze %E ist genau die Größe des Ziels"
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "Zu wenige Argumente für %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "ungültiges Argument für %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "nicht unterstütztes Argument für %qD"
@@ -16319,72 +16433,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr "das Aufrufen von %qD mit einem nicht-null-Argument ist unsicher"
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "beide Argumente für %<__builtin___clear_cache%> müssen Zeiger sein"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "Trampolin für geschachtelte Funktion %qD erzeugt"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD hat neue Semantik in GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "Unbekannte Architekturspezifikation in Speichermodell für eingebaute Funktion"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "ungültiges Speichermodell-Argument für eingebaute Funktion"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "Fehler-Speichermodell kann nicht stärker als Erfolgs-Speichermodell für %<__atomic_compare_exchange%> sein"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "ungültiges Fehler-Speichermodell für %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ungültiges Speichermodell für %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ungültiges Speichermodell für %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "nicht-konstantes Argument 1 für __atomic_always_lock_free"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "nicht-ganzzahliges Argument 1 für __atomic_is_lock_free"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer wird für dieses Ziel nicht unterstützt"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer wird für dieses Ziel nicht unterstützt"
@@ -16391,7 +16505,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack ()%>"
@@ -16398,12 +16512,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "Zweites Argument für %<__builtin_longjmp%> muss 1 sein"
@@ -16410,62 +16524,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Zielformat unterstützt »-fcheck-pointer-bounds« nicht"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "Zielformat unterstützt nicht »unendlich«"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> in Funktion mit fester Parameterzahl verwendet"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> ohne Argument gerufen"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "Zweiter Parameter von %<va_start%> ist nicht letztgenanntes Argument"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "undefiniertes Verhalten, wenn zweiter Parameter von %<va_start%> mit %<register%>-Speicherklasse deklariert wird"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kerstes Argument von %qD muss ein Zeiger, das zweite eine Ganzzahlkonstante sein"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Kletztes Argument von %qD ist keine Ganzzahlkonstante zwischen 0 und 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%KVersuch, Nicht-Heap-Objekt %qD freizugeben"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%KVersuch, Nicht-Heap-Objekt freizugeben"
@@ -17630,37 +17744,37 @@
 msgid "conversion to incomplete type"
 msgstr "Konvertierung in unvollständigen Typen"
 
-#: convert.c:990
+#: convert.c:992
 #, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "Vektor vom Typ %qT kann nicht in Typ %qT konvertiert werden, da sie unterschiedlich groß sind"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "zusammengesetzter Wert verwendet, wo Ganzzahl erwartet wurde"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "Zeigerwert verwendet, wo »complex« erwartet wurde"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "zusammengesetzter Wert verwendet, wo »complex« erwartet wurde"
 
-#: convert.c:1121
+#: convert.c:1123
 #, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "Wert vom Typ %qT kann nicht in Vektortyp %qT konvertiert werden, da sie unterschiedlich groß sind"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "Wert kann nicht in einen Vektor umgewandelt werden"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "zusammengesetzten Wert verwendet, wo Festkomma erwartet wurde"
@@ -17815,12 +17929,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "Mehrere EH-Persönlichkeiten werden nur mit Assemblern unterstützt, die die Direktive .cfi_personality unterstützen"
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr "-gdwarf-6 wird als Version 5 ausgegeben, mit Inkompatibilitäten"
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "Nicht-Delegitimiertes UNSPEC %s (%d) am Variablenort gefunden"
@@ -17931,12 +18045,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "Schreiben von %wu Bit Daten außerhalb der Grenzen des Zielobjekts, Daten wurden auf %wu Bit abgeschnitten"
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%KAufruf von %qs mit Attributfehler deklariert: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%KAufruf von %qs mit Attributwarnung deklariert: %s"
@@ -17951,12 +18065,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "die Rahmengröße von %wd Bytes überschreitet %wd Bytes"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "endgültige Abzugsdatei %qs der Befehle konnte nicht geöffnet werden: %m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "endgültige Abzugsdatei %qs der Befehle konnte nicht geschlossen werden: %m"
@@ -17966,42 +18080,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "große Festkommakonstante implizit auf Festkommatypen abgeschnitten"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "Vergleich ist immer %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "»oder« nicht passender Ungleichheits-Tests ist immer 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "»und« sich gegenseitig ausschließender Gleichheits-Tests ist immer 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstante in Vergleich verringert wird"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstanten um einen Vergleich kombiniert werden"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "Faltungstest: ursprünglicher Baum durch Faltung geändert"
@@ -18538,28 +18652,28 @@
 msgid "can%'t write PCH file"
 msgstr "PCH-Datei kann nicht geschrieben werden"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr "Quellargument für %qD ist dasselbe wie für das Ziel"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr "%G%qD Ziel unverändert, nachdem keine Bytes aus einem String der Länge %E kopiert wurden"
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "%G%qD Ziel unverändert, nachdem keine Bytes kopiert wurden"
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "%G%qD angegebene Grenze %E ist genau die Größe des Ziels"
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr "%G%qD angegebene Grenze %E überschreitet die Zielgröße %wu"
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr "%G%qD angegebene Grenze %E ist genau die Größe der Quelle"
 
@@ -18573,12 +18687,13 @@
 msgid "null pointer dereference"
 msgstr "Dereferenzierung eines Nullzeigers"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "hier deklariert"
@@ -19095,10 +19210,10 @@
 msgstr "%G%qD Offset %s ist außerhalb der Grenzen von Objekt %qD mit Typ %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD ist hier deklariert"
@@ -19127,7 +19242,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr "%G%qD Offset %s des Objekts an %qE ist außerhalb der Grenzen des referenzierten Teilobjekts %qD mit Typ %qT an Offset %wu"
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr "%G%qD Das Quellargument ist dasselbe wie das Zielargument"
 
@@ -19467,252 +19582,257 @@
 msgid "function cannot be instrumented"
 msgstr "Funktion kann nicht instrumentiert werden"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr "virtuelle Tabelle des Typs %qD verletzt die One-Definition-Rule"
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr "Variable mit demselben Assemblernamen wie die virtuelle Tabelle ist in anderer Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr "virtuelle Tabelle des Typs %qD enthält RTTI-Information"
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr "wird aber überragt von einer Tabelle ohne RTTI-Informationen aus anderer Übersetzungseinheit"
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr "RTTI wird für diesen Typ nicht funktionieren"
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr "virtuelle Tabelle des Typs %qD verletzt die One-Definition-Rule"
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr "die virtuelle Tabelle des in Konflikt stehenden Typs aus der anderen Übersetzungseinheit ist unterschiedlich groß"
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr "der in Konflikt stehende Typ aus der anderen Übersetzungseinheit hat unterschiedliche RTTI-Information"
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr "der in Konflikt stehende Typ aus der anderen Übersetzungseinheit"
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "enthält zusätzliche virtuelle Methode %qD"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr "der in Konflikt stehende Typ aus der anderen Übersetzungseinheit hat virtuelle Tabelle mit mehr Einträgen"
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "virtuelle Methode %qD"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr "sollte der virtuellen Methode %qD entsprechen, tut es aber nicht"
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr "der in Konflikt stehende Typ aus der anderen Übersetzungseinheit hat virtuelle Tabelle mit unterschiedlichem Inhalt"
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "Typ %qT verletzt die One-Definition-Rule von C++"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "ein unterschiedlicher Typ ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr "der erste Unterschied der entsprechenden Definitionen ist Feld %qD"
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr "der erste Unterschied der entsprechenden Definitionen ist Methode %qD"
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr "Typ %qT (in unbenanntem Namensraum definiert) kann nicht zum Typ %qT passen (über Grenzen von Übersetzungseinheiten hinaus)"
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr "Typ %qT (in unbenanntem Namensraum definiert) kann nicht passen (über Grenzen von Übersetzungseinheiten hinaus)"
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "der inkompatible Typ, der in einer anderen Übersetzungseinheit definiert ist"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr "Typname %qs sollte dem Typnamen %qs entsprechen"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "der inkompatible Typ ist hier definiert"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr "Arraytypen haben unterschiedliche Grenzen"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "unverträgliche Rückgabetypen"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "Fehlzuordnung in implizitem this-Zeiger"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "unverträgliche Typen in Parameter %i"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "Typen haben unterschiedliche Anzahl von Parametern"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "Typ %qT verletzt für sich genommen die One-Definition-Rule von C++"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "Typ %qT sollte Typ %qT entsprechen"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr "ein Typ mit unterschiedlichen Qualifizierern ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "Ein Typ mit unterschiedlichen Attributen ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr "eine Aufzählung mit unterschiedlichen Wertnamen ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr "eine Aufzählung mit anderen Werten ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr "eine Aufzählung mit unterschiedlich vielen Werten ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr "ein Typ mit unterschiedlicher Genauigkeit ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr "ein Typ mit unterschiedlichem Vorzeichen ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr "er ist in einer anderen Übersetzungseinheit als Zeiger in unterschiedlichem Adressraum definiert"
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr "er ist in einer anderen Übersetzungseinheit als Zeiger auf einen anderen Typen definiert"
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr "ein Array unterschiedlicher Größe ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "hat unterschiedlichen Rückgabetyp in einer anderen Übersetzungseinheit"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "hat unterschiedliche Parameter in einer anderen Übersetzungseinheit"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr "ein Typ aus einer anderen Übersetzungseinheit ist nicht polymorph"
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr "ein Typ aus einer anderen Übersetzungseinheit ist polymorph"
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr "ein Typ mit unterschiedlichen Zeigern in der virtuellen Tabelle ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr "ein Typ mit unterschiedlichen Basistypen ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "ein Feld mit unterschiedlichem Namen ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr "ein Feld mit selbem Namen aber unterschiedlichem Typ ist in einer anderen Übersetzungseinheit definiert"
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "Felder haben unterschiedliches Layout in einer anderen Übersetzungseinheit"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -19733,7 +19853,7 @@
 msgid "the extra base is defined here"
 msgstr "die zusätzliche Basisklasse ist hier definiert"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -19740,7 +19860,7 @@
 msgstr[0] "Wenn Typ %qD »final« wäre, würde %i Aufruf devirtualisiert werden"
 msgstr[1] "Wenn Typ %qD »final« wäre, würden %i Aufrufe devirtualisiert werden"
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19747,7 +19867,7 @@
 msgstr[0] "Wenn Typ %qD »final« wäre, würde %i Aufruf, der %lli-mal ausgeführt wurde, devirtualisiert werden"
 msgstr[1] "Wenn Typ %qD »final« wäre, würden %i Aufrufe, die %lli-mal ausgeführt wurden, devirtualisiert werden"
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -19754,7 +19874,7 @@
 msgstr[0] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf einschalten"
 msgstr[1] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen einschalten"
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -19761,7 +19881,7 @@
 msgstr[0] "Wenn die Methode %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf einschalten"
 msgstr[1] "Wenn die Methode %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen einschalten"
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -19768,7 +19888,7 @@
 msgstr[0] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufruf, der %lli-mal ausgeführt wurde, einschalten"
 msgstr[1] "Wenn der virtuelle Destruktor von %qD als »final« deklariert wäre, würde das die Devirtualisierung von %d Aufrufen, die %lli-mal ausgeführt wurden, einschalten"
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20042,30 +20162,38 @@
 msgstr "Zielsystem unterstützt Funktionsversions-Dispatcher nicht"
 
 #: multiple_target.c:91
-#, gcc-internal-format
-msgid "default target_clones attribute was not set"
+#, fuzzy, gcc-internal-format
+#| msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "Standard-»target_clones«-Attribut wurde nicht gesetzt"
 
-#: multiple_target.c:324
-#, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+#: multiple_target.c:343
+#, fuzzy, gcc-internal-format
+#| msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "einzelnes »target_clones«-Attribut wird ignoriert"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "Klone für Attribut %<target_clones%> können nicht erzeugt werden"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "Funktion %q+F kann nie kopiert werden, da sie das Attribut %<noclone%> hat"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, gcc-internal-format
 msgid "default target was not set"
 msgstr "Standard-Ziel wurde nicht gesetzt"
 
+#: multiple_target.c:379
+#, fuzzy, gcc-internal-format
+#| msgid "missing value in %<target()%> pragma or attribute"
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr "fehlender Wert für Pragma oder Attribut %<target()%>"
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -20377,12 +20505,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "nicht erkanntes Kommandozeilenargument in Option %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %qs sind: %s; meinten Sie %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "gültige Argumente für %qs sind: %s"
@@ -20979,22 +21107,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "Ausgabeoperand %d muss %<&%>-Bedingung verwenden"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Falsches next_regno für leere Kette (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Zyklus in regno-Kette (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Falsches oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Nicht leeres Register in Kette (%s %u %i)"
@@ -21038,7 +21166,7 @@
 msgstr "Register von %qD für mehrere globale Registervariablen verwendet"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "Konflikt mit %qD"
@@ -21280,182 +21408,182 @@
 msgstr "%qD nach Referenzierung in Assemblierung umbenannt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:992
+#: symtab.c:998
 #, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "Interner Fehler: function symbol is not function"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "Interner Fehler: variable symbol is not variable"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "Interner Fehler: node has unknown type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "Interner Fehler: node not found node->decl->decl_with_vis.symtab_node"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "Interner Fehler: node differs from node->decl->decl_with_vis.symtab_node"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "Interner Fehler: assembler name hash list corrupted"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "Interner Fehler: node not found in symtab assembler name hash"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "Interner Fehler: double linked list of assembler names corrupted"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "Interner Fehler: node has body_removed but is definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1062
+#: symtab.c:1068
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "Interner Fehler: node is analyzed but it is not a definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "Interner Fehler: node is alias but not implicit alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1072
+#: symtab.c:1078
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "Interner Fehler: node is alias but not definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "Interner Fehler: node is weakref but not an transparent_alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "Interner Fehler: node is transparent_alias but not an alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "Interner Fehler: node is in same_comdat_group list but has no comdat_group"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "Interner Fehler: same_comdat_group list across different groups"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "Interner Fehler: mixing different types of symbol in same comdat groups is not supported"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "Interner Fehler: node is alone in a comdat group"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "Interner Fehler: same_comdat_group is not a circular list"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "Interner Fehler: comdat-local symbol referred to by %s outside its comdat"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "Interner Fehler: implicit_section flag is set but section isn't"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Interner Fehler: Both section and comdat group is set"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Interner Fehler: Alias and target's section differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Interner Fehler: Alias and target's comdat groups differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Interner Fehler: Transparent alias and target's assembler names differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Interner Fehler: Chained transparent aliases"
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "Interner Fehler: symtab_node::verify failed"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Interner Fehler: Two symbols with same comdat_group are not linked by the same_comdat_group list."
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "Funktion %q+D Teil des Alias-Zyklus"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "Variable %q+D Teil des Alias-Zyklus"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "Abschnitt des Aliases %q+D muss zum Abschnitt seines Ziels passen"
@@ -22640,12 +22768,12 @@
 msgid "control reaches end of non-void function"
 msgstr "Kontrollfluss erreicht Ende von Nicht-void-Funktion"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "Der Rückgabewert von %qD, der mit dem Attribut warn_unused_result deklariert wurde, wird ignoriert"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "Rückgabewert der mit dem Attribut warn_unused_result definierten Funktion wird ignoriert"
@@ -23163,7 +23291,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "Vektorumverteilungsoperation wird stückweise ausgeweitet"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "Vektorisierung für eine SIMD-Schleife nicht durchgeführt"
@@ -23203,92 +23331,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "side-effects element in no-side-effects CONSTRUCTOR"
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "Arrays von Funktionen sind sinnlos"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "Rückgabetyp der Funktion kann keine Funktion sein"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "tree check: %s, have %s in %s, at %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "tree check: expected none of %s, have %s in %s, at %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD ist veraltet: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD ist veraltet"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE ist veraltet: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE ist veraltet"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "Typ ist veraltet: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "Typ ist veraltet"
@@ -23314,242 +23442,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "type variant differs by "
+msgid "type variant differs by %s"
 msgstr "bla bla bla kann eh nicht übersetzt werden"
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "Typvariante hat unterschiedliche TYPE_SIZE_UNIT"
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT der Typvariante"
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT des Typs"
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "type variant with TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "type variant has different TYPE_VFIELD"
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "type variant has different TYPE_BINFO"
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "type variant's TYPE_BINFO"
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "type's TYPE_BINFO"
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "type variant has different TYPE_FIELDS"
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "first mismatch is field"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr "and field"
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "type variant has different TREE_TYPE"
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "type variant's TREE_TYPE"
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "type's TREE_TYPE"
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "type is not compatible with its variant"
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "Main variant is not defined"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL has different TYPE_CANONICAL"
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL is not compatible"
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "TYPE_MODE of TYPE_CANONICAL is not compatible"
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr "TYPE_CANONICAL of main variant is not main variant"
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO is not TREE_BINFO"
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE is not record nor union"
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE is not record nor union"
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAXVAL_VALUE_RAW ist nicht NULL"
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "Enum value is not CONST_DECL or INTEGER_CST"
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "Enum value name is not IDENTIFIER_NODE"
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "Array TYPE_DOMAIN is not integer type"
 
-#: tree.c:13745
+#: tree.c:13750
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS defined in incomplete type"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Wrong tree in TYPE_FIELDS list"
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES is not TREE_VEC"
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "wrong TYPE_CACHED_VALUES entry"
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Wrong entry in TYPE_ARG_TYPES list"
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "TYPE_VALUES_RAW field is non-NULL"
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "Interner Fehler: TYPE_CACHED_VALUES_P is set while it should not"
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG is set on wrong type code"
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE is not main variant"
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type failed"
@@ -23574,12 +23703,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "kaputtes Werteprofil: %s-Profilzähler (%d von %d) ist inkonsistent zu Basisblock-Zähler (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "Obere Größengrenze zur Variablenverfolgung mit -fvar-tracking-assignments überschritten; neuer Versuch ohne"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "Grenze zur Variablenverfolgung überschritten"
@@ -24459,7 +24588,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "der Compiler kann davon ausgehen, dass die Adresse von %qD immer zu %<true%> evaluiert"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "Um Zuweisung, die als Wahrheitswert verwendet wird, werden Klammern empfohlen"
@@ -24710,7 +24839,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "Index %E markiert einen Offset größer als die Größe von %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "Arraygröße ist zu groß"
@@ -25319,7 +25448,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Variablen für Speicher"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -25334,22 +25463,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -25894,8 +26023,8 @@
 msgid "wrong type argument to %s"
 msgstr "Argument falschen Typs für %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "Überlauf in Konstanten-Ausdruck"
@@ -26526,7 +26655,7 @@
 msgstr "im Aufruf von %<memset%> ist die Länge gleich der Anzahl der Elemente angegeben, ohne sie mit der Elementgröße zu multiplizieren"
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "Vergleich zwischen den Typen %qT und %qT"
@@ -26602,7 +26731,7 @@
 msgstr[0] "Argument %i ist als »restrict« markiert, wird aber auch in Argument %Z übergeben"
 msgstr[1] "Argument %i ist als »restrict« markiert, wird aber auch in Argumenten %Z übergeben"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "diese Bedingung hat identische Zweige"
@@ -26730,47 +26859,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s hat ungültige Silizium-Revision"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops ist veraltet, Ersatz: -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d ist nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps ist veraltet, Ersatz: -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d ist nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions ist veraltet, Ersatz: -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d ist nicht zwischen 0 und %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d ist nicht zwischen 0 und 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> wird derzeit nur auf GNU/Linux unterstützt"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> erfordert Assemblerunterstützung für CFI-Direktiven"
@@ -26796,31 +26925,31 @@
 msgstr "für die Option »-mcache-block-size=X« sind nur die Werte 4, 8, 16, 32, 64, 128, 256 oder 512 gültig"
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "unbekannter Schalter -mdebug-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "unbekannter Schalter -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "Option -msingle-float ist äquivalent zu -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "Option -msimple-fpu ignoriert"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "%<-fsplit-stack%> wird derzeit nur auf PowerPC64 GNU/Linux mit glibc-2.18 oder neuer unterstützt"
@@ -27306,8 +27435,8 @@
 msgstr "Pragma oder Attribut %<target(\"%s=%s\")%> ist nicht gültig"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
@@ -27388,8 +27517,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "Falscher Wert %qs für -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27500,11 +27629,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27514,145 +27643,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr "Attribut %qE bezieht sich nur auf Funktionen"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_arc_aligned%> mit variabler Ausrichtung"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "Ungültiger Ausrichtungswert für %<__builtin_arc_aligned%>"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr "Eingebauter Operand sollte ein vorzeichenloser 6-Bit-Wert sein"
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "Operand 1 sollte eine vorzeichenlose 3-Bit-Konstante sein"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Operand 2 sollte ein vorzeichenloser 3-Bit-Wert sein (I0–I7)"
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Operand 1 sollte ein vorzeichenloser 3-Bit-Wert sein (I0–I7)"
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "Operand 2 sollte ein vorzeichenloser 8-Bit-Wert sein"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "Operand 3 sollte ein vorzeichenloser 8-Bit-Wert sein"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "Operand 4 sollte ein vorzeichenloser 8-Bit-Wert sein (0–255)"
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Operand 3 sollte ein vorzeichenloser 3-Bit-Wert sein (I0–I7)"
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "Operand 2 sollte ein vorzeichenloser 3-Bit-Wert sein (subreg 0–7)"
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "Operand 2 sollte ein gerader 3-Bit-Wert sein (subreg 0,2,4,6)"
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "Operand %d der eingebauten Funktion muss konstant sein"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "Operand %d sollte eine vorzeichenlose 6-Bit-Konstante sein"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "Operand %d sollte eine vorzeichenlose 8-Bit-Konstante sein"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "Operand %d sollte eine vorzeichenlose 3-Bit-Konstante sein"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr "unbekannter eingebauter direkter Operandentyp für Operand %d"
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "Registernummer muss bereits zur Kompilierzeit eine Konstante sein. Probieren Sie eine stärkere Optimierungsstufe"
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr "Operand für »sleep«-Befehl muss eine ganzzahlige Kompilierzeit-Konstante zwischen 0 und 63 sein"
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "Befehlsadresse nicht festgelegt, nachdem shorten_branches aufgerufen wurde"
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "Befehlsadressen nicht freigegeben"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "Attribut %qE ist nur für die Architektur ARCv2 gültig"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "Argument des Attributs %qE fehlt"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "Attribut %qE erlaubt nur eine Ganzzahlkonstante als Argument"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "Attribut %qE ist nur für die ARC-EM-Architektur gültig"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "Attribut %qE kann nur auf Typen angewandt werden"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "Argument des Attributs %qE wird ignoriert"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "Attribut %qE bezieht sich nur auf Variablen"
@@ -27678,153 +27797,153 @@
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie Krypto-Befehle einschalten (zum Beispiel mit »-mfloat-abi=softfp -mfpu=crypto-neon«)"
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "Wähler muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "der Wertebereich des Selektors sollte 0 bis 7 sein"
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "der Wertebereich des Selektors sollte 0 bis 3 sein"
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "der Wertebereich des Selektors sollte 0 bis 1 sein"
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "Maske muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "der Wertebereich der Maske ist 0 bis 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_rori_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_ror_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_si64 im Code prüfen."
@@ -28629,12 +28748,12 @@
 msgid "invalid IACC argument"
 msgstr "ungültiges IACC-Argument"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs erwartet ein konstantes Argument"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "Konstantes Argument außerhalb des Wertebereiches für %qs"
@@ -28734,566 +28853,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "Position in PCH-Datei kann nicht gesetzt werden: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "falsches Argument %qs für Option %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "Größenbereiche der Option %qs sollten aufsteigend sein"
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "falscher Strategiename %qs für Option %qs angegeben"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "Strategiename %qs für Option %qs angegeben, wird jedoch für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "unbekannte Ausrichtung %qs für Option %qs angegeben"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "der Maximalwert für den letzten Größenbereich sollte für Option %qs -1 sein"
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "zu viele Größenbereiche in Option %qs angegeben"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Unbekannter Parameter für Option »-mtune-ctrl«: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel-MCU-psABI wird im %s-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> ist veraltet; stattdessen entsprechend %<-mtune=k8%> oder %<-mtune=generic%> verwenden"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> ist veraltet; stattdessen entsprechend %<target(\"tune=k8\")%> oder %<target(\"tune=generic\")%> verwenden"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Adressmodus %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mabi=ms wird in der X32-ABI nicht unterstützt"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Codemodell %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel wird in dieser Konfiguration nicht unterstützt"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-Bit-Modus nicht einkompiliert"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%>-CPU kann nur für %<-mtune=%>-Schalter verwendet werden"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%>-CPU kann nur für %<target(\"tune=\")%>-Schalter verwendet werden"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<intel%>-CPU kann nur für %<-mtune%>-Schalter verwendet werden"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<intel%>-CPU kann nur für %<target(\"tune=\")%>-Attribut verwendet werden"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Die ausgewählte CPU unterstützt nicht den x86-64 Befehlssatz"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX unterstützt x32 nicht"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "falscher Wert (%qs) für Schalter %<-march=%>"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "unbekannter Wert (%qs) für %<target(\"arch=\")%>-Attribut"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-march=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "gültige Argumente für %<-march=%> sind: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "falscher Wert (%qs) für Schalter %<-mtune=%>"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "unbekannter Wert %qs für %<target(\"tune=\")%>-Attribut"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"tune\")%> sind: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm wird für Intel-MCU-psABI ignoriert"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d ist nicht zwischen 0 und %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d ist nicht zwischen %d und %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d ist nicht zwischen %d und 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount ist für -fPIC nicht implementiert"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<-maccumulate-outgoing-args%> für Korrektheit"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<target(\"accumulate-outgoing-args\")%> für Korrektheit"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "feststehendes ebp-Register erfordert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "feststehendes ebp-Register erfordert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry wird für 32 Bit in Kombination mit -fpic nicht unterstützt"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry ist nicht mit SEH verträglich"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues wird derzeit nicht zusammen mit SEH unterstützt"
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "unbekannte Option für -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs ist keine gültige Zahl in -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs ist kein gültiger Offset in »-mstack-protector-guard-offset=«"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs ist kein gültiges Basisregister in -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr "%<-fcf-protection=branch%> benötigt Intel-CET-Unterstützung. Verwenden Sie eine der Optionen %<-mcet%> oder %<-mibt%>, um CET einzuschalten"
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr "%<-fcf-protection=return%> benötigt Intel-CET-Unterstützung. Verwenden Sie eine der Optionen %<-mcet%> oder %<-mshstk%>, um CET einzuschalten"
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr "%<-fcf-protection=full%> benötigt Intel-CET-Unterstützung. Verwenden Sie %<-mcet%> oder sowohl %<-mibt%> als auch %<-mshstk%>, um CET einzuschalten"
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) ist unbekannt"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") wurde bereits spezifiziert"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "die Attribute %<interrupt%> und %<naked%> sind nicht kompatibel"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstützt."
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> und %<-fcheck-pointer-bounds%> sind nicht kompatibel"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-Befehle sind in »%s«-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "%s-Befehle sind in Funktionen mit »no_caller_saved_registers«-Attribut nicht erlaubt"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qT mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 unterstützt »ms_abi«-Attribut nicht"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue ist mit geschachtelter Funktion nicht verträglich"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorargument ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorrückgabe ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-Vektorrückgabe ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-Vektorargument ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-Vektorrückgabe ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-Vektorargument ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-Vektorrückgabe ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "Das ABI der Struct-Übergabe mit einem flexiblen Arrayelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "Das ABI der Union-Übergabe mit »long double« hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "Das ABI der Strukturübergabe mit komplexem Gleitkommaelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-Registerrückgabe mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-Registerargument mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-Registerrückgabe mit ausgeschaltetem x87"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit SSE-Aufrufkonvention, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "dies ist ein GCC-Bug; ein Workaround ist, die aufgerufene Funktion mit dem »used«-Attribut zu markieren"
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues ist nicht kompatibel mit %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "Attribut ms_hook_prologue ist mit -mfentry für 32 Bit nicht verträglich"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) wird in Interrupt-Service-Routinen nicht unterstützt. Ein Workaround ist, Funktionen mit Aggregat-Rückgabetypen zu vermeiden."
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack unterstützt nicht fastcall mit geschachtelter Funktion"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack unterstützt nicht 2 Registerparameter für eine geschachtelte Funktion"
@@ -29300,311 +29404,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack unterstützt nicht 3 Registerparameter"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "V-Modifikator an nicht-ganzzahligem Register"
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "nicht unterstützte Größe für Ganzzahlregister"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "erweiterte Register haben keine oberen Hälften"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "nicht unterstützte Operandengröße für erweitertes Register"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "Nicht-Ganzzahl-Operand mit Operandencode »z« verwendet"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "Interrupt-Dienst-Routinen können nicht direkt aufgerufen werden"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr "das ABI zum Übergeben von leeren Klassen (%qT) als Parametern ändert sich mit -fabi-version=12 (GCC 8)"
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden"
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Kein Dispatcher für %s gefunden"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden: %s"
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversionen können nicht als gnu_inline markiert werden, Körper müssen generiert werden"
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Multiversionierung erfordert »ifunc«, was in dieser Konfiguration nicht unterstützt wird"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter für eingebaute Funktion muss Zeichenkettenkonstante oder Literal sein"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter für eingebaute Funktion ist ungültig: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Das letzte Argument muss ein 2-Bit-Immediate sein"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fünftes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "drittes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "das letzte Argument muss ein 3-Bit-Immediate sein"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Das vorletzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "das dritte Argument muss eine Vergleichskonstante sein"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "Falscher Vergleichsmodus"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "Falscher Rundungsoperand"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Der direkte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Das direkte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Das direkte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "Selektor eine Ganzzahlkonstante im Bereich 0..%wi sein"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE erfordert unbekannte ISA-Option"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE erfordert ISA-Option %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "das letzte Argument muss ein Immediate sein"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "Das letzte muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "Das vierte Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "Falscher Hinweis-Operand"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Das Argument für xabort muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "Attribute ms_abi und sysv_abi sind nicht verträglich"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Argument des Attributes %qE ist nicht (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ »unsigned %sint« sein"
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp »void« haben"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "Alternativen sind in asm-Flag-Ausgabe nicht erlaubt"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "unbekannte Ausgabe %qs des asm-Schalters"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ungültiger Typ für asm-Flag-Ausgabe"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Unbekanntes architekturspezifisches Speichermodell"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE nicht mit ACQUIRE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE nicht mit RELEASE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "nicht unterstützte simdlen %d"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "nicht unterstützter Rückgabetyp %qT für SIMD"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "nicht unterstützter Argumenttyp %qT für SIMD"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Zeigerprüfer benötigt MPX-Unterstützung auf diesem Ziel. Verwenden Sie »-mmpx«, um MPX einzuschalten."
@@ -29825,7 +29929,7 @@
 msgstr "interrupt_thread ist nur auf Fido verfügbar"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "Ausdruck der Stapelgrenze wird nicht unterstützt"
@@ -30357,7 +30461,37 @@
 msgid "constant argument out of range for %s"
 msgstr "Konstantes Argument außerhalb des Wertebereiches für %s"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "diese eingebaute Funktion ist nur auf dem fr450 verfügbar"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "diese eingebaute Funktion ist nur auf dem fr450 verfügbar"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin is not supported for this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "diese eingebaute Funktion wird auf diesem Ziel nicht unterstützt"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "don't support string extension instructions"
+msgid "don't support performance extension instructions"
+msgstr "Erweiterungsbefehle für Zeichenketten einschalten"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate performance extension version 2 instructions."
+msgid "don't support performance extension version 2 instructions"
+msgstr "Erweiterungsbefehle für Performance Version 2 einschalten."
+
+#: config/nds32/nds32-intrinsic.c:760
 #, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr "Erweiterungsbefehle für Zeichenketten einschalten"
@@ -30378,43 +30512,61 @@
 msgstr "mehrere Interruptattribute für Funktion %qD"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "geschachtelte Funktionen werden bei reduzierter Registeranzahl nicht unterstützt"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "intrinsischer Registerindex ist außerhalb des gültigen Bereichs"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
+#, fuzzy, gcc-internal-format
+#| msgid "intrinsic register index is out of range"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "intrinsischer Registerindex ist außerhalb des gültigen Bereichs"
+
+#: config/nds32/nds32.c:3508
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "ungültiger ID-Wert für Interrupt-/Exception-Attribut"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "ungültiger ID-Wert für »reset«-Attribut"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "ungültige NMI-Funktion für »reset«-Attribut"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "ungültige »warm«-Funktion für »reset«-Attribut"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
 #, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
+#, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "lageunabhängiger Code nicht unterstützt"
 
@@ -30623,37 +30775,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr "statische Initialisierung der Variablen %q+D in %<.shared%>-Speicher wird nicht unterstützt"
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr "in PTX-Assembler können keine unausgerichteten Zeiger erzeugt werden"
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX unterstützt keine schwachen Deklarationen (nur schwache Definitionen)"
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "Attribut %qE erfordert den Rückgabetyp »void«"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "Attribut %qE nicht mit Speicherklasse »auto« erlaubt"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "vector_length (%d) wird verwendet, %d wird ignoriert"
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "vector_length (%d) wird verwendet, Laufzeiteinstellung wird ignoriert"
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "num_workers (%d) wird verwendet, %d wird ignoriert"
@@ -30747,12 +30899,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "Ausschuss am Ende von #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
@@ -30802,7 +30954,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert akzeptiert nur 3 Argumente"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Kennzeichner von Zeiger-Ziel-Typ"
@@ -31104,7 +31256,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "das Layout von Aggregaten, die Vektoren mit %d-Byte-Ausrichtung enthalten, hat sich in GCC 5 geändert"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz zurückgegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
@@ -31114,7 +31266,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "das ABI der Parameterübergabe für Aggregate mit %d-Byte-Ausrichtung hat sich in GCC 5 geändert"
@@ -31124,12 +31276,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "das ABI für die Übergabe von homogenen float-Aggregaten hat sich in GCC 5 geändert"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz übergegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
@@ -31139,28 +31291,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "internal error: builtin function %s already processed"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Argument 1 muss ein 8-Bit-Feldwert sein"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Argument 1 muss ein vorzeichenbehaftetes 5-Bit-Symbol sein"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 7-Bit-Literal sein"
@@ -31180,12 +31332,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "Eingebaute Funktion %s kann nur im 64-Bit-Modus verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Argument %d muss ein vorzeichenloses Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Argument %d ist ein vorzeichenloses Literal, aber außerhalb des gültigen Bereichs"
@@ -31207,53 +31359,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "hwcap %s ist ein ungültiges Argument für eingebaute Funktion %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 4-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 1-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Argument 1 muss 0 oder 2 sein"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Argument 2 muss 0 oder 1 sein"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argument 3 muss im Bereich 0..15 liegen"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Argument für %qs muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ungelöste Überladung des eingebauten Altivec %qF"
@@ -31378,7 +31530,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internal error: builtin function %s, argument %d had unexpected argument type %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "Stapelrahmen zu groß"
@@ -31388,12 +31540,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack verwendet Register r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Stapelrahmen größer als 2G wird für -fsplit-stack nicht unterstützt"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
@@ -31403,22 +31555,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Bei Verwendung der Option -mno-pointers-to-nested-functions kann nicht die Adresse einer geschachtelten Funktion verwendet werden."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
@@ -31428,7 +31580,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne -mvsx ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
@@ -31892,22 +32044,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "unbekannte CPU %qs für »-mtune«"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr "-mdiv erfordert -march, um die %<M%>-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr "die angeforderte ABI erfordert -march, um die %qc-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr "ABI erfordert -march=rv%d"
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d muss zwischen %d und %d liegen"
@@ -31972,30 +32124,36 @@
 "Der Kernel hat einen nicht unterstützten CPU-Namen zurückgegeben: %s\n"
 "Bitte geben Sie den CPU-Namen explizit an. Gültige CPU-Namen sind: %s"
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 3 Argumente"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 1 Argument"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, fuzzy, gcc-internal-format
+#| msgid "builtin function %qs requires the %qs option"
+msgid "builtin %qs requires builtin %qs"
+msgstr "eingebaute Funktion %qs erfordert die Option %qs"
+
+#: config/rs6000/rs6000-c.c:7058
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "Eingebaute Funktion %qs wird in dieser Compiler-Konfiguration nicht unterstützt"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ungültige Parameterkombination für AltiVec-spezifisches intrinsisches %qs"
@@ -32118,169 +32276,169 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs ist veraltet und wird unter keinen Umständen empfohlen"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; %qs schaltet sie ein"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; %qs schaltet sie ein"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "internal error: builtin function %qs already processed"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "Argument 1 von %qs muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "Argument 1 von %qs ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "eingebaute Funktion %qs kann nur im 64-Bit-Modus verwendet werden"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "eingebaute Funktion %qs akzeptiert nur ein Zeichenkettenargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "CPU %qs ist ein ungültiges Argument für eingebaute Funktion %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs ist ein ungültiges Argument für eingebaute Funktion %qs"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "eingebaute Funktion %qs erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "zweites Argument für %qs muss im Bereich 0..12 liegen"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "drittes Argument für %qs muss im Bereich 0..12 liegen"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "Argument 1 von %s muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "eingebaute Funktion %qs ist nur für den Cell-Prozessor gültig"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "eingebaute Funktion %qs erfordert die Option %qs"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "eingebaute Funktion %qs erfordert die Optionen %qs und %qs"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "eingebaute Funktion %qs erfordert ISA 3.0 IEEE 128-Bit-Gleitkommazahlen"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "eingebaute Funktion %qs erfordert die Optionen %qs (oder neuer), sowie %qs oder %qs"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "eingebaute Funktion %qs wird mit den aktuellen Optionen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "internal error: builtin function %qs had an unexpected return type %qs"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs verwendet Register r29"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Bei Verwendung der Option %qs kann die Adresse von geschachtelten Funktionen nicht verwendet werden"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ungültige CPU %qs für %s%qs%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s ist ungültig"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> schaltet %<-m%s%> aus"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "das Attribut %<target_clones%> erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
@@ -33076,7 +33234,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-Wert nicht ignoriert wie es sein sollte"
@@ -33328,7 +33486,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "Deklaration von %qD überdeckt einen Parameter"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
@@ -33338,7 +33496,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "Deklaration von %qD überdeckt einen vorhergehenden lokalen Bezeichner"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "verdeckte Deklaration ist hier"
@@ -33398,7 +33556,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "jeder nicht deklarierte Bezeichner wird nur einmal für jede Funktion, in der er vorkommt, gemeldet"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "Marke %qE außerhalb einer Funktion referenziert"
@@ -33428,7 +33586,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "Doppelte Markendeklaration %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "doppelte Marke %qD"
@@ -33546,7 +33704,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> außerhalb des Bereichs des Funktionsprototypen nicht erlaubt"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
@@ -33801,7 +33959,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "Speicherklasse für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "Speicherklasse für Typnamen angegeben"
@@ -33960,7 +34118,7 @@
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
@@ -34087,7 +34245,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "Ein Element einer Struktur oder Union kann nicht variabel modifizierten Typ haben"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "Variable oder Feld %qE als »void« deklariert"
@@ -34267,7 +34425,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
@@ -34317,7 +34475,7 @@
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Arrayelement in Union"
@@ -34353,7 +34511,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "Redeklaration von %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
@@ -34383,7 +34541,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO-C beschränkt Aufzählungswerte auf Bereich von %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline-Funktion %qD wurde das Attribut »noinline« gegeben"
@@ -34413,7 +34571,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
@@ -34528,12 +34686,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
@@ -34596,7 +34754,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
@@ -34741,37 +34899,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-Kombinierer verweist auf Variable %qD, die weder %<omp_out%> noch %<omp_in%> ist"
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-Initialisierung verweist auf Variable %qD, die weder %<omp_priv%> noch %<omp_orig%> ist"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "left shift of negative value"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "Links-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "Links-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "Rechts-Schiebe-Weite >= Breite des Typs"
@@ -34801,7 +34959,7 @@
 msgid "to match this %qs"
 msgstr "andere Fundstelle von %qs ist hier"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -34842,7 +35000,7 @@
 msgstr "unbekannter Typname: %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -34857,7 +35015,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -34872,8 +35030,8 @@
 msgid "unexpected attribute"
 msgstr "unerwartetes Attribut"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%<fallthrough%>-Attribut ohne darauffolgendes %<;%>"
@@ -34911,7 +35069,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kann nur mit einem einzelnen Deklarator verwendet werden"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> oder %<;%> erwartet"
@@ -34939,7 +35097,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO-C90 unterstützt nicht %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "Zeichenkettenliteral erwartet"
@@ -35003,13 +35161,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "Komma am Ende der Aufzählungsliste"
@@ -35139,7 +35297,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> vor %<else%> erwartet"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ohne vorheriges %<if%>"
@@ -35173,22 +35331,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "Anweisung erwartet"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<if%>-Anweisung empfohlen"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<else%>-Anweisung empfohlen"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "es wird empfohlen, explizite geschweifte Klammern zu setzen, um mehrdeutiges %<else%> zu vermeiden"
@@ -35208,12 +35366,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ungültiges Schleifenvariable in schneller Aufzählung"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC ivdep%>-Pragma"
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC unroll%>-Pragma"
@@ -35240,12 +35398,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "Division %<sizeof (%T) / sizeof (%T)%> berechnet nicht die Anzahl der Feldelemente"
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "der Operand des ersten %<sizeof%> wurde hier deklariert"
@@ -35521,7 +35679,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "Operanden von %<__builtin_complex%> unterschiedlichen Typs"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "falsche Anzahl der Argumente für %<__builtin_shuffle%>"
@@ -35581,76 +35739,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "das %<setter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "Setter-Name muss mit %<:%> beendet werden"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "das %<getter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> erfordert einen Zuweisungsausdruck, der zu einer nichtnegativen Ganzzahlkonstante kleiner als %u evaluiert"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> darf nur im Datei-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweisung erwartet"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Ganzzahlausdruck vor »)« erwartet"
@@ -35665,53 +35823,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> oder %<present%> erwartet"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> oder %<shared%> erwartet"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> oder %<exit%> erwartet"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> erwartet"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "zu viele %<if%>-Klauseln mit %qs-Modifizierer"
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "zu viele %<if%>-Klauseln"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "zu viele %<if%>-Klauseln ohne Modifizierer"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "wenn eine der %<if%>-Klauseln einen Modifizierer verwendet, müssen alle %<if%>-Klauseln Modifizierer verwenden"
@@ -35733,82 +35891,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "Wert von %<num_tasks%> muss positiv sein"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Wert von %<grainsize%> muss positiv sein"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Wert von %<priority%> muss positiv sein"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> erwartet"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> erwartet"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-Ausdruck muss ganzzahlig sein"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "Wert %qs muss positiv sein"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "zu viele %<static%>-Argumente"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "unerwartetes Argument"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%>-Argument muss eine positive, ganzzahlige Konstante sein"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "%<ordered%>-Argument muss ein positiver, ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> oder Bezeichner erwartet"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "widersprüchliche Modifizierer %<monotonic%> und %<nonmonotonic%> angegeben"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "Wert der Chunkgröße muss positiv sein"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -35818,12 +35976,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "Wert von %<num_teams%> muss positiv sein"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "Wert von %<thread_limit%> muss positiv sein"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "Ausdruck für %<aligned%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
@@ -35843,17 +36001,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "Ausdruck der %<simdlen%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ungültige Abhängigkeitsart"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ungültige Zuordnungsart"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ungültige »dist_schedule«-Art"
@@ -35863,67 +36021,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ungültige »proc_bind«-Art"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "Klausel %<#pragma acc%> erwartet"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss die erste Klausel von %qs sein"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "keine gültigen Klauseln in %<#pragma acc declare%> angegeben"
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Arrayabschnitt in %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "In %<#pragma acc declare link%> muss %qD eine globale Variable sein"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ungültige OpenACC-Klausel im Datei-Gültigkeitsbereich"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<extern%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<global%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Variable %qD wird in %<#pragma acc declare%> mehr als einmal verwendet"
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "hinter %<#pragma acc %s%> wird %<data%> erwartet"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> hat keine Datenverschiebeklausel"
@@ -35938,7 +36096,7 @@
 msgid "expected function name"
 msgstr "Funktionsname erwartet"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD bezeichnet keine Funktion"
@@ -35948,42 +36106,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Funktionsdeklaration oder -definition auftreten"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Deklaration oder Definition einer einzelnen Funktion auftreten"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> wird bereits auf %qD angewendet"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> muss vor Verwendung angewendet werden"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> muss vor Definition angewendet werden"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> muss mindestens eine %<device%>- oder %<host%>- or %<self%>-Klausel enthalten"
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
@@ -35993,22 +36151,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-Klauselparameter ist weniger als %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%>-Klausel darf nicht zusammen mit %<ordered%>-Klausel mit einem Parameter angegeben werden"
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
@@ -36018,72 +36176,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "nicht genügend perfekt geschachtelte Schleifen"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%>-Klausel mit Parameter darf nicht beim %qs-Konstruk angegeben werden"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> mit %<depend%>-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> hinter %qs erwartet"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> erwartet"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> muss mindestens eine %<from%>- oder %<to%>-Klausel enthalten"
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> mit Zuordnungstyp außer %<to%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> mit Zuordnungstyp außer %<from%>, %<release%> oder %<delete%> an %<map%>-Klausel"
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
@@ -36103,32 +36261,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "hinter %<#pragma omp declare simd%> muss direkt eine Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "hinter %<#pragma omp declare simd%> muss direkt eine einzelne Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> mit Klauseln zwischen %<#pragma omp declare target%> ohne Klauseln und %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD ist sowohl in %<link%>- als auch %<to%>-Klauseln des Deklarationsziels angegeben"
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> erwartet"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> erwartet"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma opt end declare target%> ohne zugehöriges %<#pragma omp declare target%>"
@@ -36183,47 +36341,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "eins der Argumente für den Initialisierungsaufruf sollte %<&omp_priv%> sein"
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> oder %<reduction%> oder %<target%> erwartet"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Verwendung als %<threadprivate%> deklariert"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
@@ -36238,7 +36396,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD hat unvollständigen Typ %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "falsche Verwendung eines void-Ausdruckes"
@@ -36359,7 +36517,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indizierter Wert ist weder Array noch Zeiger noch Vektor"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "Arrayindex ist keine Ganzzahl"
@@ -36384,7 +36542,7 @@
 msgid "enum constant defined here"
 msgstr "enum-Konstante hier definiert"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> auf Array-Funktionsparameter %qE gibt die Größe von %qT zurück"
@@ -36487,17 +36645,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "implizite Umwandlung von %qT in %qT bei Übergabe von Argument an Funktion"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Vergleich mit Zeichenkettenliteral führt zu unspezifiziertem Verhalten"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "Vergleich zwischen Zeiger und '\\0'"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "wollten Sie vielleicht den Zeiger dereferenzieren?"
@@ -36522,7 +36680,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "Arithmetik mit Zeiger auf unvollständigen Typen"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "Arithmetik mit Zeiger auf leeres Aggregat"
@@ -36755,7 +36913,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "Typumwandlung von Funktionsaufruf des Typs %qT in unpassenden Typen %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "Typkonvertierung in Zeiger von Ganzzahl anderer Breite"
@@ -36907,7 +37065,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
@@ -36974,7 +37132,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ungültige Verwendung eines Nicht-L-Wert-Arrays"
@@ -37044,12 +37202,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionelles C lehnt automatische Gesamt-Initialisierung ab"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "Initialisierung eines flexiblen Array-Elements"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-Array mit wide-Zeichenkette initialisiert"
@@ -37095,7 +37253,7 @@
 msgid "invalid initializer"
 msgstr "ungültige Initialisierung"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
@@ -37110,7 +37268,7 @@
 msgid "braces around scalar initializer"
 msgstr "geschweifte Klammern um Skalar-Initialisierung"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "Initialisierung eines flexiblen Array-Elements in geschachteltem Kontext"
@@ -37240,7 +37398,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO-C verbietet %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
@@ -37280,7 +37438,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "»case«-Marke ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-Marke nicht innerhalb einer switch-Anweisung"
@@ -37290,17 +37448,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-Marke nicht innerhalb einer switch-Anweisung"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-Anweisung nicht innerhalb einer Schleife oder »switch«"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-Anweisung nicht innerhalb einer Schleife"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-Anweisung mit OpenMP für Schleife verwendet"
@@ -37325,22 +37483,22 @@
 msgid "expression statement has incomplete type"
 msgstr "Ausdrucksanweisung hat unvollständigen Typ"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Vergleich von Vektoren mit verschiedenen Element-Typen"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Vergleich von Vektoren mit unterschiedlicher Elementanzahl"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "kein ganzzahliger Typ mit derselben Größe wie %qT gefunden"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "Vergleich von Gleitkomma mit == oder != ist unsicher"
@@ -37391,7 +37549,7 @@
 msgstr "geordneter Vergleich von Zeiger mit Null-Zeiger"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordneter Vergleich von Zeiger mit Ganzzahlnull"
@@ -37421,12 +37579,12 @@
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
@@ -37436,25 +37594,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%>-Ausdruck %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "Bitfeld %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE ist ein Element eines Union-Typs"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE in %qs-Klausel muss eine Variable sein"
@@ -37465,70 +37623,70 @@
 msgstr "%<_Atomic%>-Deklaration %qD in %qs-Klausel"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD in %qs-Klausel ist eine threadprivate Variable"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "Untere Grenze %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Länge %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Arrayabschnitt der Länge 0 in %qs-Klausel"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "für Arraytyp mit unbekannten Grenzen muss ein Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negative untere Grenze in Arrayabschnitt in %qs-Klausel"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "Arrayabschnitt mit negativer Länge in %qs-Klausel"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "untere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "Länge %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "obere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "für Zeigertyp muss der Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "Arrayabschnitt ist in %qs-Klausel nicht zusammenhängend"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE hat weder Zeiger- noch Arraytyp"
@@ -37548,7 +37706,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE hat ungültigen Typ für %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
@@ -37558,17 +37716,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Elementtyp variabler Länge in %<reduction%>-Klausel eines Arrays"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%>-Klausel darf nicht zusammen mit %<copyprivate%> verwendet werden"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "Modifizierer sollte an %<simd%>- oder %<for%>-Konstrukten nicht in %<linear%>-Klausel angegeben werden"
@@ -37583,18 +37741,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD in %<linear%>-Klausel"
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "Schrittweite %qE der %<linear%>-Klausel muss konstant oder ein Parameter sein"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD tritt in Reduktionsklauseln mehrfach auf"
@@ -37606,32 +37764,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD tritt in Daten- und Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE ist in Klausel %<firstprivate%> keine Variable"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE ist in Klausel %<lastprivate%> keine Variable"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE ist %<aligned%>-Klausel keine Variable"
@@ -37651,55 +37809,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE ist in %<depends%>-Klausel keine Variable"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Arrayabschnitt in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Bewegungsklausel mehrfach auf"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE in %qs-Klausel ist weder Variablen- noch Funktionsname"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE tritt in derselben %<declare target%>-Direktive mehrfach auf"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE in %<uniform%>-Klausel ist kein Argument"
@@ -37709,32 +37867,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "Variable %qs ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "%<nonmonotonic%>-Modifizierer für Planungsart %qs angegeben"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<inbranch%>-Klausel ist inkompatibel mit %<notinbranch%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-Klauselwert ist größer als %<safelen%>-Klauselwert"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-Planungsmodifizierer zusammen mit %<ordered%>-Klausel angegeben"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-Klauselschritt ist ein Parameter %qD, der nicht in der %<uniform%>-Klausel angegeben ist"
@@ -37863,7 +38021,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  keine bekannte Umwandlung für Argument %d von %qH nach %qI"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -37941,24 +38099,24 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr "  ein geerbter Konstruktor ist kein Kandidat für Initialisierung aus einem Ausdruck desselben oder eines abgeleiteten Typs"
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "Umformung von %qH nach %qI ist mehrdeutig"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr "das Initialisieren von %qH mit %qI in einem umgewandelten konstanten Ausdruck bindet nicht direkt"
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "Umwandlung von %qH nach %qI in einem umgewandelten konstanten Ausdruck"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%D(%A)%> ist nicht eindeutig"
@@ -37965,606 +38123,606 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "Zeiger auf Elementfunktion %qE kann nicht ohne Objekt aufgerufen werden; verwenden Sie beispielsweise %<.*%> oder %<->*%>"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "keine Übereinstimmung für Aufruf von %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Aufruf von %<(%T) (%A)%> ist nicht eindeutig"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "mehrdeutiges Überladen für "
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr "keine Übereinstimmung für "
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr " (Operandentypen sind %qT, %qT und %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr " (Operandentypen sind %qT und %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr " (Operandentyp ist %qT)"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "ternärer %<operator?:%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "ternärer %<operator?:%> in %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%<operator%s%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> in %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "%<operator[]%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<operator[]%> in %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, gcc-internal-format
 msgid "%qs"
 msgstr "%qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%qs in %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> in %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> in %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO-C++ verbietet das Auslassen des mittleren Terms eines »?:«-Ausdruckes"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr "abgeleiteter skalarer Typ %qT muss ein Ganzzahl- oder Gleitkommatyp derselben Größe wie %qT sein"
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "Umwandlung von Skalar %qH in Vektor %qI führt zum Abschneiden"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "unverträgliche Vektortypen in bedingtem Ausdruck: %qT, %qT und %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "zweiter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der dritte Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "dritter Operand für Bedingungsoperator ist vom Typ %<void%>, aber der zweite Operand ist weder ein Throw-Ausdruck noch vom Typ %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "Operanden für ?: haben verschiedene Typen: %qT und %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr "  und jeder Typ kann zu jedem anderen konvertiert werden"
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "implizite Umwandlung von %qH in %qI, um an das Ergebnis im anderen Zweig der Bedingung anzugleichen"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "Aufzählungsfehler in bedingtem Ausdruck: %qT vs. %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "Aufzählungs- und Nicht-Aufzählungstyp in bedingtem Ausdruck"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert, stattdessen wird Präfixoperator versucht"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "Vergleich zwischen %q#T und %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr "Exceptionaufräumen für dieses Placement-New wählt delete-Operator für Nicht-Placement"
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr "%qD ist eine übliche (nicht-placement) Deallokationsfunktion in C++14 (oder mit -fsized-deallocation)"
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD ist eine gewöhnliche (nicht-Platzierungs) Deallokationsfunktion"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "keine passende Freigabefunktion für %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "kein geeignetes %<operator %s%> für %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D ist in diesem Zusammenhang »private«"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "hier als »private« deklariert"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D ist in diesem Zusammenhang »protected«"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "hier als »protected« deklariert"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D ist in diesem Zusammenhang unzugänglich"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Übergabe von NULL an Nicht-Zeiger-Argument %P von %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "Konvertierung in Nicht-Zeiger-Typ %qT von NULL"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%<false%> wird für Argument %P von %qD in Zeigertyp umgewandelt"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "%<false%> wird in Zeigertyp %qT umgewandelt"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "zu viele geschweifte Klammern um Initialisierung für %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "Umwandlung von %qH nach %qI erfordert direkte Initialisierung"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ungültige benutzerdefinierte Umwandlung von %qH in %qI"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  Argument %P von %qD wird initialisiert"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 msgid "invalid conversion from %qH to %qI"
 msgstr "ungültige Umwandlung von %qH in %qI"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "Umwandlung in %qT von Initialisierungsliste würde expliziten Konstruktor %qD verwenden"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "in C++11 und neuer kann ein Defaultkonstruktor explizit sein"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "rvalue-Referenz vom Typ %qH kann nicht an lvalue vom Typ %qI gebunden werden"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "nicht-konstante lvalue-Referenz vom Typ %qH kann nicht an rvalue vom Typ %qI gebunden werden"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "das Binden der Referenz vom Typ %qH an %qI streicht Qualifizierer"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "das Bitfeld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "das gepackte Feld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "der R-Wert %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implizite Umwandlung von %qH in %qI bei Übergabe von Argument an Funktion"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr "enum %qT mit eingeschränkter Sichtbarkeit wird vor »-fabi-version=6« als Typ %qT, später jedoch als %qT durch »...« übergeben"
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "Referenztyp %qT kann nicht über %<...%> empfangen werden"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursive Auswertung des Standardarguments für %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "Aufruf von %qD verwendet das Standardargument für Parameter %P, der noch nicht definiert wurde"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Argument des Funktionsaufrufs könnte Kandidat für Formatattribut sein"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "Verwendung einer multiversionierten Funktion ohne Standardargument"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  in Aufruf von %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT ist keine erreichbare Basis von %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT ermittelt als %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (dies kann mit -fno-deduce-init-list abgeschaltet werden)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Argumente werden an Auslassungspunkte des geerbten Konstruktors %qD übergeben"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung"
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivialen Typs %#qT%s"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT mit Element %qs %qD"
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung oder Wertinitialisierung"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Wertinitialisierung"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD Säubern eines Objekts von nichttrivialem Typ %#qT%s"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung oder Kopierinitialisierung"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierinitialisierung"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivial kopierbaren Typs %#qT%s"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD Schreibzugriff auf ein Objekt mit einem gelöschten Kopierkonstruktor"
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD Kopieren eines Objekts mit nichttrivialem Typ %#qT aus einem Array von %#qT"
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD Kopieren eines Objekts des Typs %#qT mit Element %qs %qD aus einem Array von %#qT; verwenden Sie eine Zuweisung oder Kopierinitialisierung stattdessen"
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Bytes unverändert"
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Byte unverändert"
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des nichttrivial kopierbaren Typs %#qT; verwenden Sie stattdessen %<new%> oder %<delete%>"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Kopierkonstruktor; verwenden Sie stattdessen %<new%> und %<delete%>"
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Destruktor"
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD Verschieben eines Objekts des nichttrivialen Typs %#qT und Größe %E in eine Region der Größe %E"
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT wird hier deklariert"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Konstruktor verweist auf sich selbst"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "um eine funktionsartige Umwandlung zu erreichen, entfernen Sie das redundante %<::%D%>"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%s(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%s(%A)%> ist mehrdeutig"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtuelle %q#D aus nichtstatischem Datenelement-Initialisierer heraus aufgerufen"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtuelle %q#D aus Konstruktor heraus aufgerufen"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtuelle %q#D aus Destruktor heraus aufgerufen"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "Elementfunktion %qD kann nicht ohne Objekt aufgerufen werden"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "Übergabe von %qT wählt %qT statt %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "Wahl von %qD statt %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 msgid "  for conversion from %qH to %qI"
 msgstr "  für Umwandlung von %qH in %qI"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  denn die Umwandlungsfolge für das Argument ist besser"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "Zuordnungsfehler der Standardargumente in Überladungsauflösung"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " Kandidat 1: %q#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " Kandidat 2: %q#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ besagt, dass diese mehrdeutig sind, auch wenn die schlechteste Umwandlung für das erste besser ist als die schlechteste Umwandlung für das zweite:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE konnte nicht von %qH nach %qI umgewandelt werden"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "eine vorübergehende Bindung an %qD besteht nur, bis der Konstruktor beendet ist"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ungültige Initialisierung einer nicht-konstanten Referenz des Typs %qH von rvalue des Typs %qI"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ungültige Initialisierung einer Referenz des Typs %qH von Ausdruck des Typs %qI"
 
@@ -38603,8 +38761,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kann nicht mit %q#D überladen werden"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "vorherige Deklaration von %q#D"
@@ -38645,7 +38803,7 @@
 msgstr "%qD erbt das %E-ABI-Tag, das %qT (im Rückgabetyp verwendet) hat"
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qT hier deklariert"
@@ -38725,7 +38883,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "diese Flexibilität ist veraltet und wird demnächst entfernt"
@@ -39002,7 +39160,7 @@
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
@@ -39072,7 +39230,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(ein Zeiger auf ein Element kann nur mit %<»&%E%> erzeugt werden)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "zu wenig Typinformationen"
@@ -39167,333 +39325,333 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD ist nicht als %<constexpr%>-Funktion verwendbar, denn:"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "Kontrollfluss für %<constexpr%>-Aufruf fällt hinten aus der Funktion"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "Aufruf für interne Funktion %qE"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "Ausdruck %qE bezeichnet keine %<constexpr%>-Funktion"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "Aufruf der nicht-%<constexpr%>-Funktion %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD in konstantem Ausdruck aufgerufen, bevor die Definition vollständig war"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD in konstantem Ausdruck aufgerufen"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD vor seiner Definition verwendet"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "Aufruf hat ringförmige Abhängigkeit"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "Auswertungstiefe von %<constexpr%> überschreitet Höchstwert %d (-fconstexpr-depth= verwenden, um dies zu erhöhen)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "rechter Operand des Schiebeausdrucks %q+E ist negativ"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "rechter Operand des Schiebeausdrucks %q+E ist mindestens so groß wie die Genauigkeit des linken Operanden"
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker Operand des Schiebeausdrucks %q+E ist negativ"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "Schiebeausdruck %q+E läuft über"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "Arithmetik mit Nullzeiger in %qE"
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arrays %qD vom Typ %qT"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array %qD vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arraytyps %qT"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "Zugriff auf uninitialisiertes Arrayelement"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Dereferenzierung eines Nullzeigers in %qE"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "veränderliches %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "Zugriff auf Element %qD statt auf initialisiertes Element %qD in Konstantenausdruck"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "Zugriff auf uninitialisiertes Element %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Dereferenzierung eines Null-Zeigers"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "auf Wert von %qE wird über ein %qT GL-Wert in Konstantenausdruck zugegriffen"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "der Wert von %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD in seiner eigenen Initialisierung verwendet"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D ist nicht konstant"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D ist volatile"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD wurde nicht mit konstantem Ausdruck initialisiert"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD wurde nicht als %<constexpr%> definiert"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD hat keinen Ganzzahl- oder Aufzählungstyp"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "Modifikation von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "Anzahl der Schleifendurchläufe in %<constexpr%> überschreitet Höchstwert %d (»-fconstexpr-loop-limit=« verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Wert %qE vom Typ %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "Ein »reinterpret_cast« ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "Umwandlung eines Nullpointers vom Typ %qT in %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Ausdruck %qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "Anweisung ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unexpected expression %qE of kind %s"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE ist kein Konstantenausdruck, da er auf veränderliche Teilobjekte von %qT verweist"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE ist kein Konstantenausdruck, da er auf eine unvollständig initialisierte Variable verweist"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Umwandlung von Zeigertyp %qT in arithmetischen Typ %qT in Konstantenausdruck"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "Ausdruck %qE hat Seiteneffekte"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Lambda-Einfangen von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "da er als glvalue verwendet wird"
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast von Integer nach Zeiger"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "Verwendung von %<this%> in Konstantenausdruck"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Lambda-Ausdruck ist erst ab C++17 ein konstanter Ausdruck"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "Typeid-Ausdruck ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<static%> deklariert"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<thread_local%> deklariert"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Arrayinitialisierung"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr "throw wird immer terminate() aufrufen"
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr "in C++11 sind Destruktoren per Default »noexcept«"
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr "in C++11 löst das ein »throw« aus, da Destruktoren per Default »noexcept« sind"
@@ -39534,7 +39692,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "Umwandlung von %qH in %qI löscht Qualifizierer"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Umwandlung von %qT in %qT dereferenziert nicht den Zeiger"
@@ -39543,306 +39701,306 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "Typ %qH kann nicht in den Typ %qI umgewandelt werden"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "Umwandlung von %q#T nach %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "das Ergebnis der Umwandlung ist nicht spezifiziert, da %qE außerhalb des Wertebereichs des Typs %qT liegt"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T verwendet, wo %qT erwartet wurde"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "%qE konnte nicht von %<void%> nach %<bool%> umgewandelt werden"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T verwendet, wo ein Gleitkommawert erwartet wurde"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "Umwandlung von %qH in nicht-skalaren Typen %qI angefordert"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "Der Rückgabewert von %qD (mit »nodiscard«-Attribut markiert) wird ignoriert"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "Der Rückgabewert von Typ %qT (mit »nodiscard«-Attribut markiert) wird ignoriert"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "im Aufruf von %qD, hier deklariert"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "Pseudo-Destruktor wird nicht aufgerufen"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des unvollständigen Typs %qT zu"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in zweitem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in drittem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in rechtem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in linkem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "Indirektion greift nicht auf Objekt unvollständigen Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des Typs %qT zu"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in zweitem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in drittem Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in rechtem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in linkem Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "implizite Dereferenzierung greift nicht auf Objekt des Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT zu"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im zweiten Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im dritten Operanden des bedingten Ausdrucks zu"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im rechten Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT im linken Operanden des Kommaoperators zu"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT in Anweisung zu"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "Indirektion greift nicht auf Objekt des nicht trivial kopierbaren Typs %qT in Erhöhungsausdruck zu"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "Umwandlung in void greift nicht auf Objekt %qE des unvollständigen Typs %qT zu"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im zweiten Operanden des bedingten Ausdrucks zugegriffen"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im dritten Operanden des bedingten Ausdrucks zugegriffen"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im rechten Operanden des Kommaoperators zugegriffen"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird nicht im linken Operanden des Kommaoperators zugegriffen"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird in Anweisung nicht zugegriffen"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "auf Variable %qE des unvollständigen Typs %qT wird in Erhöhungsausdruck nicht zugegriffen"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "Umwandlung in void kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "zweiter Operand des bedingten Ausdrucks kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "dritter Operand des bedingten Ausdrucks kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "rechter Operand des Komma-Operators kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "linker Operand des Komma-Operators kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "Anweisung kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "Erhöhungsausdruck kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "zweiter Operand des bedingten Ausdrucks ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "dritter Operand des bedingten Ausdrucks ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "rechter Operand des Komma-Operators ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "linker Operand des Komma-Operators ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "Anweisung ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "Erhöhungsausdruck ist eine Referenz, kein Aufruf, zur Funktion %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "zweiter Operand des bedingten Ausdrucks hat keinen Effekt"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "dritter Operand des bedingten Ausdrucks hat keinen Effekt"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "rechter Operand des Komma-Operators hat keinen Effekt"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "linker Operand des Komma-Operators hat keinen Effekt"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "Anweisung hat keinen Effekt"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "Erhöhungsausdruck hat keinen Effekt"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "Umwandlung von NULL in Nicht-Zeiger-Typ"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "Template-Argument für %qD kann nicht aus Default-Typumwandlungen bestimmt werden"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "mehrdeutige Standard-Typumwandlung von %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  in Frage kommende Umwandlungen beziehen %qD und %qD ein"
@@ -39882,197 +40040,197 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD wurde %<extern%> deklariert und später %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "Deklaration von %qF hat unterschiedlichen Exceptionspezifizierer"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "von vorheriger Deklaration %qF"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "Redeklaration %qD unterscheidet sich in %<constexpr%> von vorheriger Deklaration"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "vorherige Deklaration %qD"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr "Konzept %q#D kann nicht spezialisiert werden"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "Redeklaration von %q#D hat möglicherweise keine Default-Argumente"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "Literales Operatortemplate %q+D steht mit rohem Literaloperator %qD in Konflikt"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "roher Literaloperator %q+D steht mit literalem Operatortemplate %qD in Konflikt"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "vorherige Definition von %qD war hier"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "vorherige Deklaration von %qD war hier"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "eingebaute Funktion %qD als Nicht-Funktion deklariert"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "eingebaute Funktion %q#D wird überdeckt"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "Bibliotheksfunktion %q#D wird überdeckt"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "Bibliotheksfunktion %q#D als Nicht-Funktion %q#D redeklariert"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "Deklaration von %q+#D steht mit eingebauter Deklaration %q#D in Konflikt"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "Redeklaration von %<pragma omp declare reduction%>"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "vorherige Deklaration von %<pragma omp declare reduction%>"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "Deklaration von %q#D steht mit eingebauter Deklaration %q#D in Konflikt"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "Definition von %q#D macht eingebaute Deklaration %q#D mehrdeutig"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "neue Deklaration %q#D macht eingebaute Deklaration %q#D mehrdeutig"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "Deklaration %q#D wird ignoriert"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D als andere Symbolart redeklariert"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "unverträgliche Deklaration des Templates %q+#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "mehrdeutig machende neue Deklaration %q+#D"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "alte Deklaration %q#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "in Konflikt stehende Deklaration für C-Funktion %q+#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "macht neue Deklaration %q+#D mehrdeutig"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "in Konflikt stehende Deklaration %q+#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "bisherige Deklaration als %q#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr "%q#D wurde bereits hier definiert"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D wurde bereits hier deklariert"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "Prototyp für %q#D angegeben"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "vorherige Nicht-Prototyp-Definition hier"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "steht mit neuer Deklaration von %q+#D mit %qL-Bindung in Konflikt"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "bisherige Deklaration mit %qL-Bindung"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "Standardargument für Parameter %d von %q#D angegeben"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "bisherige Spezifikation in %q+#D hier"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "redundante Redeklaration von %qD im selben Gültigkeitsbereich"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "Definition von %q+D gelöscht"
@@ -40085,39 +40243,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explizite Spezialisierung von %qD nach erster Verwendung"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: Sichtbarkeitsattribut ignoriert, da es in Konflikt mit vorheriger Deklaration steht"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "Redefinition von %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD steht mit verwendeter Funktion in Konflikt"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D nicht in Klasse deklariert"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D mit Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D ohne Attribut %<gnu_inline%> »inline« redeklariert"
@@ -40125,630 +40283,631 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Redeklaration des »friend« %q#D kann keine Standardtemplateargumente haben"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "Thread-lokale Deklaration von %q#D folgt nicht-Thread-lokaler Deklaration"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "Nicht-Thread-lokale Deklaration von %q#D folgt Thread-lokaler Deklaration"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "Redeklaration von %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redundante Redeklaration von %<constexpr%>static-Datenmember %qD"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "lokale Sprungmarke %qE steht in Konflikt mit bestehender Sprungmarke"
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr "vorherige Sprungmarke"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  von hier"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  beendet OpenMP-strukturierten Block"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  überschneidet Initialisierung von %q#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  Eintritt in Gültigkeitsbereich von %q#D mit nicht-trivialem Destruktor"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr "  %s"
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  tritt in catch-Block ein"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  überspringt Initialisierung von %q#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  Eintritt in Gültigkeitsbereich von %q#D mit nicht-trivialem Destruktor"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  tritt in try-Block ein"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  synchronisierte oder atomare Anweisung wird betreten"
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr "  betritt if-Anweisung mit %<constexpr%>"
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  tritt in OpenMP-strukturierten Block ein"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ungültiger Ausgang von strukturiertem OpenMP-Block"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ist kein Typ"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD ohne Template-Parameter verwendet"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ist keine Klasse"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "kein Klassentemplate namens %q#T in %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "kein Typ namens %q#T in %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "Nachschlagen von %qT in %qT ist nicht eindeutig"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Klassentemplate ist"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Typ ist"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "Template-Parameter passen nicht zum Template %qD"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%<-fno-for-scope%> ist veraltet"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr "%<-ffriend-injection%> ist veraltet"
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr "-faligned-new=%d ist keine Zweierpotenz"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Konstruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Destruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Zuweisungsoperator ist in anonymem Aggregt nicht erlaubt"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "Attribut in Deklaration von %q#T ignoriert"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "Attribut für %q#T muss dem Schlüsselwort %qs folgen"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "mehrere Typen in einer Deklaration"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "Redeklaration des eingebauten C++-Typs %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kann nur für Variablen oder Funktionsdeklarationen angegeben werden"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "fehlender Typname in typedef-Deklaration"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO-C++ verbietet anonyme structs"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kann nur innerhalb einer Klasse angegeben werden"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kann nur für Konstruktoren angegeben werden"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "eine Speicherklasse kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> wurde in dieser Deklaration ignoriert"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> kann nicht für Typdeklarationen verwendet werden"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "Attribut in expliter Instanziierung %q#T ignoriert"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "auf explizite Instanziierung kann kein Attribut angewendet werden"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "auf Klassentyp %qT angewandte Attribute außerhalb einer Definition werden ignoriert"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "auf abhängigen Typ %qT angewandte Attribute ohne zugehörige Deklaration werden ignoriert"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen decltype verwenden)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "Deklaration von %q#D hat %<extern%> und ist initialisiert"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "Definition von %q#D ist als »dllimport« markiert"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D ist kein static-Datenelement von %q#T"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "Nichtelement-Templatedeklaration von %qD"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "entspricht nicht der Element-Templatedeklaration hier"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO-C++ erlaubt nicht, %<%T::%D%> als %<%T::%D%> zu definieren"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "doppelte Initialisierung von %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "Deklaration von %q#D außerhalb einer Klasse ist keine Definition"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD in %<constexpr%>-Funktion als %<thread_local%> deklariert"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qD in %<constexpr%>-Funktion als %<static%> deklariert"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "Variable %q#D hat Initialisierung, aber unvollständigen Typ"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "Elemente des Arrays %q#D haben unvollständigen Typ"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "Aggregat %q#D hat unvollständigen Typ und kann nicht definiert werden"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD als Referenz deklariert, aber nicht initialisiert"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "Name in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "Name %qD in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "nicht-trivial markierte Initialisierungen nicht unterstützt"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-Designator %qE ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "Initialisierung gibt nicht die Größe von %qD an"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "Arraygröße fehlt in %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "Array %qD der Größe null"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Speichergröße von %qD ist unbekannt"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Speichergröße von %qD ist nicht konstant"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik der Inline-Variable %q#D ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik von static-Variable %q#D in inline-Funktion ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "dies kann durch das Löschen der Initialisierung umgangen werden"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "nicht initialisiertes const %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Funktion"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Kontext"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T hat keinen benutzerdefinierten Default-Konstruktor"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "Konstruktor ist nicht benutzerdefiniert, da er im Klassenkörper ausdrücklich standardisiert ist"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "und der implizit definierte Konstruktor initialisiert %q#D nicht"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Ungültiger Typ %qT als Initialisierung für einen Vektor des Typs %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "Initialisierung für %qT muss geklammert sein"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> in benannter Initialisierung im GNU-Stil für Klasse %qT verwendet"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT hat kein nicht-statisches Datenelement namens %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ungültige Initialisierung für %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "geschweifte Klammern fehlen um Initialisierung für %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "Elemente des Arrays %q#T haben unvollständigen Typ"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "zusammengesetztes Literal variabler Größe"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D hat unvollständigen Typ"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalares Objekt %qD erfordert ein Element in Initialisierung"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "in C++98 muss %qD mit Konstruktor initialisiert werden, nicht mit %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "Array %qD mit geklammerter Zeichenkettenkonstante %qE initialisiert"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "Initialisierung ungültig für statisches Element mit Konstruktor"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(eine Initialisierung außerhalb der Klasse ist erforderlich)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "Referenz %qD wird mit sich selbst initialisiert"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO-C++17 erlaubt Speicherklassenangabe %<register%> nicht"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-Speicherklassenangabe verwendet"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "Initialisierung für %<decltype(auto) %D%> hat Funktionstyp (%<()%> vergessen?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "Variablenkonzept hat keine Initialisierung"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "vorherige Typdeklaration von %q#D wird überschattet"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Strukturelement hat"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Unionelement hat"
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+#| msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "nicht-public-Element %qD von %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da sowohl er als auch seine Basisklasse %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da seine Basisklassen %qT und %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "Array mit variabler Länge %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40755,7 +40914,7 @@
 msgstr[0] "%u Name für strukturelle Bindung angegeben"
 msgstr[1] "%u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40762,7 +40921,7 @@
 msgstr[0] "nur %u Name für strukturelle Bindung angegeben"
 msgstr[1] "nur %u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40769,1327 +40928,1339 @@
 msgstr[0] "während %qT in %wu Element zerlegt wird"
 msgstr[1] "während %qT in %wu Elemente zerlegt wird"
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "Vektor %qT variabler Länge kann nicht zerlegt werden"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "während %qT in %E Elemente zerlegt wird"
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "in Initialisierung der Variable %qD für strukturierte Bindung"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "Union-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "nicht-Array-nicht-Klassentyp %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Lambda-Abschluss-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
+#, fuzzy, gcc-internal-format
+#| msgid "structured binding refers to incomplete type %qT"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
+
+#: cp/decl.c:7774
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "Klassentyp %qT ohne nicht-static-Datenelemente kann nicht dekomponiert werden"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Arraygröße fehlt in %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Array %qT der Größe null"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "Konzept %q#D mit Funktionsparametern deklariert"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "Konzept %q#D mit hergeleitetem Rückgabetyp deklariert"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Konzept %q#D mit nicht-%<bool%>-Rückgabetyp %qT"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "Konzept %qD hat keine Definition"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "Definition der expliziten Spezialisierung %qD in friend-Deklaration"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ungültige Verwendung der Template-ID %qD in Deklaration des ursprünglichen Templates"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "Standardargumente sind nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> kann nicht als Template deklariert werden"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "%<::main%> kann nicht als %<constexpr%> deklariert werden"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> kann nicht statisch deklariert werden"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statische Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "Herleitungshinweis %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "Herleitungshinweis %qD darf keinen Funktionskörper haben"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literaler Operator mit C-Bindung"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD hat ungültige Argumentliste"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "Ganzzahl-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "Gleitkomma-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
+
+#: cp/decl.c:8996
+#, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD muss eine Nicht-Elementfunktion sein"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> muss %<int%> zurückgeben"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "Definition des implizit deklarierten %qD"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "Definition des explizit standardisierten %q+D"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D wurde hat hier ausdrücklichen Standardwert bekommen"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "keine Elementfunktion %q#D in Klasse %qT deklariert"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> kann nicht als globale Variable deklariert werden"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "eine Nicht-Template-Variable kann nicht %<concept%> sein"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "Konzept muss Typ %<bool%> haben"
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit unvollständigem Typ"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> erforderlich für Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ungültige Initialisierung innerhalb der Klasse des statischen Datenelements vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO-C++ verbietet Initialisierung des nicht konstanten statischen Elements %qD in der Klasse"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO-C++ verbietet Initialisierung der Elementkonstante %qD vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "Arraygröße von %qD hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "Arraygröße hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "Größe des Arrays ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "Größe des Arrays %qD ist negativ"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "Größe des Arrays ist negativ"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO-C++ verbietet Array %qD der Größe null"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO-C++ verbietet Array der Größe null"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "Größe des Arrays %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO-C++ verbietet Array %qD variabler Länge"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO-C++ verbietet Array variabler Länge"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "Array %qD variabler Länge wird verwendet"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "Array variabler Größe wird verwendet"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "Überlauf in Arraygröße"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD als Array von %qT deklariert"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "Deklaration von %qD als Array von voids"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "Array von void wird erzeugt"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "Deklaration von %qD als Array von Funktionen"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "Array von Funktionen wird erzeugt"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "Deklaration von %qD als Array von Referenzen"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "Feld von Referenzen wird erzeugt"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "Deklaration von %qD als Feld von Funktionselementen"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "Feld von Funktionselementen wird erzeugt"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qD als multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "Angabe des Rückgabetyps für Konstruktor ist ungültig"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Qualifizierer sind bei Konstruktordeklarationen nicht erlaubt"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "Angabe des Rückgabetyps für Destruktor ist ungültig"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "Qualifizierer sind bei Destruktordeklarationen nicht erlaubt"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "Rückgabetyp für %<operator %T%> angegeben"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "Qualifizierer sind bei Deklaration von %<operator %T%> nicht erlaubt"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "Rückgabetyp für Herleitungshinweis angegeben"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "Qualifizierer sind bei Deklaration von Herleitungshinweis nicht erlaubt"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Template-Template-Parameter %qT in Deklaration von Ableitungshinweis"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "decl-specifier in Deklaration von Ableitungshinweis"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unbenannte Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%>-Spezifizierer ungültig für Variable %qD mit Gültigkeitsbereich Block"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "»inline«-Variablen sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T ist keine Klasse oder Namensbereich"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "Deklaration von %qD als Nicht-Element"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "Deklaration von %qD als %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "Deklaration von %qD als Parameter"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<concept%> darf nicht in typedef-Deklarationen auftreten"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> kann nicht in typedef-Deklaration auftreten"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "zwei oder mehr Datentypen in Deklaration von %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "in Konflikt stehende Spezifikationen für Deklaration von %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C++ unterstützt nicht, dass einfaches %<complex%> %<double complex%> bedeutet"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO-C++ verbietet Deklaration von %qs ohne Typ"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> wird von diesem Ziel nicht unterstützt"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO-C++ unterstützt %<__int%d%> for %qs nicht"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> oder %<unsigned%> ungültig für %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> und %<unsigned%> für %qs gleichzeitig angegeben"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> ungültig für %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> ungültig für %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> ungültig für %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> oder %<short%> ungültig für %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> oder %<char%> ungültig für %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> oder %<short%> mit »char« für %qs angegeben"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> und %<short%> für %qs gleichzeitig angegeben"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> oder %<long%> ungültig für %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed oder unsigned ungültig verwendet für %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ungültig für %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "Template-Platzhaltertyp %qT muss von einer einfachen declarator-id gefolgt sein"
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<static%> sein"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<constexpr%> sein"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "»typedef«-Deklaration in Parameterdeklaration ungültig"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Speicherklasse für Template-Parameter %qs angegeben"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "Speicherklassenangaben sind in Parameterdeklarationen ungültig"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "ein Parameter kann nicht als %<concept%> deklariert sein"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "ein Parameter kann nicht als %<constexpr%> deklariert sein"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<inline%> deklariert werden"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<typedef%> deklariert werden"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<constexpr%> deklariert werden"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %qs deklariert werden"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<concept%> deklariert werden"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<register%> deklariert werden"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<static%> deklariert werden"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<extern%> deklariert werden"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<mutable%> deklariert werden"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<auto%> (C++98) deklariert werden"
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom Typen %qT sein"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "Typ muss cv-qualifizierter %<auto%> oder Referenz auf cv-qualifizierten %<auto%> sein"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "mehrere Speicherklassen in Deklaration von %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Speicherklasse %qs angegeben"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "Speicherklasse für Parameter %qs angegeben"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geschachtelte Funktion %qs als %<extern%> deklariert"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "Deklaration höchster Ebene von %qs gibt %<auto%> an"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "Funktions-Gültigkeitsbereich %qs ist implizit auto und deklarierte %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "Speicherklassenangaben sind in friend-Funktionsdeklarationen ungültig"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "unnötige Klammern in Deklaration von %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "»requires«-Klausel für Rückgabetyp"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "hergeleiteter Rückgabetyp nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen kann keinen hergeleiteten Rückgabetyp haben"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
+#, fuzzy, gcc-internal-format
+#| msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "hergeleiteter Klassentyp %qT in Rückgabetyp von Funktion"
+
+#: cp/decl.c:11156
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Herleitungshinweis für %qT muss angehängten Rückgabetyp haben"
 
-#: cp/decl.c:11099
+#: cp/decl.c:11169
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
-msgstr "hergeleiteter Klassentyp %qT in Rückgabetyp von Funktion"
-
-#: cp/decl.c:11111
-#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "angehängter Rückgabetyp %qT den Ableitungshinweises ist keine Spezialisierung von %qT"
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "folgender Rückgabetyp nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Konstruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Konstruktoren dürfen nicht als %<virtual%> deklariert sein"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "friend-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "eine Umwandlungsfunktion darf keinen angehängten Rückgabetyp haben"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT definiert werden"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT deklariert werden"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> in »friend«-Deklaration"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren und Umwandlungsoperatoren können %<explicit%> sein"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statisches %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "Konstante %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-clause an Typedef"
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-clause an type-id"
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "»requires«-Klausel in Deklaration von Nichtfunktionstyp %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%>-Parameter darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "nicht-statisches Datenelement mit Platzhalter %qT deklariert"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO-C++ verbietet flexibles Arrayelement %qs"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO-C++ verbietet flexible Arrayelemente"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Funktion %qD wurde innerhalb einer Union als »virtual« deklariert"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kann nicht als »virtual« deklariert werden, da es immer statisch ist"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "ein Destruktor kann nicht %<concept%> sein"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Destruktor kann nicht %<constexpr%> sein"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "ein Konstruktor kann nicht %<concept%> sein"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ein Konzept kann keine Elementfunktion sein"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Variablentemplates %qD als Funktion deklariert"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "Variablentemplate hier deklariert"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen %qT"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "statisches Datenelement %qE als %<constexpr%> deklariert"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (%<constexpr%>) muss Initialisierung haben"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "nicht-statisches Datenelement %qE als %<concept%> deklariert"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "nicht-statisches Datenelement %qE als %<constexpr%> deklariert"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> ist für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs ungültig"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
@@ -42096,77 +42267,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "Deklaration der %<constexpr%>-Variable %qD ist keine Definition"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von cv-qualifiziertem Typ %qT in Parameterdeklaration"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von Typ %<void%> in Parameterdeklaration"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
@@ -42186,169 +42357,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO-C++ verbietet Überladen des Operators ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD darf keine Argumente nehmen"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf void wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "Umwandlung in void wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "Umwandlung in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf Basisklasse wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "Umwandlung in Basisklasse wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT hat hier eine vorherige Deklaration"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -42360,94 +42531,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT ist mit mehreren direkten Basisklassen definiert"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT ist mit direkter virtueller Basisklasse definiert"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
@@ -42456,77 +42627,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Aufzählungswert für %qD muss ganzzahligen oder Aufzählungstyp ohne Gültigkeitsbereich haben"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<long%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Aufzählungswert %qE ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen %qT"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "ungültige Funktionsdeklaration"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ungültige Elementfunktionsdeklaration"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -42566,7 +42737,7 @@
 msgid "deleting %qT is undefined"
 msgstr "Löschen von %qT ist nicht definiert"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "Templatedeklaration von %q#D"
@@ -42579,7 +42750,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "Destruktor %qD als Element-Template deklariert"
@@ -42689,42 +42860,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "Breite des Bit-Feldes %qD hat Nicht-Ganzzahl-Typ %qT"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "statisches Datenelement %q+D innerhalb von »declare target«-Direktive"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonymes struct nicht innerhalb eines benannten Typs"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "privates Element %q#D in anonymer Union"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "geschütztes Element %q#D in anonymer Union"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonymes Aggregat im Gültigkeitsbereich eines Namespace muss statisch sein"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonyme Union ohne Element"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> muss Typ %qT zurückgeben"
@@ -42733,67 +42904,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "der erste Parameter von %<operator_new%> kann nicht das Standardargument haben"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> nimmt Typ %<size_t%> (%qT) als ersten Parameter"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> muss Typ %qT zurückgeben"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nimmt Typ %qT als ersten Parameter"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ keine Bindung hat"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ vom Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT hat ein Feld %qD, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als der Typ seines Feldes %qD deklariert"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT hat Basis %qT, dessen Typ keine Bindung hat"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat Basis %qT, dessen Typ von Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT hat Basis %qT, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als seine Basis %qT deklariert"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D (durch einen unbenannten Typen deklariert) wird verwendet, aber nirgends definiert"
@@ -42802,62 +42973,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Funktion %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D verweist nicht auf den unqualifizierten Typen und wird daher nicht zum Binden verwendet"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D (durch lokalen Typen %qT deklariert) wird verwendet, aber nirgends definiert"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "Typ %qT ohne Bindung verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "Typ %qT ohne Bindung für Funktionsdeklaration %q#D mit Bindung deklariert"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "Mangeln von %q#D als %qE steht mit einer vorherigen Mangelung in Konflikt"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "vorherige Mangelung von %q#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "Eine spätere Option -fabi-version= (oder =0) verhindert diesen Fehler mit einer Änderung im Mangeln"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "das Programm sollte auch %qD definieren"
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-Funktion %qD verwendet, aber nirgendwo definiert"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "Standardargument fehlt für Parameter %P von %q+#D"
@@ -42864,17 +43035,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "Lambda, das %<…%> verwendendet, wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "Verwendung von eingebautem Parameterpack %qD außerhalb eines Templates"
@@ -42884,112 +43055,112 @@
 msgid "with"
 msgstr "mit"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, gcc-internal-format
 msgid "(no argument)"
 msgstr "(kein Argument)"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr "[…]"
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "erweiterte Initialisierungsliste nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "explizite Umwandlungsoperatoren nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "variadische Templates nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "Lambda-Ausdrücke nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 »auto« ist nur mit »-std=c++11« oder »-std=gnu++11« verfügbar"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "enums mit Gültigkeitsbereich nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "Standard- und gelöschte Funktionen nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "»inline« Namensräume nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "Überschreibsteuerung (override/final) nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "nicht-statische Initialisierungen für Datenelemente nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "benutzerdefinierte Literale nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "delegierende Konstruktoren nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "erbende Konstruktoren nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11-Attribute nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "ref-Qualifizierer sind nur mit »-std=c++11« oder »-std=gnu++11« verfügbar"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "unvollständiger Typ %qT in geschachtelter Namensangabe verwendet"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "Referenz auf %<%T::%D%> ist mehrdeutig"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD ist kein Element von %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ist kein Element von %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> wurde nicht deklariert"
@@ -43135,358 +43306,358 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(wenn das nicht beabsichtigt war, sollte sichergestellt werden, dass das Funktions-Template bereits deklariert wurde, und <> hier hinter Funktionsnamen eingefügt wurde) "
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "Wertinitialisierung des unvollständigen Typen %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "Feld mit unbekannter Grenze %qT kann nicht mit Werten initialisiert werden"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "Wertinitialisierung des Funktionstypen %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "Wertinitialisierung des Referenztypen %qT"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursive Instanziierung von Vorgabeinitialisierer für Element %qD"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "Vorgabeinitialisierer für Element %qD erforderlich vor dem Ende der umschließenden Klasse"
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, gcc-internal-format
 msgid "defined here"
 msgstr "hier definiert"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "Initialisierung eines flexiblen Arrayelements %q#D"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD sollte in Elementinitialisierungsliste initialisiert werden"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD wird mit sich selbst initialisiert"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ungültige Initialisierung für Arrayelement %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "nicht initialisiertes konstantes Element in %q#T"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D sollte initialisiert werden"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "nicht initialisiertes Referenzelement in %q#T"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD wird initialisiert nach"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Basis %qT wird initialisiert nach"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  Basis %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  während es hier initialisiert wurde"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "mehrere Initialisierungen für %qD angegeben"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "mehrere Initialisierungen für Basis %qT angegeben"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Initialisierungen für mehrere Elemente von %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "Basisklasse %q#T sollte explizit im Kopierkonstruktor initialisiert werden"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "Klasse %qT hat keinen Feldnamen %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D« ist ein statisches Datenelement; es kann nur bei seiner Definition initialisiert werden"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D ist kein Nicht-static-Datenelement von %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unbenannte Initialisierung für %qT, das keine Basisklassen hat"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unbenannte Initialisierung für %qT, das Mehrfachvererbung verwendet"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD ist sowohl eine direkte Basis als auch eine indirekte virtuelle Basis"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Typ %qT ist keine direkte oder virtuelle Basis von %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Typ %qT ist keine direkte Basis von %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ist kein Klassentyp"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "unvollständiger Typ %qT hat kein Element %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ungültiger Zeiger auf Bitfeld %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion %qD"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ungültige Verwendung des nicht-statischen Datenelementes %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Objekt vom Typ %<%T [%wu]%> und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Array vom Typ %qT und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Objekt vom Typ %qT und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Ganzzahlüberlauf in Arraygröße"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "Arraygröße in »new«-Ausdruck muss konstant sein"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "im »new«-Ausdruck ist kein variabel modifizierter Typ erlaubt"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr "nichtkonstante Länge für neues Array muss direkt angegeben werden, nicht über typedef"
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "Nichtkonstante Länge in Array-new muss ohne Klammern um die Typ-ID angegeben werden"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "ungültiger Typ %<void%> für %<new%>"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "nicht initialisierte Konstante in %<new%> von %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "Kein passendes %qD in Klasse %qT gefunden"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "Abfrage des Elementes %qD ist mehrdeutig"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> für Typ %qT mit erweiterter Ausrichtung %d"
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "verwendet %qD, das jedoch keinen Ausrichtungsparameter hat"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "verwenden Sie %<-faligned-new%>, um die C++17-Unterstützung für überausgerichtetes New einzuschalten"
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "geklammerte Initialisierung in Array-»new«"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "Größe des Arrays bei »new« muss Ganzzahltyp haben"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "»new« kann nicht auf Referenztyp angewendet werden"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "»new« kann nicht auf Funktionstyp angewendet werden"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "mögliches Problem bei Aufruf des »delete[]«-Operators erkannt"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische Operator »delete[]« wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "Initialisierung endet vorzeitig"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "unbekannte Arraygröße in »delete«"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "mögliches Problem bei Aufruf des »delete«-Operators erkannt"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische Operator »delete« wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "Löschen des Objekts mit abstraktem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt undefiniertes Verhalten"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "Löschen des Objekts mit polymorphem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt möglicherweise undefiniertes Verhalten"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "Typ für Vektor-»delete« ist weder Zeiger- noch Arraytyp"
@@ -43497,8 +43668,9 @@
 msgstr "Array mit Laufzeitgrenzen kann nicht durch Kopie eingefangen werden, sondern nur über eine Referenz"
 
 #: cp/lambda.c:557
-#, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+#, fuzzy, gcc-internal-format
+#| msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "Einfangen des Typs %qT variabler Größe, der nicht ein N3639-Array mit Laufzeitgrenzen ist"
 
 #: cp/lambda.c:561
@@ -43581,67 +43753,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(mit %<-fpermissive%> wird G++ den Code akzeptieren, aber die Verwendung eines nicht deklarierten Namens ist veraltet)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "defektes typeof, stattdessen decltype verwenden"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "__underlying_type wird vernichtet"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "unbekannter Festkommatyp wird vernichtet"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "Verwendung der eingebauten Eigenschaft %qE in Funktionssignatur; stattdessen sollten Bibliothekseigenschaften verwendet werden"
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "%C wird gemangelt"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "ausgelassener mittlerer Operand für Operator %<?:%> kann nicht verarbeitet werden"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "Zeichenkettenliteral in Signatur des Funktionstemplate"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "gemangelter Name für %qD wird sich ich C++17 ändern, da die Exceptionangabe Teil des Funktionstyps ist"
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "der gemangelte Name von %qD hat sich zwischen %<%s=%d%> (%qD) und %<%s=%d%> (%qD) geändert"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "der gemangelte Name von %qD ändert sich zwischen %<%s=%d%> (%qD) und %<%s=%d%> (%qD)"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "der gemangelte Name eines Thunks für %qD ändert sich zwischen »-fabi-version=%d« und »-fabi-version=%d«"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "der gemangelte Name von %qD ändert sich zwischen »-fabi-version=%d« und »-fabi-version=%d«"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "der gemangelte Name der Initialisierungswächter-Variable für %qD ändert sich zwischen »-fabi-version=%d« und »-fabi-version=%d«"
@@ -43760,42 +43932,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "vorgegebene Funktion %q+D mit Standardargument"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D steht mit vorheriger Deklaration in Konflikt"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D verdeckt Konstruktor für %q#D"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "in Konflikt stehende Deklaration %q#D mit Bindung für die Sprache \"C\""
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "durch andere Ausnahmespezifikationen"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "Deklaration von %q#D überdeckt einen Parameter"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "Deklaration von %qD überdeckt ein Element von %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "lokale externe Deklaration von %q#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "passt nicht zu vorheriger Deklaration %q#D"
@@ -43803,57 +43975,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "Friend-Deklaration %qD in lokaler Klasse ohne vorherige Deklaration"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr "injizierte befreundete %qD ist aufgrund von %<-ffriend-injection%> sichtbar"
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "Suche nach %qD hat sich geändert"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr "passt nach ISO-Standardregeln zu diesem %qD"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr "  passt nach den alten Regeln zu diesem %qD"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "Namenssuche von %qD hat sich für ISO-Regeln zum »for«-Gültigkeitsbereich geändert"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "veraltete Bindung %qD kann nicht verwendet werden, weil sie einen Destruktor hat"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr "bei %qD wird veraltete Bindung verwendet"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %<%s(%E)%> %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%qT ist weder Namensraum noch enum ohne eigenen Gültigkeitsbereich"
@@ -43860,12 +44032,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "eine %<using%>-Deklaration kann keine Template-ID angeben. Stattdessen %<using %D%> versuchen"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "namespace %qD in %<using%>-Deklaration nicht erlaubt"
@@ -43872,103 +44044,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT ist kein Namensbereich"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD wurde in diesem Gültigkeitsbereich bereits deklariert"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD nicht deklariert"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "»using«-Deklaration für Nicht-Element im Gültigkeitsbereich der Klasse"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> benennt Destruktor"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> benennt Konstruktor in %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "Konstruktoren können nicht von indirekter Basis %qT geerbt werden"
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "kein Element passt zu %<%T::%D%> in %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "Deklaration von %qD nicht in einem Namensbereich um %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explizite Qualifizierung in Deklaration von %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD wurde nicht innerhalb von %qD deklariert"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "sondern nur hier als %<friend%>"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD sollte innerhalb von %qD deklariert werden"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "Attribut %qD erfordert ein einzelnes NTBS-Argument"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "Attribut %qD ist bedeutungslos, da die Elemente des anonymen Namensraums lokale Symbole erhalten"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "Attribut %qD an unbenanntem Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "Attribut %qD an nicht-»inline«-Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "Attribut-Anweisung %qD wird ignoriert"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "obere Grenze von %d Namensräumen für %qE durchsucht"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -43975,78 +44147,86 @@
 msgstr[0] "empfohlene Alternative:"
 msgstr[1] "empfohlene Alternativen:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "empfohlene Alternative: %qs"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr "%<std::%s%> ist im Header %qs definiert; haben Sie vergessen, %<#include %s%> zu schreiben?"
 
-#: cp/name-lookup.c:5719
+# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79869
+#: cp/name-lookup.c:5711
+#, fuzzy, gcc-internal-format
+#| msgid "%s is not available for %s architecture"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "»%s« ist für die %s-Architektur nicht verfügbar"
+
+#: cp/name-lookup.c:5929
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "das Makro %qs war noch nicht definiert"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "es wurde später hier definiert"
 
-#: cp/name-lookup.c:6476
-#, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+#: cp/name-lookup.c:6687
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "Deklaration von std::initializer_list entspricht nicht #include <initializer_list>, ist kein Template"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "starke %<using%>-Direktive wird nicht mehr unterstützt"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "Sie können stattdessen einen %<inline%>-Namensraum verwenden"
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "Attribute werden an lokaler %<using%>-Direktive ignoriert"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "Namensbereich-Alias %qD ist hier nicht erlaubt, %qD angenommen"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "es können maximal %d Namensräume geschachtelt werden"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "ein %<inline%>-Namensraum muss bei der ersten Definition angegeben werden"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD hier definiert"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX Eintritt in pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX pop_everything () wird verlassen\n"
@@ -44066,7 +44246,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P is not set to true"
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> ist nicht direkt gefolgt von Funktionsdeklaration oder -definition"
@@ -44091,7 +44271,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "Abfrage des Elementes %qE in Nicht-Klassentyp %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> wurde nicht deklariert"
@@ -44171,7 +44351,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO-C++ verbietet Gleitkommaliterale in Konstanten-Ausdrücken"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "Eine Typumwandlung, die weder zu ganzzahligen noch Aufzählungstypen führt, kann nicht in einem Konstantenausdruck auftreten"
@@ -44393,7 +44573,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "literaler Operator für Zeichenketten %qD mit Argumenten %qT, %qT konnte nicht gefunden werden"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "Deklaration erwartet"
@@ -44473,7 +44653,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "Bereich %qT vor %<~%> ist kein Klassenname"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> ist nur mit -std=c++14 oder -std=gnu++14 verfügbar"
@@ -44488,862 +44668,853 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-Name %qD als Destruktor-Deklarator verwendet"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> in Spezifikation mit geschachteltem Namen gefunden, %<::%> erwartet"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype wird zu %qT ausgewertet, was keine Klasse oder Aufzählungstyp ist"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "Bezeichner %qD für Funktionstemplate ist geschachteltem Namens-Spezifizierer"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "Bezeichner %qD für Variablentemplate ist geschachteltem Namens-Spezifizierer"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ist kein Template"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "Spezifikation mit geschachteltem Namen erwartet"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Typen dürfen nicht in Typumwandlungen definiert werden"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO-C++ verbietet zusammengesetzte Literale"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "zwei aufeinander folgende %<[%> dürfen nur ein Attribut einführen"
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ungültige Verwendung von %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> ist kein Klassenelement"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "nicht-skalarer Typ"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO-C++ erlaubt kein %<alignof%> mit einem Nicht-Typ"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "Typen dürfen nicht in %<noexcept%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "Typen dürfen nicht in einem »new«-Ausdruck definiert werden"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "Arraygrenze hinter geklammerter type-id ist verboten"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "Klammern um die Type-ID sollten entfernt werden"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "Initialisierung des new-Ausdrucks für Typ %<auto%> erfordert genau ein Element"
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "»expression-list« oder »type-id« erwartet"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "Typen dürfen nicht in einem »new-type-id« definiert werden"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "Ausdruck in new-Deklarator muss Ganzzahl- oder Aufzählungstyp haben"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "Verwendung einer Typumwandlung nach %q#T im alten Stil"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "Operator %<>>%> wird in C++11 wie zwei spitze schließende Klammern behandelt"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "Klammern um %<>>%>-Ausdruck empfohlen"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO-C++ erlaubt nicht ?: mit ausgelassenem mittleren Operanden"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in conditions"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "Typen dürfen nicht in Bedingungen definiert werden"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "Lambda-Ausdruck in ungeprüftem Kontext"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "Lambda-Ausdruck in Templateargument"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "unerwartetes Ende der Auffangliste"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %<this%> ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "%<*this%>-Capture ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "Initialisierungen für Lambda-Captures sind nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "nicht-leere Initialisierung »init-capture« eines Lambdas"
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "Erfassung von Nicht-Variable %qE"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D hier deklariert"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "Erfassung der Variable %qD ohne automatische Speicherdauer"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %qD ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "Explizite Erfassung (als Referenz) von %qD ist mit Standarderfassung (als Referenz) gedoppelt"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "Lambda-Templates sind nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "Lambda-Templates sind nur mit -std=c++2a oder -std=gnu++2a verfügbar"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Standardargument für Lambda-Parameter angegeben"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "doppeltes %<mutable%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "%<constexpr%>-Lambda ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "Attribute am Anfang der Anweisung werden ignoriert"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "benannte Anweisung erwartet"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-Marke %qE nicht innerhalb einer switch-Anweisung"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> vor %qE erforderlich, da %qT ein abhängiger Gültigkeitsbereich ist"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> benennt Konstruktor, nicht den Typ"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "zusammengesetzte Anweisung in %<constexpr%>-Funktion"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "%<if constexpr%> ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "»init-statement in Auswahlanweisungen« ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "Typen dürfen nicht in Bedingungen definiert werden"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat unvollständigen Typ"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat %<end%>-Element, aber kein %<begin%>"
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat %<begin%>-Element, aber kein %<end%>"
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "Bereichsbasierte %<for%>-Schleifen sind nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> in %<constexpr%>-Funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "zusätzliches %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> nicht am Anfang eines Blocks"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "Nicht-Variable %qD in Deklaration mit mehr als einem Deklarator mit Platzhaltertyp"
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für %qT: %qT und dann %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "Vermischung von Deklarationen und Funktionsdefinitionen ist verboten"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "in einer for-Bereichs-Deklaration dürfen keine Typen definiert werden"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "Initialisierung in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "mehrere Deklarationen in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "strukturierte Bindungen sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "leere Deklaration für strukturierte Bindung"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ungültige Initialisierung für strukturierte Bindungsdeklaration"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> außerhalb einer Klasse verwendet"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "Bedeutung von %<auto%> ändert in C++11 die Bedeutung; Bitte entfernen"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-Spezifizierung in Bedingung ungültig"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD ungültig in Lambda"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "Klassendefinition darf nicht als »friend« deklariert sein"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ungültige Bindungsspezifikation"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "static_assert ohne Text ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "Typen dürfen nicht in %<decltype%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "Typen dürfen nicht in einem »conversion-type-id« definiert werden"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ungültige Verwendung von %<auto%> in Umwandlungsoperator"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "Verwendung von %<auto%> in Umwandlungsoperator von Elementtemplate kann niemals hergeleitet werden"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "Initialisierung für Element %qD kann nicht expandiert werden"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "veraltete Basisklasseninitialisierung"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> in diesem Kontext nicht erlaubt (eine qualifizierte Elementinitialisierung ist implizit ein Typ)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "unerwartetes Schlüsselwort; entfernen Sie Leerzeichen zwischen Anführungszeichen und Suffixbezeichner"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "Suffixbezeichner erwartet"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "hinter Schlüsselwort %<operator%> wird leere Zeichenkette erwartet"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ungültiges Encoding-Präfix in Literal-Operator"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "Operator erwartet"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Schlüsselwort %<export%> nicht implementiert, und wird ignoriert"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ungültiger beschränkter Typparameter"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualifizierter Typparameter"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "variadische Einschränkung ohne %<...%> eingeführt"
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ungültige Verwendung von %<auto%> in Default-Templateargument"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Templateparameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "Template-Parameterpacks können keine Standardargumente haben"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "Template-ID erwartet"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kann keine Templateargumentliste einleiten"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ist eine andere Schreibweise für %<[%>. Leerraum zwischen %<<%> und %<::%> einfügen"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(bei Verwendung von %<-fpermissive%>, %<-std=c++11%> oder %<-std=gnu++11%> wird G++ den Code akzeptieren)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "Syntaxfehler in Templateargumentliste"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "Templatename erwartet"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "Nicht-Template %qD als Template verwendet"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "%<%T::template %D%> verwenden, um dies als Template zu kennzeichnen"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "Parameterbündel vor %<...%> erwartet"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "Templateargument erwartet"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ungültiges Templateargument ohne Typ"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "explizite Instanziierung darf kein %<inline%> verwenden"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "explizite Instanziierung darf kein %<constexpr%> verwenden"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "Templatespezialisierung mit C-Bindung angegeben"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Typspezifizierer erwartet"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Verwendung von %<auto%> in Lambda-Parameterdeklaration benötigt -std=c++14 oder -std=gnu++14"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration benötigt -std=c++14 oder -std=gnu++14"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration benötigt -fconcepts"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "Template-ID für Typ erwartet"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "Typ-Name erwartet"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "ausführliche Typ-Spezifikation für einen enum mit Gültigkeitsbereich darf nicht das Schlüsselwort %qD verwenden"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "Deklaration %qD deklariert nichts"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "Attribute an instanziiertem Typen ignoriert"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "Attribute an Templateinstanziierung ignoriert"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "Attribute an Spezifizierer ausführlichen Typs ignoriert, der keine Vorwärtsdeklaration ist"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ist ein Aufzählungstemplate"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD benennt keinen Aufzählungstyp in %qT"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "unbenanntes »enum« mit Gültigkeitsbereich ist nicht erlaubt"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> oder %<{%> erwartet"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aufzählungsliste kann nicht zu Template-Instanziierung hinzugefügt werden"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "geschachtelter Namensgeber %qT für enum-Deklaration benennt weder Klasse noch Namensraum"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in Namensraum %qD, der nicht %qD einschließt"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in %qD, das nicht %qD einschließt"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "zusätzliche Qualifizierung nicht erlaubt"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO-C++ verbietet leere unbenannte Aufzählung"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "intransparente Enum-Spezifikation ohne Namen"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "intransparente Enum-Spezifikation muss einfachen Bezeichner verwenden"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ist kein Namensbereichs-Name"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "Namensraumname erwartet"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "verschachtelte Namensraumdefinitionen sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "Name eines geschachtelten Namensraums erwartet"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "Name eines Namensraums erwartet"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "eine verschachtelte Namensraum-Definition darf keine Attribute haben"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "eine verschachtelte Namensraumdefinition darf nicht inline sein"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "Namensbereich %qD betreten"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-Definition ist hier nicht erlaubt"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "Pack-Expansion in using-Deklaration ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "eine Template-ID darf nicht in »using«-Deklaration auftreten"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "kommagetrennte Liste in using-Deklaration ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "Zugriffsdeklarationen sind zugunsten von %<using%>-Deklarationen veraltet; Vorschlag: %<using%> hinzufügen"
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "Typen dürfen nicht in Alias-Templatedeklarationen definiert werden"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> in %<constexpr%>-Funktion"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "eine Funktionsdefinition ist hier nicht erlaubt"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "asm-Spezifikation ist bei Funktionsdefinition nicht erlaubt"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Konstruktor, Destruktor oder Typumwandlung erwartet"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "Initialisierung erwartet"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Initialisierung für Funktion bereitgestellt"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "Attribute hinter geklammerter Initialisierung werden ignoriert"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Nicht-Funktion %qD als implizites Template deklariert"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "Arraygrenze ist keine Ganzzahlkonstante"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "Element des abhängigen Typedef %qT kann nicht definiert werden"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ist kein Typ"
@@ -45352,17 +45523,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ungültiger Deklarator"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ungültige Verwendung des Konstruktors als Template"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "%<%T::%D%> statt %<%T::%D%> verwenden, um den Konstruktor mit qualifiziertem Namen zu benennen"
@@ -45369,382 +45540,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id in Deklaration"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "Deklarator erwartet"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD ist ein Namensbereich"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "Zeiger auf Element der Nicht-Klasse %q#T kann nicht erzeugt werden"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Ptr-Operator erwartet"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "mehrere ref-qualifier"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE benötigt %<-fgnu-tm%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "doppelter Virt-Spezifizierer"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "fehlende Templateargumente nach %qT"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ungültige Verwendung von %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "in Template-Argumenten dürfen keine Typen definiert werden"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ungültige Verwendung von %<auto%> in Templateargument"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Typspezifikation erwartet"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> oder %<...%> erwartet"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "Typen dürfen nicht in Parametertypen definiert werden"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "Standardargumente sind nur für Funktionsparameter zugelassen"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Parameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "Templateparameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Parameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "erweiterte Initialisierungsliste ist nur mit -std=c++2a oder -std=gnu++2a verfügbar"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen (GNU)"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen von C99"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "entweder sollten alle Initialisierer-Klauseln benannt sein oder gar keine"
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> ist in benannten Initialisierungen nicht erlaubt"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "%<.%s%>-Name wird mehrfach in derselben Initialisierungsliste verwendet"
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "Klassenname erwartet"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> hinter Klassendefinition erwartet"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> hinter Strukturdefinition erwartet"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> hinter Uniondefinition erwartet"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> oder %<:%> erwartet"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "für eine Klasse kann kein %<override%> angegeben werden"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globale Qualifizierung von Klassenname ist ungültig"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "qualifizierter Name benennt keine Klasse"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "Schlüsselwort %<template%> nicht innerhalb des Klassenkopfnamens erlaubt"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ungültiger Klassenname in Deklaration von %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "einer expliziten Spezialisierung muss %<template <>%> vorausgehen"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Funktions-Template %qD als Klassentemplate redeklariert"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "Typnamen-Typ kann nicht aufgelöst werden"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "vorherige Definition von %q#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr "ISO-C++ verbietet Typname-Schlüssel in Template-Template-Parameter; verwenden Sie -std=c++17 oder -std=gnu++17"
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> oder %<typename%> erwartet"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "in C++03 muss bei Deklaration eines »friend« ein Klassenschlüssel verwendet werden"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "»friend«-Deklaration benennt keine Klasse oder Funktion"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "Speicherklasse an anonymem Aggregat im Klassenbereich ist nicht erlaubt"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "Defaultinitialisierer für Bitfeld-Elemente sind nur mit -std=c++2a oder -std=gnu++2a verfügbar"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "Defaultinitialisierer für unbenanntes Bitfeld-Element"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ erlaubt Bitfeld-Attribute nur vor dem %<:%>-Token"
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "reiner Spezifizierer bei Funktionsdefinition"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "zusätzliches %<;%> hinter Funktionsdefinition innerhalb einer Klasse"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "überflüssiges %<,%> am Ende der Elementdeklaration"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> am Ende von Elementdeklaration erwartet"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ungültige reine Spezifikation (nur %<= 0%> ist erlaubt)"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "eine geschweift geklammerte Initialisierung ist hier nicht erlaubt"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> mehr als einmal in Basisspezifikation angegeben"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mehr als ein Zugriff in Basisspezifikation angegeben"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "Schlüsselwort %<typename%> nicht außerhalb von Templates erlaubt"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> nicht erlaubt in diesem Kontext (die Basisklasse ist implizit ein Typ)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "Typen dürfen nicht in einer Ausnahmespezifikation definiert werden"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 erlaubt keine dynamischen Ausnahmespezifikationen"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamische Ausnahmespezifikationen sind in C++11 veraltet"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ungültige Verwendung von %<auto%> in Ausnahmespezifikation"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> in %<constexpr%>-Funktion"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "Typen dürfen nicht in Ausnahmedeklarationen definiert werden"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Attribut, das Präfix verwendet, wird zusammen mit Gültigkeitsbereich-Attribut-Token verwendet"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "Bezeichner für den Attributnamen erwartet"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "Attribut %<noreturn%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "Attribut %<deprecated%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Attribut vor %<...%> erwartet"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "Attribut mit Präfix ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> ist nur mit -fconcepts verfügbar"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "ein requires-Ausdruck darf nicht außerhalb eines Templates auftreten"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -45753,518 +45924,518 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Nicht-Typ Templateargumentpack <char…> oder <typename CharT, CharT…> erwartet"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Template für Nicht-Typ Argumentpack <char...> erwartet"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "leere introduction-list"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "kein passendes Konzept für template-introduction"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "eine Klassen-Templatedeklaration darf nichts anderes deklarieren"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++-Nachrichtenempfänger erwartet"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ungültiger reduction-identifier"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "zu wenige for-Schleifen um sie einzuklappen"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierungsklausel"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "»id-expression (arguments)« erwartet"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "eins der Aufrufargumente für die Initialisierung sollte %<omp_priv%> oder %<&omp_priv%> sein"
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "vordeklarierter arithmetischer Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "Referenztyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- oder __restrict-qualifizierter Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> benennt eine Menge von Überladungen"
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bezeichnet keine Funktion innerhalb eines Namensraum"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "Ausschuss am Ende von %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Optimierungen zwischen Modulen noch nicht implementiert für C++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Implizite Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-Bindung beginnt hier"
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "Datenelement %qD kann kein Elementtemplate sein"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ungültige Elementtemplatedeklaration %qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explizite Spezialisierung in Gültigkeitsbereich des Nicht-Namensbereiches %qD"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "einschließende Klassentemplates werden nicht explizit spezialisiert"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "Spezialisierung von %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "Spezialisierung von %qD in anderem Namensbereich"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "  aus Definition von %q#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explizite Instanziierung von %qD in Namensbereich %qD (das nicht Namensbereich %qD einschließt)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "Name der Klasse verdeckt Template-Templateparameter %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "Spezialisierung des Alias-Template %qD"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explizite Spezialisierung des Nicht-Templates %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "Spezialisierung von %qT hinter Instanziierung"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "%q#T wird in anderem Namensbereich spezialisiert"
@@ -46271,88 +46442,88 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "Spezialisierung %qT hinter Instanziierung %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "Templatespezialisierung von %qD durch ISO C++ nicht erlaubt"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "Spezialisierung von %qD nach Instanziierung"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ist kein Funktionstemplate"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD ist kein variadisches Template"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "Template-ID %qD für %q+D passt zu keiner Templatedeklaration"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "%d %<template<>%> gefunden, %d werden für Spezialisierung eines Elementfunktionstemplates benötigt"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "mehrdeutige Templatespezialisierung %qD für %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "variadische Templates nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "zu viele Templateheader für %qD (sollten %d sein)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "Elemente einer explizit spezialisierten Klasse sind ohne Templateheader definiert"
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explizite Spezialisierung von %qD außerhalb seines Namensraums muss einen nested-name-specifier verwenden"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explizite Instanziierung von %qD außerhalb seines Namensraums muss einen nested-name-specifier verwenden"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "der expliziten Spezialisierung %q#D fehlen möglicherweise Attribute"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "fehlende primäre Templateattribute %s"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "fehlendes primäres Templateattribut %s"
@@ -46359,57 +46530,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "Template-ID %qD in Deklaration des ersten Templates"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "Templateparameterliste in expliziter Instanziierung verwendet"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "Definition für explizite Instanziierung angegeben"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "zu viele Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "zu wenige Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "der expliziten Spezialisierung von %D muss %<template <>%> vorausgehen"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "explizite Spezialisierung als %<concept%> deklariert"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "Nichttyp-Teilspezialisierung %qD ist nicht erlaubt"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "Teilspezialisierung %qD, die weder »class« noch »variable« ist, ist nicht erlaubt"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "Standardargument in expliziter Spezialisierung angegeben"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ist keine Templatefunktion"
@@ -46422,137 +46593,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "Spezialisierung der implizit deklarierten speziellen Elementfunktion"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "keine Elementfunktion %qD in %qT deklariert"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "»friend«-Deklaration %qD ist für explizite Spezialisierung nicht sichtbar"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%<friend%>-Deklaration hier"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "explizite Spezialisierung des Funktionskonzepts %qD"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Argument von __integer_pack muss zwischen 0 und %d liegen"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "Expansion der Basisinitialisierung %qT enthält keine Parameterpacks"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "Expansionsmuster %qT enthält keine Argumentpacks"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "Expansionsmuster %qE enthält keine Argumentpacks"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "Parameterbündel nicht mit %<...%> aufgelöst:"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonym>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "Deklaration des Templateparameters %q+D überdeckt einen Templateparameter"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "Deklaration von %q+#D überdeckt einen Templateparameter"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "Templateparameter %qD hier deklariert"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "Spezialisierung des Variablenkonzepts %q#D"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "Templateparameter nicht in partieller Spezialisierung herleitbar:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente und ist nicht eingeschränkter als das primäre Template; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "ursprüngliches Template hier"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partielle Spezialisierung ist nicht näher spezialisiert als das ursprüngliche Template, da es mehrere Parameter mit einer »pack«-Erweiterung ersetzt"
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "Teilspezialisierung %qD ist nicht spezialisierter als"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "primäres Template %qD"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "Argument %qE für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "Argument %qT für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "Templateargument %qE betrifft Templateparameter"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46559,17 +46730,17 @@
 msgstr[0] "Typ %qT des Templatearguments %qE hängt von Templateparameter ab"
 msgstr[1] "Typ %qT des Templatearguments %qE hängt von Templateparametern ab"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "Deklaration von %qD macht vorherige Template-Instanziierung für %qD mehrdeutig"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "teilweise Spezialisierung von %qD nach Instanziierung von %qD"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "kein Standard-Argument für %qD"
@@ -46577,47 +46748,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "Parameterpack %q+D muss am Ende der Templateparameterliste sein"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "Standardtemplateargumente dürfen in friend-Redeklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "Standardtemplateargumente dürfen in friend-Deklaration nicht verwendet werden"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "Standardtemplateargumente dürfen in Funktionstemplates nicht ohne -std=c++11 und -std=gnu++11 verwendet werden"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Standardtemplateargumente dürfen in teilweiser Spezialisierung nicht verwendet werden"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "Template %qD deklariert"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "Templateklasse ohne Namen"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
@@ -46627,57 +46798,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ungültige Templatedeklaration von %qD"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "Template-Definition eines Nicht-Templates %q#D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d Ebenen von Template-Parametern für %q#D erwartet, %d erhalten"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d Template-Parameter für %q#D erhalten"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d Template-Parameter für %q#T erhalten"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  aber %d benötigt"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "Template-Argumente für %qD passen nicht zum ursprünglichen Template %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "verwenden Sie %<template<>%> für eine explizite Spezialisierung"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ist kein Template-Typ"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "keine Templatespezifizierer in Deklaration von %qD angegeben"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46684,7 +46855,7 @@
 msgstr[0] "mit %d Template-Parameter redeklariert"
 msgstr[1] "mit %d Template-Parametern redeklariert"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46691,12 +46862,12 @@
 msgstr[0] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 msgstr[1] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "Template-Parameter %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "hier als %q#D redeklariert"
@@ -46705,117 +46876,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Redefinition des Standardarguments für %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprüngliche Definition trat hier auf"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "Redeklaration %q#D mit unterschiedlichen Constraints"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprüngliche Deklaration trat hier auf"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "es muss die Adresse einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "es muss der Name einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "es muss ein Zeiger auf ein Element der Form %<&X::Y%> sein"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "da es ein Element von %qT ist"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr " Template-Parameter %qD konnte nicht ermittelt werden"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr " Typen %qT und %qT haben unverträgliche CV-Qualifizierer"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr " unpassende Typen %qT und %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr " Templateparameter %qD ist kein Parameterpack wie Argument %qD"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr " Templateargumente %qE passt nicht zum konstanten Zeiger auf Element %qE"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr " %qE entspricht nicht %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr " unpassende Herleitung von Parameterpack mit %qT und %qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr " hergeleitete Typen für Parameter %qT stehen in Konflikt (%qT und %qT)"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr " hergeleitete Werte für Nicht-Typ-Parameter %qE stehen in Konflikt (%qE und %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr " Arraytyp %qT mit veränderlicher Größe ist kein gültiges Templateargument"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr " Typ %qT von Elementfunktion ist kein gültiges Templateargument"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46822,287 +46993,293 @@
 msgstr[0] "  Kandidat erwartet mindestens %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet mindestens %d Argumente, %d angegeben"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr " %qE (Typ %qT) kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr " %qT ist mehrdeutige Basisklasse von %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr " %qT ist nicht vom Typ %qT abgeleitet"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr " Templateparameter eines Template-Templatearguments sind mit anderen hergeleiteten Templateargumenten unverträglich"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr " für %qT kann kein Template aus Nicht-Templatetyp %qT hergeleitet werden"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr " Template-Argument %qE passt nicht zu %qE"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da Zeichenkettensymbole in diesem Zusammenhang nicht verwendet werden können"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "in Templateargument für Typ %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "Templateargument %qE für Typ %qT ist keine konstante Ganzzahl"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ist kein gültiges Templateargument für %qT, da es keine Adresse einer Variable ist"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qE keine Variable ist"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "die Adresse des %qT-Teilobjekts von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument, weil sie keine statische Lebensdauer hat"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein Objekt mit Bindung ist"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil Objekt %qD keine Bindung hat"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "Attribute an Templateargument %qE werden ignoriert"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Verwendung des Destruktors %qE als Typ"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "unpassende Beschränkungen für Argument %d in Template-Parameterliste für %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD erwartet, %qD erhalten"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "Templateargument %qE konnte nicht von %qT in %qT umgewandelt werden"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte mindestens %d sein)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "für %qD bereitgestellt"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Alias-Template %qD"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Konzept %qD"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "jegliche Instanziierung mit nichtleerer Parameterpackung wäre unzulässig"
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "Template-Einschränkung fehlgeschlagen"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Verwendung des ungültigen Variablentemplates %qE"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen)"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "flexibles Arrayelement in Union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "Falten einer leeren Expansion über %O"
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qT"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qE"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %qD"
@@ -47120,276 +47297,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Array zurück"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT wird in %qT aufgelöst, was kein Klassentyp ist"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
@@ -47401,106 +47578,112 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen) bei Instanziierung von %q+D, möglicherweise von Erzeugung der virtuellen Tabelle"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "Schlüsselwort %<template%> nicht innerhalb der declarator-id erlaubt"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert %<#include <initializer_list>%>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "Nicht-Klassen-Template %qT ohne Template-Argumente verwendet"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "Templateargumente für %qT können nicht abgeleitet werden, da es keine Ableitungshinweise gibt"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "invalid use of %<auto%> in template argument"
+msgid "invalid use of %qT in template argument"
+msgstr "ungültige Verwendung von %<auto%> in Templateargument"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -47703,7 +47886,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ungültiger angegebener Gültigkeitsbereich in Pseudodestruktor-Name"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "qualifizierter Typ %qT passt nicht zum Destruktornamen ~%qT"
@@ -47753,7 +47936,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
@@ -47825,294 +48008,296 @@
 msgstr "%qT ist kein Aufzählungstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpack __bases nur in Templatedeklaration gültig"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "%<offsetof%> kann nicht auf Destruktor %<~%T%> angewandt werden"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr "zweiter Operand von %<offsetof%> ist weder ein einzelner Bezeichner noch eine Folge von Elementzugriffen und Arrayreferenzen"
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
+
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<offsetof%> kann nicht auf Aufzähler %qD angewandt werden"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "offsetof innerhalb von »non-standard-layout«-Typ %qT ist undefiniert"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> ist in OpenMP nur innerhalb von %<declare simd%>-Klauseln erlaubt"
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "benutzerdefinierte Reduktionsauflösung ist mehrdeutig"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE hat konstanten Typ für %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "benutzerdefinierte Reduktion mit Konstruktorinitialisierung für Basisklasse %qT"
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "»linear«-Klausel mit Modifizierer %qs wird auf Nicht-Referenz-Variable mit Typ %qT angewandt"
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ganzzahlig noch Zeiger ist"
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "Ausdruck für »linear«-Schrittweite muss ganzzahlig sein"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD ist in Klausel %<firstprivate%> keine Variable"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD ist in Klausel %<lastprivate%> keine Variable"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "statischer %<gang%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "statischer %<gang%>-Ausdruck muss positiv sein"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "Ausdruck für %<gang%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "Ausdruck für %<vector%>-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "Ausdruck für %<worker%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "Wert von %<gang%> muss positiv sein"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "Wert der %<vector%>-Länge muss positiv sein"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "Wert der %<worker%>-Nummer muss positiv sein"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig, positiv und konstant sein"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-ID muss ganzzahlig sein"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Ausdruck für %<dist_schedule%>-Chunkgröße muss ganzzahlig sein"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD ist in %<aligned%>-Klausel keine Variable"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "Ausdruck für Ausrichtung der %<aligned%>-Klausel muss ganzzahlig sein"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD ist in %<depend%>-Klausel keine Variable"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "Template %qE in Klausel %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "überladener Funktionsname %qE in Klausel %qs"
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "Ausdruck für %<grainsize%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "Ausdruck für %<priority%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "Ausdruck für %<num_tasks%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Variable %qs ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Argument für %<tile%> erfordert ganzzahligen Typ"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist weder Datei-, Namens- noch Blockbereichsvariable"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> Direktive %qE nicht in Definition von %qT"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> zusammen mit Iterationsvariable %qE verwendet"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statische Behauptung gescheitert"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statische Erklärung gescheitert: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Argument für decltype muss ein Ausdruck sein"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
@@ -48237,12 +48422,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "Attribut %qE wird auf »extern \"C\"«-Deklaration %qD angewendet"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "Null als Nullzeigerkonstante"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: failed in %s, at %s:%d"
@@ -48302,727 +48487,723 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "selber kanonischer Typknoten für die unterschiedlichen Typen %qT und %qT"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ungültige Anwendung von %qs auf Elementfunktion"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ungültige Anwendung von %<sizeof%> auf ein Bitfeld"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<sizeof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ungültige Anwendung von %<__alignof%> auf ein Bitfeld"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<__alignof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "Argument für %<alignas%> hat nicht-ganzzahligen Typen %qT"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion vom Typ %qT"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "Adresse eines temporären Wertes wird verwendet"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbietet, eine Zeichenkettenkonstante in %qT zu konvertieren"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "veraltete Konvertierung von Zeichenkettenkonstante in %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "Anforderung des Elements %qD in %qE, das vom Zeigertyp %qT ist (vielleicht war %<->%> gemeint?)"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "Abfrage des Elementes %qD in %qE, das vom Nicht-Klassentyp %qT ist"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "ungültige Verwendung des nicht-statischen Datenelements %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ungültiger Zugriff auf nicht-statisches Datenelement %qD in virtueller Basis des NULL-Objektes"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "Objekttyp %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "der zerstörte Typ ist %qT, aber der Destruktor verweist auf %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "auf Feld %q#D kann mittels %q#D zugegriffen werden"
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ist kein Element von %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT ist keine Basis von %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %qE?"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T hat kein Element namens %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD ist keine Elementtemplatefunktion"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT ist kein Zeiger auf Objekt"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ungültige Verwendung von Arrayindizierung bei Zeiger auf Element"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ungültige Verwendung des unären %<*%> bei Zeiger auf Element"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ungültige Verwendung impliziter Umwandlung bei Zeiger auf Element"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "linker Operand von %<->*%> muss Zeiger auf Klasse sein, ist aber ein Zeiger auf Element des Typs %qT"
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "Index fehlt in Arrayreferenz"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "Indizierung eines als %<register%> deklarierten Arrays"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indizierter Wert ist weder ein Array noch ein Zeiger"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "bei Verwendung von %qE fehlt Objekt"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "Funktion %qD kann nicht aufgerufen werden"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO-C++ verbietet den Aufruf von %<::main%> vom Programm aus"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<.*%> oder %<->*%> muss verwendet werden, um Zeiger auf Element als Funktion in %<%E (...)%> aufzurufen, z.B. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Ausdruck kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "zu viele Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "zu wenige Argumente für Konstruktor %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "zu viele Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Zu wenige Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "zu viele Argumente für Funktion %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "zu wenige Argumente für Funktion %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "zu viele Argumente für Methode %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "zu wenige Argumente für Methode %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "zu viele Argumente für Funktion"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "zu wenige Argumente für Funktion"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "Parameter %P von %qD hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "Parameter %P hat unvollständigen Typen %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "Die Adresse von %qD wird nie NULL sein"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "der Compiler kann annehmen, dass die Adresse von %qD niemals NULL ist"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "Umwandlung in Typ %qT von überladener Funktion wird angenommen"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL in Arithmetik verwendet"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "linker Rotationszähler ist negativ"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "rechter Rotationszähler ist negativ"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "linker Rotationszähler >= Breite des Typs"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "rechter Rotationszähler >= Breite des Typs"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger und Ganzzahl"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Operandentypen sind %qT und %qT"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "ungeordneter Vergleich mit Nicht-Gleitkomma-Argument"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qH in %qI zur Anpassung an anderen Operanden des Binärausdrucks"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ungültige Operanden der Typen %qT und %qT für binäres %qO"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers des Typs %<void *%> in Subtraktion"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf eine Funktion in Subtraktion"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf Methode in Subtraktion"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ungültige Verwendung eines Zeigers auf einen unvollständigen Typen in Zeigerarithmetik"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "Adresse des Konstruktors %qD wird genommen"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "Adresse des Destruktors %qD wird genommen"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ungültige Verwendung von %qE um Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  eine qualifizierte ID ist erforderlich"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "Klammern um %qE können nicht verwendet werden, einen Zeiger auf Elementfunktion zu erzeugen"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer nicht qualifizierten oder geklammerten nicht-statischen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer gebundenen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "Adresse eines temporären Wertes wird ermittelt"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "Adresse eines X-Wertes (R-Wert-Referenz) wird genommen"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse der Funktion %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "Zeiger auf Referenzelement %qD kann nicht erzeugt werden"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "Versuch, die Adresse eines Bitfelds zu bestimmen"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr "%<~%> auf einem Ausdruck vom Typ »bool«"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "meinten Sie ein logisches Nicht (%<!%>)?"
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO-C++ verbietet erhöhen einer Aufzählung"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO-C++ verbietet verringern einer Aufzählung"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht erhöht werden"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht verringert werden"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Erhöhen eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Verringern eines Zeigers vom Typ %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator--%> ist verboten"
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist in C++17 verboten"
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist veraltet"
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "Adresse von %<this%> kann nicht ermittelt werden, das ein R-Wert-Ausdruck ist"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "Adresse für %qD angefordert, was als %<register%> deklariert ist"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "Listeninitialisierung für Nicht-Klassentyp darf nicht geklammert sein"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Initialisierung behandelt"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Speicherinitialisierung behandelt"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in funktionaler Umwandlung behandelt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80191
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Ausdrucksliste für »%s« wird als zusammengesetzten Ausdruck behandelt"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "kein Kontext, um Typ von %qE aufzulösen"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "Umwandlung des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "nutzlose Umwandlung in Typ %q#T"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "Typkennzeichner an Umwandlungs-Rückgabetyp ignoriert"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "ungültiges static_cast vom Typ %qT in den Typ %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 msgid "converting from %qH to %qI"
 msgstr "Umwandlung von %qH nach %qI"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "ungültige Typumwandlung eines R-Wert-Ausdrucks des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr "Typumwandlung von %qH nach %qI verliert Genauigkeit"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Funktionstypen von %qH nach %qI"
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Elementzeigertypen von %qH nach %qI"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "Umwandlung von %qH in %qI erhöht erforderliche Ausrichtung des Zieltyps"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "Umwandlung zwischen Zeiger auf Funktion und Zeiger auf Objekt ist bedingt unterstützt"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ungültige Umwandlung von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ungültige Verwendung von const_cast mit Typ %qT, das weder Zeiger, Referenz, noch vom Typ eines Zeigers auf Datenelement ist"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "ungültige Verwendung von const_cast mit Typ %qT, das ein Zeiger oder Referenz auf Funktionstyp ist"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "ungültiges const_cast eines R-Wertes des Typs %qT in Typ %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "ungültiges const_cast von Typ %qT in Typ %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO-C++ verbietet Umwandlung in Arraytyp %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ungültige Umwandlung in Funktionstyp %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  in Auswertung von %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "Zuweisung an Array von Initialisierungsliste"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "unverträgliche Typen in Zuweisung von %qT an %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "Array als Initialisierung verwendet"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Ungültige Arrayzuweisung"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   in Umwandlung in Zeiger auf Elementfunktion"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Umwandlung in Zeiger auf Element über virtuelle Basis %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   in Umwandlung in Zeiger auf Element"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ungültige Umwandlung in Typ %qT von Typ %qT"
 
-#: cp/typeck.c:8786
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "%qH kann nicht nach %qI für Argument %qP nach %qD umgewandelt werden"
+#: cp/typeck.c:8812 cp/typeck.c:8829
+msgid "cannot convert %qH to %qI"
+msgstr "%qH kann nicht nach %qI umgewandelt werden"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qH kann nicht nach %qI im Standardargument umgewandelt werden"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qH kann nicht nach %qI bei Argumentübergabe umgewandelt werden"
 
-#: cp/typeck.c:8800
-msgid "cannot convert %qH to %qI"
-msgstr "%qH kann nicht nach %qI umgewandelt werden"
-
-#: cp/typeck.c:8804
+#: cp/typeck.c:8833
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qH kann nicht nach %qI in Initialisierung umgewandelt werden"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qH kann nicht nach %qI in Rückgabe umgewandelt werden"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qH kann nicht nach %qI in Zuweisung umgewandelt werden"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "Klassentyp %qT ist unvollständig"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Parameter %qP von %qD könnte Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "Parameter könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Ziel der Umwandlung könnte Kandidat ein für ein Formatattribut sein"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Ziel der Initialisierung könnte ein Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "linke Seite der Zuweisung könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "bei Übergabe des Arguments %P von %qD"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "Referenz auf temporären Wert wird zurückgegeben"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "Referenz auf Nicht-L-Wert zurückgegeben"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "Referenz auf lokale Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "Wert von Destruktor zurückgegeben"
@@ -49029,55 +49210,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "vom Behandler eines Funktions-try-Blocks eines Konstruktors kann nicht zurückgekehrt werden"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "Rückgabe eines Wertes von einem Konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "Return-Anweisung ohne Wert, in %qT zurückgebender Funktion"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "Initialisierungsliste wird zurückgegeben"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "widersprüchliche Typen %qT und %qT für Lambda-Rückgabetypen hergeleitet"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für automatischen Rückgabetyp: %qT und dann %qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "Return-Anweisung mit Wert, in Funktion mit Rückgabetyp %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> darf nicht NULL zurückgeben, außer es ist mit %<throw()%> deklariert (oder -fcheck-new ist eingeschaltet)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "temporärer Wert wird als L-Wert verwendet"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "X-Wert (R-Wert-Referenz) wird als L-Wert verwendet"
@@ -49298,140 +49479,140 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "Konstruktorsyntax verwendet, aber kein Konstruktor für Typ %qT deklariert"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "verengende Umwandlung von %qE von %qH nach %qI innerhalb von { } ist in C++11 ungültig"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "verengende Umwandlung von %qE von %qH nach %qI innerhalb von { }"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " der Ausdruck hat einen konstanten Wert, ist aber kein konstanter Ausdruck im Sinne von C++"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-Array mit Nicht-wide-Zeichenkette initialisiert"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "Ganzzahlarray mit unverträglicher wide-Zeichenkette initialisiert"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "Initialisierungs-Zeichenkette für char-Array ist zu lang"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD mit nicht initialisierten Feldern"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "Designator-Reihenfolge für Feld %qD passt nicht zur ursprünglichen Deklaration in %qT"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen rvalue"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen lvalue"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht vor C++2a einen lvalue"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Arraytyp %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "Templateargumente für %qT von () können nicht hergeleitet werden"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -49869,29 +50050,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr "Wert für Feldkonstruktor bei %L darf nicht unbegrenzt polymorph sein [F2008: C4106]"
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Unterschiedliche CHARACTER-Längen (%ld, %ld) in Feldkonstruktor bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr "spec_dimen_size(): Bad dimension"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr "gfc_ref_dimen_size(): Bad dimension"
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Ungültige Felddimension bei %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
@@ -49898,25 +50079,25 @@
 msgstr "Interner Fehler: Simplification error"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr "Interner Fehler: gfc_ref_dimen_size(): Bad dimen_type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr "Interner Fehler: gfc_array_dimen_size(): Bad dimension"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr "Interner Fehler: gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr "Interner Fehler: gfc_find_array_ref(): No ref found"
@@ -50914,7 +51095,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Höchste Erweiterungsstufe mit Typ %qs bei %L erreicht"
@@ -51085,7 +51266,7 @@
 msgid "deferred type parameter at %C"
 msgstr "Parameter mit zurückgestelltem Typ bei %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalarer INTEGER-Ausdruck bei %L erwartet"
@@ -51335,451 +51516,451 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Feld mit expliziter Form, aber nichtkonstanten Grenzen bei %C"
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs bei %C ist eine Redefinition der Deklaration in der entsprechenden Schnittstelle für MODUL PROCEDURE %qs"
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Entität %qs bei %C kann keine Initialisierung haben"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Doppelte Feldspezifikation für Cray-Zeigerende bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Couldn't set pointee array spec."
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisierung im alten Stil bei %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Ungültige Initialisierung im alten Stil für abgeleitete Typkomponente bei %C"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Syntaxfehler in Initialisierung im alten Stil von %s bei %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisierung bei %C ist nicht für eine Zeigervariable"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Zeigerinitialisierung bei %C benötigt %<=>%>, nicht %<=%>"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung einer Variablen bei %C ist in einer PURE-Prozedur nicht erlaubt"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initialisierung einer allozierbaren Komponente bei %C ist nicht erlaubt"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Die Komponente bei %C mit KIND- oder LEN-Attribut erscheint nicht in der Typparameterliste bei %L"
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Die Komponente bei %C, die in der Typparameterliste bei %L erscheint, hat weder KIND- noch LEN-Attribut"
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Die Komponente bei %C, die ein Typparameter ist, muss ein Skalar sein"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Deklaration %s*%d im alten Stil wird bei %C nicht unterstützt"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nicht-Standard Typ-Deklaration %s*%d bei %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Fehlende rechte Klammer bei %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Skalaren Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Die Art %d wird für Typ %s bei %C nicht unterstützt"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Typ-Parameter nach C-Art ist für Typ %s, aber Typ bei %L ist %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Fehlende rechte Klammer oder Komma bei %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Die Art %d wird für CHARACTER bei %C nicht unterstützt"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfehler in CHARACTER-Deklaration bei %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr "RECORD bei %C ist eine Erweiterung, muss mit »-fdec-structure« eingeschaltet werden"
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Strukturname nach RECORD bei %C erwartet"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "Die Typparameter-Angabenliste bei %C kann nicht gleichzeitig ASSUMED- und DEFERRED-Parameter enthalten"
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Die Typparameter-Angabenliste bei %C enthält nicht genug Parameterausdrücke"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Der abgeleitete Parameter %qs bei %C hat keinen Vorgabewert"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Der Parameterausdruck bei %C muss vom Typ INTEGER sein, nicht %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "Der KIND-Parameter %qs bei %C darf weder ASSUMED noch DEFERRED sein"
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Der Wert für den KIND-Parameter %qs bei %C lässt sich nicht auf einen konstanten Ausdruck reduzieren"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "Die Typparameter-Angabenliste bei %C enthält zu viele Parameterausdrücke"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Der parametrisierte abgeleitete Typ bei %C ist mehrdeutig"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-Typ bei %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Bei %C verwendeter BYTE-Typ ist auf der Zielmaschine nicht verfügbar"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Vermuteter Typ bei %C ist für Komponenten nicht erlaubt"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Vermuteter Typ bei %C"
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE mit intrinsischer Typspezifikation bei %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX bei %C"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typname %qs bei %C ist mehrdeutig"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-Anweisung bei %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typname %qs bei %C in Konflikt mit vorher deklarierter Entität bei %L, die den gleichen Namen hat"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Doppelte IMPLICIT NONE-Anweisung bei %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE mit Angabenliste bei %C"
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Fehlender Zeichenbereich in IMPLICIT bei %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Buchstaben in IMPLICIT-Anweisung bei %C müssen in alphabetischer Reihenfolge sein"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-Anweisung bei %C folgt auf IMPLICIT NONE (Typ-)Anweisung"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Leere IMPLICIT-Anweisung bei %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-Anweisung bei %C ist nur in einem INTERFACE-Körper erlaubt"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT-Anweisung bei %C ist im Körper einer Schnittstelle für Modulprozedur nicht erlaubt"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste benannter Einträge bei %C erwartet"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "IMPORT %qs aus Host-Sichtbarkeitseinheit bei %C nicht möglich - existiert nicht."
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs bereits aus Host-Sichtbarkeitseinheit bei %C IMPORTiert"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfehler in IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Fehlende Kodimensionsangabe bei %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Fehlende Dimensionsangabe bei %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Doppeltes Attribut %s bei %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s bei %L ist eine DEC-Erweiterung, muss mit %<-fdec-static%> eingeschaltet werden"
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "KIND-Attribut bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Komponente mit KIND-Attribut bei %C muss ein INTEGER sein"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Komponente mit KIND-Attribut bei %C muss per Default Ganzzahlart (%d) sein"
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "LEN-Attribut bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponente mit LEN-Attribut bei %C muss INTEGER sein"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Komponente mit LEN-Attribut bei %C muss per Default Ganzzahlart (%d) sein"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut bei %L ist in TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s bei %L in einer TYPE-Definition"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Attribut %s bei %L ist außerhalb des Spezifikationsabschnitts eines Moduls nicht erlaubt"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribut bei %L ist außerhalb einer TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "ASYNCHRONOUS-Attribut bei %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "CONTIGUOUS-Attribut bei %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED bei %C nur in Spezifikationsabschnitts eines Moduls erlaubt"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "PROTECTED-Attribut bei %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "VALUE-Attribut bei %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "VOLATILE-Attribut bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Bad attribute"
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Mehrere Bezeichner mit einzelner Spezifikation NAME= bei %C angegeben"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implizit deklarierte BIND(C)-Funktion %qs bei %L ist möglicherweise nicht interoperabel mit C"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %L könnte inkompatibel mit C sein, obwohl gemeinsamer Block %qs BIND(C) ist"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs bei %L ist nicht C-kompatibel, aber sie ist BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variable %qs bei %L könnte mit C inkompatibel sein, aber sie ist BIND(C)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %L kann nicht mit BIND(C) deklariert werden, da sie nicht global ist"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute POINTER und BIND(C) haben"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute ALLOCATABLE und BIND(C) haben"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Rückgabetyp der BIND(C)-Funktion %qs bei %L kann kein Feld sein"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Rückgabetyp der BIND(C)-Funktion %qs bei %L kann keine Zeichenkette sein"
@@ -51786,953 +51967,953 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbol %qs bei %L ist als PRIVATE markiert, aber wurde mit Bindung %qs markiert"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Entweder Entität oder Name eines gemeinsamen Blocks für Attribut-Spezifikationsanweisung bei %C erforderlich"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entität oder Name eines gemeinsamen Blocks für Attribut-Spezifikationsanweisung bei %C fehlt"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Fehlendes Symbol"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-Anweisung bei %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Abgeleiteter Typ bei %C wurde vorher nicht definiert und kann daher nicht in einer abgeleiteten Typdefinition auftreten"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaxfehler in anonymer Struktur-Deklaration bei %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfehler in Daten-Deklaration bei %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE-Präfix bei %C"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-Prozedur bei %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE und IMPURE dürfen bei %C nicht gleichzeitig stehen"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Argument für Alternativrückgabe bei %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Bei %C wird ein Parametername erwartet"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Name %qs bei %C ist der Name der Prozedur"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Parameterliste in Typdeklaration bei %C erwartet"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Unerwartete Angaben in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Doppelter Name %qs in Parameterliste bei %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Doppeltes Symbol %qs in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Konflikt in formalen Argumentnamen (%s/%s) von MODULE PROCEDURE bei %C"
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Konflikt in Anzahl der formalen Argumente von MODULE PROCEDURE bei %C"
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-Variable bei %C muss vom Funktionsnamen verschieden sein"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Unerwartete Angaben hinter Funktionsdeklaration bei %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "BIND(C)-Attribut bei %L kann nicht für eine interne Prozedur angegeben werden"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C)-Attribut bei %C erfordert eine Schnittstelle mit BIND(C)"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-Prozedur mit NAME darf kein POINTER-Attribut bei %C haben"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Scheinprozedur bei %C kann kein BIND(C)-Attribut mit NAME haben"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Prozedur %qs bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfehler in PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> nach Bindeattributen bei %C erwartet"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS oder explizite Schnittstelle bei %C erforderlich"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfehler in Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE bei %C muss in einer allgemeinen Schnittstelle sein"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "»::« in MODULE PROCEDURE-Anweisung bei %L"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formale Argumentliste in Funktionsdefinition bei %C erwartet"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C)-Attribut bei %L kann nur für Variablen oder gemeinsame Blöcke verwendet werden"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines PROGRAMmes auftreten"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines MODULEs auftreten"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SUBMODULEs auftreten"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von BLOCK DATA auftreten"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines STRUCTURE-Blockes auftreten"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DERIVED TYPE Blockes auftreten"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines IF-THEN-Blockes auftreten"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DO-Blockes auftreten"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SELECT-Blockes auftreten"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines FORALL-Blockes auftreten"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines WHERE-Blockes auftreten"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines enthaltenen Subprogrammes auftreten"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Unerwartete ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-Anweisung bei %C kann nicht in einer enthaltenen Prozedur auftreten"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Erforderte Klammern vor BIND(C) bei %C fehlen"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ungültiger C-Name in NAME=-Spezifizierung bei %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfehler in NAME=-Spezifikation für Bindungsmarke bei %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Spezifikation NAME= bei %C sollte ein konstanter Ausdruck sein"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-Angabe bei %C sollte ein Skalar der Standardzeichenart sein"
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Schließende Klammer für Bindungsmarke bei %C fehlt"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "In BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "For Schein-Prozedur %s in BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME nicht erlaubt bei BIND(C) für ABSTRACT INTERFACE bei %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Unerwartete END-Anweisung bei %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-Anweisung statt %s-Anweisung bei %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "»%s«-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamen von %qs in »%s«-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Beendenden Namen bei %C erwartet"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Marke %qs für »%s«-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Fehlende Feldspezifikation bei %L in DIMENSION-Anweisung"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Für %s bei %L wurden Dimensionen nach dessen Initialisierung angegeben"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Feldspezifikation bei %L in CODIMENSION-Anweisung fehlt"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Feldspezifikation muss bei %L aufgeschoben werden"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Unerwartetes Zeichen in Variablenliste bei %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> bei %C erwartet"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variablennamen bei %C erwartet"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-Zeiger bei %C muss eine Ganzzahl sein"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-Zeiger bei %C hat %d Bytes Genauigkeit; Speicheradressen benötigen %d Bytes"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "»,« bei %C erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "Couldn't set Cray pointee array spec."
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "»)« bei %C erwartet"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> oder Ende der Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray-Zeiger-Deklaration bei %C benötigt den Schalter -fcray-pointer"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-Anweisung bei %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators %s bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators .%s. bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfehler in PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variablennamen bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Zeichen »=« in PARAMETER-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ausdruck bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisierung einer bereits initialisierten Variablen bei %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER ohne »()« bei %C"
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Unerwartete Zeichen in PARAMETER-Anweisung bei %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s bei %C ist eine DEC-Erweiterung, muss mit »-fdec-static« eingeschaltet werden"
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "In AUTOMATIC-Anweisung bei %C wird eine »entity-list« erwartet"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaxfehler in AUTOMATIC-Anweisung bei %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "»entity-list« in STATIC-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaxfehler in STATIC-Anweisung bei %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Umfassende SAVE-Anweisung bei %C folgt vorheriger SAVE-Anweisung"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-Anweisung bei %C folgt umfassender SAVE-Anweisung"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfehler in SAVE-Anweisung bei %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfehler in VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE für Coarray-Variable %qs bei %C angegeben, die use-/host-assoziiert ist"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfehler in VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfehler in ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE-PROCEDURE-Deklaration bei %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE bei %C muss in einer generischen Modulschnittstelle sein"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsische Prozedur bei %L kann keine MODULE PROCEDURE sein"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Mehrdeutiges Symbol in TYPE-Definition bei %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbol %qs bei %C wurde vorher noch nicht definiert"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs in EXTENDS-Ausdruck bei %C ist kein abgeleiteter Typ"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kann bei %C nicht erweitert werden, da es BIND(C) ist"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kann bei %C nicht erweitert werden, da es ein SEQUENCE-Typ ist"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PRIVATE im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PUBLIC im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT-Typ bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Failed to create structure type '%s' at %C"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Typdefinition von %qs bei %C wurde bereits bei %L definiert"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Ausschuss hinter MAP-Anweisung bei %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Ausschuss hinter UNION-Anweisung bei %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s bei %C ist eine DEC-Erweiterung, muss mit »-fdec-structure« eingeschaltet werden"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Strukturname erwartet in unverschachtelter Strukturdeklaration bei %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Ausschuss hinter unverschachtelter STRUCTURE-Anweisung bei %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Strukturname %qs bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "»::« in TYPE-Definition bei %C erwartet"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typname %qs bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Abgeleiteter Typname %qs bei %C hat bereits einen Basistypen von %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Abgeleitete Typdefinition von %qs bei %C wurde bereits definiert"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Syntaxfehler hinter PARAMETERIZED-TYPE-Deklaration bei %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-Zeigerende bei %C kann nicht Feld mit impliziter Form sein"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM und ENUMERATOR bei %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Zähler übersteigt den C-Ganzzahltyp bei %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L nicht mit Ganzzahlausdruck initialisiert"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Anweisung zur ENUM-Definition vor %C erwartet"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfehler in ENUMERATOR-Definition bei %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Doppelte Zugriffsspezifikation bei %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges NOPASS bei %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges PASS bei %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Doppeltes POINTER-Attribut bei %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Doppeltes NON_OVERRIDABLE bei %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Doppeltes DEFERRED bei %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Zugriffsspezifikation bei %C erwartet"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindeattribut bei %C erwartet"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE und DEFERRED können nicht gleichzeitig bei %C auftreten"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-Attribut ist für Prozedurzeiger-Komponente bei %C erforderlich"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Schnittstellenname nach %<(%> bei %C erforderlich"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> bei %C erwartet"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Schnittstelle muss für DEFERRED-Bindung bei %C angegeben werden"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(Schnittstelle) bei %C sollte als DEFERRED deklariert sein"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-Liste bei %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> ist ungültig für DEFERRED-Bindung bei %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> in PROCEDURE-Bindung mit explizitem Ziel bei %C erforderlich"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindungsziel hinter %<=>%> bei %C erforderlich"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typ %qs mit DEFERRED-Bindung bei %C ist nicht ABSTRACT"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine Prozedur mit Bindungsname %qs für den abgeleiteten Typ %qs bei %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC bei %C muss innerhalb eines CONTAINS eines abgeleiteten Typs sein"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> bei %C erwartet"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generischer Name oder Operatordeskriptor bei %C erwartet"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Kaputte GENERIC-Anweisung bei %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> bei %C erwartet"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine nicht-generische Prozedur mit Bindungsname %qs für den abgeleiteten Typ %qs bei %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindung bei %C muss denselben Zugriff wie bereits definierte Bindung %qs haben"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Spezifischer Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs bereits als spezifische Bindung für das generische %qs bei %C definiert"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Ausschuss hinter GENERIC-Bindung bei %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-Deklaration bei %C muss innerhalb eines CONTAINS-Abschnitts eines abgeleiteten Typs stehen"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklaration abgeleiteten Typs mit FINAL bei %C muss im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Leeres FINAL bei %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Prozedurname im Modul bei %C erwartet"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> bei %C erwartet"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Unbekannter Prozedurname %qs bei %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs bei %C ist bereits als FINAL-Prozedur definiert"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Unbekanntes Attribut in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfehler in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Direktive %<GCC unroll%> bei %2$C verlangt eine konstante Anzahl (maximal %1$u)"
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaxfehler in !GCC$-UNROLL-Direktive bei %C"
@@ -53081,27 +53262,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "BOZ-Literal bei %L verwendet, um Nicht-Ganzzahlvariable %qs zu initialisieren"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "BOZ-Literal bei %L außerhalb einer DATA-Anweisung und außerhalb von INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ-Literal bei %L ist bitweise übertragenes Nicht-Ganzzahlsymbol %qs"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetischer Unterlauf des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option %<-fno-range-check%> ausgeschaltet werden"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetischer Überlauf des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option %<-fno-range-check%> ausgeschaltet werden"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetisches NaN des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option %<-fno-range-check%> ausgeschaltet werden"
@@ -53426,7 +53607,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Zwischenergebnis-Feld bei %L wird erzeugt"
@@ -53436,62 +53617,62 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Aufruf von Funktion %qs bei %L wird entfernt"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "falscher Ausdruck"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr "falscher Operator"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "illegal OP in optimize_comparison"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Variable %qs bei %L auf undefinierten Wert innerhalb der bei %L beginnenden Schleife gesetzt, als INTENT(OUT)-Argument für Unterprogramm %qs"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Variable %qs bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Unterprogramm %qs definiert werden"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Schleife, die bei %L beginnt"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Schleife, die bei %L beginnt"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Variable %qs bei %L auf undefinierten Wert innerhalb der bei %L beginnenden Schleife gesetzt, als INTENT(OUT)-Argument für Funktion %qs"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variable %qs bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Funktion %qs definiert werden"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Code zur Neu-Reservierung des reservierbaren Feldes bei %L wird hinzugefügt"
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr "Scalarization using DIMEN_RANGE unimplemented"
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "Schleifen bei %L werden getauscht"
@@ -53611,12 +53792,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -54817,7 +54998,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
@@ -56268,12 +56449,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Unerwarteter Ausschuss inter $OMP FLUSH-Anweisung bei %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr "Redefinition der vordefinierten !$OMP DECLARE REDUCTION »%s« bei %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr "Redefinition der vordefinierten !$OMP DECLARE REDUCTION bei %L"
@@ -56514,8 +56695,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-Parameter der Klausel bei %L ist weniger als COLLAPSE"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
@@ -56557,7 +56738,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Symbol %qs bei %L in mehreren Klauseln vorhanden"
@@ -56898,184 +57079,184 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "Zusammengefallene »%s«-Schleifen formen bei %L keinen rechteckigen Wiederholungsraum"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "Zusammengefallene »%s«-Schleifen bei %L nicht perfekt geschachtelt"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "zu wenige DO-Schleifen für zusammengefallenes %s bei %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "Die %1$s-Direktive bei %3$L darf nicht innerhalb einer %2$s-Region angegeben werden"
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$ACC LOOP darf ohne Schleifensteuerung bei %L kein DO WHILE oder DO sein"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$ACC-LOOP-Iterationsvariable bei %L muss vom Typ integer sein"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "»%s !$ACC LOOP«-Schleifen bei %L formen keinen rechteckigen Wiederholungsraum"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79861
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "»%s !$ACC LOOP«-Schleifen bei %L nicht perfekt geschachtelt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79861
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "zu wenige DO-Schleifen für »%s !$ACC LOOP« bei %L"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr "!$ACC LOOP %s in PARALLEL-Region erlaubt keine »%s«-Argumente bei %L"
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr "Gangübergreifende Schleife bei %L ist innerhalb einer anderen gangübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr "Gangübergreifende Schleife bei %L ist innerhalb einer workerübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr "Workerübergreifende Schleife bei %L ist innerhalb einer anderen workerübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Workerübergreifende Schleife bei %L ist innerhalb einer anderen vektorübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Vektorübergreifende Schleife bei %L ist innerhalb einer anderen vektorübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "Klausel SEQ steht in Konflikt mit INDEPENDENT bei %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "Klausel SEQ steht in Konflikt mit GANG bei %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "Klausel SEQ steht in Konflikt mit WORKER bei %L"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "Klausel SEQ steht in Konflikt mit VECTOR bei %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "Klausel SEQ steht in Konflikt mit AUTO bei %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "Klausel AUTO steht in Konflikt mit GANG bei %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "Klausel AUTO steht in Konflikt mit WORKER bei %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "Klausel AUTO steht in Konflikt mit VECTOR bei %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr "Gekachelte Schleife bei %L kann nicht über Gangs, Worker oder Vektoren übergreifend parallelisiert werden"
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE bei %L erfordert konstanten Ausdruck"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "PARAMETER-Objekt %qs ist bei %L nicht erlaubt"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Feldabschnitte: %qs ist in !$ACC DECLARE bei %L nicht erlaubt"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr "OMP TARGET UPDATE bei %L erfordert mindestens eine TO- oder FROM-Klausel"
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr "!$OMP DECLARE SIMD bei %2$L sollte auf die enthaltende Prozedur %1$qs verweisen"
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Variable außer OMP_PRIV oder OMP_ORIG wird bei %L in INITIALIZER-Klausel von !$OMP DECLARE REDUCTION verwendet"
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Variable außer OMP_OUT oder OMP_IN wird bei %L in Kombinierer von !$OMP DECLARE REDUCTION verwendet"
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr "Ungültiger Operator für !$OMP DECLARE REDUCTION %s bei %L"
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr "CHARACTER-Länge in !$OMP DECLARE REDUCTION %s ist bei %L nicht konstant"
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Unterprogrammaufruf mit alternativen Rückgaben in Kombinierer von !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Unterprogrammaufruf mit alternativen Rückgaben in INITIALIZER-Klausel von !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr "Eins der tatsächlichen Argumente in INITIALIZER-Klausel von !$OMP DECLARE REDUCTION bei %L muss OMP_PRIV sein"
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr "Fehlende INITIALIZER-Klausel für !$OMP DECLARE REDUCTION von abgeleitetem Typ ohne Defaultinitialisierer bei %L"
@@ -58435,7 +58616,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit »-frecursive« verwendet werden"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert, aber nirgendwo definiert"
@@ -58545,7 +58726,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ; meinen Sie %qs?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
@@ -58930,229 +59111,229 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC %qs bei %L gefunden"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs bei %L sollte eine FUNCTION sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Bad expression type"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie überläuft"
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie unterläuft"
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index %qs kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L müssen Typparameter der gleichen Art haben"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ LOCK_TYPE sein noch eine LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ EVENT_TYPE sein noch eine EVENT_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Feldspezifikation oder feldwertiger SOURCE=-Ausdruck erforderlich in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird »*« erwartet"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L darf nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG-Variable bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L darf nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -59161,232 +59342,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektor bei %L darf nicht NULL() sein"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektor bei %L hat keinen Typ"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name %qs bei %L wird als Feld verwendet"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor muss in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS bei %L überlappt sich mit TYPE IS bei %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ %qs bei %L muss erweiterbar sein"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ %qs bei %L muss eine Erweiterung von %qs sein"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ %qs bei %L"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Die Typspezifikation bei %L muss angeben, dass jeder Parameter mit Längentyp vermutet ist"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO-%s-Prozedur bei %L muss rekursiv sein"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Ereignis-Variable bei %L muss Skalar mit EVENT_TYPE sein"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray oder koindiziert sein"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray, aber nicht koindiziert sein"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Argument UNTIL_COUNT= bei %L muss ein skalarer INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
@@ -59393,12 +59574,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -59406,108 +59587,108 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index %qs wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Bad block type"
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%ld/%ld) bei %L abgeschnitten"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Die unreine Variable bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Zuweisung an polymorphes Koarray bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L erfordert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein - bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Ausdrücken als Zwischenergebnisse auftreten würden."
@@ -59514,69 +59695,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsergebnis auf der linken Seite der Zuweisung bei %L muss Zeiger-Attribut haben."
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine INTEGER-Variable"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable %qs bei %L wurde keine Zielmarke zugewiesen"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ungültiges NULL bei %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen skalaren REAL- oder INTEGER-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): No expression on DO WHILE"
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Bad statement code"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variable %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
@@ -59583,7 +59764,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet denselben globalen Bezeichner wie Entität bei %L aus Modul %qs"
@@ -59591,57 +59772,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Prozedur %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt %qs bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld %qs bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ %qs der CLASS-Variable %qs bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable %qs bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %qs bei %L darf nicht mit Wirt verbunden sein, da er von unverträglichem bei %L definierten Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Einbezogenes SAVE für Modulvariable %qs bei %L, benötigt wegen Standardinitialisierung"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat Parameter mit aufgeschobenem Typ und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
@@ -59648,889 +59829,889 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Das Feld %qs im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable %qs bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-%qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s bei %L"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion %qs bei %L muss konstante Länge haben"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs hat PRIVATE-Typ und kann kein Scheinargument von %qs bei %L sein, das PUBLIC ist"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur %qs in PUBLIC-Schnittstelle %qs bei %L nimmt Scheinargumente von %qs, das PRIVATE ist"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-Funktion %qs bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion %qs bei %L darf weder POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht feld-wertig sein"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht zeiger-wertig sein"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rein sein"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rekursiv sein"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion %qs bei %L"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedurzeiger %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionsergebnisvariable %qs bei %L von elementarer Funktion %qs darf nicht die Attribute ALLOCATABLE oder POINTER haben"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis %qs als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in ELEMENTAL-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in PURE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in RECURSIVE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s zwischen der MODULE-PROCEDURE-Deklaration in Modul %qs und der Deklaration bei %L in (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur %qs bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ %qs haben"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur %1$qs hat denselben Rang (%3$d) wie %4$qs"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Bei %2$L wurde nur FINAL-Feldprozedur für abgeleiteten Typ %1$qs definiert, skalare wird ebenfalls empfohlen"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs und %qs können nicht gemischte FUNCTION/SUBROUTINE für GENERIC %qs bei %L sein"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs und %qs für GENERIC %qs bei %L sind mehrdeutig"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung %qs als Ziel des GENERIC %qs bei %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs bei %L muss auf spezifische Bindung abzielen, %qs ist ebenfalls GENERIC"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs bei %L muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle sein"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %qs für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur %qs bei %L hat den gleichen Namen wie eine Komponente von %qs"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur %qs bei %L hat den selben Namen wie eine vererbte Komponente von %qs"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ %1$qs muss ABSTRACT sein, da %3$qs DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente %qs bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente %qs bei %L mit Koarray-Komponente darf ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente %qs bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponente %qs von BIND(C)-Typ bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter %qs von %qs mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente %qs von %qs bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente %qs muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente %qs von %qs bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente %qs ist ein PRIVATE-Typ und kann nicht Komponente von %qs sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Die Zeigerkomponente %qs bei %qs bei %L hat nicht deklarierten Typ"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "In Konflikt stehende Initialisierungen in Union bei %L und %L"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ %qs bei %L eine Koarray-Komponente hat, muss der Elterntyp %qs auch eine haben"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parametrisierter Typ %1$qs hat bei %3$L keine Komponente, die zu Parameter %2$qs gehört"
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Das Objekt %qs bei %L hat aufgeschobenen LEN-Parameter %qs und ist weder allozierbar noch ein Zeiger"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "Das AUTOMATIC-Objekt %qs bei %L darf kein SAVE-Attribut haben und dard auch keine Variable im main-Programm, einem Modul oder einem Teilmodus sein (F08/C513)"
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Das Objekt %qs bei %L mit ASSUMED-Typparametern muss ein Dummy oder ein SELECT-TYPE-Selektor sein (F08/4.2)"
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Falsche Spezifikation für Feld bei %L mit angenommener Größe"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-Variable %qs bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variable %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Bad expression"
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-Blockelement %qs bei %L darf in der PURE-Prozedur %qs kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -60988,7 +61169,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Unexpected type"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Zeichen %qs in Zeichenkette bei %L kann nicht in Zeichenart %d umgewandelt werden"
@@ -61638,18 +61819,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Intrinsische Funktion %qs (%d) nicht erkannt"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Argument %<dim%> des intrinsischen »%s« bei %L ist kein gültiger Dimensionsindex"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Sorry, die Event-Komponente des abgeleiteten Typs bei %L wird noch nicht unterstützt"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Event-Variable bei %L darf nicht koindiziert sein"
@@ -61835,177 +62016,177 @@
 msgid "previously defined here as %s"
 msgstr "vorher hier als %s definiert"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "mehrere vorherrschende Definitionen für %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD wurde bereits definiert"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "vorher hier definiert"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "%qD verletzt die One-Definition-Rule von C++"
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "Typ von %qD passt nicht zur ursprünglichen Deklaration"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "Ausrichtung von %qD ist größer als ursprüngliche Deklaration"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr "Größe von %qD passt nicht zur ursprünglichen Deklaration"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "%qD wurde vorher hier deklariert"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr "Code könnte fehloptimiert werden, es sei denn, -fno-strict-aliasing wird angegeben"
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "Variable %qD als Funktion redeklariert"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "Funktion %qD als Variable redeklariert"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "vorher hier deklariert"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "Bytecode-Strom: Ausschuss am Ende des »symbols«-Abschnitts"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "Hex-Zahl konnte nicht eingelesen werden"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "unerwarteter Dateiname %s in Linker-Auflösungsdatei. %s erwartet"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "Datei-Offset konnte nicht eingelesen werden"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "unerwarteter Offset"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ungültige Zeile in Auflösungsdatei"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ungültige Auflösung in Auflösungsdatei"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "Auflösungs-Sub-ID %wx nicht in Objekt-Datei"
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "LTO-Deklarationen von %s können nicht gelesen werden"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "»%s« kann nicht geöffnet werden"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "»%s« kann nicht in den Speicher geladen werden"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "»%s« kann nicht gelesen werden"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() gescheitert"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid gescheitert"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "Streaming-Kindprozess fehlgeschlagen"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "Der Streaming-Kindprozess wurde durch ein Signal beendet"
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "kein Dateiname für LTRANS-Ausgabeliste angegeben"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "LTRANS-Ausgabeliste »%s« kann nicht geöffnet werden: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "beim Schreiben in LTRANS-Ausgabeliste %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "LTRANS-Ausgabeliste »%s« kann nicht geschlossen werden: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "Datei zur Symbolauflösung konnte nicht geöffnet werden: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "fehlende Auflösungsdaten für %s"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "Fehler beim Einfügen von Übersetzungseinheiten"
@@ -62948,6 +63129,52 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "für nicht existierende Methode %qE wird Selektor erzeugt"
 
+# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=84807
+#~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+#~ msgstr "Eingebaute Funktionen und Codeerzeugung für Control-flow Enforcement Technology (CET) unterstützen."
+
+#~ msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+#~ msgstr "Aktiviert insbesondere das Nachverfolgen von indirekten Sprüngen im Rahmen der Control-Flow Enforcement Technology (CET)."
+
+#~ msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#~ msgstr "Höchstanzahl von Bytes, um Inline-Code mit schleifenfreiem Code zu vergleichen. Ein Wert von 0 bedeutet, dass memcmp überhaupt nicht geinlinet wird."
+
+#~ msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+#~ msgstr "Höchstanzahl von Bytes, um Inline-Code mit schleifenbasiertem Code zu vergleichen. Wenn die Länge zur Übersetzungszeit nicht bekannt ist, wird nach dieser Anzahl von Bytes memcmp aufgerufen. Der Vorgabewert für die Länge hängt von der Zielarchitektur ab (-mtune=)."
+
+#~ msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
+#~ msgstr "%K%qD das Schreiben von %E Bytes in eine Region der Größe %E lässt die Zielregion überlaufen"
+
+#~ msgid "%K%qD reading %E bytes from a region of size %E"
+#~ msgstr "%K%qD Lesen von %E Bytes aus einer Region der Größe %E"
+
+#~ msgid "builtin operand should be an unsigned 6-bit value"
+#~ msgstr "Eingebauter Operand sollte ein vorzeichenloser 6-Bit-Wert sein"
+
+#~ msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
+#~ msgstr "Operand für »sleep«-Befehl muss eine ganzzahlige Kompilierzeit-Konstante zwischen 0 und 63 sein"
+
+#~ msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
+#~ msgstr "%<-fcf-protection=branch%> benötigt Intel-CET-Unterstützung. Verwenden Sie eine der Optionen %<-mcet%> oder %<-mibt%>, um CET einzuschalten"
+
+#~ msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
+#~ msgstr "%<-fcf-protection=return%> benötigt Intel-CET-Unterstützung. Verwenden Sie eine der Optionen %<-mcet%> oder %<-mshstk%>, um CET einzuschalten"
+
+#~ msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
+#~ msgstr "%<-fcf-protection=full%> benötigt Intel-CET-Unterstützung. Verwenden Sie %<-mcet%> oder sowohl %<-mibt%> als auch %<-mshstk%>, um CET einzuschalten"
+
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat %<end%>-Element, aber kein %<begin%>"
+
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat %<begin%>-Element, aber kein %<end%>"
+
+#~ msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
+#~ msgstr "zweiter Operand von %<offsetof%> ist weder ein einzelner Bezeichner noch eine Folge von Elementzugriffen und Arrayreferenzen"
+
+#~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
+#~ msgstr "%qH kann nicht nach %qI für Argument %qP nach %qD umgewandelt werden"
+
 #~ msgid "%G%qD output truncated copying %E byte from a string of length %E"
 #~ msgstr "%G%qD Ausgabe abgeschnitten, beim Kopieren von %E Byte aus einer Zeichenkette der Länge %E"
 
Index: gcc/po/ja.po
===================================================================
--- gcc/po/ja.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/ja.po	(.../branches/gcc-8-branch)
@@ -19,7 +19,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.6.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2011-10-30 18:48+0900\n"
 "Last-Translator: Yasuaki Taniguchi <yasuakit@gmail.com>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -168,40 +168,40 @@
 msgid "negative insn length"
 msgstr "負の命令長です"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "命令を分割できませんでした"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "無効な 'asm' です: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr ""
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr ""
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "%% 文字の後に被演算子の数字がありません"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "被演算子の数字が範囲外です"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "無効な %%-code です"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "'%%l' 被演算子が label ではありません"
@@ -212,13 +212,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "浮動小数定数を使い損ねました"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1288,27 +1288,27 @@
 msgid "At top level:"
 msgstr "トップレベル:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "メンバ関数 %qs 内"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "関数 %qs 内"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 #, fuzzy
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "%s:%d から include されたファイル内"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "%s:%d から include されたファイル内"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr ""
@@ -3122,9 +3122,9 @@
 msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
@@ -3140,7 +3140,7 @@
 msgstr "無効な %%r 値"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3147,13 +3147,13 @@
 msgstr "無効な %%R 値"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
@@ -3184,7 +3184,7 @@
 msgstr "無効な %%U 値"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
@@ -3195,7 +3195,7 @@
 msgstr "無効な %%C 値"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
@@ -3206,7 +3206,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3218,61 +3218,61 @@
 msgid "invalid operand address"
 msgstr "無効なアドレスです"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p コードへの無効な被演算子です"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s コードへの無効な被演算子です"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3280,19 +3280,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "無効な被演算子出力コード"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "認識できない定数のようなもの"
 
@@ -3328,7 +3328,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
@@ -3467,8 +3467,8 @@
 msgstr "無効な const_double 被演算子"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3685,110 +3685,110 @@
 msgid "bad output_condmove_single operand"
 msgstr "誤った output_condmove_single 被演算子"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid use of type"
 msgid "invalid use of asm flag output"
 msgstr "無効な型の使用法です"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid vector permutation constant"
 msgid "invalid vector immediate"
 msgstr "無効なベクトル順列定数です"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
@@ -3827,7 +3827,7 @@
 msgstr "無効な %%P 被演算子です"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -3881,7 +3881,7 @@
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -4048,146 +4048,146 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無効な %%H 値"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 #| msgid "Enable unaligned load/store instruction"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4318,22 +4318,22 @@
 msgid "created and used with different endianness"
 msgstr "作成時と使用時でエンディアンが異なります"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "無効な %%Y 被演算子です"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "無効な %%A 被演算子です"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "無効な %%B 被演算子です"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
@@ -4340,23 +4340,23 @@
 msgid "invalid %%C operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "無効な %%f 被演算子です"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "無効な %%s 被演算子です"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4596,14 +4596,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -4618,7 +4618,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -4626,7 +4626,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -4640,7 +4640,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
@@ -4647,7 +4647,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -4657,13 +4657,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
@@ -4672,18 +4672,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
@@ -4691,23 +4691,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
@@ -4716,7 +4716,7 @@
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -4728,46 +4728,46 @@
 msgid "expected label"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "候補 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "候補 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "case ラベルにジャンプしています"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  catch ブロックに入ります"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 msgid "enters OpenMP structured block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 #| msgid "Generate code for huge switch statements"
 msgid "enters synchronized or atomic statement"
 msgstr "巨大な swich 文用コードを生成する"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -4863,7 +4863,7 @@
 msgid "<statement>"
 msgstr "<文>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<不明>"
@@ -4882,127 +4882,127 @@
 msgid "<unparsed>"
 msgstr "<未構文解析>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 #, fuzzy
 #| msgid "<lambda"
 msgid "<lambda>"
 msgstr "<ラムダ"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<式エラー>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<不明な演算子>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "大域スコープ:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "静的メンバ関数 %qs 内"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "コピーコンストラクタ %qs 内"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "コンストラクタ %qs 内"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "デストラクタ %qs 内"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "ラムダ関数内"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, fuzzy, c-format
 #| msgid "%s: In instantiation of %qs:\n"
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s: %qs のインスタンス内:\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 #| msgid "%s: In instantiation of %qs:\n"
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s: %qs のインスタンス内:\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 #, fuzzy
 #| msgid "%s:%d:   recursively instantiated from %qs\n"
 msgid "recursively required from %q#D\n"
 msgstr "%s:%d:   %qs から再帰的に実体化されました\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 #| msgid "%s:%d:   recursively instantiated from here"
 msgid "recursively required from here\n"
 msgstr "%s:%d:   ここから再帰的に実体化されました"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "called from here"
 msgid "required from here\n"
 msgstr "ここから呼び出されました"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 #, fuzzy
 #| msgid "%s:%d:%d:   instantiated from %qs\n"
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d:%d:   %qs から実体化されました\n"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "候補:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
@@ -5047,48 +5047,48 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "単項マイナスへの引数の型が間違っています"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "単項プラスへの引数の型が間違っています"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "ビット反転への引数の型が間違っています"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs への引数の型が間違っています"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "複素共役(~)への引数の型が間違っています"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5373,11 +5373,11 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
@@ -5557,47 +5557,47 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5639,12 +5639,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5912,6 +5912,7 @@
 msgstr "-Xbind-now と -Xbind-lazy は併用できません"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 #, fuzzy
 #| msgid "consider using '-pg' instead of '-p' with gprof(1)"
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
@@ -9332,7 +9333,7 @@
 msgstr "変数を 32 ビット境界に整列する"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 #| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
@@ -9917,7 +9918,7 @@
 msgstr "固定するレジスタの範囲を指定する"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -10805,7 +10806,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "与えられた ABI に準拠したコードを生成する"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -11350,7 +11351,7 @@
 msgstr "PCLMUL 組み込み関数とコード生成をサポートする"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -11359,12 +11360,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -11377,47 +11378,49 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "MMX と SSE の組み込み関数とコード生成をサポートする"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
 msgstr "関数呼び出しと戻り用に call と rtc を使用する"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "関数の返す型が関数であってはなりません"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation"
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "BMI 組み込み関数とコード生成をサポートする"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation"
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "BMI 組み込み関数とコード生成をサポートする"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -11942,7 +11945,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "廃止されました。代わりに -Os を使用してください"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -11950,7 +11953,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -12064,7 +12067,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\t与えられた CPU 用のスケジュールコードを使用する"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -12106,7 +12109,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -12202,27 +12205,27 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "vector/scalar (VSX) 命令を使用する"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "複数命令のロード/ストアを生成する"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12242,19 +12245,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -12270,15 +12273,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12288,17 +12291,17 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Enable 32-bit multiply instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "32 ビット乗算命令を有効にする"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12308,7 +12311,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "小さな集合体をレジスタで返す"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 #| msgid "valid arguments to %qs are: %s"
 msgid "Valid arguments to -mstack-protector-guard=:"
@@ -12349,14 +12352,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "関数プロローグの前にプロファイル用の mcount を呼び出す"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "ABI 呼び出し規約を選択する"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -13211,7 +13213,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -13459,14 +13461,22 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mfused-madd%> は廃止されました。代わりに %<-ffp-contract=%> を使用してください"
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+msgid "Max number of pairs of load insns for compare."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
@@ -13479,10 +13489,49 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-mcpu=%> は廃止されました。代わりに %<-mtune=%> または %<-march=%> を使用してください"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\tトレースバック表を full、part、または no のいずれかにする"
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\tlong double のサイズを指定する (64 または 128 ビット)"
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+#| msgid "%qE is deprecated"
+msgid "%qs is deprecated"
+msgstr "%qE は廃止されました"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "ABI 呼び出し規約を選択する"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Select method for sdata 取り扱い用の方法を選択する"
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "即値 TLS オフセットのビットサイズを指定する"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -14899,114 +14948,175 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "gcc が LIW 命令を生成することを許可する"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "ビッグエンディアンモードでコードを生成する"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate conditional move instructions."
 msgstr "ビット命令を生成する"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate performance extension instructions."
 msgstr "ビット命令を生成する"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Use hardware floating point conversion instructions"
 msgid "Generate performance extension version 2 instructions."
 msgstr "ハードウェア浮動小数点変換命令を使用する"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate string extension instructions."
 msgstr "ビット命令を生成する"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "isel 命令を生成する"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate 16-bit instructions."
 msgstr "ビット命令を生成する"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
 msgstr "複数コアサポートを有効にする"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the register allocation order"
 msgid "Specify the cpu for pipeline model."
 msgstr "レジスタ確保順を指定する"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "すべてのコンストラクタとデストラクタが非公開の場合に警告する"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "isel 命令を生成する"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "浮動小数の乗算/加算命令を生成する"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "68881 浮動小数点命令を使用したコードを生成する"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "68881 浮動小数点命令を使用したコードを生成する"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -16127,14 +16237,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "複数命令のロード/ストアを生成する"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-#| msgid "%qE is deprecated"
-msgid "%qs is deprecated"
-msgstr "%qE は廃止されました"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Allow gcc to generate LIW instructions"
@@ -18986,8 +19088,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "計算された値が使用されません"
@@ -19015,7 +19117,7 @@
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected integer"
@@ -19476,7 +19578,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -19503,13 +19605,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -19558,9 +19660,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -19573,8 +19675,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "前方での `%s' の宣言"
@@ -19707,83 +19809,75 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数が少なすぎます"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid argument to %qD"
 msgstr "無効な %qD の使用です"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument to %qD"
@@ -19791,76 +19885,76 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin___clear_cache%> への両方の引数はポインタでなければいけません"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr ""
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD の意味合いは GCC 4.4 で変更になりました"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid memory model argument to builtin"
 msgstr "組み込み関数への無効な引数です"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19868,7 +19962,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K %<__builtin_va_arg_pack ()%> の無効な使用法です"
@@ -19875,12 +19969,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K %<__builtin_va_arg_pack_len ()%> の無効な使用法です"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
@@ -19887,66 +19981,66 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "ターゲット形式は無限大をサポートしません"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "ターゲット形式は無限大をサポートしません"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> が引数の数が固定の関数内で使用されました"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> の第二引数が、最後の名前付き引数ではありません"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "%<va_start%> の第二引数が %<register%> 記憶域の場合の動作は不定です"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%K ヒープではないオブジェクト %qD を free する試みです"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K ヒープではないオブジェクトを free する試みです"
@@ -21136,39 +21230,39 @@
 msgid "conversion to incomplete type"
 msgstr "不完全型への変換です"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert between vector values of different size"
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "異なるサイズのベクトル値の間での変換はできません"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "整数型があるべき箇所で、集合体の値が使われました"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "複素数型があるべき箇所で、ポインタ値が使われました"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "複素数型があるべき箇所で、集合体の値が使われました"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert between vector values of different size"
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "異なるサイズのベクトル値の間での変換はできません"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "値をベクトルへ変換できません"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "固定小数点型があるべき箇所で、集合体の値が使われました"
@@ -21325,12 +21419,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -21440,12 +21534,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -21461,12 +21555,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "フレームサイズ (%wd バイト) が %wd バイトより大きいです"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "最終命令ダンプファイル %qs が開けません: %m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "最終命令ダンプファイル %qs を閉じられません: %m"
@@ -21476,42 +21570,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大きな固定小数定数が暗黙的に固定整数型に切り詰められました"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較が常に %d となります"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -22060,28 +22154,28 @@
 msgid "can%'t write PCH file"
 msgstr "PCH ファイルを書き込めません"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -22097,12 +22191,13 @@
 msgid "null pointer dereference"
 msgstr "NULL ポインタ"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "ここで宣言されています"
@@ -22613,10 +22708,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -22647,7 +22742,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -22997,258 +23092,263 @@
 msgid "function cannot be instrumented"
 msgstr "共用体を透過的にできません"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 #| msgid "enum type defined here"
 msgid "the incompatible type is defined here"
 msgstr "列挙型がここで定義されています"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
 msgstr "配列参照が範囲外です"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "<return value> "
 msgid "return value type mismatch"
 msgstr "<戻り値> "
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "型が前方の外部宣言と一致しません"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 #| msgid "different parameter types"
 msgid "types have different parameter counts"
 msgstr "引数の型が異なります"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "type %qT should match type %qT"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -23270,37 +23370,37 @@
 msgid "the extra base is defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23592,34 +23692,38 @@
 msgstr "ターゲット形式は無限大をサポートしません"
 
 #: multiple_target.c:91
-#, fuzzy, gcc-internal-format
-#| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
-msgstr "version 属性が文字列ではありません"
+#, gcc-internal-format
+msgid "default %<target_clones%> attribute was not set"
+msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
-#| msgid "%qE incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
-msgstr "互換性がない %qE 属性は無視されました"
+#| msgid "%<fast_interrupt%> attribute directive ignored"
+msgid "single %<target_clones%> attribute is ignored"
+msgstr "%<fast_interrupt%> 属性指示は無視されました"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be copied because it receives a non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "関数 %q+F は非局所 goto を受け取るため決して複製されません"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for %qD"
 msgid "default target was not set"
 msgstr "%qD 用のデフォルト引数がありません"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -23940,13 +24044,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
@@ -24575,22 +24679,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -24635,7 +24739,7 @@
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting types for %q+D"
 msgid "conflicts with %qD"
@@ -24879,163 +24983,163 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qE は変数にのみ適用できます"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "メソッド '%s' はクラス内に見つかりません"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "node is alias but not definition"
 msgstr "古いスタイルの関数定義です"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa に失敗しました"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as variable"
 msgid "function %q+D part of alias cycle"
 msgstr "関数 %qD が変数として再宣言されました"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D set but not used"
 msgid "variable %q+D part of alias cycle"
 msgstr "変数 %q+D が設定されましたが使用されていません"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -26246,12 +26350,12 @@
 msgid "control reaches end of non-void function"
 msgstr "制御が非 void 関数の終りに到達しました"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "warn_unused_result 属性付きで宣言されている関数の戻り値を無視しています"
@@ -26762,7 +26866,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -26807,95 +26911,95 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "関数の配列は意味がありません"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "関数の返す型が関数であってはなりません"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型は廃止されました: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "型は廃止されました"
@@ -26920,246 +27024,246 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "type is not compatible with its variant"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "Main variant is not defined"
 msgstr "環境変数 %qs が定義されていません"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -27185,12 +27289,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "破損した値のプロファイルです: %s プロファイルの総合計数 (%d) は BB 数 (%d) と一致しません"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "変数追跡サイズ制限が -fvar-tracking-assignments を超過しています。-fvar-tracking-assignments 無しで再度試みています"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "変数追跡サイズ制限が超過しました"
@@ -28110,7 +28214,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "真偽値として使われる代入のまわりでは、丸括弧の使用をお勧めします"
@@ -28372,7 +28476,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "配列のサイズが大きすぎます"
@@ -29004,7 +29108,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -29020,22 +29124,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -29590,8 +29694,8 @@
 msgid "wrong type argument to %s"
 msgstr "%s への間違った型の引数です"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "定数式内でオーバーフローしました"
@@ -30245,7 +30349,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
@@ -30327,7 +30431,7 @@
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -30464,54 +30568,54 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops%s is obsolete, use -falign-loops%s"
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "%salign-loops%s は廃止予定です。-falign-loops%s を使用してください"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-jumps%s is obsolete, use -falign-jumps%s"
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "%salign-jumps%s は廃止予定です。-falign-jumps%s を使用してください"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-functions%s is obsolete, use -falign-functions%s"
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "%salign-functions%s は廃止予定です。-falign-functions%s を使用してください"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s が 0 と %d の間ではありません"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sbranch-cost=%d%s is not between 0 and 5"
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s が 0 と 5 の間ではありません"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> は現在のところ GNU/Linux 上でのみサポートされています"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
@@ -30537,31 +30641,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "不明な -mdebug-%s スイッチです"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "不明なスイッチ -mlong-double-%s です"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "-msingle-float オプションは -mhard-float と等価です"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "-msimple-fpu オプションは無視されました"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
@@ -31062,8 +31166,8 @@
 msgstr "attribute(target(\"%s\")) が不明です"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -31145,8 +31249,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31262,11 +31366,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31276,158 +31380,148 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%> への無効な引数です"
 
-#: config/arc/arc.c:6556
-#, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea は -mmulticore と併せて使用するべきです"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "symbol used as immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "即値被演算子として使用されるシンボルです"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 #| msgid "Bad address, not register:"
 msgid "insn addresses not freed"
 msgstr "誤ったアドレスです。レジスタではありません:"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE は変数にのみ適用できます"
@@ -31454,154 +31548,154 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "セレクタは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "マスクは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32458,12 +32552,12 @@
 msgid "invalid IACC argument"
 msgstr "無効な IACC 引数です"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs には定数引数が予期されます"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "%qs 用の定数引数が範囲外です"
@@ -32572,18 +32666,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "PCH ファイル内で位置を設定できません: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument in option %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -32590,47 +32684,47 @@
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs にクラス名が指定されていません"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "不明なレジスタ名です: %s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -32637,541 +32731,526 @@
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "profiling not supported with -mg"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mg でのプロファイルはサポートされていません"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i ビットモードが使用できるようにコンパイルされていません"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "選択した CPU は x86-64 命令セットをサポートしていません"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s は %s をサポートしません"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary%s is not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") は既に指定されています"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qT を呼び出しています<"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib はサポートしません"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "可変長配列メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "long double を持つ共用体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタを戻して (return) います"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタ引数があります"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 が無効な状態で x87 レジスタを戻して (return) います"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 属性は 32 ビット用の -mfentry と併用できません"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -33179,335 +33258,335 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %qD set but not used"
 msgid "Parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE は isa オプション %s が必要です"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後の引数は即値でなければいけません"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown IRA algorithm %qs"
 msgid "unknown asm flag output %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand output code"
 msgid "invalid type for asm flag output"
 msgstr "無効な被演算子出力コード"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 #| msgid "unknown architecture %qs"
 msgid "unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33734,7 +33813,7 @@
 msgstr "interrupt_thread は fido 上でのみ使用出来ます"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "スタック制限式はサポートされていません"
@@ -34294,8 +34373,37 @@
 msgid "constant argument out of range for %s"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "この組み込み関数は fr450 上でのみ利用できます"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "この組み込み関数は fr450 上でのみ利用できます"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "nested functions not supported on this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "入れ子になった関数はこのターゲットではサポートされていません"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Support code generation of crc32 instruction."
+msgid "don't support performance extension version 2 instructions"
+msgstr "crc32 命令のコード生成をサポートする。"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 #| msgid "Enable sign extend instructions"
 msgid "don't support string extension instructions"
 msgstr "符号付き拡張命令を有効にする"
@@ -34319,11 +34427,11 @@
 msgstr "複数の割り込み属性は許可されていません"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "a nested function is not supported for reduced registers"
@@ -34330,37 +34438,54 @@
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "命令に対して無効なレジスタです"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "言語 %s は認識できません"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "%qE 属性用としては無効なベクトル型です"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -34587,39 +34712,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE 属性は型に関しては無視されます"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 属性は自動記憶域クラスでのみ許可されています"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34713,12 +34838,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall の末尾にゴミがあります"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -34772,7 +34897,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert は 3 個の引数のみ受け付けます"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -35081,7 +35206,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35091,7 +35216,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
@@ -35102,13 +35227,13 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35119,30 +35244,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -35164,13 +35289,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -35196,58 +35321,58 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "第三引数は 4 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "第三引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -35388,7 +35513,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "スタックフレームが大きすぎます"
@@ -35398,13 +35523,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -35414,22 +35539,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
@@ -35439,7 +35564,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
@@ -35908,22 +36033,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -35995,34 +36120,39 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "ifunc はこの設定ではサポートされていません"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
@@ -36159,47 +36289,47 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function to %s already processed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -36206,7 +36336,7 @@
 msgstr "%s は 1 個の引数のみ受け付けます"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -36213,140 +36343,140 @@
 msgstr "%qs は -mcpu= への引数としては無効です"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "%q+D の第二引数は %<char **%> であるべきです"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "third argument to %qs must be 0..12"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "builtin function %qs requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE not supported for MIPS16"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "組み込み関数 %qE は MIPS16 用にはサポートされていません"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "レジスタ r2 と r5 を使用する"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -37186,7 +37316,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void の値が本来の意味通りに無視されませんでした"
@@ -37439,7 +37569,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
@@ -37449,7 +37579,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "`%s' の宣言は前方のローカルシンボルを覆い隠します"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "隠された宣言はここです"
@@ -37512,7 +37642,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "未宣言の識別子は出現した各関数内で一回のみ報告されます"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ラベル %qE があらゆる関数の外側から参照されました"
@@ -37542,7 +37672,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "重複したラベルの宣言 %qE です"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複したラベル %qD です"
@@ -37664,7 +37794,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> は関数プロトタイプスコープ以外では許可されていません"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -37922,7 +38052,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "無名仮引数用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "型名用に記憶域クラスが指定されました"
@@ -38085,7 +38215,7 @@
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
@@ -38223,7 +38353,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "変数またはフィールド %qE が void と宣言されています"
@@ -38408,7 +38538,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "%qs 式内での型定義は C++ では無効です"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
@@ -38458,7 +38588,7 @@
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
@@ -38496,7 +38626,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> の再定義です"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定したモードは列挙値用には小さすぎます"
@@ -38526,7 +38656,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
@@ -38557,7 +38687,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
@@ -38672,12 +38802,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
@@ -38743,7 +38873,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
@@ -38899,38 +39029,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右シフト回数が負です"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右シフト回数 >= 型の幅となっています"
@@ -38962,7 +39092,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -39004,7 +39134,7 @@
 msgstr "不明な型名 %qE です"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -39020,7 +39150,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -39035,8 +39165,8 @@
 msgid "unexpected attribute"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -39077,7 +39207,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> または %<;%> が予期されます"
@@ -39105,7 +39235,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "文字列リテラルが予期されます"
@@ -39172,13 +39302,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列挙型リストの最後にコンマがあります"
@@ -39310,7 +39440,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> が %<else%> の前に予期されます"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> の前に %<if%> がありません"
@@ -39344,22 +39474,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "文が予期されます"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%<if%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%<else%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "%<else%> が曖昧になることを避けるために明示的に中括弧で括ることを推奨します"
@@ -39379,12 +39509,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -39412,12 +39542,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -39727,7 +39857,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -39788,79 +39918,79 @@
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -39877,59 +40007,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -39952,93 +40082,93 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "%<throw%> が予期されます"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
 msgstr "%<class%> が予期されます"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -40049,13 +40179,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -40075,19 +40205,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -40099,72 +40229,72 @@
 msgid "invalid proc_bind kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -40180,7 +40310,7 @@
 msgid "expected function name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "メンバ関数の名前を欠いています"
@@ -40190,44 +40320,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -40237,22 +40367,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -40262,76 +40392,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -40352,34 +40482,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -40437,48 +40567,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -40494,7 +40624,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD は不完全型を持っています"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void 式の無効な使用法です"
@@ -40621,7 +40751,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "添字が付けられた値が、配列、ポインタまたはベクトルではありません"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "配列の添字が整数型ではありません"
@@ -40646,7 +40776,7 @@
 msgid "enum constant defined here"
 msgstr "列挙型定数がここで定義されています"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -40752,18 +40882,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "文字列リテラルの比較結果は不定です"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "ポインタと整数との比較を行なっています"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -40788,7 +40918,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -41028,7 +41158,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "型 %qT の関数呼び出しから一致しない型 %qT へのキャストです"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "異なるサイズの整数からポインタへのキャストです"
@@ -41185,7 +41315,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
@@ -41258,7 +41388,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "非左辺値配列の無効な使用です"
@@ -41334,12 +41464,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "伝統的な C では自動集約初期化を拒否します"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "可変配列メンバを初期化しています"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "ワイド文字列から char 配列が初期化されています"
@@ -41385,7 +41515,7 @@
 msgid "invalid initializer"
 msgstr "無効な初期化子です"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
@@ -41400,7 +41530,7 @@
 msgid "braces around scalar initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "入れ子になったコンテキスト内で可変配列メンバを初期化しています"
@@ -41530,7 +41660,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C は %<goto *expr;%> を禁止しています"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
@@ -41571,7 +41701,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "switch 文の外にある case ラベルです"
@@ -41581,17 +41711,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP のループ用に break 文が使用されています"
@@ -41618,24 +41748,24 @@
 msgid "expression statement has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "different number of results"
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "浮動小数点の比較で == や != を使うのは安全ではありません"
@@ -41686,7 +41816,7 @@
 msgstr "NULL ポインタがあるポインタの順序比較です"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "整数 0 とポインタとの順序比較です"
@@ -41717,12 +41847,12 @@
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -41733,25 +41863,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "メンバ関数の名前を欠いています"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -41764,18 +41894,18 @@
 msgstr "%qs 句が多すぎます"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -41782,55 +41912,55 @@
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -41851,7 +41981,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE は %<reduction(%s)%> 用の無効な型を持っています"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -41862,17 +41992,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -41887,18 +42017,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -41911,33 +42041,33 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE は %<firstprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -41960,61 +42090,61 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -42026,32 +42156,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -42199,7 +42329,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -42281,28 +42411,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "オーバーロードされている %<%D(%A)%> の呼び出しが曖昧です"
@@ -42309,650 +42439,650 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "%<(%T) (%A)%> への呼び出しが適合しません"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> の呼び出しが曖昧です"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous overload for %qs in %<%s %E%>"
 msgid "ambiguous overload for "
 msgstr "%qs 用の %<%s %E%> 内にあるオーバーロードが曖昧です"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "no match for "
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "二項演算子 %s への無効な被演算子です (%qT と %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "ternary %<operator?:%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E ? %E : %E%> 内にある三項演算子 %<operator?:%> が適合しません "
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator%s%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%<operator%s%> で %<%E%s%> 内にあるものが適合しません"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "%<operator[]%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E[%E]%> 内の %<operator[]%> が適合しません"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%qs で %<%s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<operator%s%> で %<%E %s %E%> 内にあるものが適合しません"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "no match for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%<operator%s%> で %<%s%E%> 内にあるものが適合しません"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ は中間項が省略された ?: 式を禁止しています"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T と %q#T の間での比較です"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator %s%> は %qT 用としては適切ではありません"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "ここで宣言されています"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D はアクセス出来ません"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL から非ポインタ型 %qT へ変換しています"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT 用の初期化子の周りに中括弧が多すぎます"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, fuzzy, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "関数呼び出しの引数が format 属性の候補であるようです"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (-fno-deduce-init-list でこれを無効に出来ます)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "オーバーロードされた %<%s(%A)%> の呼び出しは曖昧です"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "デストラクタから値を返そうとしています"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "conversion from %q#T to %q#T"
 msgid "  for conversion from %qH to %qI"
 msgstr "%q#T から %q#T への変換です"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " 候補 1: %q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " 候補 2: %q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "無効なバージョン番号形式"
@@ -42993,8 +43123,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前方での `%s' の宣言"
@@ -43035,7 +43165,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qT declared here"
@@ -43120,7 +43250,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -43417,7 +43547,7 @@
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
@@ -43488,7 +43618,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "型情報が不十分です"
@@ -43584,351 +43714,351 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右シフト回数が負です"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not initialized with a constant expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qE は初期化されていません"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D は const ではありません"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D は volatile です"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -43977,7 +44107,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -43988,311 +44118,311 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "%q#T から %q#T への変換です"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "%qE が型 %qT の範囲外にあるので変換結果は不定です"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T が %qT が予期される場所で使用されました"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T が浮動小数点値が予期される場所で使用されました"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "%qT から非スカラ型 %qT への変換が要求されました"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "疑似デストラクタが呼び出されません"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr ""
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "文は効果がありません"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT からのデフォルトの型変換が曖昧です"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -44337,211 +44467,211 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr ""
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr ""
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 msgid "cannot specialize concept %q#D"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "組み込み関数 %q#D を覆い隠しています"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "ライブラリ関数 %q#D を覆い隠しています"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "ライブラリ関数 %q#D は非関数 %q#D として再宣言されています"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "前方での `%s' の暗黙的な宣言"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a built-in function"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "%q+D の宣言が組み込み関数を隠します"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a built-in function"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "%q+D の宣言が組み込み関数を隠します"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "空の宣言です"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr ""
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "関数 %qE の暗黙的な宣言です"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "previously defined here"
 msgid "%q#D previously defined here"
 msgstr "前はここで定義されました"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%q#D previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "`%s' と型が矛盾します"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %q+D with no linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "リンク無し %q+D の再定義です"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr ""
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous specification in %q#D here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %q+D"
@@ -44555,12 +44685,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "data area of %q+D conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -44567,28 +44697,28 @@
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -44596,647 +44726,647 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %q+D"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%q+D の冗長な再宣言です"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  ここから"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  catch ブロックに入ります"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "unknown type name %qE"
 msgid "no type named %q#T in %q#T"
 msgstr "不明な型名 %qE です"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr ""
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "type is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "型は廃止されました"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "要求された整列が 2 の累乗ではありません"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一つの宣言に複数の型があります"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typdef 宣言で型名を欠いています"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "`%s' の宣言で型がデフォルトの `int' とされました"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef `%s' が初期化されました"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "重複した初期化子"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "変数 `%s' には初期化子がありますが、不完全型です"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "自明でないラベルのついた初期化子です"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "initialized variable %q+D is marked dllimport"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "初期化された変数 %q+D は dllimport とマークされています"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無効なビット列初期化子です"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C89 は複合リテラルを禁じます"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pramga が括弧で囲まれた文字列リテラルを受け取りました"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(クラス外での初期化を必要とします)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -45243,963 +45373,974 @@
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "source is a pointer to incomplete type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "ソースは不完全型へのポインタです"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java メソッド %qD が非 Java 戻り型 %qT を持ちます"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD cannot be a bit-field"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' は `int' を返さなければなりません"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, fuzzy, gcc-internal-format
 msgid "size of array is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "配列の次元がオーバーフローしました"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名変数やフィールドが void と宣言されました"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "変数またはフィールドが void と宣言されました"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> または %<unsigned%> は %qs に対しては無効です"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> は %qs に対しては無効です"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> は %qs に対しては無効です"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> は %qs に対しては無効です"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> または %<short%> は %qs に対しては無効です"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>、%<int%>、%<short%>、または %<char%> は %qs に対しては無効です"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> または %<short%> が char と共に %qs に対して指定されています"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> または %<long%> は %qs に対しては無効です"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed または unsigned の使用は %qs に対しては無効です"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex は %qs に対しては無効です"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "仮引数宣言の中の typedef 宣言は無効です"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qE declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "入れ子になった関数 %qE が %<extern%> と宣言されています"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, fuzzy, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "ネストした関数 `%s' は `extern' に宣言されました"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "`%s' のトップレベルの宣言が `auto' を指定します"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
-#, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
-msgstr ""
-
-#: cp/decl.c:11099
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/decl.c:11111
+#: cp/decl.c:11156
 #, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.c:11169
+#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -46206,410 +46347,410 @@
 msgstr "コンストラクタは virtual 宣言できません"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function %qD without object"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
@@ -46616,78 +46757,78 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -46707,170 +46848,170 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -46882,94 +47023,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "述語は識別子でなければなりません"
@@ -46978,82 +47119,82 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant is too large for %<unsigned long%> type"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -47095,7 +47236,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%qT の削除は定義されていません"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
@@ -47108,7 +47249,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "デストラクタ %qD がメンバテンプレートとして宣言されています"
@@ -47224,45 +47365,45 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "ビットフィールドの幅が %qD 非整数型 %qT です"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "無名構造体が名前つき型の中にありません"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "無名共用体内に非公開メンバ %q+#D があります"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonumous 名前空間の集合体は static でなければなりません"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "メンバがない無名共用体です"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> の戻り型は %qT でなければいけません"
@@ -47271,67 +47412,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> は第一引数として型 %<size_t%> (%qT) をとります"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "`operator delete' の戻り型は `void' でなければなりません"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "`operator delete' は第一引数として `void *' 型をとります"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
@@ -47340,63 +47481,63 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "`%s' が使われましたが未定義です"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "仮引数リストからの仮引数名を欠いています"
@@ -47403,17 +47544,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -47423,128 +47564,128 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "引数がありません"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr ""
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr ""
@@ -47690,72 +47831,72 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "（もしこれがあなたの意図したものでなければ、関数テンプレートは既に宣言済である事を確認し、ここの関数名の後ろに <> を付け足してください） -Wno-non-template-friend でこの警告表示を無効にします"
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "value-initialization of incomplete type %qT"
 msgstr "%qs を不完全型 %qT へ適用することは無効です "
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "共用体がここで定義されています"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD はこの関数内で初期化されずに使用されています"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
@@ -47762,296 +47903,296 @@
 msgid "%q#D should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%qD will be initialized after"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "無効な初期化子"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "基底クラスを持つクラスのオブジェクト用の初期化子リストです"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "無効な参照型です"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %qT is invalid in C++"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "式内で整数がオーバーフローしました"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "variably modified type not allowed in new-expression"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "new に対して無効な型である `void'"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "フィールド '%s' がクラス内に見つかりません"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "関数型に対して new を適用できません"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初期設定子の末尾が本来より早く出現しました"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete での配列サイズが不明です"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
@@ -48063,7 +48204,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -48148,67 +48289,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "警告: "
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -48328,42 +48469,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr ""
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "`%s' のセクションは前方でに宣言されたものと衝突します"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d 個のコンストラクタが見つかりました\n"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "無効な宣言です"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %qD"
 msgid "does not match previous declaration %q#D"
@@ -48372,57 +48513,57 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, fuzzy, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "`%s' の名前引きは変更されました"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, fuzzy, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "`%s' の名前引きは新たな ISO `for' スコープに変わりました"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%s=%s は数値ではありません"
@@ -48429,12 +48570,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr ""
@@ -48441,187 +48582,192 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%s=%s は数値ではありません"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr ""
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr ""
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "`%s' 属性の疑似命令が無視されました"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "`this' は静的メンバ関数から使用できません"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "弱い %q+D は %qE として定義できません"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "構造体がここで定義されています"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "メソッド属性を指定するのは最後のみでなければいけません"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -48642,7 +48788,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -48667,7 +48813,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -48748,7 +48894,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -48977,7 +49123,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -49061,7 +49207,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
@@ -49077,902 +49223,892 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ は複合リテラルを禁じます"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "無効な %qD の使用です"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "非スカラー型"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected expression-list or type-id"
 msgstr "式が予期されます"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "古いスタイルのキャストを使用しています"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| と共に使われる && の周りでは括弧をつけることをお勧めします"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "一つの空の宣言中に、二つの型が指定されています"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "lambda-expression in template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%q#D declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複した %<volatile%> です"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "attributes in parameter array declarator ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ラベル付き文が予期されます"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case ラベル %qE が switch 文の中にありません"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "空の宣言です"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "メンバ関数 %qD 用の無効な初期化子です"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> がクラスの外側で使用されています"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, fuzzy, gcc-internal-format
 #| msgid "%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> は C++0x で意味が変更になります。削除してください"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無効なリンク指定です"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "前時代的な古いスタイルの基底クラス初期化子です"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "識別子が予期されます"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "二進演算内で無効な被演算子です"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "演算子が予期されます"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "cv-qualified type parameter"
 msgstr "無効なパラメータ %qs です"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "マクロ引数リストにあり得ないトークン"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "テンプレート名が予期されます"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "型指定が予期されます"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "型名が予期されます"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> または %<{%> が予期されます"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD は名前空間名ではありません"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -49981,17 +50117,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無効な宣言子です"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -49998,392 +50134,392 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "宣言子が予期されます"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD は名前空間です"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ポインタ演算子が予期されます"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-specifier"
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> または %<...%> が予期されます"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "メソッドは関数ポインタに変換できません"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "構造体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> または %<:%> が予期されます"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "クラス %s 用のファイルを見つけられません。"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD の宣言内に無効なクラス名です"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T の前の定義"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<:%> または %<...%> が予期されます"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -50392,531 +50528,531 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "乗算命令を有効にする"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c method declaration is expected"
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不十分な型情報"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "メンバ関数の名前を欠いています"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option は関数内では許可されていません"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "`%s' が再定義されました"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -50923,92 +51059,92 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD は変数ではありません"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "Code 属性を欠いています"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
@@ -51016,57 +51152,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "`operator delete' の宣言内に多すぎる引数"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, fuzzy, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが少なすぎます"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD はテンプレート関数ではありません"
@@ -51079,143 +51215,143 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "メンバ関数 %qD は %qT 内では宣言されていません"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "shadowed declaration is here"
 msgid "friend declaration here"
 msgstr "隠された宣言はここです"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <無名>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "重複したラベル %qD です"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -51222,17 +51358,17 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 用のデフォルト引数がありません"
@@ -51240,47 +51376,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "仮引数リスト中の `void' はリスト全体を占めなければなりません"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -51290,57 +51426,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "非テンプレート %q#D のテンプレート定義です"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -51347,7 +51483,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -51354,12 +51490,12 @@
 msgstr[0] "`%s' の宣言は仮引数を覆い隠します"
 msgstr[1] "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
@@ -51368,122 +51504,122 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %q+#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51491,294 +51627,300 @@
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "内部一貫性がありません"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "共用体に可変配列メンバがあります"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -51797,279 +51939,279 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -52081,111 +52223,116 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "不完全な typedef `%s' の使用は不適切です"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -52397,7 +52544,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -52448,7 +52595,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
@@ -52523,314 +52670,314 @@
 msgstr "%qT はテンプレート型ではありません"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -52966,12 +53113,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "Tree 検査: %s があるべき所に %s があります(%s 内, %s:%d)"
@@ -53033,755 +53180,749 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ビットフィールドに `__alignof' が適用されました"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "添字をつけられた値が配列でもポインタでもありません"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "メンバへのポインタ構築の使用でオブジェクトを欠いています"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "組み込み関数 %qs を無効に出来ません"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ はプログラムの中から `::main' を呼び出すことを禁じます"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "関数に対する引数が多すぎます"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "関数への引数が少なすぎます"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "関数ポインタが計算で使われました"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "%s ローテート回数が負の値です"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "%s ローテート回数が負の値です"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "%s ローテート回数 >= 型の幅です"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "%s ローテート回数 >= 型の幅です"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ はポインタと整数との比較を禁じます"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "非浮動小数点引数での順序付けられない比較です"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ポインタ演算で不完全型へのポインタを使うことは無効です"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ は `::main' 関数のアドレスを取ることを禁じます"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type bool"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "register 変数 `%s' のアドレスが要求されました"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "NaN から整数への変換です"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "%s: 全体的な精度の低下"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "キャストによってポインタが示す型の要求アラインメントが増加します"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ は関数ポインタとオブジェクトポインタの間でのキャストを禁じます"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C は共用体型へのキャストを禁じます"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "配列の不正な初期化"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "代入として無効な左辺値です"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   ポインタからメンバ関数への変換で"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "無効なバージョン番号形式"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qE from type %qT to type %qT"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "%qE を型 %qT から型 %qT へ変換できません"
+#| msgid "cannot convert type %qT to type %qT"
+msgid "cannot convert %qH to %qI"
+msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-#| msgid "cannot convert type %qT to type %qT"
-msgid "cannot convert %qH to %qI"
-msgstr "型 %qT から型 %qT へ変換できません"
-
-#: cp/typeck.c:8804
-#, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in return"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert to a pointer type"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "デストラクタから値を返そうとしています"
@@ -53788,56 +53929,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "コンストラクタの関数 try ブロックのハンドラからは return できません"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -54060,148 +54201,148 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "非ワイド文字列から int の配列が初期化されました"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "非ワイド文字列から int の配列が初期化されました"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "char の配列にとって初期化子文字列が長すぎます"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -54629,28 +54770,28 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overflow in array dimension"
 msgid "Bad array dimension at %L"
 msgstr "配列の次元がオーバーフローしました"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -54657,22 +54798,22 @@
 msgid "Simplification error"
 msgstr "gimplification に失敗しました"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -55671,7 +55812,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -55847,7 +55988,7 @@
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -56100,452 +56241,452 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "重複した初期化子"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "-traditional は C++ では受け付けられません"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can%'t set %qE attribute after definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "FPU レジスタ内の機能の値を返す"
@@ -56552,964 +56693,964 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "数値がありません"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter name omitted"
 msgid "A parameter name is required at %C"
 msgstr "仮引数名が省略されています"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "配列の次元を宣言で指定することはできません"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "parameter name missing from parameter list"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "ENTRY statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected statement"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "文が予期されます"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無効なビット列初期化子です"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "'%s' トークンの所で文法エラー"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> が予期されます"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "述語は識別子でなければなりません"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "配列を仮引数リストによって初期化しようとしています"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "VALUE statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close read state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "読み込んだ状態ファイル %s を閉じるのに失敗しました [%s]"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "関数を inline にできません"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD は既に定義されています"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "反復子 `%s' は非整数型です"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "`*' の前に型の名前があるべきです"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "識別子が必要です"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "')' が必要です"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<::%>"
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> が予期されます"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "%<=%> が予期されます"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> が予期されます"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
@@ -57845,27 +57986,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -58191,7 +58332,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "一時オブジェクトへの参照を返そうとしています"
@@ -58201,65 +58342,65 @@
 msgid "Removing call to function %qs at %L"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "式が予期されます"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "誤った move です"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -58379,12 +58520,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -59581,7 +59722,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -61020,12 +61161,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -61265,8 +61406,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -61309,7 +61450,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -61651,182 +61792,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "不十分な型情報"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -63184,7 +63325,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
@@ -63295,7 +63436,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -63672,229 +63813,229 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index must be integer"
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -63903,234 +64044,234 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "expected numeric type"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -64137,12 +64278,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -64150,107 +64291,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -64257,67 +64398,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -64324,7 +64465,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -64332,57 +64473,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -64389,893 +64530,893 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -65714,7 +65855,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -66355,18 +66496,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "言語 %s は認識できません"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -66553,184 +66694,184 @@
 msgid "previously defined here as %s"
 msgstr "前はここで定義されました"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr ""
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD は既に定義されています"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "前はここで定義されました"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%qD was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "関数 %qD が変数として再宣言されました"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "前はここで宣言されました"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "ダンプファイル %s を開けませんでした"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr ""
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr ""
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr ""
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr ""
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "%s を開けません"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "%s を開けません"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "%s を開けません"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "atexit failed"
 msgid "waitpid failed"
 msgstr "atexit に失敗しました"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr ".rpo ファイルの名前を変更しています"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/zh_TW.po
===================================================================
--- gcc/po/zh_TW.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/zh_TW.po	(.../branches/gcc-8-branch)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.8.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2013-06-07 23:29+0800\n"
 "Last-Translator: Wei-Lun Chao <bluebat@member.fsf.org>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@linux.org.tw>\n"
@@ -150,40 +150,40 @@
 msgid "negative insn length"
 msgstr "指令長度為負"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "無法分離指令"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "無效的「asm」："
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "巢狀的組譯風格指示"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "未結束的組譯風格指示"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "%% 字母後缺少運算元號"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "運算元號超出範圍"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "無效的 %%-code"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "「%%l」運算元不是一個標籤"
@@ -194,13 +194,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "錯誤地使用了浮點常數"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1249,27 +1249,27 @@
 msgid "At top level:"
 msgstr "在頂層："
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, fuzzy, c-format
 msgid "In member function %qs"
 msgstr "在中成員函式 %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, fuzzy, c-format
 msgid "In function %qs"
 msgstr "在中函式 %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 #, fuzzy
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    內聯的從 %qs 於 %s:%d:%d"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    內聯的從 %qs 於 %s:%d"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, fuzzy, c-format
 msgid "    inlined from %qs"
 msgstr "    內聯的從 %qs"
@@ -3104,9 +3104,9 @@
 msgid "invalid address mode"
 msgstr "無效的定址模式"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
@@ -3122,7 +3122,7 @@
 msgstr "無效 %%r 值"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3129,13 +3129,13 @@
 msgstr "無效 %%R 值"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
@@ -3166,7 +3166,7 @@
 msgstr "無效 %%U 值"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
@@ -3177,7 +3177,7 @@
 msgstr "無效 %%C 值"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
@@ -3188,7 +3188,7 @@
 msgstr "不明的不可預期重定位"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3199,61 +3199,61 @@
 msgid "invalid operand address"
 msgstr "無效的 %%d 運算元"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%Z code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%z code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operands to %%c code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%M code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p 程式碼的運算元無效"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R 程式碼的運算元無效"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L 程式碼的運算元無效"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U 程式碼的運算元無效"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V 程式碼的運算元無效"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%O code"
@@ -3261,19 +3261,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "無效的運算元輸出程式碼"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "預期的常數無法識別"
 
@@ -3308,7 +3308,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
@@ -3439,8 +3439,8 @@
 msgstr "無效的 const_double 運算元"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3658,99 +3658,99 @@
 msgid "bad output_condmove_single operand"
 msgstr "錯誤的 output_condmove_single 運算元"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "錯誤地使用了 %<restrict%>"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "無效的運算元類型使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "運算元不是 offsettable 記憶體參考，無效的運算元編碼『H』"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "運算元的約束無效"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "無效的控制述詞"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "不明的指令模式"
 
@@ -3789,7 +3789,7 @@
 msgstr "無效的 %%P 運算元"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -3846,7 +3846,7 @@
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -4021,147 +4021,147 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4291,43 +4291,43 @@
 msgid "created and used with different endianness"
 msgstr "建立和使用時使用了不同的高/低位位元組在前設定"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "無效的 %%Y 運算元"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "無效的 %%A 運算元"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "無效的 %%B 運算元"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "無效的 %%C 運算元"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "無效的 %%D 運算元"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "無效的 %%f 運算元"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "無效的 %%s 運算元"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4550,14 +4550,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -4572,7 +4572,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -4580,7 +4580,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -4595,7 +4595,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
@@ -4602,7 +4602,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -4612,13 +4612,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
@@ -4628,18 +4628,18 @@
 msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -4647,23 +4647,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
@@ -4673,7 +4673,7 @@
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -4684,46 +4684,46 @@
 msgid "expected label"
 msgstr "預期的頻道"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "備選 1："
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "備選 2："
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "跳轉至標籤 %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "跳轉至 case 標籤"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  進入 try 區塊"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  進入 catch 區塊"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 msgid "enters OpenMP structured block"
 msgstr "  輸入 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 #| msgid "Generate code for huge switch statements"
 msgid "enters synchronized or atomic statement"
 msgstr "為巨型的 switch 敘述產生程式碼"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -4829,7 +4829,7 @@
 msgid "<statement>"
 msgstr "<statement>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, fuzzy, gcc-internal-format
 msgid "<unknown>"
 msgstr "<unknown>"
@@ -4850,130 +4850,130 @@
 msgid "<unparsed>"
 msgstr "<unparsed>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 #, fuzzy
 msgid "<lambda>"
 msgstr "<lambda"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 #, fuzzy
 msgid "<expression error>"
 msgstr "<expression error>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 #, fuzzy
 msgid "<unknown operator>"
 msgstr "<unknown operator>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 #, fuzzy
 msgid "At global scope:"
 msgstr "於全域範圍："
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 msgid "In static member function %qs"
 msgstr "在中靜態成員函式 %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, fuzzy, c-format
 msgid "In copy constructor %qs"
 msgstr "在中複製建構函式 %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 msgid "In constructor %qs"
 msgstr "在中建構子 %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 msgid "In destructor %qs"
 msgstr "在中解構式 %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 msgid "In lambda function"
 msgstr "在中 lambda 函式"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, fuzzy, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s：在中替代的 %qS：\n"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "%s：在中實體化的 %q#D：\n"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 #, fuzzy
 msgid "%r%s:%d:%d:%R   "
 msgstr "%s:%d:%d：  "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 #, fuzzy
 msgid "%r%s:%d:%R   "
 msgstr "%s:%d：  "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, fuzzy, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "遞迴必要項由替代的 %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, fuzzy, c-format
 msgid "required by substitution of %qS\n"
 msgstr "必要項由替代的 %qS\n"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 #, fuzzy
 msgid "recursively required from %q#D\n"
 msgstr "遞迴必要項從 %q#D\n"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 msgid "required from %q#D\n"
 msgstr "必要項從 %q#D\n"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 msgid "recursively required from here\n"
 msgstr "遞迴必要項從在此"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 msgid "required from here\n"
 msgstr "必要項從在此"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 #, fuzzy
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%s:%d:%d：  [跳過 %d 實體化語境]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 #, fuzzy
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%s:%d：  [跳過 %d 實體化語境]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 #, fuzzy
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d:%d：  在中 constexpr 擴展的 %qs"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 #, fuzzy
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "備選為："
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -5029,52 +5029,52 @@
 msgid "source type is not polymorphic"
 msgstr "來源型態不是 polymorphic"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "單位元減的運算元類型錯誤"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "單位元加的運算元類型錯誤"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的引數類型錯誤"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能對該類型的引數求絕對值"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能對該類型的引數求共軛"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "在中引數到一元！"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "沒有 pre-increment 運算子用於型態"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "沒有 post-increment 運算子用於型態"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "沒有 pre-decrement 運算子用於型態"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "沒有 post-decrement 運算子用於型態"
@@ -5363,11 +5363,11 @@
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "指標賦值"
 
@@ -5548,57 +5548,57 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "不一致分級用於運算子於 %%L 和 %%L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
@@ -5642,12 +5642,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Unequal 字元長度 (%ld/%ld) 在中 %s"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "引數 NCOPIES 的重複 intrinsic 是負 (它的值是 %ld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 #, fuzzy
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "引數 NCOPIES 的重複 intrinsic 太大"
@@ -5923,6 +5923,7 @@
 msgstr "-Xbind-now 與 -Xbind-lazy 不相容"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 #, fuzzy
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "認為使用『-pg』以代替『-p』與 gprof (1)"
@@ -9362,7 +9363,7 @@
 msgstr "在 32 位元邊界上對齊變數"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 #| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
@@ -9926,7 +9927,7 @@
 msgstr "指定範圍的暫存器要讓固定的"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -10801,7 +10802,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "產生遵循給定 ABI 的程式碼"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 #, fuzzy
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "已知 ABIs (用於使用與 -mabi=選項)："
@@ -11307,7 +11308,7 @@
 msgstr "支援 PCLMUL 內建函式和編碼產生"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -11317,12 +11318,12 @@
 msgstr "已知手臂架構 (用於使用與 -march=選項)："
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -11335,47 +11336,47 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "支援 MMX 和 SSE 內建函式及程式碼產生"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 msgid "Make all function calls indirect."
 msgstr "警告關於函式呼叫 elimination"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "函式不能回傳函式"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 #, fuzzy
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "已知 M68K microarchitectures (用於使用與 -mtune=選項)："
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "支援 BMI 內建函式和編碼產生"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "支援 BMI 內建函式和編碼產生"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -11893,7 +11894,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "不宜用選項。 使用 -mvrsave 做為替代"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 #, fuzzy
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr "指定有多少位元組應該被移動內聯之前呼叫出到 memcpy/memmove"
@@ -11902,7 +11903,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -12010,7 +12011,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\t排程編碼用於給定的 CPU"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr "-mtraceback=\t選取全部、部分，或沒有追溯表格"
@@ -12046,7 +12047,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "有效引數到 -mfloat-gprs=："
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr "-mlong-double-<n>\t指定大小的長雙倍 (64 或 128 位元)"
@@ -12140,25 +12141,25 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "使用向量/純量 (VSX) 指令"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "產生載入/儲存多重指令"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12178,19 +12179,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -12206,15 +12207,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12224,16 +12225,16 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "啟用 32-bit multiply 指令"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12243,7 +12244,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "在暫存器中回傳小聚合"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "有效引數到 -mfloat-gprs=："
@@ -12281,14 +12282,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "呼叫 mcount 用於側寫檔之前函式 prologue"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "選擇 ABI 呼叫約定"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 msgid "Select method for sdata handling."
 msgstr "選取方法用於 sdata 處理"
@@ -13132,7 +13132,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "避免重疊目的和位址暫存器於 LDRD 指令"
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 #, fuzzy
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "啟用 unaligned 字詞和 halfword 存取到包裝的資料。"
@@ -13376,14 +13376,26 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%<-mfused-madd%> 被不宜用；使用 %<-ffp-contract=%>做為替代"
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare with loops."
+msgstr "去開關後的循環所能有的最大指令數"
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop"
+msgid "Max number of pairs of load insns for compare."
+msgstr "單一循環最大的剝離數"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
@@ -13394,6 +13406,35 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%<-mcpu=%>被不宜用；使用 %<-mtune=%>或 %<-march=%>做為替代"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\t選取全部、部分，或沒有追溯表格"
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\t指定大小的長雙倍 (64 或 128 位元)"
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+msgid "%qs is deprecated"
+msgstr "%qE 被不宜用"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "選擇 ABI 呼叫約定"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "選取方法用於 sdata 處理"
+
 #: config/rs6000/sysv4.opt:32
 #, fuzzy
 #| msgid "Put read-only data in SECTION"
@@ -13400,6 +13441,12 @@
 msgid "Allow readonly data in sdata."
 msgstr "在 SECTION 中存放唯讀資料"
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "指定執行緒局部存儲偏移量立即數值的位大小"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -14809,110 +14856,173 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "允許 gcc 到產生 SETLB 和 Lcc 指令"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "產生高位位元組在前的程式碼"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "產生低位位元組在前的程式碼"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "指派暫存器前重新調度指令"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "指派暫存器前重新調度指令"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 msgid "Generate conditional move instructions."
 msgstr "啟用條件移動指令用法。"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 msgid "Generate performance extension instructions."
 msgstr "產生位元指令"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 msgid "Generate performance extension version 2 instructions."
 msgstr "使用硬體浮點數轉換指令"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 msgid "Generate string extension instructions."
 msgstr "產生位元指令"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "產生 isel 指令"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 msgid "Generate 16-bit instructions."
 msgstr "產生位元指令"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 msgid "Enable Virtual Hosting support."
 msgstr "啟用 multicore 支援"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 #, fuzzy
 msgid "Known arch types (for use with the -march= option):"
 msgstr "已知手臂架構 (用於使用與 -march=選項)："
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 #, fuzzy
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "已知編碼式樣 (用於使用與 -mcmodel=選項)："
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 msgid "Specify the cpu for pipeline model."
 msgstr "選取編碼式樣"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 #, fuzzy
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "已知 M68K CPUs (用於使用與 -mcpu=選項)："
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
 #, fuzzy
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "已知浮點 ABIs (用於使用與 -mfloat-abi=選項)："
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
+#, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "當所有建構式和解構函式都是私有時給出警告"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "產生 isel 指令"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "產生浮點乘加指令"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "使用配對的單精度浮點指令"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "產生使用 68881 浮點指令的程式碼"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -15991,13 +16101,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "產生載入/儲存多重指令"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-msgid "%qs is deprecated"
-msgstr "%qE 被不宜用"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate tablejump insns"
@@ -18853,8 +18956,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "計算出的值未被使用"
@@ -18885,7 +18988,7 @@
 msgstr "預期的布林值型態"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19385,7 +19488,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE 屬性衝突與屬性 %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -19411,12 +19514,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -19465,9 +19568,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -19480,8 +19583,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -19613,83 +19716,75 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "給函式 %<va_start%> 的參數太少"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid argument to %qD"
 msgstr "錯誤地使用了 %qD"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "不受支援的引數類型到內建函式"
@@ -19696,72 +19791,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "兩者引數到 %<__builtin___clear_cache%>必須是指標"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "trampoline 產生的用於巢狀的函式 %qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, fuzzy, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD 變更的語意在中 GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "無效的記憶體式樣引數到內建"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, fuzzy, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "失敗記憶體式樣無法 stronger 比成功記憶體式樣用於 %<__atomic_compare_exchange%>"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, fuzzy, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "無效的失敗記憶體式樣用於 %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無效的記憶體式樣用於 %<__atomic_load%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無效的記憶體式樣用於 %<__atomic_store%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "non-constant 引數 1 到 __atomic_always_lock_free"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "non-integer 引數 1 到 __atomic_is_lock_free"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
@@ -19768,7 +19863,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack()%>"
@@ -19775,12 +19870,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack_len()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> 的第二個引數必須是 1"
@@ -19787,63 +19882,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "目的格式不支援無限大浮點數"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "目的格式不支援無限大浮點數"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "在定參數的函式中使用了 %<va_start%>"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "錯誤的引數數量到函式 %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "錯誤的引數數量到函式 %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> 的第二個參數不是最後一個具名參數"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, fuzzy, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "未定義的行為時秒參數的 %<va_start%> 被宣告與 %<register%>貯藏體"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%Kfirst 引數的 %D 必須是指標，秒整數常數"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%Klast 引數的 %D 不是整數常數介於 0 和 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, fuzzy, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kattempt 以釋放 non-heap 物件 %qD"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, fuzzy, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kattempt 以釋放 non-heap 物件"
@@ -21026,37 +21121,37 @@
 msgid "conversion to incomplete type"
 msgstr "轉換為不完全類型"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "can%'t 轉換介於向量值的不同的大小"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "需要整數時使用了聚合值"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "需要複數時使用了指標值"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "需要複數時使用了聚合值"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "can%'t 轉換介於向量值的不同的大小"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "can%'t 轉換值到向量"
 
-#: convert.c:1168
+#: convert.c:1170
 #, fuzzy, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "彙總值使用的位置定點被預期"
@@ -21211,12 +21306,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多重 EH 身分被支援只有與組譯器支援.cfipersonality 指令(_P)"
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) 找到在中變數位置"
@@ -21326,12 +21421,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性錯誤：%s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性警告：%s"
@@ -21346,12 +21441,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "影格大小的 %wd 位元組是大於 %wd 位元組"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "無法開啟最後的 insn 傾印檔案 %qs：%m"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "無法關閉最後的 insn 傾印檔案 %qs：%m"
@@ -21361,42 +21456,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大定點常數隱含地截短至定點型態"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較結果始終為 %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "對兩個不匹配的不等比較取 %<or%> 的結果總為 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "對兩個互斥的相等比較取 %<and%> 的結果永遠是 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "假設帶正負號溢位不發生時縮小常數在中比較"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "假設帶正負號溢位不發生時合併常數周圍比較"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, fuzzy, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折疊檢查：原來的樹變更的由折疊"
@@ -21940,28 +22035,28 @@
 msgid "can%'t write PCH file"
 msgstr "can%'t 寫入 PCH 檔案"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -21975,12 +22070,13 @@
 msgid "null pointer dereference"
 msgstr "空指標"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "宣告的在此"
@@ -22480,10 +22576,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -22516,7 +22612,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -22861,257 +22957,262 @@
 msgid "function cannot be instrumented"
 msgstr "%qs 函式無法有引數"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "為非虛方法 %q+D 指定了初始值設定項"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, fuzzy, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "虛擬函式 %q+D"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "不相容的類型在中二進位運算式"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "不相容的類型在中發送"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
 msgstr "對陣列的參照超出範圍"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "return value type mismatch"
 msgstr "欄位初始值設定類型不匹配"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "implicit this pointer type mismatch"
 msgstr "欄位初始值設定類型不匹配"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "型態不匹配在中 nontype 參數包裝"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "不同的參數類型"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type %qT should match type %qT"
 msgstr "類型 %qT 不是由類型 %qT 衍生的"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, fuzzy, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, fuzzy, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -23132,37 +23233,37 @@
 msgid "the extra base is defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23446,30 +23547,35 @@
 msgstr "目標 CPU 不支援 unaligned 存取"
 
 #: multiple_target.c:91
-#, fuzzy, gcc-internal-format
-msgid "default target_clones attribute was not set"
-msgstr "版本屬性並非字串"
+#, gcc-internal-format
+msgid "default %<target_clones%> attribute was not set"
+msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
-msgid "single target_clones attribute is ignored"
-msgstr "%qE 不相容的屬性忽略"
+msgid "single %<target_clones%> attribute is ignored"
+msgstr "%<fast_interrupt%> 屬性指令忽略"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "函式 %q+F 可以永不被複製因為它接收 non-local 前往"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 msgid "default target was not set"
 msgstr "預設引數 %qE 使用 %qD"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -23784,12 +23890,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -24397,22 +24503,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "輸出運算元 %d 必須使用 %<&%> 約束"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data：[%u] 不當的 next_regno 用於清空鏈接 (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data：迴圈在中 regno 鏈接 (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data：[%u] 不當的 oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data：[%u] 非空 reg 在中鏈接 (%s %u %i)"
@@ -24456,7 +24562,7 @@
 msgstr "暫存器的 %qD 用於多重全域暫存器變數"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "衝突與 %qD"
@@ -24696,157 +24802,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D 重新命名的之後被引用在中組譯的"
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "函式回傳了一個函式"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qE 屬性只有套用到變數"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "節點有錯誤的仿本清單"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "節點找不到在中 cgraphhash(_H)"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, fuzzy, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group 並非環狀清單"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group 並非環狀清單"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, fuzzy, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "函式 %q+D 部分的別名週期"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "變數 %q+D 部分的別名週期"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -26015,12 +26121,12 @@
 msgid "control reaches end of non-void function"
 msgstr "控制達到結束的 non-void 函式"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "忽略傳回值的函式宣告的與屬性 warn_unused_result"
@@ -26524,7 +26630,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "向量隨機播放作業將被展開 piecewise"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -26564,92 +26670,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "函式陣列是沒有意義的"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "函式不能回傳函式"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：%s，得到 %s 在 %s，於 %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：不需要 %s，得到 %s 在 %s，於 %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "樹檢查：需要類別 %qs，得到 %qs(%s) 在 %s，於 %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "樹檢查：並未預期類別 %qs，有 %qs (%s) 在中 %s，於 %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：預期的 ompclause %s(_C)，有 %s 在中 %s，於 %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "樹檢查：預期的樹該含有 %qs 結構，有 %qs 在中 %s，於 %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "樹檢查：存取的 elt %d 的 treevec 與 %d elts 在中 %s(_V)，於 %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "樹檢查：存取的 elt %d 的 treevec 與 %d elts 在中 %s(_V)，於 %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 %s 與 %d 運算元在中 %s，於 %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 ompclause %s 與 %d 運算元在中 %s(_C)，於 %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型態被不宜用：%s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "類型已過時"
@@ -26674,242 +26780,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "%s：時間戳記與圖檔案不匹配\n"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%qD 不是相容與 %qD"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "環境變數 %qs 無法定義"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verifygimple 失敗(_G)"
@@ -26934,12 +27040,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "已損壞值側寫檔：%s 側寫檔計數器 (%d 超出 %d) 不一致與 basic-block 計數 (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, fuzzy, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "變數追蹤大小限制超出的與 -fvar-tracking-assignments，重試而無需"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, fuzzy, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "變數追蹤大小限制超出"
@@ -27838,7 +27944,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建議在做為真值的賦值敘述前後加上括號"
@@ -28091,7 +28197,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "索引 %E 指出偏移大於大小的 %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "大小的陣列太大"
@@ -28706,7 +28812,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -28721,22 +28827,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -29284,8 +29390,8 @@
 msgid "wrong type argument to %s"
 msgstr "錯誤的型態引數到 %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常數運算式溢出"
@@ -29928,7 +30034,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "比較介於類型 %qT 和 %qT"
@@ -30010,7 +30116,7 @@
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -30143,47 +30249,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s 有無效的 silicon 修訂"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "-malign-loops 已經過時，請使用 -falign-loops"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之間"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "-malign-jumps 已經過時，請使用 -falign-jumps"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d 未被介於 0 和 %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "-malign-functions 已過時，請使用 -falign-functions"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d 未被介於 0 和 %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "-mbranch-cost=%d 不在 0 和 5 之間"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%> 目前只有支援的於 GNU/Linux"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
@@ -30209,31 +30315,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "不明的 -mdebug-%s 開關"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "不明切換 -mlong-double-%s"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, fuzzy, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "-msingle-float 選項 equivalent 到 -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, fuzzy, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "-msimple-fpu 選項忽略"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, fuzzy, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr "%<-fsplit-stack%> 目前只有支援的於 GNU/Linux"
@@ -30716,8 +30822,8 @@
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
@@ -30797,8 +30903,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 開關的值 %qs 錯誤"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -30912,11 +31018,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -30926,151 +31032,141 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE 屬性只有套用到函式"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%> 的引數無效"
 
-#: config/arc/arc.c:6556
-#, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea 應該被使用與 -mmulticore"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "符號使用的做為即時運算元"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "不當的位址，無法暫存器："
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 屬性允許只有整數常數引數"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "%qE 屬性只有套用到函數型式"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE 屬性只有套用到變數"
@@ -31097,153 +31193,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "選擇子必須是立即數值"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "遮罩必須是一個立即數值"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 屬性引數應該被介於 0 到 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32056,12 +32152,12 @@
 msgid "invalid IACC argument"
 msgstr "無效的 IACC 引數"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs 需要一個常數引數"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "常數引數超過 %qs 的範圍"
@@ -32162,17 +32258,17 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "can%'t 設定位置在中 PCH 檔案：%m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -32179,562 +32275,547 @@
 msgstr "%q+D 的暫存器名無效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "對齊指定的用於函式 %qE"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs 沒有指定類別名"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "不明的暫存器名：%s"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, fuzzy, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-f%s 不受支援：已忽略"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel 不支援在中這個組態"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未編譯入對 %i 位模式的支援"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您選擇的 CPU 不支援 x86-64 指令集"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s 不支援 %s"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= 所帶參數(%s)不正確"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %sarch=%s %s"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= 所帶參數(%s)不正確"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %stune=%s %s"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之間"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, fuzzy, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, fuzzy, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs 並非有效選項到前置處理器"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "選項 (「%s」) 已經指定的"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qT 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "不支援 multilib"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 不是相容與巢狀的函式"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻出現了 SSE 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻有 SSE 向量回傳值，這變更了 ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX，卻出現了 MMX 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX卻回傳 MMX 向量，這變更了 ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與 flexible 陣列成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI 的傳遞聯合與長雙倍已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中回傳"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中傳遞參數"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, fuzzy, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 暫存器回傳與 x87 已停用"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert：%s 與 %s 賦值相容"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 屬性 isn%'t 相容與 -mfentry 用於 32-bit"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支援 fastcall 與巢狀的函式"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支援 2 暫存器  參數用於巢狀的函式"
@@ -32741,317 +32822,317 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "擴充的暫存器沒有高半部分"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "non-integer 運算元使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的參數無效：%s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後一筆引數必須是 2-bit 即時"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fifth 引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引數必須是常數"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "對樹結區段的共享不正確"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE 需要不明 isa 選項"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE 需要 isa 選項 %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後一筆引數必須是即時"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "無效的型態用於製作函式"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "不支援的組合：%s"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33275,7 +33356,7 @@
 msgstr "interruptthread 是可用只有於 fido(_T)"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支援堆疊限制運算式"
@@ -33807,8 +33888,35 @@
 msgid "constant argument out of range for %s"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "此內建函式只在 fr450 上可用"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "此內建函式只在 fr450 上可用"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "巢狀的函式不支援於這個目標"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr "支援編碼產生的 crc32 指令。"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr "啟用符號延伸指令"
 
@@ -33829,46 +33937,64 @@
 msgstr "多重插斷屬性不允許"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "巢狀的函式不支援於這個目標"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "intrinsic register index is out of range"
 msgstr "請求的 init_priority 越界"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+#| msgid "Intrinsic function %s(%d) not recognized"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "內部函式 %s(%d) 無法識別"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "無效的型態用於迭代變數 %qE"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "屬性 %qs 的參數無效"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "屬性 %qs 的參數無效"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "屬性 %qs 的參數無效"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "停用 position-independent 編碼 (PIC) 用於使用在中作業系統內核編碼"
@@ -34084,39 +34210,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE 屬性在類型上被忽略"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 屬性不允許用於自動存儲類別"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34210,12 +34336,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall 末尾有無用字元"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -34265,7 +34391,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vecinsert 只有接受 3 引數(_I)"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -34574,7 +34700,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 回傳向量參照：非標準的 ABI 擴充，不保證相容性"
@@ -34584,7 +34710,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
@@ -34594,12 +34720,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 傳遞向量參照：非標準的 ABI 擴充，不保證相容性"
@@ -34609,30 +34735,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -34653,13 +34779,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -34682,55 +34808,55 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs 是無效的引數到 -mcpu="
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "引數 3 必須是一個 4 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "引數 3 必須是 2-bit 無正負號實字"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "引數 1 必須是映射"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "數字必須是 0 或 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, fuzzy, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "無法解析的過載用於 Altivec 內建 %qF"
@@ -34857,7 +34983,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "堆疊框架太大"
@@ -34867,12 +34993,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "# pragma GCC 目標未被支援用於這個機器"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
@@ -34882,22 +35008,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
@@ -34907,7 +35033,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
@@ -35371,22 +35497,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
@@ -35449,30 +35575,35 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s 只有接受 1 引數"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -35601,175 +35732,175 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "引數必須是常數"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s 只有接受 1 引數"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "%qs 是無效的引數到 -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs 是無效的引數到 -mcpu="
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "%q+D 的第二個參數類型應該是 %<char **%>"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "引數必須是常數"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "內建函式 %s 是只有有效用於儲存格處理器"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "內建函式 %s 未被支援與目前的選項"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "內部錯誤：內建函式 %s 有未預期的傳回類型 %s"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "使用暫存器 r2 和 r5"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -36580,7 +36711,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如預期地被忽略"
@@ -36833,7 +36964,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD 的宣告隱藏了一個全域宣告"
@@ -36843,7 +36974,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD 的宣告隱藏了先前的一個局部變數"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "帶陰影宣告是在此"
@@ -36905,7 +37036,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每個 undeclared 識別碼被報告只一次用於每個函式看來在中"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "標籤 %qE 在所有函式外被參照"
@@ -36935,7 +37066,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "重複的標籤定義 %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複的標籤 %qD"
@@ -37053,7 +37184,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不允許在中不同於函式原型範圍"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -37311,7 +37442,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "貯藏類別指定的用於未命名參數"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "為類型名指定了存儲類別"
@@ -37473,7 +37604,7 @@
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
@@ -37603,7 +37734,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "成員的結構或聯合無法有 variably 已修改型態"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "變數或欄位 %qE 宣告為 void"
@@ -37783,7 +37914,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "定義輸入 %qs 運算式無效在中 C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
@@ -37833,7 +37964,7 @@
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
@@ -37869,7 +38000,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> 重宣告"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定的模式對列舉值來說太小"
@@ -37899,7 +38030,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
@@ -37930,7 +38061,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
@@ -38045,12 +38176,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
@@ -38114,7 +38245,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
@@ -38263,38 +38394,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次數為負"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次數大於或等於類型寬度"
@@ -38326,7 +38457,7 @@
 msgid "to match this %qs"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -38367,7 +38498,7 @@
 msgstr "不明型態名稱 %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -38382,7 +38513,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -38397,8 +38528,8 @@
 msgid "unexpected attribute"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -38440,7 +38571,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要 %<,%> 或 %<;%>"
@@ -38468,7 +38599,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支援 %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字串"
@@ -38534,13 +38665,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列舉表以逗號結尾"
@@ -38670,7 +38801,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "預期 %<}%>之前 %<else%>expected %<}%> before %<else%>預期 %<}%>之前 %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, fuzzy, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> 而無需前一個 %<if%>"
@@ -38704,22 +38835,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要敘述"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建議大括號周圍清空內文在中 %<if%> 敘述"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建議大括號周圍清空內文在中 %<else%> 敘述"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建議明確的大括號到避免模稜兩可的 %<else%>"
@@ -38739,12 +38870,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "無效的迭代變數在中快速列舉類型"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -38771,12 +38902,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "型態的欄位宣告的在此"
@@ -39064,7 +39195,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_complex%>運算元的不同的類型"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
@@ -39124,76 +39255,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "缺少%<=%>(之後 %<setter%>屬性)missing %<=%> (after %<setter%> attribute)缺少%<=%>(之後 %<setter%>屬性)"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "預期的整數運算式"
@@ -39208,53 +39339,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -39276,83 +39407,83 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "預期 %<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "預期 %<class%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多引數"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 屬性引數不是整數常數"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "宣告中同時使用了 %<long%> 和 %<void%>"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -39362,12 +39493,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
@@ -39387,18 +39518,18 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -39408,68 +39539,68 @@
 msgid "invalid proc_bind kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "無效的輸入宣告"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -39484,7 +39615,7 @@
 msgid "expected function name"
 msgstr "預期的函式"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -39495,42 +39626,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
@@ -39540,22 +39671,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
@@ -39565,73 +39696,73 @@
 msgid "not enough perfectly nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -39651,32 +39782,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "預期 %<decltype%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
@@ -39731,47 +39862,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
@@ -39787,7 +39918,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD 類型不完全"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "對 void 運算式的無效使用"
@@ -39912,7 +40043,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "註標的值是 neither 陣列 nor 指標 nor 向量"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "陣列下標不是一個整數"
@@ -39937,7 +40068,7 @@
 msgid "enum constant defined here"
 msgstr "enum 常數定義的在此"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -40040,18 +40171,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "比較與字串實字結果於未規定行為"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比較指標和整數"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -40077,7 +40208,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -40317,7 +40448,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
@@ -40478,7 +40609,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
@@ -40550,7 +40681,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "對非左值陣列的無效使用"
@@ -40626,12 +40757,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "傳統 C 不接受自動的聚合初始化"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "對彈性陣列成員的初始化"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "用寬字串初始化 char 陣列"
@@ -40677,7 +40808,7 @@
 msgid "invalid initializer"
 msgstr "無效的初始值設定"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
@@ -40692,7 +40823,7 @@
 msgid "braces around scalar initializer"
 msgstr "標量初始化帶大括號"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在巢狀的上下文中初始化彈性陣列成員"
@@ -40822,7 +40953,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允許 %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
@@ -40863,7 +40994,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "大小寫標貼不是整數常數運算式"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 標籤出現在開關敘述外"
@@ -40873,17 +41004,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> 標籤未出現在 switch 敘述內"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "中斷敘述使用的與 OpenMP 用於迴圈"
@@ -40910,22 +41041,22 @@
 msgid "expression statement has incomplete type"
 msgstr "運算式敘述類型不完全"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "比較向量與不同的元件類型"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "比較向量與不同的元件號碼的"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "使用 == 或 != 比較浮點數是不安全的"
@@ -40976,7 +41107,7 @@
 msgstr "已排序的比較的指標與空指標"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指標與整數 0 比較大小"
@@ -41006,12 +41137,12 @@
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -41021,26 +41152,26 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD 不是一個成員範本函式"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -41051,18 +41182,18 @@
 msgstr "太多 %qs 子句"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -41069,54 +41200,54 @@
 msgstr "陣列 new 的大小必須有整數類型"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qD 沒有積分或列舉類型型態"
@@ -41136,7 +41267,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE 有無效的型態用於 %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -41146,17 +41277,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -41171,18 +41302,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD 出現一次以上在中資料子句"
@@ -41194,32 +41325,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE 並非變數在中子句 %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE 並非變數在中子句 %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -41240,55 +41371,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -41299,32 +41430,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -41468,7 +41599,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -41546,27 +41677,27 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "從 %qT 到 %qT 的轉換有歧義"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "呼叫多載的 %<%D(%A)%> 有歧義"
@@ -41573,638 +41704,638 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "沒有物件不能呼叫成員函式指標 %E，考慮使用 .* 或 ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "對 %<(%T) (%A)%> 的呼叫沒有匹配"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "對 %<(%T) (%A)%> 的呼叫有歧義"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "模稜兩可的過載用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "無效的運算元到二進位 %s (有 %qT 和 %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "沒有匹配用於三進 %<operator?:%> 在中 %<%E？%E：%E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "預期 %<operator%>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "沒有匹配用於 %<operator[]%> 在中 %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "沒有匹配用於 %<operator%s%> 在中 %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, fuzzy, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "秒運算元到條件式運算子是的型態 %<void%>，但是第三運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, fuzzy, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "第三運算元到條件式運算子是的型態 %<void%>，但是第二運算元是 neither throw-expression nor 的型態 %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, fuzzy, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "運算元到 ?:有不同的類型 %qT 和 %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他結果的條件"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "條件運算式中列舉不匹配：%qT 對 %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "列舉和非列舉類型一起出現在條件運算式中"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> 沒有出現在字尾 %qs 中，嘗試使用字首運算子"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "沒有 %<%D(整數)%>宣告的用於後綴 %qs"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在 %q#T 和 %q#T 間比較"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "沒有相應 deallocation 函式用於 %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "沒有合適的 %<operator %s%> 給 %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "宣告的在此"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "宣告的在此"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D 無法存取"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "將 NULL 做為非指標引數 %P 傳遞給 %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "將 NULL 轉換到非指標類型 %qT"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "轉換 %<false%> 到指標類型用於引數 %P 的 %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "轉換 %<false%> 到指標類型 %qT"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "太多大括號周圍初始設定式用於 %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "無效的使用者定義的轉換從 %qT 到 %qT"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化引數 %P，屬於 %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "轉換到 %qT 從初始設定式清單會使用明確的建構子 %qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "無法將位元段 %qE 繫結到 %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能將緊實的欄位 %qE 繫結到 %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "無法將右值 %qE 繫結到 %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "呼叫到 %qD 使用預設引數用於參數 %P, 該項不是未定義"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函式的引數可能是 format 屬性的備選"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT 是 %qT 的一個不可存取的基礎類別"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "deducing %qT 做為 %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, fuzzy, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (您可以停用這個與 -fno-deduce-init-list)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "常數參考它自己"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  用於 function-style 演員陣容，移除冗餘 %<::%D%>"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "沒有匹配函式用於呼叫到 %<%T::運算子 %T(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "對多載的 %<%s(%A)%> 的呼叫有歧義"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "建構式回傳值"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "解構函式回傳值"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "沒有物件無法呼叫成員函式 %qD"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "傳遞 %qT 時選擇 %qT 而不是 %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "選擇 %qD 而不是 %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  因為前者的引數類型轉換序列更好"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "預設引數不匹配在中過載解析度"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidate 1:%q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidate 2:%q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "無法轉換 %qE 從 %qT 到 %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暫時的約束到 %qD 只有持續直到建構子離開"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -42250,8 +42381,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前一個宣告 %q+#D"
@@ -42296,7 +42427,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "%qD 宣告的在此"
@@ -42380,7 +42511,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, fuzzy, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
@@ -42671,7 +42802,7 @@
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
@@ -42741,7 +42872,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "類型資訊不充分"
@@ -42838,341 +42969,341 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D 不是可用做為 constexpr 函式因為："
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E並非常數運算式"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "運算式 %qE 不指定 constexpr 函式"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "呼叫到 non-constexpr 函式 %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "呼叫有環狀依存性"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右移次數為負"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "可變的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "存取 %qD 成員以代替初始化的 %qD 成員在中常數運算式"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "存取值的 %qE 透過 %qT glvalue 在中常數運算式"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD 已用於它的本身初始設定式"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D 不是常數"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D 是易變的"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD 未被初始化的與常數運算式"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, fuzzy, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "運算式 %qE 有 side-effects"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, fuzzy, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -43220,7 +43351,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "從 %qT 轉換到 %qT 並未提領指標"
@@ -43231,309 +43362,309 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "不能將類型 %qT 轉換為類型 %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "從 %q#T 到 %q#T 的轉換"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, fuzzy, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "結果的轉換被未指定的因為 %qE 超出範圍的型態 %qT"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "不應使用 %q#T 而應使用 %qT"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "無法轉換 %qE 從 %qT 到 %qT"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "需要浮點數值時使用了 %q#T"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "請求從 %qT 轉換到非標量類型 %qT"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "偽解構函式未被呼叫"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "轉換到虛值將無法存取物件的不完整型態 %qT"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中敘述"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "間接取值將無法存取物件的不完整型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "轉換到虛值將無法存取物件的型態 %qT"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中敘述"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, fuzzy, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "隱含的解參考將無法存取物件的型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中敘述"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "間接取值將無法存取物件的 non-trivially-copyable 型態 %qT 在中用於遞增運算式"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "轉換到虛值將無法存取物件 %qE 的不完整型態 %qT"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中秒運算元的條件運算式"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中第三運算元的條件運算式"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中權限運算元的逗號運算子"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中向左運算元的逗號運算子"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中敘述"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, fuzzy, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "變數 %qE 的不完整型態 %qT 將無法被存取在中用於遞增運算式"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "轉換到虛值無法解析位址的多載化函式"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "秒運算元的條件運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "第三運算元的條件運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "右運算元的逗號運算子無法解析位址的多載化函式"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "左運算元的逗號運算子無法解析位址的多載化函式"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "敘述無法解析位址的多載化函式"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "用於遞增運算式無法解析位址的多載化函式"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "秒運算元的條件運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "第三運算元的條件運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "右運算元的逗號運算子是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "左運算元的逗號運算子是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "敘述是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "用於遞增運算式是參考，無法呼叫，到函式 %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "秒運算元的條件運算式沒有任何效果"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "右運算元的逗號運算子沒有任何效果"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "左運算元的逗號運算子沒有任何效果"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "敘述沒有任何效果"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "將 NULL 轉換為非指標類型"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT 的預設類型轉換有歧義"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  備選轉換包括 %qD 和 %qD"
@@ -43575,221 +43706,221 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD 先被宣告為 %<extern%> 後又被宣告為 %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "宣告的 %qF 有不同的異常說明符"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "從先前的宣告 %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
 msgstr "先前的宣告 %q+D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "重新宣告的朋友 %q#D 可能無法有預設模板引數"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "實字運算子模板 %q+D 衝突與原始實字運算子 %qD"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, fuzzy, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "原始實字運算子 %q+D 衝突與實字運算子模板 %qD"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "%q+D 的上一個定義在此"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "%q+D 的上一個宣告在此"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "內建函式 %q+D 未被宣告為函式"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "陰影內建函式 %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "陰影函式庫函式 %q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "函式庫函式 %q#D 重宣告為非函式 %q#D"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "與內建宣告 %q#D 衝突"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "%qD 的宣告隱藏了一個全域宣告"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration %q+#D"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "先前對於 %q+#D 的非函式宣告"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "與內建宣告 %q#D 衝突"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "使內建宣告 %q#D 出現歧義"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "使內建宣告 %q#D 出現歧義"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "無效的輸入宣告"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D 被重新宣告為不同意義的符號"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "範本宣告 %q#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "old declaration %q#D"
 msgstr "全域宣告 %q+#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "前一個宣告 %q+#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D 已在此定義過"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
 msgstr "%q+#D 已在此宣告過"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "%q+#D 的原型"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "追隨 non-prototype 定義在此"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "%q+#D 的早先宣告有 %qL 連結"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "previous declaration with %qL linkage"
 msgstr "%q+#D 的早先宣告有 %qL 連結"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in %q+#D"
 msgid "previous specification in %q#D here"
 msgstr "但先前在 %q+#D 中已有指定"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "刪除的定義的 %qD"
@@ -43802,39 +43933,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "『setter』屬性的內容 %qD 衝突與前一個宣告"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "重複定義的 %q#D"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD 衝突與使用的函式"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D 無法宣告的在中類別"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯與 %<gnu_inline%> 屬性"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯而無需 %<gnu_inline%> 屬性"
@@ -43842,1612 +43973,1623 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "重新宣告的朋友 %q#D 可能無法有預設模板引數"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local 宣告的 %q#D 追隨 non-thread-local 宣告"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local 宣告的 %q#D 追隨 thread-local 宣告"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "重新宣告的 %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前一個宣告"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  從這裡"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  離開 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "  輸入範圍的 %q+#D 該項有 non-trivial 解構式"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  進入 catch 區塊"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "  輸入範圍的 %q+#D 該項有 non-trivial 解構式"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  進入 try 區塊"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  輸入 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD 並非型態"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD 使用時未帶範本參數"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T 並非類別"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類別範本，在%q#T 中 "
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "查找的 %qT 在中 %qT 是模稜兩可的"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非類別模板"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非型態"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "範本參數與範本不符"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "協定 %qE 被不宜用"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "要求的對齊邊界不是 2 的某次方"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有建構式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有構構函式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "屬性用於 %q#T 必須追隨 %qs 關鍵字"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一個宣告指定了多個類型"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "對 C++ 內建類型 %qT 的重宣告"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 宣告中缺少類型名"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允許匿名結構"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能為建構式指定 %<explicit%>"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> 被忽略在中這個宣告"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略屬性套用到類別型態 %qT 外側的定義"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略屬性套用到附屬型態 %qT 而無需關聯的宣告"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD 被初始化的 (使用 decltype 做為替代)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D 宣告有 %<extern%> 並被初始化"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D 宣告為範本"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允許將 %<%T::%D%> 定義為 %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允許成員 %qD 的初始化"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "變數 %q#D 有初始值設定，但是類型不完全"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "陣列 %q#D 的元素類型不完全"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合 %q#D 類型不完全，無法被定義"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD 宣告為參照卻未被初始化"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名稱已用於 GNU-style 指定的初始設定式用於陣列"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名稱 %qD 用在 GNU 風格的陣列指定元素初始值設定中"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值設定不受支援"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值設定無法決定 %qD 的大小"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD 缺少陣列大小"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小為 0 的陣列 %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "貯藏大小的 %qD isn%'t 已知"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "貯藏大小的 %qD isn%'t 常數"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  您可以解決方法這個由移除初始設定式"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T 沒有任何 user-provided 預設建構函式"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建構子未被 user-provided 因為它是明確的缺席在中類別本體"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建構子不初始化 %q+#D"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無效類型 %qT 做為類型為 %qT 的向量的初始化設定"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT 的初始化設定必須在大括號內"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E]=%>已用於 GNU-style 指定的初始設定式用於類別 %qT"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "元件的陣列 %q#T 有不完整型態"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "variable-sized 複合實字"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "純量物件 %qD 需求一個元件在中初始設定式"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在中 C++98 %qD 必須被初始化的由建構子，無法由 %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "陣列 %qD 被有括號的字面字串 %qE 所初始化"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "建構式中對靜態成員的初始化無效"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一個類別外的初始化)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "無效的使用的成員函式 (did 您忘記%<()%>?)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隱藏了早先的類型宣告 %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr "無法表單成員指標的 non-class %q#T"
+#| msgid "%qT is an inaccessible base of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs 指定的用於結構欄位"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "無法分解位址"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "來源是的不完整類別型態"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法 %qD 回傳非 Java 類型 %qT"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在夥伴宣告中定義明確特例化 %qD"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本範本的宣告中對範本識別碼 %qD 的使用無效"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "夥伴範本特例化 %qD 中不允許出現預設參數"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "實字運算子與 C 鏈結"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 有無效的引數清單"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "浮點數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, fuzzy, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
+
+#: cp/decl.c:8996
+#, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> 必須回傳 %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隱含宣告的 %qD 的定義"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "定義的 explicitly-defaulted %q+D"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D 明確的缺席在此"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成員函式 %q#D 未在類別 %qT 中宣告"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的不完整型態"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> 所需自 in-class 初始化的靜態資料成員 %q#D 的 non-integral 型態"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的 non-literal 型態"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "類別中對具有非整數類型 %qT 的靜態資料成員的初始化無效"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允許在類別內初始化非常數靜態成員 %qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允許初始化成員常數 %qD，因為它有非整數的類型 %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "陣列 %qD 的大小具有非整數類型 %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "陣列 %qD 的大小為負"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "陣列大小為負數"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允許大小為 0 的陣列"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++禁止變數長度陣列 %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++禁止變數長度陣列"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "變數長度陣列 %qD 被使用"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, fuzzy, gcc-internal-format
 msgid "variable length array is used"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "陣列維數溢出"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "宣告的 %qD 做為陣列的虛值"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "建立陣列的虛值"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "宣告的 %qD 做為陣列的函式"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "建立陣列的函式"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "宣告的 %qD 做為陣列的參考"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "建立陣列的參考"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "宣告的 %qD 做為陣列的函式成員"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "建立陣列的函式成員"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "宣告多維陣列必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "為建構式指定回傳值無效"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "為 %<operator %T%> 指定了回傳值"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名變數或欄位宣告為 void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "變數或欄位宣告為 void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "無效的使用的限定名稱 %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "無效的使用的限定名稱 %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "無效的使用的限定名稱 %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T 並非類別或命名空間"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD 未宣告為成員"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少宣告識別碼：使用了保留字 %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "宣告的 %qD 做為 %<typedef%>"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "宣告的 %qD 做為參數"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs 的宣告指定了兩個以上的資料類型"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允許宣告無類型的 %qs"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> 或 %<unsigned%>無效的用於 %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> 和 %<unsigned%>指定的一起用於 %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> 無效的用於 %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> 無效的用於 %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> 無效的用於 %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> 或 %<short%>無效的用於 %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>，%<int%>，%<short%>，或 %<char%>無效的用於 %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> 或 %<short%>指定的與字元用於 %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> 和 %<short%>指定的一起用於 %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> 或 %<long%>無效的用於 %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "為 %qs 使用 long、short、signed 或 unsigned 無效"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "對 %qs 而言無效的複數"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "參數宣告中出現的 typedef 宣告無效"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "貯藏類別指定的用於模板參數 %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "為參數宣告指定了無效的存儲類別"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "巢狀的函式 %qE 宣告 %<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "為參數 %qs 指定了存儲類別"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在頂層將 %qs 宣告為 %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函式作用欄位的 %qs 隱含為 auto，卻被宣告為 %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "為夥伴函式宣告指定了無效的存儲類別"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.c:11095
-#, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
-msgstr ""
-
-#: cp/decl.c:11099
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/decl.c:11111
+#: cp/decl.c:11156
 #, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.c:11169
+#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -45454,253 +45596,253 @@
 msgstr "建構式不能被宣告為虛函式"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -45707,162 +45849,162 @@
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
@@ -45869,79 +46011,79 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
@@ -45961,177 +46103,177 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "轉換到參考到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -46143,95 +46285,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -46240,77 +46382,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "無效的函式宣告"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "無效的成員函式宣告"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -46350,7 +46492,7 @@
 msgid "deleting %qT is undefined"
 msgstr "刪除 %qT 未定義"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D 宣告為範本"
@@ -46363,7 +46505,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "解構函式 %qD 被宣告為一個成員範本"
@@ -46476,45 +46618,45 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "寬度的 bit-field %qD 有 non-integral 型態 %qT"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "匿名結構不在具名類型內"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "匿名聯合中出現私有成員 %q+#D"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "命名空間欄位的匿名聚合必須是靜態的"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "匿名聯合沒有成員"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> 必須回傳 %qT"
@@ -46523,67 +46665,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, fuzzy, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "第一個參數的 %<operator new%> 無法有預設引數"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> 的第一個參數類型為 %<size_t%> (%qT)"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> 必須回傳 %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> 的第一個參數類型為 %qT"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT 宣告的與更大可視性比型態的它的欄位 %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
@@ -46592,64 +46734,64 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D 未指明非限定類型，所以它不做為外部連結"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, 宣告的使用本地型態 %qT，被使用但是永不定義"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D 衝突與前一個宣告"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "前一個宣告 %q+#D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (或=0) 避免這個錯誤與變更在中 mangling"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了內聯函式 %q+D 但從未定義過"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "參數 %P (屬於 %q+#D)缺少預設引數"
@@ -46656,17 +46798,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -46677,113 +46819,113 @@
 msgid "with"
 msgstr "與"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "沒有參數"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, fuzzy, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, fuzzy, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "明確的轉換運算子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, fuzzy, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, fuzzy, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, fuzzy, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "範圍的 enums 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, fuzzy, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, fuzzy, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, fuzzy, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "強制變更控制項 (強制變更/最後的) 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, fuzzy, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "非靜態資料成員初始設定式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, fuzzy, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, fuzzy, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, fuzzy, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "巢狀名指定中使用了不完全的類型 %qT"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "對 %<%T::%D%> 的參照有歧義"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD 不是 %qD 的成員"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%> 尚未宣告"
@@ -46930,363 +47072,363 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(如果這不是什麼您預想的，確定函式模板已宣告的和加入<>之後函數名稱在此) "
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "value-initialization 的不完整型態 %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "無法 value-initialize 陣列的不明約束 %qT"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "value-initialization 的參考類型 %qT"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "聯合定義的在此"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD 應該被初始化的在中成員初始值清單"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D 將隨後被初始化"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基礎類別 %qT 將在"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  基礎類別 %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  時初始化的在此"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "多重初始化施用於 %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "多重初始化施用於基底 %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化用於多重成員的 %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基礎類別 %q#T 應該是明確的初始化的在中複製建構函式"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D 是一個靜態資料成員；它只能在定義時被初始化"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "對沒有基礎類別的 %qT 的無名初始化"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "對使用了多繼承的 %qT 的無名初始化"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD 既是一個直接基礎類別又是一個間接虛基礎類別"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全類型 %qT 沒有成員 %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "參照位元段 %qD 指標無效"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "對非靜態資料成員 %qD 的無效使用"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "整數溢出"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "變數「%s」在 %L 處上下文中必須是常數"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "對 new 而言類型 %<void%> 無效"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%> %q#T 時常數未初始化"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合適的 %qD，在類別 %qT 中"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "對成員 %qD 的請求有歧義"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "parenthesized 初始設定式在中陣列新"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用於參照類型"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用於函式類型"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值設定在完成之前結束"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 時陣列大小不明"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "刪除物件的抽象類別型態 %qT 該項有 non-virtual 解構式將造成未定義的行為"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "刪除物件的 polymorphic 類別型態 %qT 該項有 non-virtual 解構式也許造成未定義的行為"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
@@ -47298,7 +47440,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -47382,68 +47524,68 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(如果您使用 %<-fpermissive%>，G++ 會接受您的程式碼，但是允許使用未定義的名稱是過時的風格)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, fuzzy, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "mangling typeof，使用 decltype 做為替代"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, fuzzy, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "mangling __underlying_type"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, fuzzy, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "mangling 不明定點型態"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "mangling %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "省略的 %<?:%> 中運算元不能被修飾"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, fuzzy, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "字串實字在中函式模板簽名"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD 修飾後的名稱將在 GCC 的未來版本中有變化"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -47563,46 +47705,46 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D 衝突與前一個宣告"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D 隱藏了 %q#T 的建構式"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D 的宣告隱藏了一個參數"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "全域宣告 %q+#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -47611,62 +47753,62 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "%qD 的名稱查閱已變更"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  在 ISO 標準規則下匹配此 %q+D"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  在舊規則下匹配此 %q+D"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, fuzzy, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "名稱查找的 %qD 變更的用於 ISO %<for%> 範圍"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "  在 %q+D 使用過時的繫結"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -47674,12 +47816,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "using 宣告不能指定一個範本識別碼。請嘗試 %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "不允許在 using 宣告中使用命名空間 %qD"
@@ -47686,183 +47828,189 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT 不是一個命名空間"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD 已在此作用欄位中宣告過"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD 未宣告"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> 指定了解構函式"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> 在 %qT 內指定了建構式"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "沒有與 %<%T::%D%> 匹配的成員，在 %q#T 中"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD 的宣告中有明確的限定"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD 應當已在 %qD 內部宣告過"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD 屬性是無意義的自從成員的匿名命名空間提取本機符號"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定 %qD 屬性被忽略"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空間搜尋的用於 %qE"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建議的替代方案："
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "建議的替代方案："
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%<this%> is unavailable for static member functions"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "靜態成員函式中不能使用 %<this%>"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D 無法定義 %qE"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "結構定義的在此"
 
-#: cp/name-lookup.c:6476
-#, fuzzy, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
-msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
+#: cp/name-lookup.c:6687
+#, gcc-internal-format
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
+msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "這裡不允許命名空間別名 %qD，假定為 %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法屬性必須被指定的於結束只有"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX 進入 pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX 離開 pop_everything ()\n"
@@ -47882,7 +48030,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -47907,7 +48055,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "要求用於成員 %qE 在中 non-class 型態 %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>未被宣告"
@@ -47987,7 +48135,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮點實字無法出現在中 constant-expression"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "演員陣容到型態不同於積分或列舉類型型態無法出現在中 constant-expression"
@@ -48211,7 +48359,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "無法找到字串實字運算子 %qD 與 %qT，%qT 引數"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "預期的宣告"
@@ -48292,7 +48440,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "範圍 %qT 之前 %<~%>並非 class-name"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
@@ -48307,872 +48455,862 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名 %qD 用於解構函式宣告"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, fuzzy, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "找到 %<:%>在中 nested-name-specifier，預期 %<::%>"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype 評估到 %qT，該項並非類別或列舉類型型態"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "巢狀名指定中使用了不完全的類型 %qT"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD 不是一個範本"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "類型可能無法被定義在中演員陣容"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ 不允許複合字面值"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "錯誤地使用了 %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>並非類別成員"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, fuzzy, gcc-internal-format
 msgid "non-scalar type"
 msgstr "non-scalar 型態"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++不允許 %<alignof%> 與 non-type"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "類型可能無法被定義在中 %<noexcept%> 運算式"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "類型可能無法被定義在中 new-expression"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的類型識別碼後面不能出現陣列邊界"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要運算式類型"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 宣告中的運算式必須具有整數或列舉類型"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "使用舊式的類型轉換"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>運算子被視為兩正確角度中括號在中 C++11"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建議 parentheses 周圍 %<>>%>運算式"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++不允許 ?:與省略的中間運算元"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
 #, fuzzy, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "類型可能無法被定義在中條件"
+
+#: cp/parser.c:10119
+#, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "lambda-expression 在中 unevaluated 語境"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "lambda-expression 在中 unevaluated 語境"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "預期的結束的 capture-list"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %<this%> 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "範圍的 enums 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+#D 宣告的在此"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "擷取的變數 %qD 與 non-automatic 貯藏體持續時間"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %qD 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明確的 by-reference 擷取的 %qD 冗餘與 by-reference 擷取預設"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複的 %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "預期 labeled-statement"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 標籤 %qE 未出現在 switch 敘述中"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, fuzzy, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "需要 %<typename%> 之前 %qE 因為 %qT 是附屬範圍"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>名稱建構子，不是型態"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> 運算式的型態 %qT 有不完整型態"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, fuzzy, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "range-based %<for%> 運算式的型態 %qT 有 %<end%>成員並不是 %<begin%>"
-
-#: cp/parser.c:12063
-#, fuzzy, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "range-based %<for%> 運算式的型態 %qT 有 %<begin%>成員並不是 %<end%>"
-
-#: cp/parser.c:12115
-#, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多餘的 %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>無法於起始部分的區塊"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合宣告和函式定義"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "預期的宣告"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "無效的初始設定式用於成員函式 %qD"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> 使用的外側的類別"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> 變更平均在中 C++11; 請移除它"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D 無效，在 %q#T 中"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "類別定義不能被宣告為夥伴"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, fuzzy, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無效的連繫規格"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "類型可能無法被定義在中 %<decltype%> 運算式"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有建構子需成員初始設定式"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代錯誤的舊式基礎類別初始值設定"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(限定的初始值設定隱含地是一個類型)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介於 %<「」%>和字尾識別碼"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "預期的字尾識別碼"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "預期的清空字串之後 %<operator%> 關鍵字"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "無效的運算元在中三進作業"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "預期的運算子"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無效的使用的模板模板參數 %qT"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "預期 template-id"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以 %<<::%> 開始一個範本引數清單"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> 是 %<[%> 的另一種拼法。請在 %<<%> 和 %<::%> 間加上空格"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用 %<-fpermissive%> G++將接受您的編碼)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "範本引數表語法錯誤"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "預期 template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用 %<%T::template %D%> 來表示這是一個範本"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "明確的實體化不應該使用 %<inline%> 說明符"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化範本有 C 連結"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "預期的型態說明符"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "預期 template-id 用於型態"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "預期 type-name"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用於範圍的 enum 必須不使用 %<%D%>關鍵字"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣告 %qD 不宣告任何事"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "屬性忽略的於 elaborated-type-specifier 該並非前置宣告"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD 是列舉類型模板"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "預期 %<;%>或 %<{%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "無法加入列舉值清單到模板具現化"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "宣告的 %qD 在中命名空間 %qD 該項不封閉 %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD 宣告出現在 %qD 中，而後者並不包含 %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "額外合格不允許"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而無需名稱"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必須使用簡單的識別碼"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "列舉量不能有屬性 %C"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "範本識別碼不允許出現在 using 宣告中"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "存取宣告被不宜用在中 favour 的 using-declarations；建議：加入 %<using%> 關鍵字"
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "類型可能無法被定義在中別名模板宣告"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition 未被允許在此"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函式定義中不允許出現 asm 指定"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "預期的建構子、解構式，或類型轉換"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "預期的初始設定式"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "初始設定式提供的用於函式"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函式 %q+D 重宣告為內聯的"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "陣列邊界不是一個整數常數"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "無法定義成員的附屬 typedef %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>並非型態"
@@ -49181,17 +49319,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無效的宣告子"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "將建構式做為範本用法無效"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用 %<%T::%D%> 而不是 %<%T::%D%> 來以限定名指定建構式"
@@ -49198,388 +49336,388 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%q+D 在宣告前使用"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "預期的宣告子"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD 是一個命名空間"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "無法表單成員指標的 non-class %q#T"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "預期 ptr-operator"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "無效的使用的 %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "類型可能無法被定義在中模板引數"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "預期 type-specifier"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "預期 %<,%>或 %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "預設參數只允許出現在函式參數中"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++不允許 C99 指定的初始設定式"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "預期 class-name"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "預期 %<;%>之後結構定義"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "預期 %<{%>或 %<:%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "無法指定 %<override%> 用於類別"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "全域合格的類別名稱無效"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "限定名稱不名稱類別"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD 的宣告中類別名無效"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "明確特例化前必須有 %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "無法解析 typename 型態"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T 的上一個定義"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "在中 C++03 class-key 必須被使用時宣告朋友"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函式定義上有 pure 指定"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "無效的 pure 說明符 (只有 %<=0%>被允許)"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "brace-enclosed 初始設定式未被允許在此"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> 指定的一次以上在中 base-specified"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超過一個存取說明符在中 base-specified"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(基礎類別隱含地是一個類型)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "動態異常規格被不宜用在中 C++0x; 使用 %<noexcept%> 做為替代"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要識別碼或 %<(%>"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%>不是可用在中 Objective-C 1.0"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "異動作業運算式無法出現在中 constant-expression"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -49588,412 +49726,412 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "啟用 multiply 指令"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "沒有宣告任何東西"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -50000,113 +50138,113 @@
 msgstr "%qD 不是一個成員範本函式"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "垃圾於結束的 %<# pragma GCC pchpreprocess%(_P)>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "# pragma GCC 選項未被允許內部函式"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "資料成員 %qD 不能是成員範本"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "明確特例化出現在非命名空間作用欄位 %qD 中"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "所包含的類別範本並未被明確特例化"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空間內對 %qD 的特例化"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  從 %q+#D 的定義"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "名稱的類別陰影模板模板參數 %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT 的實體化在特例化之後"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "在不同命名空間中特例化 %q#T"
@@ -50113,67 +50251,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT 的實體化在 %qT 的特例化之後"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "模板特殊化的 %qD 不允許由 ISO C++"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD 的特例化在實體化之後"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD 不是一個函式範本"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD 並非變數"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "範本識別碼 %qD(屬於 %q+D)不匹配任何範本宣告"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, fuzzy, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "發現 %d %<template<>%>，需要 %d 用於專用化成員函式模板"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧義的範本特例化 %qD (為 %q+D)"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -50180,24 +50318,24 @@
 msgstr "在初次使用後明確特例化 %qD"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "在之前宣告的在此"
@@ -50204,60 +50342,60 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "範本識別碼 %qD 出現在基本範本的宣告中"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "明確初始化中出現了範本參數清單"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "為明確實體化提供的定義"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太少"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD 的明確特例化必須由 %<template <>%> 引入"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "明確特例化時指定了預設參數"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD 不是一個範本函式"
@@ -50270,162 +50408,162 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隱含宣告的特殊成員函式"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成員函式 %qD 未在 %qT 中宣告"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%L 處 ACOS 的參數必須在 -1 和 1 之間"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基底初始設定式擴展 %<%T%>不含任何參數包裝"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "擴展胚騰 %<%T%>不含任何引數包裝"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "擴展胚騰 %<%E%>不含任何引數包裝"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "參數包裝無法展開的與 %<...%>："
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到範本參數："
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "參數包裝引數 %qE 必須是於結束的模板引數清單"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "參數包裝引數 %qT 必須是於結束的模板引數清單"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "型態 %qT 的模板引數 %qE 依存於模板參數"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "局部特化的 %qT 之後實體化的 %qT"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 沒有預設參數"
@@ -50433,48 +50571,48 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "參數包裝 %qE 必須是於結束的模板參數清單"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "預設模板引數可能無法被已用於函式模板朋友重新宣告"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "預設模板引數可能無法被已用於函式模板朋友宣告"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "預設模板引數可能無法被已用於函式模板而無需 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "預設模板引數可能無法被已用於局部特化"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "參數 %qD 被宣告為 void"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "範本類別沒具名字"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
@@ -50484,74 +50622,74 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD 範本宣告無效"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "對非範本 %q#D 的範本定義"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 級的 %q#D 範本參數，卻給出了 %d 級"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 個範本參數，為 %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "得到 %d 個範本參數，為 %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  但實際需要 %d 個"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "模板引數到 %qD 不匹配原來的模板 %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用模板<>用於明確的特殊化"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT 不是一個範本類型"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD 的宣告中沒有 template 限定"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeclared 與 %d 模板參數"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "前一個宣告 %q+D 使用 %d 模板參數"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "範本參數 %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
@@ -50560,413 +50698,418 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE 並非有效模板引數用於型態 %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必須是成員指標的形式 %<&X::Y%>"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  類型 %qT 和 %qT 有不相容的 cv-qualifiers"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  不匹配的類型 %qT 和 %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  模板參數 %qD 並非參數包裝，但是引數 %qD 是"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  模板引數 %qE 不匹配成員指標常數 %qE"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE 不是 equivalent 到 %qE"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  deduced 衝突類型用於參數 %qT (%qT 和 %qT)"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 衝突值用於 non-type 參數 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  無法轉換 %qE (型態 %qT) 輸入 %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT 未被衍生自 %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板參數的模板模板引數是不一致與其他 deduced 模板引數"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  無法 deduce 模板用於 %qT 從 non-template 型態 %qT"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  模板引數 %qE 不匹配 %qD"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為字面字串不能用在此上下文中"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qE 並非變數"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是物件與外部連結"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為物件 %qD 沒有外部連結"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "內部一致性錯誤"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr "flexible 陣列成員在中聯合"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定義 %q#D 的預設參數"
@@ -50984,280 +51127,280 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -51270,112 +51413,117 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "無效的 non-type 模板引數"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -51585,7 +51733,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "偽解構函式名的限定作用欄位無效"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的類型 %qT 不匹配解構函式名 ~%qT"
@@ -51636,7 +51784,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
@@ -51708,297 +51856,297 @@
 msgstr "%qT 不是列舉類型型態"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "參數包裝 __bases 只有有效在中模板宣告"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "無法套用 %<offsetof%> 到解構式 %<~%T%>"
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD 並非變數在中子句 %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片結束必須是整數"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "太多 %qs 子句"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "靜態假設失敗：%E"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -52127,12 +52275,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "零做為空指標常數"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失敗，於 %s:%d"
@@ -52192,755 +52340,749 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "相同權威的型態節點用於不同的類型 %T 和 %T"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs 用於成員函式無效"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "無效的應用程式的 %<sizeof%> 到 bit-field"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<sizeof%> 到運算式的函數型式"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "無效的應用程式的 %<__alignof%>到 bit-field"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<__alignof%>到運算式的函數型式"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "需位址的暫時的陣列"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "要求用於成員 %qD 在中 %qE，該項是的指標類型 %qT (也許您 meant 以使用 %<->%> ?)"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "對成員 %qD 的請求出現在 %qE 中，而後者具有非類別類型 %qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "對非靜態資料成員 %qE 的使用無效"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "無效的存取到非靜態資料成員 %qD  的空值物件"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "物件類型 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被解構的類型是 %qT，但解構函式卻使用了 %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> 不是 %qT 的成員"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT 不是 %qT 的基礎類別"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD 不是一個成員範本函式"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT 不是一個參照物件的類型"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "無效的使用的陣列索引於成員指標"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "無效的使用的一元 %<*%>於成員指標"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "無效的使用的隱含轉換於成員指標"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "陣列參照缺少下標"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下標運算的左運算元既非陣列也非指標"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用 %qE 時缺少物件"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "無法停用內建函式 %qs"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允許在程式裡呼叫 %<::main%>"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, fuzzy, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必須使用 %<.*%>或 %<->*%> 到呼叫成員指標函式在中 %<%E (...)%>，例如： %<(...->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "太多引數到成員函式 %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "太少引數到成員函式 %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "太多引數到函式 %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "太少引數到函式 %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "太多引數到方法 %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "太少引數到方法 %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "給予函式的引數太多"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "給予函式的引數太少"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "參數 %P (屬於 %qD)的類型 %qT 不完全"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "參數 %P 的類型 %qT 不完全"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定從多載函式轉換到類型 %qT"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算術運算式中使用了 NULL"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "左旋轉計數是負"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, fuzzy, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "右旋轉計數是負"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "左旋轉計數>=寬度的型態"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "右旋轉計數>=寬度的型態"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允許比較指標和整數的值"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "非浮點引數間的無效比較"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "運算元類型 %qT 和 %qT 對二進位 %qO 而言無效"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允許在減法中使用類型為 %<void *%> 的指標"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允許在減法中使用函式指標"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允許在減法中使用參照方法的指標"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指標算術中使用參照不完全類型的指標無效"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "需位址的建構子 %qE"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用 %qE 形成成員函式指標的用法無效。"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  需要一個限定的識別碼"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parentheses 周圍 %qE 無法用來表單成員函式指標"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過提取一個未限定的或帶括號的非靜態成員函式的位址來形成一個成員函式指標。請使用 %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過取已繫結的成員函式的位址來建構成員函式指標。請改用 %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "取臨時變數的位址"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, fuzzy, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "需位址的 xvalue (rvalue 參考)"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允許取函式 %<::main%> 的位址"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能建立參照參照成員 %qD 的指標"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "無法取得位元段 %qD 的位址"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr "需位址的運算式的型態 %<void%>"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++禁止遞減 enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞增指標的型態 %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞減指標的型態 %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求明確暫存器變數 %qD 的位址。"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "請求宣告為 %<register%> 的 %qD 的位址"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer 用於 non-class 型態必須不被 parenthesized"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "運算式清單視為複合式表示式在中初始設定式"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "運算式清單視為複合式表示式在中 mem-initializer"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "運算式清單視為複合式表示式在中 functional 演員陣容"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 運算式清單被看作複合運算式"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "沒有語境到解析型態的 %qE"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "演員陣容從型態 %qT 輸入 %qT 演員陣容暫離限定元"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "staticcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "%qT 使用了局部類型 %qT"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 static_cast 無效"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "從 %qT 轉換到 %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "從 %qT 到 %qT 的轉換損失精度"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "比較介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "從 %qT 到 %qT 的轉換增大了目的類型的對齊需求"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允許在函式指標和物件指標間進行轉換"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它既不是指標，也不是參照，也不是資料成員指標"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它是一個指標函式類型的指標或參照"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允許轉換為陣列類型 %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函式類型 %qT 的轉換無效"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  在求 %<%Q(%#T, %#T)%> 值時"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "指派到陣列從初始設定式清單"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "將 %qT 賦值給 %qT 時類型不相容"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "陣列使用的做為初始設定式"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "無效的陣列指派"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "  在成員函式指標轉換中"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成員指標轉換經由虛基礎類別 %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "  在成員指標轉換中"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到類型 %qT 的轉換無效，從類型 %qT"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "不能從 %qT 轉換到 %qT，為引數 %qP(屬於 %qD)"
+msgid "cannot convert %qH to %qI"
+msgstr "無法轉換 %qT 到 %qT"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "無法轉換 %qT 到 %qT 在中預設引數"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "無法轉換 %qT 到 %qT 在中引數傳遞"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-msgid "cannot convert %qH to %qI"
-msgstr "無法轉換 %qT 到 %qT"
-
-#: cp/typeck.c:8804
-#, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "無法轉換 %qT 到 %qT 在中回傳"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "參數 %qP 的 %qD 也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "參數也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "目標的轉換也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "目標的初始化也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "left-hand 側邊的指派也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在傳遞引數 %P (屬於 %q+D)"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "回傳了一個非左值的參照"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "回傳了對局部變數的 %q+D 的參照"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "解構函式回傳值"
@@ -52947,56 +53089,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能從建構式的異常處理中回傳"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "建構式回傳值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<brace-enclosed initializer list>"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "不一致類型 %qT 和 %qT deduced 用於 lambda 傳回類型"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> 不能回傳 NULL，除非它被宣告為 %<throw()%> (或 -fcheck-new 起作用)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, fuzzy, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "使用暫時的做為 lvalue"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, fuzzy, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "使用 xvalue (rvalue 參考) 做為 lvalue"
@@ -53224,145 +53366,145 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "使用了建構式的語法，但沒有為類型 %qT 宣告建構式"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {} 被不當形式的在中 C++11"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {}"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "運算式在中靜態假設不是整數常數運算式"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int 型陣列由非寬字串初始化"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-array 初始化的從不相容的 wide 字串"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "用以初始化字元陣列的字串太長"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -53797,28 +53939,28 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "不同的字元長度 (%d/%d) 在中陣列建構子於 %L"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -53825,22 +53967,22 @@
 msgid "Simplification error"
 msgstr "gimplification 失敗"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -54878,7 +55020,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "最大值延伸等級達到的與型態『%s』於 %L"
@@ -55056,7 +55198,7 @@
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003:已推遲型態參數於 %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -55314,454 +55456,454 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "重製陣列 spec 用於 Cray 點於 %C"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "在中指標初始化於 %C 時發生錯誤"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C 的初始化不是為指標變數準備的"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "在 %C 處的指標初始化需要「=>」，而不是「=」"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C 處需要一個初始化運算式"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C 處對變數的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "初始化的 allocatable 成分於 %C 未被允許"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "指標成分『%s』的『%s』於 %L 是型態該未被宣告"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "舊式的型態宣告 %s*%d 在 %C 處不被支援"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nonstandard 類型宣告 %s*%d 於 %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "缺少右括號於 %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C 處需要初始化運算式"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C 處需要標量初始化運算式"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Kind %d 不支援用於型態 %s 於 %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C kind 型態參數是用於型態 %s 但是型態於 %L 是 %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "缺少右括號或逗號於 %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Kind %d 未被支援用於字元於 %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Kind 型態參數用於實體於 %L 不同從 kind 型態參數的 typespec"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "第一個參數的 %<operator new%> 無法有預設引數"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "運算式於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "擴充：%C 處的 BYTE 類型"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C 使用到的 BYTE 類型在目標平臺上不可"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008:型態與 intrinsic-type-spec 於 %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "延伸：雙倍複雜於 %C"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "類型名「%s」(於 %C 處)有歧義"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003:類別敘述於 %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "型態名稱『%s』於 %C 衝突與在之前宣告的實體於 %L, 該項有同名"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C 處 IMPLICIT NONE 敘述重複"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "缺少字元範圍在中隱含的於 %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C 處 IMPLICIT 敘述中的字母必須按序排列"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "無法匯入『%s』從主機範圍單位於 %C - 不存在。"
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "『%s』已經匯入的從主機範圍單位於 %C。"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "語法時發生錯誤匯入敘述於 %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "缺少codimension 規格於 %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C 處沒有指定維數"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重複的 %s 屬性，位於 %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "成分在中型態於 %C 必須前繼含有"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s 屬性於 %L 未被允許外側的規格部分的模組"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003:非同步屬性於 %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008:CONTIGUOUS 屬性於 %C"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "保護的於 %C 只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003:保護的屬性於 %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003:值屬性於 %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003:易變的屬性於 %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "多重識別碼提供的與單一名稱=說明符於 %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "隱含地宣告的繫結©函式『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 可能無法是 C 可交流的 kind 雖然共同區塊『%s』是繫結©"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "類型宣告『%s』於 %L 不是 C 可交流的但是它是繫結©"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "變數『%s』於 %L 可能無法是 C 可交流的 kind 但是它是繫結©"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 無法宣告的與繫結©自從它並非全域"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法陣列"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法字元串"
@@ -55768,974 +55910,974 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "符號『%s』於 %L 被標記私人的但是已被給定的繫結標貼『%s』"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "需要還是實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "缺少實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "缺少數字"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "衍生類型於 %C 未被在之前定義的和因而無法出現在中衍生類型定義"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必須不出現兩者於 %C"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C 處需要替代的回傳標籤"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "參數名稱省略"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "名稱「%s」(位於 %C)是一個程序的名稱"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C 處陣列宣告需要另外一維"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C 處參數清單中有非預期的無用字元"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "重製名稱『%s』在中關聯於 %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符號「%s」在 %C 處的參數清單中重複出現"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C 處 RESULT 變數不能與函式同名"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008:繫結©屬性於 %L 可能無法被指定的用於內部程序"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "繫結©屬性於 %C 需求介面與繫結©"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "繫結©程序與名稱可能無法有指標屬性於 %C"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "虛設程序於 %C 可能無法有繫結©屬性與名稱"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "程序『%s』於 %L 已經有基本型式的 %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "語法時發生錯誤程序敘述於 %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "預期『::』之後 binding-attributes 於 %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003:程序指標成分於 %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "語法時發生錯誤程序指標成分於 %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "程序於 %C 必須是在中通用介面"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003:程序敘述於 %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "預期的形式引數清單在中函式定義於 %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "繫結©屬性於 %L 只能使用用於變數或共同區塊"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C 處的 ENTRY 敘述不能出現在 PROGRAM 中"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C 處的 ENTRY 敘述不能出現在 BLOCK DATA 中"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DERIVED TYPE 區塊中"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 IF-THEN 區塊中"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DO 中"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 FORALL 區塊中"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 WHERE 區塊中"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C 處的 ENTRY 敘述不能出現在巢狀的子程式中"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "缺少必要項 parentheses 之前繫結©於 %C"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無效的 C 名稱在中名稱=說明符於 %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "語法時發生錯誤名稱=說明符用於繫結標貼於 %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "缺少關閉同位用於繫結標貼於 %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "用於虛設程序 %s，沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "名稱不允許於繫結©用於摘要介面於 %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Fortran 2008:結束敘述以代替 %s 敘述於 %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 敘述在 %L 處"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 敘述，於 %C"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要塊名「%s」在「%s」運算式中，於 %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "需要標籤「%s」，為 %s 敘述，於 %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中尺寸敘述"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "維度指定的用於 %s 於 %L 之後它的 initialisation"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中 CODIMENSION 敘述"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L 處陣列指定必須延遲"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C 處變數清單中有非預期的無用字元"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "在 %C 處需要「(」"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在 %C 處需要變數名"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray 指標於 %C 有 %d 位元組的精確度；記憶體位址需求 %d 位元組"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在 %C 處需要「)」"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "在 %C 處需要「,」或敘述尾"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "含義未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "可選的未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray 指標宣告於 %C 需求 -fcray-pointer 旗標"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008:CONTIGUOUS 敘述於 %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "存取規格的 %s 運算子於 %C 已指定的"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "存取規格的.%s。運算子於 %C 已指定的"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003:保護的敘述於 %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "私人的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "公用的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "預期的變數名稱於 %C 在中參數敘述"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 敘述中需要 = 符號"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 敘述中需要運算式"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "初始化已經初始化的變數於 %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C 處 PARAMETER 敘述中有非預期的字元"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket 儲存敘述於 %C 追隨前一個儲存敘述"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "值未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003:值敘述於 %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "語法時發生錯誤值敘述於 %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003:易變的敘述於 %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易變的用於 coarray 變數『%s』於 %C, 該項是 use-/ host-associated"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003:非同步敘述於 %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "語法時發生錯誤非同步敘述於 %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "模組程序於 %C 必須是在中通用模組介面"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsic 程序於 %L 無法模組程序"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "模稜兩可的符號在中類型定義於 %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "『%s』在中延伸運算式於 %C 並非衍生類型"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "『%s』無法進階於 %C 因為它是繫結©"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "『%s』無法進階於 %C 因為它是序列型態"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "衍生類型於 %C 只能是私人的在中規格部分的模組"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "衍生類型於 %C 只能是公用的在中規格部分的模組"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "摘要型態『%s』使用的於 %L"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "重複的建構標籤「%s」出現在 %C 處"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定義中需要 ::"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "衍生類型名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray 點於 %C 無法假設的形狀陣列"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003:ENUM 和列舉值於 %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C 處：列舉量超過 C 整數類型"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "列舉值 %L 無法初始化的與整數運算式"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM 定義敘述預期的之前 %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C 處 ENUMERATOR 定義中語法錯誤"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重製 access-specifier 於 %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的 NOPASS 於 %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的回合於 %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "重製指標屬性於 %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "重製 NON_OVERRIDABLE 於 %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "重製已推遲於 %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "預期 access-specifier 於 %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "預期的繫結屬性於 %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE 和已推遲無法兩者出現於 %C"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "指標屬性被必要項用於程序指標成分於 %C"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "『)』預期的於 %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "介面必須被指定的用於已推遲繫結於 %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "程序 (介面) 於 %C 應該被宣告已推遲"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "預期的繫結名稱於 %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "『=>目標』無效用於已推遲繫結於 %C"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "『::』所需的在中程序繫結與明確的目標於 %C"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "預期的繫結目標之後『=>』於 %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "型態『%s』包含已推遲繫結於 %C 不是摘要"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "已經有程序與繫結名稱『%s』用於衍生類型『%s』於 %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "通用於 %C 必須是內部衍生類型含有"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "預期『::』於 %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "預期的通用名稱或運算子描述元於 %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "預期『=>』於 %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "那裡『s 已經 non-generic 程序與繫結名稱 』%s『 用於衍生類型 』%s' 於 %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "繫結於 %C 必須有相同存取做為已經定義的繫結『%s』"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "預期的特定的繫結名稱於 %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "『%s』已經定義為特定的繫結用於通用『%s』於 %C"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "垃圾之後通用繫結於 %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "最後的宣告於 %C 必須是內部衍生類型含有區段"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "衍生類型宣告與最後的於 %C 必須是在中規格部分的模組"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "清空最後的於 %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "預期的模組程序名稱於 %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明程序名稱「%s」於 %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "『%s』於 %C 已經定義為最後的程序！"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "不明屬性在中！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "語法時發生錯誤！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -57084,27 +57226,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "延伸：BOZ 實字於 %L 用來初始化 non-integer 變數『%s』"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "延伸：BOZ 實字於 %L 外側資料敘述和外側整數/真實/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ 實字於 %L 是逐位元已轉送 non-integer 符號『%s』"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術欠位的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術溢位的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術 NaN 的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
@@ -57430,7 +57572,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "建立陣列暫時的於 %L"
@@ -57440,63 +57582,63 @@
 msgid "Removing call to function %qs at %L"
 msgstr "移除呼叫到函式『%s』於 %L"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "需要運算式"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "不當的移動"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "無效的運算元在中 gimple 比較"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -57620,12 +57762,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -58840,7 +58982,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -60295,12 +60437,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "未預期的垃圾之後 $OMP 清理敘述於 %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -60540,8 +60682,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
@@ -60584,7 +60726,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "符號『%s』呈現於多重子句於 %L"
@@ -60926,185 +61068,185 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "!$OMP 做崩潰的迴圈不表單矩形迭代空格於 %L"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "崩潰 !$OMP 做迴圈無法 perfectly 巢狀的於 %L"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP 做無法做當或做而無需迴圈控制於 %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$OMP 做迭代變數必須是的型態整數於 %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$OMP 做崩潰的迴圈不表單矩形迭代空格於 %L"
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "崩潰 !$OMP 做迴圈無法 perfectly 巢狀的於 %L"
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) 與 INTENT(%s) 在 %L 衝突"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "%qE 並非常數運算式"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -62470,7 +62612,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
@@ -62585,7 +62727,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -62962,229 +63104,229 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "Errmsg-variable 於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -63193,232 +63335,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
@@ -63425,12 +63567,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -63438,109 +63580,109 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "impure 變數於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序 (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -63547,70 +63689,70 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
@@ -63617,7 +63759,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -63625,58 +63767,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, fuzzy, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
@@ -63683,902 +63825,902 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，於 %s:%d"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L 處 ICHAR 的參數長度必須為 1"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "指標成分『%s』的『%s』於 %L 是型態該未被宣告"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "衝突在中屬性的函式引數於 %C"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -65022,7 +65164,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree()：無效類型；%s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, fuzzy, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "字元『%s』在中字串於 %L 無法轉換的進入字元 kind %d"
@@ -65677,18 +65819,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "內部函式 %s(%d) 無法識別"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "『dim』引數的 %s intrinsic 於 %L 並非有效尺寸索引"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Deferred-length 字元成分『%s』於 %L 不是未支援"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "指標物件於 %C 不應該被 coindexed"
@@ -65870,178 +66012,178 @@
 msgid "previously defined here as %s"
 msgstr "在之前定義的在此"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "多重 prevailing defs 用於 %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD 已定義"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 msgid "previously defined here"
 msgstr "在之前定義的在此"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "變數 %qD redeclared 做為函式"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "函式 %qD redeclared 做為變數"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 msgid "previously declared here"
 msgstr "在之前宣告的在此"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "位元碼串流：無用資料於結束的符號區段"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, fuzzy, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "無法剖析十六進位數字"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "未預期的檔案名稱 %s 在中鏈結器解析度檔案。預期 %s"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "無法剖析檔案偏移"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, fuzzy, gcc-internal-format
 msgid "unexpected offset"
 msgstr "未預期的偏移"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "無效的列在中解析度檔案"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "無效的解析度在中解析度檔案"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, fuzzy, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "解析度子識別號 "
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "無法讀取 LTO decls 從 %s"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "無法開啟 %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "無法映射 %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "無法讀取 %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, fuzzy, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() 失敗"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 msgid "waitpid failed"
 msgstr "atexit 失敗"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "重新命名.rpo 檔案：%m"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, fuzzy, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "沒有 LTRANS 輸出清單檔名提供"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, fuzzy, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "開啟 LTRANS 輸出清單 %s：%m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, fuzzy, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "寫入 LTRANS 輸出清單 %s：%m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, fuzzy, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "關閉 LTRANS 輸出清單 %s：%m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "無法開啟符號解析度檔案：%m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "錯誤在的期間合併的轉譯單位"
@@ -68776,6 +68918,14 @@
 #~ msgstr "%qE 不是一個類別"
 
 #, fuzzy
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "range-based %<for%> 運算式的型態 %qT 有 %<end%>成員並不是 %<begin%>"
+
+#, fuzzy
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "range-based %<for%> 運算式的型態 %qT 有 %<begin%>成員並不是 %<end%>"
+
+#, fuzzy
 #~ msgid "range-based %<for%> loops are not allowed in C++98 mode"
 #~ msgstr "range-based %<for%> 迴圈未被允許在中 C++98 模式"
 
@@ -68905,6 +69055,9 @@
 #~ msgid "invalid use of Boolean expression as operand to %<operator--%>"
 #~ msgstr "無效的使用的布林表示式做為運算元到 %<operator--%>"
 
+#~ msgid "cannot convert %qT to %qT for argument %qP to %qD"
+#~ msgstr "不能從 %qT 轉換到 %qT，為引數 %qP(屬於 %qD)"
+
 #~ msgid "return-statement with a value, in function returning 'void'"
 #~ msgstr "在回傳「void」的函式中，回傳敘述帶回傳值"
 
Index: gcc/po/id.po
===================================================================
--- gcc/po/id.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/id.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -164,40 +164,40 @@
 msgid "negative insn length"
 msgstr "panjang insn negatif"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "tidak dapat membagi insn"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "'asm': tidak valid"
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "alternatif dialek perakit bertelur"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "alternatif dialek perakit tidak terselesaikan"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "nomor operan hilang setelah %%-letter"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "nomor operan diluar dari jangkauan"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "%%-code tidak valid"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "'%%l' operan bukan sebuah label"
@@ -208,13 +208,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "konstanta pecahan disalah gunakan"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1301,29 +1301,29 @@
 msgid "At top level:"
 msgstr "Di tingkat paling atas:"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "Dalam anggota fungsi %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "Dalam fungsi %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 #, fuzzy
 #| msgid "    inlined from %qs at %s:%d:%d"
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    inlined dari %qs di %s:%d:%d"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 #, fuzzy
 #| msgid "    inlined from %qs at %s:%d"
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    inlined dari %qs di %s:%d"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    inlined dari %qs"
@@ -3209,9 +3209,9 @@
 msgid "invalid address mode"
 msgstr "alamat tidak valid"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3227,7 +3227,7 @@
 msgstr "nilai %%r tidak valid"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3234,13 +3234,13 @@
 msgstr "nilai %%R tidak valid"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
@@ -3271,7 +3271,7 @@
 msgstr "nilai %%U tidak valid"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
@@ -3282,7 +3282,7 @@
 msgstr "nilai %%C tidak valid"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
@@ -3293,7 +3293,7 @@
 msgstr "relokasi unspek tidak diketahui"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3305,61 +3305,61 @@
 msgid "invalid operand address"
 msgstr "alamat tidak valid"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "operan ke kode %%p tidak valid"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "operan ke kode %%s tidak valid"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "operan ke kode %%H/%%L tidak valid"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "operan ke kode %%U tidak valid"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "operan ke kode %%V tidak valid"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3367,19 +3367,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "operan kode keluaran tidak valid"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "konstanta yang diharapkan tidak dikenal"
 
@@ -3415,7 +3415,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
@@ -3549,8 +3549,8 @@
 msgstr "operan const_double tidak valid"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3769,111 +3769,111 @@
 msgid "bad output_condmove_single operand"
 msgstr "operan output_condmove_single buruk"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "penggunaan tidak valid dari %<restrict%>"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "predikat pengontrol tidak valid"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "mode insn tidak diketahui"
 
@@ -3913,7 +3913,7 @@
 msgstr "operan %%P tidak valid"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -3971,7 +3971,7 @@
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -4156,148 +4156,148 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4437,22 +4437,22 @@
 msgid "created and used with different endianness"
 msgstr "dibuat dan digunakan dengan endianness berbeda"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "operan %%Y tidak valid"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "operan %%A tidak valid"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "operan %%B tidak valid"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
@@ -4459,23 +4459,23 @@
 msgid "invalid %%C operand"
 msgstr "operan %%P tidak valid"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "operan %%P tidak valid"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "operan %%f tidak valid"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "operan %%s tidak valid"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4712,14 +4712,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4735,7 +4735,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4744,7 +4744,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4761,7 +4761,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
@@ -4768,7 +4768,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -4778,14 +4778,14 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4797,20 +4797,20 @@
 msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4819,24 +4819,24 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4848,7 +4848,7 @@
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4861,47 +4861,47 @@
 msgid "expected label"
 msgstr "Diduga nama"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "lompat ke label %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "lompat ke case label"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  memasuki blok percobaan"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  mamasuki blok penangkapan"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 #| msgid "  enters OpenMP structured block"
 msgid "enters OpenMP structured block"
 msgstr "  memasuki blok terstruktur OpenMP"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 #| msgid "Generate code for huge switch statements"
 msgid "enters synchronized or atomic statement"
 msgstr "Hasilkan kode untuk pernyataan besar switch"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -5013,7 +5013,7 @@
 msgid "<statement>"
 msgstr "dalam pernyataan"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown src"
 msgid "<unknown>"
@@ -5035,127 +5035,127 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr ""
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 #, fuzzy
 #| msgid "Unknown operator '%s' at %%L"
 msgid "<unknown operator>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 #| msgid "In member function %qs"
 msgid "In static member function %qs"
 msgstr "Dalam anggota fungsi %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 #| msgid "In function %qs"
 msgid "In constructor %qs"
 msgstr "Dalam fungsi %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 #| msgid "In function %qs"
 msgid "In destructor %qs"
 msgstr "Dalam fungsi %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 #| msgid "In member function %qs"
 msgid "In lambda function"
 msgstr "Dalam anggota fungsi %qs"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 #| msgid "explicit instantiation of %q#D"
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 #| msgid "provided for %q+D"
 msgid "required from %q#D\n"
 msgstr "disediakan untuk %q+D"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr ""
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 #| msgid "called from here"
 msgid "required from here\n"
 msgstr "dipanggil dari sini"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "kandidat adalah:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5219,54 +5219,54 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tipe argumen salah ke unary minus"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "tipe argumen salah ke bit-complement"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "tipe argumen salah ke abs"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "tipe argumen salah ke konjugasi"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 #, fuzzy
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "no pre-increment operator for type"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 #, fuzzy
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "no pre-decrement operator for type"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5549,11 +5549,11 @@
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
@@ -5746,59 +5746,59 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tingkat tidak konsisten untuk operator di %%L dan %%L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5844,13 +5844,13 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Panjang karakter tidak sama (%ld/%ld) dalam %s di %L"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argumen NCOPIES dari REPEAT intrinsik adalah negatif di %L"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 #, fuzzy
 #| msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
@@ -6133,6 +6133,7 @@
 msgstr "-Xbind-now dan -Xbind-lazy tidak kompatibel"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -9701,7 +9702,7 @@
 msgstr "Align variabel di sebuah batasan 32 bit"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 #| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
@@ -10280,7 +10281,7 @@
 msgstr "Spesifikasikan jangkauan dari register untuk membuat fixed"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -11188,7 +11189,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Hasilkan kode yang konform ke ABI yang diberikan"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -11734,7 +11735,7 @@
 msgstr "Dukung fungsi dalam dan pembuatan kode PCLMUL"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -11743,12 +11744,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -11761,47 +11762,49 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "Dukung fungsi dalam dan pembuatan kode MMX dan SSE"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 #| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
 msgstr "Penggunaan call dan rtc untuk pemanggilan fungsi dan returns"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support AES built-in functions and code generation"
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "Dukung fungsi dalam dan pembuatan kode AES"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support AES built-in functions and code generation"
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "Dukung fungsi dalam dan pembuatan kode AES"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 #| msgid "Assume code will be linked by GNU ld"
@@ -12342,7 +12345,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "Pilihan ditinggalkan. Gunakan -mvrsave/-mno-vrsave lebih baik"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -12350,7 +12353,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -12474,7 +12477,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "Jadwalkan kode untuk CPU yang diberikan"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "Select full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -12516,7 +12519,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "pilihan untuk -mfloat-gprs tidak valid: '%s'"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "Specify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -12616,25 +12619,25 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 #| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Hasilkan load/store multiple instruksi"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12654,19 +12657,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -12682,15 +12685,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12700,17 +12703,17 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Gunakan instruksi desimal titik pecahan"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12720,7 +12723,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "Kembali kumpulan kecil dalam registers"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr ""
 
@@ -12757,14 +12760,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "Panggil mcount untuk profiling sebelum sebuah prolog fungsi"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "Piling konvensi pemanggilan ABI"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -13637,7 +13639,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "Hindari overlapping tujuan dan alamat register di instruksi LDRD"
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -13886,14 +13888,30 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
+#: config/rs6000/rs6000.opt:334
+#, fuzzy
+#| msgid "Maximum number of errors to report"
+msgid "Max number of bytes to move inline."
+msgstr "Jumlah maksimum dari error untuk dilaporkan"
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
-msgstr ""
+#, fuzzy
+#| msgid "Maximum number of errors to report"
+msgid "Max number of bytes to compare without loops."
+msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare with loops."
+msgstr "Jumlah maksimum dari insns dari sebuah loop tidak terswitch"
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop"
+msgid "Max number of pairs of load insns for compare."
+msgstr "Jumlah maksimum dari pembukaan dari sebuah loop tunggal"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
@@ -13906,6 +13924,36 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "Select full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "Pilih penuh, bagian, atau tidak ada traceback tabel"
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, c-format
+msgid "%qs is deprecated"
+msgstr "%qs sudah ditinggalkan"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Piling konvensi pemanggilan ABI"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "Pilih metode untuk penanganan sdata"
+
 #: config/rs6000/sysv4.opt:32
 #, fuzzy
 #| msgid "Put read-only data in SECTION"
@@ -13912,6 +13960,12 @@
 msgid "Allow readonly data in sdata."
 msgstr "Tempatkan baca-sja data dalam SECTION"
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "Spesifikasikan ukuran bit dari ofset TLS langsung"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -15343,114 +15397,176 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Jangan hasilkan fused kali/tambah instruksi"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "Hasilkan kode dalam mode big endian"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "Hasilkan kode dalam mode little endian"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
 msgstr "Atur penjadwalan instruksi sebelum alokasi register"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
 msgstr "Atur penjadwalan instruksi sebelum alokasi register"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate conditional move instructions."
 msgstr "Hasilkan bit instruksi"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate performance extension instructions."
 msgstr "Hasilkan bit instruksi"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate floating point mathematics using given instruction set"
 msgid "Generate performance extension version 2 instructions."
 msgstr "Hasilkan matematik titik pecahan menggunakan set instruksi yang diberikan"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate string extension instructions."
 msgstr "Hasilkan bit instruksi"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Hasilkan instruksi isel"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate 16-bit instructions."
 msgstr "Hasilkan bit instruksi"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
 msgstr "Aktifkan dukungan multicore"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 #| msgid "Specify the register allocation order"
 msgid "Specify the cpu for pipeline model."
 msgstr "Spesifikasikan pengurutan alokasi register"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 #, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "Peringatkan ketika seluruh konstruktor dan destruktor adalah private"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "Hasilkan instruksi isel"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Hasilkan titik pecahan instruksi perkalian-penambahan"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "Gunakan pasangan-tunggal instruksi titik pecahan"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "Hasilkan kode yang menggunakan 68881 instruksi titik pecahan"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -16585,13 +16701,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Hasilkan load/store multiple instruksi"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, c-format
-msgid "%qs is deprecated"
-msgstr "%qs sudah ditinggalkan"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 #| msgid "Do not generate fused multiply/add instructions"
@@ -19560,8 +19669,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "nilai dihitung tidak digunakan"
@@ -19597,7 +19706,7 @@
 msgstr "diduga bukan tuple"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20138,7 +20247,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE atribut konflik dengan atribut %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
@@ -20168,13 +20277,13 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -20225,9 +20334,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -20240,8 +20349,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -20379,83 +20488,77 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "terlalu sedikit argumen ke fungsi %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid argument to %qD"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported argument to %qD"
@@ -20463,77 +20566,77 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "kedua argumen ke %<__builtin___clear_cache%> harus berupa penunjuk"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 #| msgid "-mstackrealign ignored for nested functions"
 msgid "trampoline generated for nested function %qD"
 msgstr "-mstackrealign diabaikan untuk fungsi nested"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD mengubah semantik dalam GCC 4.4"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid memory model argument to builtin"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -20541,7 +20644,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K penggunakan tidak valid dari %<__builtin_va_arg_pack ()%>"
@@ -20548,12 +20651,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K penggunaan tidak valid dari %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
@@ -20560,66 +20663,66 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "format target tidak mendukung infinity"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "format target tidak mendukung infinity"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> digunakan dalam fungsi dengan argumen tetap"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "jumlah dari argumen ke fungsi %<va_start%> salah"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "parameter kedua dari %<va_start%> bukan argumen bernama terakhir"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "perilaku tidak terdefinisi ketika parameter kedua dari %<va_start%> dideklarasikan dengan penyimpanan %<register%>"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K argumen terakhir dari %K bukan sebuah konstanta integer diantara 0 dan 3"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kmencoba membebaskan sebuah objek bukan heap %qD"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kmencoba membebaskan sebuah objek bukan heap"
@@ -21862,40 +21965,40 @@
 msgid "conversion to incomplete type"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "tidak dapat mengubah diantara nilai vektor dari ukuran yang berbeda"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "nilai bersama digunakan dimana sebuah integer diduga"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "nilai penunjuk digunakan dimana sebuah kompleks diduga"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "nilai bersama digunakan dimana sebuah kompleks diduga"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert between vector values of different size"
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "tidak dapat mengubah diantara nilai vektor dari ukuran yang berbeda"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert value to a vector"
 msgid "can%'t convert value to a vector"
 msgstr "tidak dapat mengubah nilai ke sebuah vektor"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "nilai bersama digunakan dimana sebuah titik tetap diduga"
@@ -22058,12 +22161,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -22177,12 +22280,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut error: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut peringatan: %s"
@@ -22198,13 +22301,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "ukuran frame %wd bytes adalah lebih besar dari %wd bytes"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "tidak dapat membuka berkas dump %qs: %s"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close final insn dump file %qs: %m"
@@ -22215,42 +22318,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "konstanta titik-tetap besar secara implisit dipotong ke tipe titik-tetap"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "perbandingan selalu %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> dari pemeriksaan tidak cocok tidak-sama selalu 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> dari mutually eksklusif test-sama selalu 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mereduksi konstanta dalam perbandingan"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mengkombinasi konstan diantar sebuah perbandingan"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "pemeriksaan fold: pohon asal diubah oleh fold"
@@ -22845,28 +22948,28 @@
 msgid "can%'t write PCH file"
 msgstr "tidak dapat menulis berkas PCH"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -22882,12 +22985,13 @@
 msgid "null pointer dereference"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -23419,10 +23523,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -23456,7 +23560,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -23827,259 +23931,264 @@
 msgid "function cannot be instrumented"
 msgstr "union tidak dapat dibuat transparan"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method %q+D"
 msgid "contains additional virtual method %qD"
 msgstr "penginisialisasi dispesifikasikan untuk metode %q+D bukan virtual"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, gcc-internal-format
 msgid "virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in return"
 msgid "the incompatible type is defined here"
 msgstr "tipe tidak kompatibel dalam kembali"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
 msgstr "Referensi array diluar cakupan"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "Function return value not set"
 msgid "return value type mismatch"
 msgstr "Fungsi mengembalikan nilai tidak diset"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type mismatch in nontype parameter pack"
 msgid "type mismatch in parameter %i"
 msgstr "tipe tidak cocok dalam paket parameter bukan tipe"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type %qT should match type %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "has different parameters in another translation unit"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -24101,7 +24210,7 @@
 msgid "the extra base is defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -24108,7 +24217,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24115,7 +24224,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -24122,7 +24231,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -24129,7 +24238,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24136,7 +24245,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -24435,34 +24544,38 @@
 msgstr "format target tidak mendukung infinity"
 
 #: multiple_target.c:91
-#, fuzzy, gcc-internal-format
-#| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
-msgstr "atribut versi bukan sebuah string"
+#, gcc-internal-format
+msgid "default %<target_clones%> attribute was not set"
+msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan goto tidak lokal"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for %qD"
 msgid "default target was not set"
 msgstr "tidak ada argumen baku untuk %qD"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -24796,13 +24909,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -25447,22 +25560,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "keluaran operan %d harus menggunakan batasan %<&%>"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Buruk nex_regno untuk rantai kosong (%u)"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Loop dalam rantai regno (%u)"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Buruk oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Tidak kosong reg dalam rantai (%s %u %i)"
@@ -25511,7 +25624,7 @@
 msgstr "register digunakan untuk dua variabel register global"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25760,165 +25873,165 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D diubah namanya setelah direferensikan dalam perakitan"
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "function symbol is not function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "titik tidak ditemukan dalam cgraph_hash"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa gagal"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has function type"
 msgid "variable %q+D part of alias cycle"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -27165,13 +27278,13 @@
 msgid "control reaches end of non-void function"
 msgstr "kontrol mencapai akhir dari fungsi bukan void"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute warn_unused_result"
@@ -27699,7 +27812,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -27744,98 +27857,98 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "array dari fungsi tidak berarti"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga kosong dari %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga kelas %qs, memiliki %qs (%s) dalam %s, di %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "pemeriksaan pohon: tidak menduga kelas %qs, memiliki %qs (%s dalam %s, di %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga omp_clause %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga pohon yang berisi struktur %qs, memiliki %qs dalam %s, di %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses elt %d dari tree_vec dengan %d elts dalam %s, di %s:%d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses elt %d dari tree_vec dengan %d elts dalam %s, di %s:%d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari omp_clause %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tipe sudah ditinggalkan"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tipe sudah ditinggalkan"
@@ -27860,245 +27973,245 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "Main variant is not defined"
 msgstr "variabel lingkungan \"%s\" tidak terdefinisi"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "field %qs memiliki tipe tidak lengkap"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -28126,12 +28239,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "%H nilai profile terkorupsi: %s profiler jumlah overall (%d) tidak cocok jumlah BB (%d)"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -29080,7 +29193,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "disarankan parentheses disekitar assignmen digunakan sebagai nilai kebenaran"
@@ -29349,7 +29462,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "ukuran dari array terlalu besar"
@@ -29991,7 +30104,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -30007,22 +30120,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -30590,8 +30703,8 @@
 msgid "wrong type argument to %s"
 msgstr "tipe argumen salah ke abs"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow dalam konstanta ekspresi"
@@ -31275,7 +31388,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
@@ -31360,7 +31473,7 @@
 msgstr[0] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 msgstr[1] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -31497,54 +31610,54 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s memiliki revisi silikon tidak valid"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-loops%s is obsolete, use -falign-loops%s"
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "%salign-loops%s sudah ditinggalkan, gunakan -falign-loops%s"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-jumps%s is obsolete, use -falign-jumps%s"
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "%salign-jumps%s sudah ditinggalkan, gunakan -falign-jumps%s"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, fuzzy, gcc-internal-format
 #| msgid "%salign-functions%s is obsolete, use -falign-functions%s"
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "%salign-functions%s sudah ditinggalkan, gunakan -falign-functions%s"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%salign-loops=%d%s is not between 0 and %d"
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "%salign-loops=%d%s tidak berada diantara 0 dan %d"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sbranch-cost=%d%s is not between 0 and 5"
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s tidak berada diantara 0 dan 5"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -31571,13 +31684,13 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "pilihan -mdebug-%s tidak dikenal"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown switch -mlong-double-%s"
 msgid "unknown switch -mlong-double-%s"
@@ -31584,19 +31697,19 @@
 msgstr "pilihan -mlong-double-%s tidak diketahui"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "pilihan -msingle-float ekuivalen dengan -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "pilihan -msimple-fpu diabaikan"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -32112,8 +32225,8 @@
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -32196,8 +32309,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "nilai buruk %qs untuk -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32315,11 +32428,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32330,132 +32443,122 @@
 msgid "%qE attribute only applies to functions"
 msgstr "atribut %qs hanya berlaku ke fungsi"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "argumen ke %<__builtin_frame_address%> tidak valid"
 
-#: config/arc/arc.c:6556
-#, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea seharusnya digunakan dengan -mmulticore"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required as increment operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "lvalue dibutuh sebagai operan peningkatan"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 #| msgid "Bad address, not register:"
 msgid "insn addresses not freed"
 msgstr "Alamat buruk, bukan register:"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -32462,27 +32565,27 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
@@ -32510,154 +32613,154 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "pemilih harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "argumen atribut `%s' seharusnya berada diantara 0 sampai 255"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33526,12 +33629,12 @@
 msgid "invalid IACC argument"
 msgstr "argumen IACC tidak valid"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs diduga sebuah konstanta argumen"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
@@ -33641,18 +33744,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "tidak dapat menset posisi dalam berkas PCH: %m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "terlalu banyak argumen ke fungsi %qs"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33659,47 +33762,47 @@
 msgstr "nama register tidak dispesifikasikan untuk %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "nama register: %s tidak dikenal"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -33706,564 +33809,549 @@
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "profiling not supported with -mg\n"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "profiling tidak didukung dengan -mg\n"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bit mode tidak terkompile"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU yang anda pilih tidak mendukung set instruksi x86-64"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s tidak mendukung %s"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "nilai (%s) buruk untuk pilihan %sarch=%s %s"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %<%s%> for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "nilai %<%s%> buruk untuk pilihan -mtune="
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "nilai (%s) buruk untuk %stune=%s %s"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_return_address%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "argumen ke %<__builtin_return_address%> tidak valid"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "pilihan -m%s= tidak diketahui dispesifikasikan: '%s'"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "pilihan(\"%s\") telah dispesifikasikan"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify when instructions are allowed to access code"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "Spesifikasikan kapan instruksi diperbolehkan untuk mengakses kode"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qT dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "tidak mendukung multilib"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "argumen vektor SSE tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE vektor kembali tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "argumen vektor MMX tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX vektor kembali tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan struct dengan sebuah anggota array flexible telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "register SSE kembali dengan SSE tidak aktif"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumen register SSE dengan SSE tidak aktif"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 register kembali dengan x87 tidak aktif"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -34271,261 +34359,261 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "register extended tidak memiliki setengah tinggi"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 #| msgid "non-integral used in condition"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "bukan integral digunakan dalam kondisi"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Argumen ke -ffpe-trap tidak valid: %s"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 #| msgid "the third argument must be a 8-bit immediate"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argumen ketiga harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE membutuhkan pilihan isa tidak diketahui"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE membutuhkan pilihan isa %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -34532,85 +34620,85 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown asm flag output %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "unknown architecture specific memory model"
 msgstr "Arsitektur '%s' tidak dikenal"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "argumen yang tidak digunakan dalam $-gaya format"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -34848,7 +34936,7 @@
 msgstr "interrupt_thread hanya tersedia di fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ekspresi batas stack tidak didukung"
@@ -35410,8 +35498,37 @@
 msgid "constant argument out of range for %s"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "fungsi bawaan ini hanya tersedia di fr450"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "fungsi bawaan ini hanya tersedia di fr450"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %qs not supported for MIPS16"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "%s not supported for nested functions"
+msgid "don't support performance extension instructions"
+msgstr "%s tidak didukung untuk fungsi nested"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "don't support string extension instructions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
@@ -35435,11 +35552,11 @@
 msgstr "multiple atribut interupsi tidak diijinkan"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35446,37 +35563,55 @@
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "register tidak valid dalam instruksi"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+#| msgid "Intrinsic function %s(%d) not recognized"
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "Fungsi instrinsik %s(%d) tidak dikenal"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -35704,39 +35839,39 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE attribut diabaikan dalam tipe"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ atribut tidak diijinkan dengan class auto storage"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -35830,12 +35965,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "sampah diakhir dari #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -35889,7 +36024,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert hanya menerima 3 argumen"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -36205,7 +36340,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dikembalikan dengan referensi: ekstensi bukan standar ABI dengan tidak ada garansi kompabilitas"
@@ -36215,7 +36350,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
@@ -36226,13 +36361,13 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dilewatkan dengan referensi: bukan ekstensi standar ABI dengan tidak ada garansi kompabilitas"
@@ -36243,30 +36378,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36288,13 +36423,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36320,60 +36455,60 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argumen dari ATANH di %L harus berada didalam jangkauan -1 ke 1"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
@@ -36507,7 +36642,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "stack frame terlalu besar"
@@ -36517,13 +36652,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target tidak didukung untuk mesin ini"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
@@ -36533,22 +36668,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
@@ -36559,7 +36694,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
@@ -37034,22 +37169,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -37121,34 +37256,39 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s hanya menerima 1 argumen"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "%J definisi alias tidak didukung dalam konfigurasi ini"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -37286,49 +37426,49 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -37335,7 +37475,7 @@
 msgstr "%s hanya menerima 1 argumen"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37342,138 +37482,138 @@
 msgstr "argumen ke fungsi bawaan tidak valid"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "argumen kedua dari %q+D seharusnya %<char **%>"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "third argument to %qs must be 0..12"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "fungsi bawaan ini hanya tersedia di fr450"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qs not supported for MIPS16"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "Gunakan register r2 dan r5"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "tipe abstrak tidak valid %qT untuk %qE"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38338,7 +38478,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "nilai void tidak diabaikan karena ini seharusnya"
@@ -38599,7 +38739,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
@@ -38609,7 +38749,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "deklarasi dari %qD membayangi sebuah lokal sebelumnya"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -38677,7 +38817,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H (Setiap identifier yang tidak dideklarasikan hanya dilaporkan sekali)"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "label %qE direferensikan diluar dari fungsi apapun"
@@ -38709,7 +38849,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "duplikasi deklarasi label %qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "duplikasi label %qD"
@@ -38834,7 +38974,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> tidak diijinkan dalam hal lain selain lingkup prototipe fungsi"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -39107,7 +39247,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
@@ -39291,7 +39431,7 @@
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
@@ -39435,7 +39575,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel atau field %qE dideklarasikan void"
@@ -39630,7 +39770,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
@@ -39682,7 +39822,7 @@
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
@@ -39722,7 +39862,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeklarasi dari %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "mode yang dispesifikasikan terlalu kecil untuk nilai enumerasi"
@@ -39753,7 +39893,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
@@ -39787,7 +39927,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -39917,12 +40057,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -39992,7 +40132,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
@@ -40148,38 +40288,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "jumlah geser kanan >= lebar dari tipe"
@@ -40212,7 +40352,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -40256,7 +40396,7 @@
 msgstr "nama register: %s tidak dikenal"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -40273,7 +40413,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -40291,8 +40431,8 @@
 msgid "unexpected attribute"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -40334,7 +40474,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "diduga %<,%> atau %<,%>"
@@ -40364,7 +40504,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "diduga string literal"
@@ -40435,13 +40575,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "koma di akhir dari daftar pengenumerasi"
@@ -40573,7 +40713,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> tanpa sebuah sebelumnya %<if%>"
@@ -40607,22 +40747,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "diduga pernyataan"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<else%>"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -40645,12 +40785,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "register tidak valid dalam instruksi"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -40679,12 +40819,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -40996,7 +41136,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -41060,83 +41200,83 @@
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%J alamat daerah atribut tidak dapat dispesifikasikan untuk fungsi"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -41153,59 +41293,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41228,95 +41368,95 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Elemen tidak diduga"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "baik %<long%> dan %<void%> dalam penspesifikasi deklarasi"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -41327,13 +41467,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
@@ -41357,19 +41497,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -41381,71 +41521,71 @@
 msgid "invalid proc_bind kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41462,7 +41602,7 @@
 msgid "expected function name"
 msgstr "diduga nama class"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -41473,44 +41613,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41520,22 +41660,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
@@ -41545,76 +41685,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41635,34 +41775,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -41721,48 +41861,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -41779,7 +41919,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "penggunaan tidak valid dari ekspresi void"
@@ -41906,7 +42046,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscrip bukan sebuah integer"
@@ -41931,7 +42071,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -42040,18 +42180,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "perbandingan dengan string literal menghasilkan perilaku yang tidak dispesifikasikan"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "perbandingan diantara penunjuk dan integer"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -42078,7 +42218,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -42328,7 +42468,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast ke penunjuk dari integer dari ukuran yang berbeda"
@@ -42505,7 +42645,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
@@ -42578,7 +42718,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
@@ -42654,12 +42794,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "tradisional C menolak inisialisasi otomatis bersama"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-array terinisialisasi dari string lebar"
@@ -42706,7 +42846,7 @@
 msgid "invalid initializer"
 msgstr "penginisialisasi tidak valid"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
@@ -42721,7 +42861,7 @@
 msgid "braces around scalar initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inisialisasi dari anggota array fleksibel dalam sebuah konteks bertelur"
@@ -42854,7 +42994,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C melarang %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
@@ -42896,7 +43036,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
@@ -42906,17 +43046,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "pernyataan break digunakan dengan OpenMP untuk loop"
@@ -42943,23 +43083,23 @@
 msgid "expression statement has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "membandingkan titik pecahan dengan == atau != adalah tidak aman"
@@ -43012,7 +43152,7 @@
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
@@ -43044,12 +43184,12 @@
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -43060,27 +43200,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -43093,19 +43233,19 @@
 msgstr "%Hterlalu banyak %qs clauses"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -43112,57 +43252,57 @@
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "zero length array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "negative length in array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -43183,7 +43323,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -43194,17 +43334,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -43219,18 +43359,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -43243,33 +43383,33 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -43292,63 +43432,63 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -43360,32 +43500,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -43534,7 +43674,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43619,28 +43759,28 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 #| msgid "conversion to %qT from boolean expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%D(%A)%> adalah ambigu"
@@ -43647,676 +43787,676 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "pointer-ke-anggota fungsi %E tidak dapat dipanggil tanpa sebuah objek; pertimbangkan menggunakan .* atau ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "tidak ada yang cocok untuk panggilan ke %<(%T) (%A)%>"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "panggilan dari %<(%T) (%A)%> adalah ambigu"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous conversion for array subscript"
 msgid "ambiguous overload for "
 msgstr "konversi ambigu untuk array subscript"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s (have %qT and %qT)"
 msgid " (operand types are %qT and %qT)"
 msgstr "operan ke binari %s tidak valid (memiliki %qT dan %qT)"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "User operators:\n"
 msgid "ternary %<operator?:%>"
 msgstr "Operator pengguna:\n"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 #| msgid "%s for ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%s untuk ternary %<operator?:%> dalam %<%E ? %E : %E%>"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator%s%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E%s%>"
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E%s%>"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Bad operator"
 msgid "%<operator[]%>"
 msgstr "Operator buruk"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator[]%> in %<%E[%E]%>"
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%s untuk %<operator[]%> dalam %<%E[%E]%>"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %qs in %<%s %E%>"
 msgid "%qs in %<%s %E%>"
 msgstr "%s untuk %qs dalam %<%s %E%>"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%E %s %E%>"
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%E %s %E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "%s for %<operator%s%> in %<%s%E%>"
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s untuk %<operator%s%> dalam %<%s%E%>"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan kedua ke operator kondisional bertipe %<void%>, tetapi operan ketika bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "operan ketiga ke opertor kondisional bertipe %<void%>, tetapi operan kedua bukan sebuah throw-expression ataupun bertipe %<void%>"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "operan ke ?: memiliki tipe berbeda %qT dan %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "enumeral tidak cocok dalam ekspresi kondisional: %qT vs %qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "perbandingan antara %q#T dan %q#T"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "tidak ada dealokasi fungsi yang berhubungan untuk %qD"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "tidak cocok %<operator %s%> untuk %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D tidak dapat diakses"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "melewatkan koson ke argumen bukan penunjuk %P dari %qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "mengubah ke tipe bukan penunjuk %qT dari KOSONG"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "terlalu banyak kurung diantara penginisialisasi untuk %qT"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  inisialisasi argumen %P dari %qD"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "mengubah ke %qT untuk daftar penginisialisasi akan menggunakan konstruktor eksplist %qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "tidak dapat mengikat bitfield %qE ke %qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "tidak dapat mengikat packed field %qE ke %qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "tidak dapat mengikat rvalue %qE ke %qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "tidak dapat melewatkan objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "tidak dapat menerima objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumen baku untuk parameter %d dari %qD belum diparse"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT bukan sebuah dasar yang bisa diakses dari %qT"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "deducing %qT as %qT"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use value-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use copy-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%s(%A)%> adalah ambigu"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "tidak dapat memanggil anggota fungsi %qD tanpa objek"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "melewatkan %qT memilih %qT diatas %qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "memilih %qD diatas %qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  karena urutan konversi untuk argumen lebih baik"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "argumen baku tidak cocok dalam kelebihan beban resolusi"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qH to %qI"
 msgstr "tidak dapat mengubah %qE ke %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -44363,8 +44503,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
@@ -44410,7 +44550,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT declared here"
@@ -44496,7 +44636,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -44801,7 +44941,7 @@
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
@@ -44874,7 +45014,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tidak cukup informasi mengenai tipe"
@@ -44976,381 +45116,381 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "PARAMETER '%s' is used at %L before its definition is complete"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "PARAMTER '%s' digunakan di %L sebelum definisinya lengkap"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs memiliki ketergantungan circular"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not initialized"
 msgid "%qD used in its own initializer"
 msgstr "%qE tidak terinisialisasi"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D adalah private"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD belum pernah dideklarasikan dalam lingkup ini"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT alters %qT constant value"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "konversi ke %qT mengubah nilai konstanta %qT"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
 msgstr "Tidak terduga akhir dari berkas dalam '%s'"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45403,7 +45543,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "casting %qT ke %qT tidak medereferensi penunjuk"
@@ -45414,341 +45554,341 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "konversi dari %q#T ke %q#T"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "hasil dari konversi tidak dispesifikasikan karena %qE diluar dari jangkauan tipe %qT"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "%q#T digunakan dimana sebuah %qT telah diduga"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "tidak dapat mengubah %qE ke %qT"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "%q#T digunakan dimana seubah nilai titik pecahan telah diduga"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "konversi dari %qT ke tipe bukan-skalar %qT diminta"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "in call to %qD, declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "pseudo-destruktor tidak dipanggil"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "apliasi tidak valid dari %qs ke tipe tidak lengkap %qT"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to void will not access object of type %qT"
 msgstr "konversi ke tipe yang tidak lengkap"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "object %qE of incomplete type %qT will not be accessed in %s"
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "objek %qE dari tipe tidak lengkap %qT tidak dapat diakses dalam %s"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "statement is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 #| msgid "%s is a reference, not call, to function %qE"
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s adalah sebuah referensi, bukan panggilan, ke fungsi %qE"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "second operand of conditional expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "third operand of conditional expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right operand of comma operator has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of comma operator has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 #| msgid "statement with no effect"
 msgid "statement has no effect"
 msgstr "pernyataan dengan tidak ada efek"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "for increment expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "mengubah NULL ke tipe bukan penunjuk"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "ambigu tipe konversi baku dari %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  kandidat konversi termasuk %qD dan %qD"
@@ -45793,229 +45933,229 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD telah dideklarasikan %<extern%> dan kemudian %<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of %qF has a different exception specifier"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "dari deklarasi sebelumnya %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "menggunakan deklarasi %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "definisi sebelumnya dari %q+D ada disini"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "deklarasi sebelumnya dari %q+D ada disini"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "shadowing built-in function %q#D"
 msgstr "pembayangan %s fungsi %q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "shadowing library function %q#D"
 msgstr "pembayangan %s fungsi %q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "perpustakaan fungsi %q#D redeklarasi sebagai bukan-fungsi %q#D"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "konflik dengan deklarasi bawaan %q#D"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 #| msgid "previous non-function declaration %q+#D"
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "deklarasi sebelumnya bukan fungsi %q+#D"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with built-in declaration %q#D"
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "konflik dengan deklarasi bawaan %q#D"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "ambigu deklarasi bawaan %q#D"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates built-in declaration %q#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "ambigu deklarasi bawaan %q#D"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "derived type declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "tipe deklarasi turunan"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D redeklarasi sebagai jenis berbeda dari simbol"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "ambigu deklarasi lama %q+#D"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "old declaration %q#D"
 msgstr "global deklarasi %q+#D"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "ambigu deklarasi lama %q+#D"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D"
 msgid "previous declaration as %q#D"
 msgstr "deklarasi sebelumnya dari %q+#D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously declared here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "prototipe untuk %q+#D"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 #| msgid "%Jfollows non-prototype definition here"
 msgid "previous non-prototype definition here"
 msgstr "%J mengikuti bukan-prototipe definisi disini"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "previous declaration with %qL linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 #| msgid "after previous specification in %q+#D"
 msgid "previous specification in %q#D here"
 msgstr "setelah spesifikasi sebelumnya dalam %q+#D"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %q+D"
@@ -46029,12 +46169,12 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
@@ -46041,7 +46181,7 @@
 msgstr "%q+D: atribut visibility diabaikan karenanya"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
@@ -46048,25 +46188,25 @@
 msgid "redefinition of %q#D"
 msgstr "redefinisi dari %q#T"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
@@ -46075,682 +46215,683 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local deklarasi dari %q+D mengikuti deklarasi bukan-thread-lokal"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local deklarasi dari %q+D mengikuti deklarasi thread-local"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  dari sini"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  keluar OpenMP structured block"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  menyilangi inisialisasi dari %q+#D"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  mamasuki blok penangkapan"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  memasuki blok percobaan"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  memasuki blok terstruktur OpenMP"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named %q#T in %q#T"
 msgid "no type named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah class template"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah tipe"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "parameter template tidak cocok dengan template"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "alignmen yang diminta bukan kelipatan dari 2"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan konstruktor tidak diijinkan dalam kumpulan anonymous"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam kumpulan anoymous"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan operator penempatan salin tidak diperbolehkan dalam kumpulan anonymous"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "atribut untuk %q+#T harus mengikuti kata kunci %qs"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "multiple tipe dalam satu deklarasi"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ menghambat struct anonymous"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> hanya dapat dispesifikasikan untuk konstruktor"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> telah diabaikan dalam deklarasi ini"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<register%> dalam file-scope deklarasi kosong"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe kelas %qT diluar dari definisi"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe dependen %qT tanpa sebuah deklarasi yang berasosiasi"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan decltype)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarasi dari %q#D memiliki %<extern%> dan terinisialisasi"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tidak mengijinkan %<%T::%D%> untuk didefinisikan sebagai %<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "duplikasi inisialisasi dari %qD"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabel %q#D memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "kumpulan %q#D memiliki tipe tidak lengkap dan tidak dapat didefinisikan"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nama digunakan dalam sebuah gaya GNU diperuntukan penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "bukan trivial designated penginisialisasi tidak didukung"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  anda dapat memperbaiki ini dengan menghapus penginisialisasi"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipe tidak valid %qT sebagai penginisialisasi untuk sebuah vektor dari tipe %qT"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elemen dari array %q#T memiliki tipe tidak lengkap"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ukuran-variabel compound literals"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "objek skalar %qD membutuhkan satu elemen dalam penginisialisasi"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "dalam C++98 %qD harus diinisialisasi dengan konstruktor, bukan dengan %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "array %qD diinisialisasi dengan tanda kurung string literal %qE"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "penginisialisasi tidak valid untuk anggota statis  dengan konstruktor"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(diluar dari kelas inisialisasi dibutuhkan)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "parameter %qD dinisialisasi"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "membayangi tipe deklarasi sebelumnya dari %q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr ""
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+#| msgid "%qT is an inaccessible base of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "%u name provided for structured binding"
@@ -46758,7 +46899,7 @@
 msgstr[0] "%Hpenginisialisasi disediakan untuk fungsi"
 msgstr[1] "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46765,7 +46906,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46772,1014 +46913,1025 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "tidak dapat menguraikan alamat"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "cannot increment a pointer to incomplete type %qT"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "metoda Java %qD memiliki tipe kembali %qT bukan Java"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "mendifinisikan eksplisit spesialisasi %qD dalam deklarasi friend"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "penggunaan tidak valid dari template-id %qD dalam deklarasi dari primary template"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "literal operator with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> harus kembali %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "bukan %q#D anggota fungsi dideklarasikan dalam kelas %qT"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ melarang inisialisasi dari anggota constant %qD dari bukan integral tipe %qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "ukuran dari array %qD memiliki tipe bukan integral %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "ukuran dari array %qD negatif"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "ukuran dari array negatif"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ melarang array dengan variabel panjang %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ melarang array dengan variabel panjang"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "array dengan panjang bervariabel  %qD digunakan"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "overflow dalam dimensi array"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spesifikasi tipe kembali untuk konstruktor tidak valid"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "tipe kembali yang dispesifikasikan untuk %<operator %T%>"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variabel tidak bernama atau field dideklarasikan void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<::%D%>"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%T::%D%>"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%D::%D%>"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T bukan sebuah kelas atau ruang nama"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "deklarasi dari %qD sebagai bukan anggota"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ melarang deklarasi dari %qs dengan tidak ada tipe"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ 1998 does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> atau %<unsigned%> tidak valid untuk %qs"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> dan %<unsigned%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> tidak valid untuk %qs"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> tidak valid untuk %qs"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> atau %<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> atau %<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> atau %<short%> dispesifikasikan dengan char untuk %qs"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> dan %<short%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> atau %<long%> tidak valid untuk %qs"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed, atau unsigned digunakan secara tidak valid untuk %qs"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "type deklarasi tidak valid dalam parameter deklarasi"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "definisi fungsi dideklarasikan %<typedef%>"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level deklarasi dari %qs menspesifikasikan %<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spesifikasi kelas penyimpanan tidak valid dalam deklarasi fungsi friend"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.c:11095
-#, gcc-internal-format
-msgid "deduction guide for %qT must have trailing return type"
-msgstr ""
-
-#: cp/decl.c:11099
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
+msgid "deduced class type %qD in function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/decl.c:11111
+#: cp/decl.c:11156
 #, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.c:11169
+#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -47786,263 +47938,263 @@
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member %<%T::%s%> within %qT"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -48049,175 +48201,175 @@
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<concept%>"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "a constructor cannot be %<concept%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
@@ -48224,82 +48376,82 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -48320,185 +48472,185 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ melarang overloading operator ?:"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -48510,96 +48662,96 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -48609,83 +48761,83 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -48726,7 +48878,7 @@
 msgid "deleting %qT is undefined"
 msgstr "menghapus %qT tidak terdefinisi"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "template deklarasi dari %q#D"
@@ -48740,7 +48892,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destruktor %qD dideklarasikan sebagai anggota template"
@@ -48859,46 +49011,46 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonymous struct tidak didalam tipe bernama"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "anggota private %q+#D dalam union anonymous"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "kumpulan namespace scope anonymous harus berupa statis"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonymous union dengan tida ada anggota"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> harus mengembalikan tipe %qT"
@@ -48907,71 +49059,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "parameter pertama dari %<operator new%> tidak dapat memiliki sebuah argumen baku"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> mengambil tipe %<size_t%> (%qT) sebagai parameter pertama"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> harus mengembalikan tipe %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> mengambil tipe %qT sebagai parameter pertama"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari tipe dari fieldnya %qD"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -48981,68 +49133,68 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D tidak merefer ke tipe tidak terkualifikasi, jadi ini tidak digunakan untuk linkage"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "daerah dari %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "fungsi inline %q+D digunakan tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argumen baku hilang untuk parameter %P dari %q+#Ddd"
@@ -49049,18 +49201,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
 msgstr "fungsi %q+D terhapus"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -49071,131 +49223,131 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "tidak ada argumen"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, fuzzy, gcc-internal-format
 #| msgid "%Hreference to %<%T::%D%> is ambiguous"
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "%Hreferensi ke %<%T::%D%> adalah ambigu"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a member of %qD"
 msgid "%qD is not a member of %qD"
 msgstr "%H%qD bukan sebuah anggota dari %qD"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<::%D%> has not been declared"
 msgid "%<::%D%> has not been declared"
@@ -49349,78 +49501,78 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(jika ini bukan yang anda inginkan, pastikan template fungsi telah dideklarasikan dan tambahkan <> setelah nama fungsi disini) "
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "value-initialization of incomplete type %qT"
 msgstr "apliasi tidak valid dari %qs ke tipe tidak lengkap %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "value-initialization of function type %qT"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "value-initialization of reference type %qT"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 #| msgid "recursive evaluation of default argument for %q#D"
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "used here"
 msgid "defined here"
 msgstr "digunakan disini"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD seharusnya diinisialisasi dalam daftar anggota inisialisasi"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD digunakan tidak terinisialisasi dalam fungsi ini"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "anggota const tidak terinisialisasi %qD"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
@@ -49427,312 +49579,312 @@
 msgid "%q#D should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "dasar %qT akan diinisialisasi setelah"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  dasar %qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  ketika diinisialisasi disini"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J multiple penginisialisasi diberikan untuk %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%J multiple penginisialisasi diberikan untuk dasar %qT"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J inisialisasi untuk multiple anggota dari %qT"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D adalah sebuah anggota data statis; ini hanya dapat diinisialisasikan di definisinya"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang tidak memiliki kelas dasar"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang menggunakan turunan multiple"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD keduanya sebuah dasar langsung dan sebuah virtual base tidak langsung"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "tipe tidak lengkap %qT tidak memiliki anggota %qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "penunjuk tidak valid ke bit-field %qD"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qD"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "integer overflow dalam ekspresi"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' not allowed in expression at %L"
 msgid "variably modified type not allowed in new-expression"
 msgstr "Dummy argumen '%s' tidak diijinkan dalam ekspresi di %L"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "tipe %<void%> tidak valid untuk new"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "tidak ada %qD yang sesuai yang ditemukan dalam kelas %qT"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "permintaan untuk anggota %qD adalah ambigu"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new tidak dapat diaplikasikan untuk mereferensikan sebuah tipe"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "penginisialisasi berakhir secara prematur"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukuran array tidak diketahui dalam delete"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
@@ -49744,7 +49896,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -49832,69 +49984,69 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(jika anda menggunakan %<-fpermissive%>, G++ akan menerima kode anda, tetapi mengijinkan penggunaan dari sebuah nama tidak dideklarasikan sudah ditinggalkan)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "mangling typeof, lebih baik gunakan decltype"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, fuzzy, gcc-internal-format
 #| msgid "mangling unknown fixed point type"
 msgid "mangling __underlying_type"
 msgstr "mangling tipe fixed point tidak diketahui"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "mangling tipe fixed point tidak diketahui"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "mangling %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "diabaikan operan tengah ke %<?:%> operan tidak dapat mangled"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "nama mangled dari %qD tidak akan berubah dalam versi yang akan datang dari GCC"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -50023,47 +50175,47 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D menyembunyikan konstruktor untuk %q#T"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklarasi dari %q#D membayangi sebuah parameter"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "global deklarasi %q+#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -50072,63 +50224,63 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "pencarian nama dari %qD berubah"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "  pasangkan ini %q+D dibawah aturan ISO baku"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "  pasangkan ini %q+D dibawah aturan lama"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "pencarian nama dari %qD berubah untuk ISO baru %<for%> scoping"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "  menggunakan obsolete binding di %q+D"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -50136,12 +50288,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "sebuah using-declaration tidak dapat menspesifikasikan sebuah template-id. Coba %<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "namespace %qD tidak diijinkan dalam using-declaration"
@@ -50148,105 +50300,105 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT bukan sebuah namespace"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD telah dideklarasikan dalam lingkup ini"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD tidak dideklarasikan"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> names desktruktor"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "tidak ada anggota yang cocok %<%T::%D%> dalam %q#T"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD seharusnya telah dideklarasikan didalam %qD"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD atribut tidak berarti karena anggota dari anonymous namespace memperoleh simbol lokal"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "atribut %qD direktif diabaikan"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -50253,85 +50405,90 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
+#, fuzzy, gcc-internal-format
+#| msgid "%<this%> is unavailable for static member functions"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
+
+#: cp/name-lookup.c:5929
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/name-lookup.c:6476
-#, fuzzy, gcc-internal-format
-#| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
-msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
+#: cp/name-lookup.c:6687
+#, gcc-internal-format
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
+msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "pilihan %qs tidak lagi didukung"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namespace alias %qD tidak diijinkan disini, diasumsikan %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX memasuki pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX meninggalkan pop_everything ()\n"
@@ -50353,7 +50510,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50382,7 +50539,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "%Hpermintaan untuk anggota %qE dalam tipe bukan kelas %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -50477,7 +50634,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "sebuah cast ke sebuah tipe selain dari sebuah integral atau tipe enumerasi tidak dapat muncul dalam sebuah ekspresi konstan"
@@ -50732,7 +50889,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -50827,7 +50984,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%Hlingkup %qT sebelum %<~%> bukan sebuah class-name"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
@@ -50845,570 +51002,561 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%Htypedef-nama %qD digunakan sebagai desktruktor deklarator"
 
-#: cp/parser.c:6110
-#, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "diduga specifier-qualifier-list"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bukan sebuah template"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ melarang compound literals"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray bound forbidden after parenthesized type-id"
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "%Harray bound dilarang setelah parenthesized tipe id"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "penggunaan dari gaya-lama cast"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> operator will be treated as two right angle brackets in C++0x"
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%H%<>>%> operator akan diperlakukan sebagai dua sudut brackets dalam C++0x"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "disarankan tanda kurung disekeliling ekspresi %<>>%>"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+#| msgid "%Hnew types may not be defined in a return type"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "lambda-expression in template-argument"
 msgstr "%Hparse error dalam daftar argumen template"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Tidak terduga akhir dari modul"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qE"
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "duplikasi %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcase label %qE not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "%Hlabel case %qE tidak dalam sebuah pernyataan switch"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "kelebihan %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__label__%> not at the beginning of a block"
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%H%<__label__%> tidak berada diawal dari sebuah blok"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmixing declarations and function-definitions is forbidden"
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "%Hpencampuran deklarasi dan definisi fungsi dilarang"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "deklarasi kosong"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<friend%> used outside of class"
 msgid "%<friend%> used outside of class"
 msgstr "%H%<friend%> digunakan diluar dari kelas"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%H%<auto%> akan mengubah arti dalam C++0x; mohon hapus itu"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D tidak valid dalam %q#T"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, fuzzy, gcc-internal-format
 #| msgid "%Hclass definition may not be declared a friend"
 msgid "class definition may not be declared a friend"
 msgstr "%Hdefinisi kelas mungkin tidka dideklarasikan sebagai friend"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 #| msgid "%Honly constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anachronistic gaya-lama kelas dasar penginisialisasi"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (sebuah anggota terkualifikasi secara implisit adalah sebuah tipe)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -51415,69 +51563,69 @@
 msgstr "operan tidak terduga"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter packs cannot have default arguments"
 msgid "template parameter packs cannot have default arguments"
 msgstr "%Htemplate parameter pack tidak dapat memiliki argumen baku"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> adalah sebuah penyebutan alternatif untuk %<[%>. Masukan spasi diantara %<<%> dan %<::%>"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(jika anda menggunakan %<-fpermissive%> G++ akan menerima kode anda)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "parse error in template argument list"
@@ -51484,7 +51632,7 @@
 msgstr "%Hparse error dalam daftar argumen template"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -51491,333 +51639,333 @@
 msgstr "diduga pernyataan"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnon-template %qD used as template"
 msgid "non-template %qD used as template"
 msgstr "%Hbukan-template %qD digunakan sebagai template"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "gunakan %<%T::template %D%> untuk mengindikasikan bahwa ini adalah template"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate specialization with C linkage"
 msgid "template specialization with C linkage"
 msgstr "%Hspesialisasi template dengan C linkage"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklarasi %qD tidak mendeklarasikan apapun"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "atribut diabaikan di elaborated type penspesifikasi yang tidak memforward sebuah deklarasi"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktifkan instantiation template otomatis"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in namespace %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam namespace %qD yang tidak dilingkupi %qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam %qD yang tidak dilingkup %qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 #| msgid "%Hextra qualification not allowed"
 msgid "extra qualification not allowed"
 msgstr "%Hekstra pengkualifikasi diabaikan"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a function-definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "initializer provided for function"
 msgstr "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -51827,19 +51975,19 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of constructor as a template"
 msgid "invalid use of constructor as a template"
 msgstr "%Hpenggunaan tidak valid dari konstruktor sebagai sebuah template"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "penggunaan %<%T::%D%> daripada %<%T::%D%> untuk menamai konstruktor dalam sebuah nama berkualifikasi"
@@ -51846,438 +51994,438 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is a namespace"
 msgid "%qD is a namespace"
 msgstr "%H%qD adalah sebuah namespace"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate cv-qualifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple ref-qualifiers"
 msgstr "multiple pemanggil inline"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "hilang target makefile setelah %qs"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdefault arguments are only permitted for function parameters"
 msgid "default arguments are only permitted for function parameters"
 msgstr "%Hargumen baku hanya diijinkan untuk parameter fungsi"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack %qD cannot have a default argument"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack cannot have a default argument"
 msgid "template parameter pack cannot have a default argument"
 msgstr "%Htemplate parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid class name in declaration of %qD"
 msgid "invalid class name in declaration of %qD"
 msgstr "%Hnama kelas tidak valid dalam deklarasi dari %qD"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, fuzzy, gcc-internal-format
 #| msgid "%Han explicit specialization must be preceded by %<template <>%>"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%Hsebuah eksplisit spesialisasi harus diawali oleh %<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprevious definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%Hdefinisi sebelumnya dari %q+#T"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "diduga nama class"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "%Hsebuah class-key harus digunakan ketikan mendeklarasikan sebuah friend"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "friend declaration does not name a class or function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "pure-specifier on function-definition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, fuzzy, gcc-internal-format
 #| msgid "invalid AE type specified (%s)\n"
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "tipe AE yang dispesifikasikan (%s) tidak valid\n"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (kelas dasar  adalah sebuah tipe implisit)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -52287,469 +52435,469 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Use media instructions"
 msgid "empty introduction-list"
 msgstr "Gunakan instruksi media"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52756,119 +52904,119 @@
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option tidak diijinkan didalam fungsi"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "anggota data %qD tidak dapat berupa sebuah anggota template"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "explisit spesialisasi dalam lingkup non-namespace %qD"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "template kelas yang melingkupi tidak secara eksplisit terspesialisasi"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  dari definisi dari %q+#D"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spesialisasi dari %qT setelah instantiation"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "spesialisasi %q#T dalam namespace berbeda"
@@ -52875,72 +53023,72 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spesialisasi %qT setelah instantiation %qT"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD bukan sebuah variabel"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD untuk %q+D tidak cocok dengan deklarasi template apapun"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -52947,25 +53095,25 @@
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "hilang atribut Code"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
@@ -52973,60 +53121,60 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "template-id %qD dalam deklarasi dari template utama"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "daftar parameter template digunakan dalam instantiation eksplisit"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definisi disediakan untuk instantiation eksplisit"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "terlalu sedikit daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplisit spesialisasi dari %qD harus dikenalkan oleh %<template <>%>"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argumen baku dispesifikasikan dalam spesialisasi eksplisit"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bukan sebuah fungsi template"
@@ -53039,152 +53187,152 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "tidak ada anggota fungsi %qD dideklarasikan dalam %qT"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "friend declaration here"
 msgstr "%J membayangi deklarasi ada disini"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "ekspansi penginisialisasi dasar %<%T%> berisi parameter packs"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "pola ekspansi %<%T%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "pola ekspansi %<%E%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameter packs tidak diekspan dengan %<...%>:"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "tipe parameter template %qT dideklarasikan %<friend%>"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack argumen %qE harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack argumen %qT harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -53192,19 +53340,19 @@
 msgstr[0] "tipe %qT dari template argumen %qE tergantung di parameter template"
 msgstr[1] "tipe %qT dari template argumen %qE tergantung di parameter template"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "tidak ada argumen baku untuk %qD"
@@ -53212,53 +53360,53 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE harus berada di akhir dari daftar parameter template"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumen baku untuk parameter dari tipe %qT memiliki tipe %qT"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parameter %qD dideklarasikan void"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -53269,58 +53417,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definisi template dari bukan template %q#D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "diduga %d tingkat dari parm template untuk %q#D, diperoleh %d"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  tetapi %d dibutuhkan"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "gunakan template<> untuk spesialisasi eksplisit"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "penspesifikasi template tidak dispesifikasikan dalam deklarasi dari %qD"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclared with %d template parameter"
@@ -53328,7 +53476,7 @@
 msgstr[0] "redeklarasikan dengan %d parameter template"
 msgstr[1] "redeklarasikan dengan %d parameter template"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter(s)"
 msgid "previous declaration %qD used %d template parameter"
@@ -53336,12 +53484,12 @@
 msgstr[0] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 msgstr[1] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parameter template %q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
@@ -53350,132 +53498,132 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT bukan sebuah anggota dari %qT"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs tidak valid untuk %qs"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53482,318 +53630,324 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena string literal tidak dapat digunakan dalam konteks ini"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "in template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "akumulator bukan sebuah konstanta integer"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  diduga sebuah template dari tipe %qD, diperoleh %qD"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "kegagalan konsistensi internal"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "%Jflexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "%J anggota array fleksibel dalam union"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -53812,288 +53966,288 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -54106,118 +54260,124 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+#| msgid "use of %qs in template"
+msgid "invalid use of %qT in template argument"
+msgstr "penggunaan dari %qs dalam template"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -54435,7 +54595,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "tidak valid pengkualifikasi lingkup dalam nama pseudo-destruktor"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
@@ -54486,7 +54646,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
@@ -54564,329 +54724,330 @@
 msgstr "%qT bukan sebuah tipe template"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke destruktor %<~%T%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<device%> id must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "reimplementasi dari class %qs"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -55028,13 +55189,13 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "pemeriksaan lang_*: gagal dalam %s, di %s:%d"
@@ -55105,799 +55266,793 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "tipe titik kanonikal sama untuk tipe berbeda %T dan %T"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplikasi tidak valid dari %qs ke anggota fungsi"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<sizeof%> ke sebuah bit-field"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<sizeof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<__alignof%> ke sebuah bit-field"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<__alignof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of temporary array"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qE"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "akses tidak valid ke anggota data tidak statis %qD dari objek KOSONG"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "tipe objek %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "tipe yang sedang dihancurkan adalah %qT, tetapi destruktor merefer ke %qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT bukan sebuah basis dari %qT"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bukan sebuah penunjuk-ke-objek tipe"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objek hilang dalam penggunaan dari %qE"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "tidak dapat menon-aktifkan fungsi bawaan %qs"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ melarang pemanggilan %<::main%> dari dalam aplikasi"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "harus menggunakan %<.*%> atau %<->*%> untuk memanggil penunjuk-ke-anggota fungsi dalam %<%E (...)%>, contoh %<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to member function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to member function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "terlalu banyak argumen ke fungsi"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "terlalu sedikit argumen ke fungsi"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P dari %qD memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "mengasumsikan cast ke tipe %qT dari fungsi overloaded"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL digunakan dalam aritmetik"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "jumlah rotasi kiri negatif"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "jumlah rotasi kanan negatif"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "jumlah rotasi kiri >= lebar dari tipe"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "jumlah rotasi kanan >= lebar dari tipe"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ melarang perbandingan diantara penunjuk dan integer"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "perbandingan tidak berurut di argumen bukan titik pecahan"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operang tidak valid untuk tipe %qT dan %qT ke binari %qO"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk dari tipe %<void *%> dalam pengurangan"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah metoda  dalam pengurangan"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "penggunaan tidak valid dari sebuah penunjuk ke sebuah tipe tidak lengkap dalam aritmetik penunjuk"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "penggunaan tidak valid dari %qE untuk membentuk sebuah penunjuk ke anggota fungsi"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  sebuah kualified-id dibutuhkan"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "tanda kurung disekitar %qE tidak dapat digunakan untuk membentuk sebuah penunjuk-ke-anggota-fungsi"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari tidak terkualifikasi atau bertanda kurun anggota bukan statis fungsi untuk membentuk sebuah penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah anggota fungsi terikat ke sebuah bentuk penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ melarang mengambil alamat dari fungsi %<::main%>"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "tidak dapat membuat penunjuk ke anggota referensi %qD"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "tidak dapat mengambil alamat dari bit-field %qD"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ melarang mengurangi sebuah enum"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ melarang meningkatkan sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ melarang mengurangi sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "alamat dari variabel eksplisit register %qD diminta"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "alamat yang diminta untuk %qD, yang dideklarasikan %<register%>"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away constness"
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "tidak valid static_cast dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "mengubah dari %qT ke %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "cast dari %qT ke %qT kehilangan presisi"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast dari %qT ke %qT menaikan alignmen yang dibutuhkan dari tipe target"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ melarang casting diantara penunjuk ke fungsi dan penunjuk ke objek"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang bukan sebuah penunjuk, referensi, ataupun sebuah tipe penunjuk-ke-anggota-data"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang merupakan sebuah penunjuk atau referensi ke sebuah tipe fungsi"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "const_cast tidak valid dari sebuah rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "const_cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ melarang casting ke sebuah tipe array %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  dalam evaluasi dari %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipe tidak kompatibel dalam assignmen dari %qT ke %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array digunakan sebagai penginisialisasi"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "assignmen array tidak valid"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dalam penunjuk ke anggota fungsi konversi"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "penunjuk ke anggota konversi melalui basis maya %qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dalam penunjuk ke anggota konversi"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
+#| msgid "cannot convert %qT to %qT in %s"
+msgid "cannot convert %qH to %qI"
+msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
-msgid "cannot convert %qH to %qI"
-msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
-
-#: cp/typeck.c:8804
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "dalam melewatkan argumen %P dari %q+D"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "referensi ke bukan-lvalue dikembalikan"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "referensi ke variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
@@ -55904,57 +56059,57 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "tidam dapat kembali dari sebuah penanganan dari sebuah fungsi-coba-blok dari sebuah konstruktor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "hilang penginisialisasi"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> harus tidak mengembalikan KOSONG kecuali ini dideklarasikan %<throw()%> (atau ada dalam pengaruh -fcheck-new )"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -56202,151 +56357,151 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "sintaks konstruktor digunakan, tetapi tidak ada konstruktor dideklarasikan untuk tipe %qT"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-array diinisialisasi dari string bukan-lebar"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-array diinisialisasi dari string lebar tidak kompatibel"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "inisialisasi-string untuk array dari karakter terlalu panjang"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "prototipe untuk %q#D tidak cocok dengan kelas apapun %qT"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#T"
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -56802,29 +56957,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Pajang KARAKTER berbeda (%d/%d) dalam konstruktor array di %L"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -56831,22 +56986,22 @@
 msgid "Simplification error"
 msgstr "gimplification gagal"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -57963,7 +58118,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -58156,7 +58311,7 @@
 msgid "deferred type parameter at %C"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -58436,486 +58591,486 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Duplikasi spesifikasi array untuk Cray pointee di %C"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Inisialisasi di %C bukan sebuah variabel penunjuk"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Inisialisasi dari penunjuk di %C membutuhkan '=>', bukan '='"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Diduga sebuah ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari variabel di %C tidak diperbolehkan alam prosedur PURE"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Inisialisasi dari komponen dapat dialokasikan di %C tidak diperbolehkan"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Komponen penunjuk '%s' dari '%s' di %L adalah sebuah tipe yang belum pernah dideklarasikan"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Tipe deklarasi gaya-lama %s*%d tidak didukung di %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Tipe deklarasi tidak-baku %s*%d di %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Hilang paranthesis kanan di %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Diduga ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Didugak ekspresi inisialisasi skalar di %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Jenis %d tidak didukung untuk tipe %s di %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Jenis tipe parameter C adalah untuk tipe %s tetapi tipe di %L adalah %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Hilang paranthesis kanan atau koma di %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Jenis %d tidak didukung untuk KARAKTER di %C"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Sintaks error dalam deklarasi KARAKTER di %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "parameter pertama dari %<operator new%> tidak dapat memiliki sebuah argumen baku"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Ekspresi di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Array '%s' di %L bukan sebuah variabel, yang tidak mereduksi ke sebuah ekspresi konstanta"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Ekstensi: BYTE tipe di %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "tipe BYTE digunakan di %C tidak tersedia dalam mesin target"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tipe nama '%s' di %C adalah ambigu"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Duplikasi pernyataan IMPLISIT NONE di %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Hilang jangkauan karakter dalam IMPLISIT di %C"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Huruf harus dalam urutan alphabet dalam pernyataan IMPLISIT di %C"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Tidak dapat IMPOR '%s' dari satuan host scoping di %C - tidak ada."
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' telah ter-IMPOR dari satuan host scoping di %C."
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Sintaks error dalam pernyataan IMPOR di %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Components in TYPE at %C must precede CONTAINS"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponen dalam TYPE di %C harus mengawali CONTAINS"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s atribut di %L tidak diperbolehka diluar dari bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "TERPROTEKSI di %C hanya diperbolehkan dalam bagian spesifikasi dari modul"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: atribut TERPROTEKSI di %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: atribut NILAI di %C"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: atribut VOLATILE di %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Multiple pengidentifikasi disediakan dengan penspesifikasi NAMA= tunggal di %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "secara implisit terdeklarasi fungsi BIND(C) '%s' di %L mungkin tidak C interoperable"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L mungkin tidak berupa jenis C dapat berinteroperasi melalui blok umum '%s' adalah BIND(C)"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Tipe deklarasi '%s' di %L bukan C interoperable tetapi ini adalah BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabel '%s' di %L mungkin bukan sebuah jenis C interoperable tetapi ini adalah bind(c)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L tidak dapat dideklarasikan dengan BIND(C)karena ini bukan sebuah global"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Tipe kembali dari fungsi BIND(C) '%s' di %L tidak dapat berupa sebuah array"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -58923,363 +59078,363 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Simbol '%s' di %L ditandai PRIVATE tetapi telah diberikan level binding '%s'"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Dibutuhkan baik entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Hilang entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "hilang angka"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Tipe turunan di %C belum pernah didefinisikan sebelumnya jadi tidak dapat muncul dalam sebuah tipe definisi turunan"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "nama prosedur = %s"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Diduga alternatif label kembali di %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "A parameter name is required at %C"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Nama '%s' di %C adalah nama dari prosedur"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Diduga dimensi lain dalam deklarasi array di %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Tidak teduga sampah dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "variabel RESULT di %C harus berbeda dari nama fungsi"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: BIND(C) atribut di %L mungkin tidak dispesifikasikan untuk sebuah prosedur internal"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "atribut BIND(C) di %C membutuhkan sebuah antar-muka dengan BIND(C)"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "prosedur BIND(C) dengan NAMA mungkin tidak memiliki atribut PENUNJUK di %C"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Prosedur dummy di %C mungkin tidak memiliki atribut BIND(C) dengan NAMA"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Diduga '::' setelah atribut binding di %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Procedure pointer component at %C"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Sintaks error dalam struktur konstruktor di %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROSEDUR di %C harus berupa sebuah antar-muka umum"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROCEDURE statement at %C"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Diduga daftar argumen formal dalam definisi fungsi di %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "atribut BIND(C) di %L hanya dapat digunakan untuk variabel atau blok umum"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah APLIKASI"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah DATA BLOK"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok TIPE TURUNAN"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok IF-THEN"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok FORALL"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok WHERE"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah subprogram terkontain"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah prosedur terkontain"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Hilang parantheses yang dibutuhkan sebelum BIND(C) di %C"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nama C tidak valid dalam penspesifikasi NAMA= di %C"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= penspesifikasi di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Hilang penutup paren untuk binding label di %C"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Untuk prosedur dummy %s, tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAMA tidak diijinkan dalam BIND(C) untuk ANTAR-MUKA ABSTRAK di %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -59286,670 +59441,670 @@
 msgstr "pernyataan %s di %C tidak dapat mengikuti pernyataan %s di %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "pernyataan %s tidak terduga di %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Diduga pernyataan %s di %C"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Diduga nama blok dari '%s' dalam pernyataan %s di %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Diduga label '%s' untuk pernyataan %s di %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensi dipesifikasikan untuk %s di %L setelah inisialisasinya"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Spesifikasi array harus deferred di %L"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Karakter tidak terduda dalam daftar variabel di %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Diduga nama variabel di %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Penunjuk Cray di %C memiliki %d bytes ketelitian; alamat memori membutuhkan %d bytes"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Diduga \")\" di %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Diduga \",\" atau akhir dari pernyataan di %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Deklarasi penunjuk cray di %C membutuhkan pilihan -fcray-pointer"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator %s di %C telah dispesifikasikan"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator .%s.  di %C telah dispesifikasikan"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PRIVATE di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PUBLIK di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nama variabel diduga di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Diduga tanda = dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Diduga ekspresi di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Inisialisasi variabel  yang telah diinisialisasi di %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket pernyataan SAVE di %C mengikuti pernyataan SAVE sebelumnya"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: pernyataan NILAI di %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROSEDUR MODUL di %C harus dalam sebuah antar-muka modul umum"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic procedure '%s' not allowed in PROCEDURE statement at %C"
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Prosedur intrinsik '%s' tidak diperbolehkan dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Ambigu simbol dalam definisi TIPE di %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' dalam ekspresi EXTENDS di %C bukan sebuah tipe turunan"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah BIND(C)"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah tipe SEQUENCE"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PRIVATE dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PUBLIK dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "tipe ABSTRAK '%s' digunakan di %L"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Duplikasi konstruksi label '%s' di %C"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Diduga :: dalam definisi TIPE di %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray Pointee di %C tidak dapat diasumsikan bentuk array"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM dan ENUMERATOR di %C"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumerator melebihi tipe integer C di %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L tidak diinisialisasi dengan ekspresi integer"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "pernyataan definisi ENUM diduga sebelum %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Sintaks error dalam definisi ENUMERATOR di %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Duplikasi penspesifikasi akses di %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal NOPASS di %C"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal PASS di %C"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate NON_OVERRIDABLE at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Diduga penspesifikasi akses di %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Diduga atribut binding di %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in NAME= specifier for binding label at %C"
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE(interface) at %C is not yet implemented"
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDUR(antar-muka) di %C belum diimplementasikan"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Diduga nama binding di %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "'::' diperlukan dalam binding PROCEDUR dengan target eksplisit di %C"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Diduga binding target setelah '=>' di %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC di %C harus berada didalam sebuah tipe turunan CONTAINS"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Diduga '::' di %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected generic name at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Diduga nama generik di %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Form tidak valid dari pernyataan APLIKASI di %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur bukan generik dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Binding di %C harus memiliki akses sama seperti telah didefinisikan binding '%s'"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Diduga nama binding spesifik di %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "'%s' telah didefinisikan sebagai binding spesifik untuk generik '%s' di %C"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Sampah setelah binding GENERIC di %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "deklarasi FINAL di %C harus berada didalam sebuah tipe turunan daerah CONTAINS"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklarasi tipe turunan dengan FINAL di %C harus berada dalam spesifikasi dari sebuah MODULE"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Kosong FINAL di %C"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Diduga nama prosedur modul di %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nama prosedur tidak dikenal \"%s\" di %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%s' di %C telah didefinisikan sebagai prosedur FINAL!"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -60315,31 +60470,31 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Ekstensi: BOZ literal di %L digunakan untuk menginisialisasi variabel bukan-integer '%s'"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Ekstensi: BOZ literal di %L diluar sebuah pernyataan DATA dan diluar INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ literal di %L adalah bitwise dapat ditransfer bukan-integer simbol '%s'"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik underflow dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinon-aktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik overflow dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinonaktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -60692,7 +60847,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Membuat array sementara di %L"
@@ -60703,70 +60858,70 @@
 msgid "Removing call to function %qs at %L"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "diduga ekspresi"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -60894,12 +61049,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -62243,7 +62398,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -63818,12 +63973,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -64095,8 +64250,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
@@ -64141,7 +64296,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
@@ -64522,197 +64677,197 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "!$OMP DO collapsed loops tidak membentuk iterasi ruang rectangular di %L"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "kolaps !$OMP DO loops tidak secara sempurna nested di %L"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO tidak dapat berupa sebuah DO WHILE atau DO tanpa pengontrol loop di %L"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$OMP DO variabel iterasi harus berupa tipe integer di %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$OMP DO collapsed loops tidak membentuk iterasi ruang rectangular di %L"
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "kolaps !$OMP DO loops tidak secara sempurna nested di %L"
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOGICAL operands are required in expression at %L"
 msgid "TILE requires constant expression at %L"
 msgstr "operan LOGICAL dibutuhkan dalam ekspresi di %L"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -66213,7 +66368,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
@@ -66339,7 +66494,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66747,22 +66902,22 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -66769,222 +66924,222 @@
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -66993,257 +67148,257 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
@@ -67250,12 +67405,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67263,113 +67418,113 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -67376,73 +67531,73 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -67450,7 +67605,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67458,64 +67613,64 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -67522,999 +67677,999 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "dalam %s, di %s:%d"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumen dari ICHAR di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Komponen penunjuk '%s' dari '%s' di %L adalah sebuah tipe yang belum pernah dideklarasikan"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -68972,7 +69127,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): tipe tidak valid: %s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -69684,19 +69839,19 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Fungsi instrinsik %s(%d) tidak dikenal"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -69902,202 +70057,202 @@
 msgid "previously defined here as %s"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %qE"
 msgid "multiple prevailing defs for %qE"
 msgstr "multiple parameter bernama %qE"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in %qT"
 msgid "%qD has already been defined"
 msgstr "%qD telah didefinisikan dalam %qT"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "previously defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "type of %qD does not match original declaration"
 msgstr "template-id %qD untuk %q+D tidak cocok dengan deklarasi template apapun"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD was previously declared here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "variable %qD redeclared as function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %qD redeclared as variable"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "previously declared here"
 msgstr "%J sebelumnya digunakan disini"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "could not open response file %s"
 msgid "could not parse file offset"
 msgstr "tidak dapat membuka berkas response %s"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected offset"
 msgstr "operan tidak terduga"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid line in the resolution file"
 msgstr "register tidak valid dalam instruksi"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid resolution in the resolution file"
 msgstr "register tidak valid dalam instruksi"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot read LTO decls from %s"
 msgstr "tidak dapat menemukan class %qs"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot open %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot map %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot open %s"
 msgid "Cannot read %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init gagal"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr "mengubah nama berkas .rpo"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "opening LTRANS output list %s: %m"
 msgstr "membuka berkas keluaran %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, fuzzy, gcc-internal-format
 #| msgid "when writing output to %s: %m"
 msgid "writing to LTRANS output list %s: %m"
 msgstr "ketika menulis keluaran ke %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "closing LTRANS output list %s: %m"
 msgstr "membuka berkas keluaran %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 #| msgid "could not open response file %s"
 msgid "could not open symbol resolution file: %m"
 msgstr "tidak dapat membuka berkas response %s"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/fi.po
===================================================================
--- gcc/po/fi.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/fi.po	(.../branches/gcc-8-branch)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1-b20160131\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2016-02-06 01:01+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -177,40 +177,40 @@
 msgid "negative insn length"
 msgstr "negatiivinen käskyn pituus"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "ei voitu jakaa käskyä osiin"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "virheellinen ”asm”: "
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "sisäkkäiset assembly-murrevaihtoehdot"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "päättämättömät assembly-murrevaihtoehdot"
 
-#: final.c:3930
+#: final.c:3933
 #, fuzzy, c-format
 msgid "operand number missing after %%-letter"
 msgstr "$-operandinumero puuttuu muotoilussa"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, fuzzy, c-format
 msgid "operand number out of range"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "virheellinen %%-koodi"
 
-#: final.c:4025
+#: final.c:4028
 #, fuzzy, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
@@ -221,13 +221,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "liukulukuvakiota käytetty väärin"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1280,25 +1280,25 @@
 msgid "At top level:"
 msgstr "Luo uusi täysleveä ikkuna olemassa olevaan gedit-instanssiin"
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "Jäsenfunktio %qs"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "Funktio %qs"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr ""
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr ""
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, fuzzy, c-format
 msgid "    inlined from %qs"
 msgstr "Muodostin %qs"
@@ -3078,9 +3078,9 @@
 msgid "invalid address mode"
 msgstr "virheellinen %%G-tila"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3096,7 +3096,7 @@
 msgstr "virheellinen %%r-arvo"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3103,13 +3103,13 @@
 msgstr "virheellinen %%R-arvo"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
@@ -3140,7 +3140,7 @@
 msgstr "virheellinen %%U-arvo"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
@@ -3151,7 +3151,7 @@
 msgstr "virheellinen %%C-arvo"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
@@ -3162,7 +3162,7 @@
 msgstr "uudelleensijoitusvirhe"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3173,58 +3173,58 @@
 msgid "invalid operand address"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "virheellinen %%M-operandi"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, fuzzy, c-format
 msgid "invalid operand to %%p code"
 msgstr "fr30_print_operand: tunnistamaton %%p-koodi"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, fuzzy, c-format
 msgid "invalid operand to %%s code"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "virheellinen %%R-operandi"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "virheellinen %%H/%%L-operandi"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "virheellinen %%U-operandi"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "virheellinen %%V-operandi"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "virheellinen %%O-operandi"
@@ -3231,18 +3231,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 #, fuzzy
 msgid "unrecognized supposed constant"
 msgstr "tunnistamaton rekisterinimi %qs"
@@ -3278,7 +3278,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, fuzzy, c-format
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
@@ -3416,8 +3416,8 @@
 msgstr "virheellinen const_double-operandi"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3651,98 +3651,98 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "virheellinen const_double-operandi"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "tuntematon move-käsky:"
@@ -3784,7 +3784,7 @@
 msgstr "virheellinen %%P-operandi"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -3843,7 +3843,7 @@
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -4017,145 +4017,145 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4286,43 +4286,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "virheellinen %%Y-operandi"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "virheellinen %%A-operandi"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "virheellinen %%B-operandi"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, c-format
 msgid "invalid %%C operand"
 msgstr "virheellinen %%C-operandi"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, c-format
 msgid "invalid %%D operand"
 msgstr "virheellinen %%D-operandi"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "virheellinen %%f-operandi"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "virheellinen %%s-operandi"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4546,14 +4546,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "”)” oli odotus"
@@ -4568,7 +4568,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "”)” oli odotus"
@@ -4576,7 +4576,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "”)” oli odotus"
@@ -4591,7 +4591,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "”)” oli odotus"
@@ -4598,7 +4598,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "”)” oli odotus"
@@ -4608,13 +4608,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -4624,18 +4624,18 @@
 msgid "expected %<.%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -4643,23 +4643,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "”)” oli odotus"
@@ -4668,7 +4668,7 @@
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "”)” oli odotus"
@@ -4679,45 +4679,45 @@
 msgid "expected label"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "ehdokas 2:"
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "hyppy nimiöön %qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "hyppy case-nimiöön"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "  siirtyy try-lohkoon"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 msgid "enters OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 msgid "enters synchronized or atomic statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 msgid "enters constexpr if statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
@@ -4814,7 +4814,7 @@
 msgid "<statement>"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<tuntematon>"
@@ -4834,122 +4834,122 @@
 msgid "<unparsed>"
 msgstr "<jäsentämätön>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr "<lambda>"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<lausekevirhe>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<tuntematon operaattori>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "Globaalilla näkyvyysalueella:"
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "Staattinen jäsenfunktio %qs"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "Muodostin %qs"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "Hajotin %qs"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "Lambda-funktio"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, fuzzy, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "%s %qs"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 #, fuzzy
 msgid "%r%s:%d:%d:%R   "
 msgstr "Käyttö: %s [-r] [-t]\n"
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 #, fuzzy
 msgid "%r%s:%d:%R   "
 msgstr "Käyttö: %s [-r] [-t]\n"
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, fuzzy, c-format
 msgid "required by substitution of %qS\n"
 msgstr "tyhjän dynaamisen merkkijonon osan korvaus"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 msgid "required from %q#D\n"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 msgid "recursively required from here\n"
 msgstr "kutsuttu täältä"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 msgid "required from here\n"
 msgstr "kutsuttu täältä"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 #, fuzzy
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 #, fuzzy
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "ehdokkaat ovat:"
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
@@ -5004,52 +5004,52 @@
 msgid "source type is not polymorphic"
 msgstr "lähde ei ole osoitin"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bittikomplementille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "konjugaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "unaariselle huutomerkille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
@@ -5366,12 +5366,12 @@
 msgid "implied END DO"
 msgstr "syötteen loppu"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 #, fuzzy
 msgid "assignment"
 msgstr "Eri tyypit osoitinsijoituksessa kohdassa %L; yritettiin tyypin %s sijoitusta tyyppiin %s"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 #, fuzzy
 msgid "pointer assignment"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
@@ -5558,55 +5558,55 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "Silmukkamuuttuja"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 msgid "iterator variable"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "Ennenaikainen säännöllisen lausekkeen loppu"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 #, fuzzy
 msgid "STAT variable"
 msgstr "tiedoston tilan lukeminen epäonnistui"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 #, fuzzy
 msgid "item in READ"
 msgstr "Soita numero"
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "uutta arkistoa ei voi lukita"
@@ -5650,12 +5650,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Erisuuret merkkipituudet (%ld/%ld) merkkijonossa %s kohdassa %L"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5911,6 +5911,7 @@
 msgstr ""
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -8996,7 +8997,7 @@
 msgstr "Kohdista muuttujat 32 bitin rajoille"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 msgid "Specify the name of the target architecture."
 msgstr "  -L, --logfile     anna lokitiedoston nimi\n"
@@ -9504,7 +9505,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr ""
 
@@ -10276,7 +10277,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Tuota 68040-koodia"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -10754,7 +10755,7 @@
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -10764,12 +10765,12 @@
 msgstr "epäkelpo osoitintila %qs"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -10782,46 +10783,47 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 msgid "Make all function calls indirect."
 msgstr "Varoita laskutoimituksista funktio-osoittimilla"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 #, fuzzy
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
+
 #: config/pa/pa64-hpux.opt:23
 #, fuzzy
 msgid "Assume code will be linked by GNU ld."
@@ -11268,7 +11270,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -11276,7 +11278,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -11377,7 +11379,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr ""
 
@@ -11410,7 +11412,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Kelvolliset argumentit ovat:\n"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr ""
 
@@ -11497,25 +11499,25 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -11535,20 +11537,20 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 #, fuzzy
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "Salli MT-käskyjen käyttö"
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 #, fuzzy
 msgid "Use vector instructions added in ISA 3.0."
 msgstr "Käytä AltiVec-käskyjä"
@@ -11565,17 +11567,17 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 #, fuzzy
 #| msgid "Enable min/max instructions"
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "Ota käyttöön min/max-käskyt"
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -11585,17 +11587,17 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 #, fuzzy
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -11603,7 +11605,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Kelvolliset argumentit ovat:\n"
@@ -11634,12 +11636,11 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 msgid "Select ABI calling convention."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr ""
 
@@ -12373,7 +12374,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -12596,14 +12597,24 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "maximum value of parameter %qs is %u"
+msgid "Max number of pairs of load insns for compare."
+msgstr "parametrin %qs maksimiarvo on %u"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
@@ -12614,10 +12625,40 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
+#: config/rs6000/rs6000.opt:410
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+#| msgid "%qE is deprecated"
+msgid "%qs is deprecated"
+msgstr "%qE on vanhentunut"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "Kutsutaan settimeofday:\n"
+
+#: config/rs6000/sysv4.opt:28
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -14009,113 +14050,176 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Tasaa funktioiden alut"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
 msgstr "Tuota koodia big-endian-tilassa"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 #| msgid "Generate code in big endian mode"
 msgid "Generate code in little-endian mode."
 msgstr "Tuota little-endian-koodia"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 msgid "Use reduced-set registers for register allocation."
 msgstr ""
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 #| msgid "Use registers for argument passing"
 msgid "Use full-set registers for register allocation."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
 #, fuzzy
+#| msgid "Align code and data to 32 bits"
+msgid "Align function entry to 4 byte."
+msgstr "Kohdista koodi ja data 32 bittiin"
+
+#: config/nds32/nds32.opt:91
+#, fuzzy
 msgid "Generate conditional move instructions."
 msgstr "Tuota mul64- ja mulu64-käskyjä"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate performance extension instructions."
 msgstr "Tuota mul64- ja mulu64-käskyjä"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate performance extension version 2 instructions."
 msgstr "Tuota mul64- ja mulu64-käskyjä"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate string extension instructions."
 msgstr "Tuota mul64- ja mulu64-käskyjä"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "Tuota mul64- ja mulu64-käskyjä"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 #| msgid "Generate bit instructions"
 msgid "Generate 16-bit instructions."
 msgstr "Tuota isel-käskyjä"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
 msgstr "Ota käyttöön moniydintuki"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 #, fuzzy
 msgid "Known arch types (for use with the -march= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 #, fuzzy
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 msgid "Specify the cpu for pipeline model."
 msgstr "Malli:"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 #, fuzzy
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
 #, fuzzy
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "epäkelpo osoitintila %qs"
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
+#, fuzzy
 #| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
 msgstr "Varoita kun kaikki muodostimet ja hajottimet ovat yksityisiä"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
 msgstr "Tuota isel-käskyjä"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+msgid "Generate single-precision floating-point instructions."
+msgstr "Salli laitteistöliukuluku-ABIn ja -käskyjen käyttö"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "Tuota koodia, joka käyttää 68881-liukulukukäskyjä"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr ""
@@ -15115,14 +15219,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Tuota mul64- ja mulu64-käskyjä"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-#| msgid "%qE is deprecated"
-msgid "%qs is deprecated"
-msgstr "%qE on vanhentunut"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 msgid "Do not generate mpy instructions for ARC700."
@@ -17599,8 +17695,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "laskettua arvoa ei käytetä"
@@ -17631,7 +17727,7 @@
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -18109,7 +18205,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -18135,12 +18231,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuuttia ei huomioida"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
@@ -18189,9 +18285,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -18204,8 +18300,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -18337,82 +18433,76 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "liian vähän argumentteja funktiolle %<va_start%>"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "argumentti %qd ei ole vakio"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_frame_address%>"
@@ -18419,72 +18509,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
@@ -18491,7 +18581,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
@@ -18498,12 +18588,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>-fuktion toisen argumentin pitää olla 1"
@@ -18510,63 +18600,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "funktiota %<va_start%> käytetty funktiossa, jolla on kiinteä määrä argumentteja"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>-funktion toinen parametri ei ole viimeinen nimetty argumentti"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -19741,37 +19831,37 @@
 msgid "conversion to incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -19926,12 +20016,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -20041,12 +20131,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivirheellä: %s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivaroituksella: %s"
@@ -20061,12 +20151,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
@@ -20076,42 +20166,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "suuri kokonaisluku implisiittisesti katkaistu etumerkittömäksi tyypiksi"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -20655,29 +20745,29 @@
 msgid "can%'t write PCH file"
 msgstr "ei voi kirjoittaa tiedostoon %s: %m"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qD source argument is the same as destination"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -20691,12 +20781,13 @@
 msgid "null pointer dereference"
 msgstr "PRINT_OPERAND null-osoitin"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "esitelty täällä"
@@ -21219,10 +21310,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -21252,7 +21343,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 #, fuzzy
 #| msgid "cleanup argument not a function"
 msgid "%G%qD source argument is the same as destination"
@@ -21603,258 +21694,263 @@
 msgid "function cannot be instrumented"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, fuzzy, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr "typeid:tä ei voi käyttää -fno-rtti-valitsimen kanssa"
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, fuzzy, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr ""
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, fuzzy, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "TAPA"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "edellinen määrittely täällä"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type name %qs should match type name %qs"
 msgstr "Käyttö: %s [VALITSIN]... NIMI TYYPPI [MAJOR MINOR]\n"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 #| msgid "Array reference out of bounds"
 msgid "array types have different bounds"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "<return value> "
 msgid "return value type mismatch"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, fuzzy, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "ehtolausekkeessa on osoitin/kokonaislukutyyppiristiriita"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "edellinen määrittely täällä"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "type %qT should match type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, fuzzy, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, fuzzy, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, fuzzy, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, fuzzy, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, fuzzy, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, fuzzy, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, fuzzy, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -21876,7 +21972,7 @@
 msgid "the extra base is defined here"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -21883,7 +21979,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -21890,7 +21986,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -21897,7 +21993,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -21904,7 +22000,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -21911,7 +22007,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -22195,30 +22291,35 @@
 #: multiple_target.c:91
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "versioattribuutti ei ole merkkijono"
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "versioattribuutti ei ole merkkijono"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 msgid "default target was not set"
 msgstr "# Ei kohde:"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -22535,12 +22636,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Kelvolliset argumentit:"
@@ -23134,22 +23235,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -23193,7 +23294,7 @@
 msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "nimellä %qD"
@@ -23434,159 +23535,159 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "funktion palauttava funktio"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qD ei ole muuttuja"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "tiedostolla %s on tuntematon tiedostotyyppi"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "node is alias but not definition"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "node is transparent_alias but not an alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, fuzzy, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Sama kuin --help=target"
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, fuzzy, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify epäonnistui"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -24752,12 +24853,12 @@
 msgid "control reaches end of non-void function"
 msgstr "ei-void-tyyppisen funktion loppu saavutettu"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "attribuutilla warn_unused_result esitellyn funktion paluuarvoa ei huomioida"
@@ -25264,7 +25365,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -25309,94 +25410,94 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, fuzzy, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "------ Semaforitaulukot --------\n"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE on vanhentunut: %s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE on vanhentunut: %s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "tyyppi on vanhentunut: %s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tyyppi on vanhentunut"
@@ -25421,243 +25522,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, fuzzy, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr "Tiedoston tyyppi eroaa"
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, fuzzy, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13083
+#: tree.c:13088
 #, fuzzy, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, fuzzy, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13156
+#: tree.c:13161
 #, fuzzy, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: tree.c:13198
+#: tree.c:13203
 #, fuzzy, gcc-internal-format
 msgid "and field"
 msgstr "kentän leveys"
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, fuzzy, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, fuzzy, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "”%s” on määrittelemättä"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, fuzzy, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, fuzzy, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: tree.c:13614
+#: tree.c:13619
 #, fuzzy, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, fuzzy, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree.c:13688
+#: tree.c:13693
 #, fuzzy, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -25683,12 +25784,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, fuzzy, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "Tiedoston kokoraja ylitetty"
@@ -26588,7 +26689,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "ehdotetaan sulkeita totuusarvona käytetyn sijoituksen ympärille"
@@ -26842,7 +26943,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "taulukon koko on liian suuri"
@@ -27462,7 +27563,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -27478,22 +27579,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "’(’ puuttuu predikaatin jäljestä"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -28043,8 +28144,8 @@
 msgid "wrong type argument to %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
@@ -28695,7 +28796,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
@@ -28777,7 +28878,7 @@
 msgstr[0] "sijoitus hylkää kohdeosoitintyypin määreitä"
 msgstr[1] "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -28908,47 +29009,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -28974,31 +29075,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "%s: tuntematon valitsin ”%s”\n"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -29488,8 +29589,8 @@
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -29570,8 +29671,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, fuzzy, gcc-internal-format
 msgid "bad builtin fcode"
@@ -29682,11 +29783,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -29696,154 +29797,144 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "tämä on käsky:"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
@@ -29869,153 +29960,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "mountin käyttöön vaaditaan pääkäyttäjän oikeudet"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "PEITE"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -30830,12 +30921,12 @@
 msgid "invalid IACC argument"
 msgstr "virheellinen IACC-argumentti"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, fuzzy, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "%qs odottaa vakioargumenttia"
@@ -30935,7 +31026,7 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
@@ -30942,566 +31033,551 @@
 "Käyttö: %s KOMENTO [ARGUMENTTI]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "Tuntematon valitsin: %s %s %s"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "tuntematon valitsin -%s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "”%s”-liitännäinen on yhteensopiva."
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
@@ -31508,204 +31584,204 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "%s: %s: täsmäävyyttä ei löydy"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "SISÄÄNRAKENNETTU CD %s\n"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
@@ -31712,109 +31788,109 @@
 "Vihje: %s\n"
 "\n"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "Funktio %qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "tuntematon värimoodi"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -32037,7 +32113,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -32569,8 +32645,35 @@
 msgid "constant argument out of range for %s"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:702
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:717
 #, fuzzy, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "ISO C kieltää sisäkkäiset funktiot"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+#| msgid "Generate bit instructions"
+msgid "don't support performance extension instructions"
+msgstr "Tuota mul64- ja mulu64-käskyjä"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+#| msgid "Generate bit instructions"
+msgid "don't support performance extension version 2 instructions"
+msgstr "Tuota mul64- ja mulu64-käskyjä"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 #| msgid "Enable sign extend instructions"
 msgid "don't support string extension instructions"
 msgstr "Ota käyttöön etumerkilliset laajennetut käskyt"
@@ -32591,46 +32694,63 @@
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
+#, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr ""
+
+#: config/nds32/nds32.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
@@ -32844,37 +32964,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -32968,12 +33088,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -33023,7 +33143,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
@@ -33339,7 +33459,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -33349,7 +33469,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -33359,12 +33479,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -33374,29 +33494,29 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -33417,13 +33537,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
@@ -33445,54 +33565,54 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -33618,7 +33738,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
@@ -33628,12 +33748,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
@@ -33643,22 +33763,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -33668,7 +33788,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -34134,22 +34254,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
@@ -34212,30 +34332,35 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, fuzzy, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
+
+#: config/rs6000/rs6000-c.c:7058
+#, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "virheellinen parametri %qs"
@@ -34361,172 +34486,172 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Vanhentunut. Tämä valitsin ei vaikuta mihinkään"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %<__builtin_args_info%> out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "tyhjä %s ei ole sallittu"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -35327,7 +35452,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
@@ -35579,7 +35704,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
@@ -35589,7 +35714,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "varjostunut esittely on täällä"
@@ -35653,7 +35778,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Jokaisesta esittelemättömästä tunnisteesta ilmoitetaan vain"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -35683,7 +35808,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "%qE-nimiön kaksoisesittely"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
@@ -35803,7 +35928,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -36061,7 +36186,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "tallennusluokka annettu nimettömälle parametrille"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "tallennusluokka annettu typenamelle"
@@ -36225,7 +36350,7 @@
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
@@ -36355,7 +36480,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "muuttuja tai kenttä %qE esitelty voidiksi"
@@ -36535,7 +36660,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
@@ -36585,7 +36710,7 @@
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
@@ -36622,7 +36747,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
@@ -36652,7 +36777,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
@@ -36683,7 +36808,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -36798,12 +36923,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
@@ -36869,7 +36994,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
@@ -37018,38 +37143,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
@@ -37082,7 +37207,7 @@
 msgid "to match this %qs"
 msgstr "toinen täsmäävyys on täällä"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
@@ -37124,7 +37249,7 @@
 msgstr "%qE ei nimeä tyyppiä"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
@@ -37139,7 +37264,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
@@ -37154,8 +37279,8 @@
 msgid "unexpected attribute"
 msgstr "Odottamattomat argumentit"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
@@ -37195,7 +37320,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -37223,7 +37348,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "odotettiin merkkijonoliteraalia"
@@ -37288,13 +37413,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "luetellun tyypin luettelon lopussa on pilkku"
@@ -37424,7 +37549,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "#else #else:n jälkeen"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ilman edeltävää %<if%>:iä"
@@ -37458,22 +37583,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<if%>-lauseessa"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<else%>-lauseessa"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "ehdotetaan aaltosulkeita epäselvän %<else%>:n välttämiseksi"
@@ -37493,12 +37618,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -37525,12 +37650,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%Jviimeksi käytetty täällä"
@@ -37824,7 +37949,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -37884,77 +38009,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "kuori on annettava polkuineen"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -37970,55 +38095,55 @@
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -38041,90 +38166,90 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<scalar%>"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "%s: liian monta argumenttia\n"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "sekä %<long%> että %<void%> esittelymääritteissä"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
@@ -38135,13 +38260,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
@@ -38161,17 +38286,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -38182,70 +38307,70 @@
 msgid "invalid proc_bind kind"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<namespace%>"
 msgid "expected %<#pragma acc%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "Funktio %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -38260,7 +38385,7 @@
 msgid "expected function name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
@@ -38270,45 +38395,45 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -38318,22 +38443,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -38343,27 +38468,27 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
@@ -38370,47 +38495,47 @@
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 # XXXXXXX
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -38430,33 +38555,33 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "# Ei kohde:"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -38514,47 +38639,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -38571,7 +38696,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
@@ -38696,7 +38821,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "taulukon indeksi ei ole kokonaisluku"
@@ -38721,7 +38846,7 @@
 msgid "enum constant defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -38824,18 +38949,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "vertailu merkkijonoliteraalin kanssa aiheuttaa määrittelemätöntä toimintaa"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "osoittimen ja kokonaisluvun välinen vertailu"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -38861,7 +38986,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
@@ -39101,7 +39226,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "tyyppimuunnos %qT-tyyppisestä funktiokutsusta yhteensopimattomaan tyyppiin %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "tyyppimuunnos erikokoisesta kokonaisluvusta osoittimeksi"
@@ -39263,7 +39388,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
@@ -39333,7 +39458,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
@@ -39409,12 +39534,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "perinteinen C ei hyväksy automaattista koostealustusta"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen alustus"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "merkkitaulukon alustus leveästä merkkijonosta"
@@ -39460,7 +39585,7 @@
 msgid "invalid initializer"
 msgstr "epäkelpo alustin"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
@@ -39475,7 +39600,7 @@
 msgid "braces around scalar initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "joustavan taulukkojäsenen alustaminen sisäkkäisessä asiayhteydessä"
@@ -39605,7 +39730,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
@@ -39646,7 +39771,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, fuzzy, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -39656,17 +39781,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -39693,22 +39818,22 @@
 msgid "expression statement has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "liukulukujen vertailu operaattoreilla == ja != on epävarmaa"
@@ -39759,7 +39884,7 @@
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
@@ -39789,12 +39914,12 @@
 msgid "used vector type where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -39805,27 +39930,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qE is a member of a union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs määritelty parametrille %qE"
@@ -39837,72 +39962,72 @@
 msgstr "bittikentän %qs leveys on nolla"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "zero length array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
@@ -39923,7 +40048,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
@@ -39934,17 +40059,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -39959,18 +40084,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -39982,32 +40107,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
@@ -40027,57 +40152,57 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
@@ -40087,32 +40212,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -40254,7 +40379,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -40333,27 +40458,27 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "operaatioita semop-kutsua kohden enintään = %d\n"
@@ -40360,242 +40485,242 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "Ei vastaavuutta"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "Virheellinen järjestelmäkutsu"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "moniselitteinen argumentti %s %s:lle"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "Ei vastaavuutta"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, fuzzy, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E::%E%> ei ole luokka eikä nimiavaruus"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "<tuntematon operaattori>"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E::%E%> ei ole tyyppi"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "%<%s %E%> esitelty parametriluettelon sisällä"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%s: odotettiin unaarista operaattoria"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C++ kieltää ?:-lausekkeen käytön ilman keskimmäistä termiä"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr ""
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, fuzzy, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "Funktio %qs:"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is inaccessible within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "muunnetaan %<false%> osoitintyyppiksi %2$qD:n argumentissa %1$P"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "liikaa aaltosulkeita %qT:n alustimen ympärillä"
@@ -40602,403 +40727,403 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi välittää %<...%>:n kautta"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
 # XXX
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT ei ole nimiavaruus"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "esitelty täällä"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "%s: valitsin on moniselitteinen; vaihtoehdot:"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "arvon palautus hajottimesta"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, fuzzy, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " ehdokas 1: %q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " ehdokas 2: %q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -41040,8 +41165,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "edellinen esittely %q+D"
@@ -41082,7 +41207,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "esitelty täällä"
@@ -41166,7 +41291,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -41459,7 +41584,7 @@
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
@@ -41529,7 +41654,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "liian vähän argumentteja"
@@ -41624,342 +41749,342 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "esittely ei esittele mitään"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "protokollalla %qE on kehäriippuvuus"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "accessing uninitialized array element"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Jako nollalla kohdassa %L"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -42008,7 +42133,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -42019,311 +42144,311 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, fuzzy, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr ""
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion to non-scalar type requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "pyydetty muuntoa ei-skalaarityypiksi"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "kutsuttu täältä"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "epäkelpo %qs:n soveltaminen vaillinaiseen tyyppiin %qT "
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr ""
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "ei-liukulukuargumentti funktiolle %qs"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, fuzzy, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "puuttuva kasvatuslauseke"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "ei-yksiselitteinen oletustyyppimuunnos tyypistä %qT"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -42365,213 +42490,213 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%<static%>-määreellä esitelty muuttuja esitelty uudelleen %<extern%>-tyyppiseksi"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "%qs esitelty funktiotaulukkona"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "edellisestä esittelystä %q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "edellinen esittely %q+D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "%q+D on yleensä funktio"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, fuzzy, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "%q+D:n osoitealue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "%q+D:n osoitealue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "ei-yksiselitteistää vanhan esittelyn %q+#D"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "ei-yksiselitteistää vanhan esittelyn %q+#D"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "tyhjä esittely"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, fuzzy, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "conflicting declaration of template %q+#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration %q+#D"
 msgstr "%q+D:lle ei ole edellistä esittelyä"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "%q+#D:n esittely"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration of C function %q+#D"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguates old declaration %q+#D"
 msgid "ambiguating new declaration of %q+#D"
 msgstr "%q+D:lle ei ole edellistä esittelyä"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "prototype specified for %q#D"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "edellinen määrittely oli täällä"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with new declaration with %qL linkage"
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "%q#D:n esittely C-kielen linkityksellä"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "%q#D:n esittely C-kielen linkityksellä"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %q+D"
@@ -42585,39 +42710,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
@@ -42625,647 +42750,647 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "säiekohtainen esittely %q#D seuraa ei-säiekohtaista esittelyä"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ei-säiekohtainen esittely %q#D seuraa säiekohtaista esittelyä"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "edellinen esittely"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  täältä"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "  siirtyy try-lohkoon"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ei ole luokka"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%> nimeää %q#T:n, joka ei ole tyyppi"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T:n attribuutin on oltava %qs-avainsanan perässä"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "useita tyyppejä yhdessä esittelyssä"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ kieltää nimettömät structit"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration %q+D"
 msgid "non-member-template declaration of %qD"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration %q+D"
 msgid "does not match member template declaration here"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "muuttujalla %q#D on alustin, mutta vaillinaista tyyppiä"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD:n koko muistissa ei ole tunnettu"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD:n koko muistissa ei ole vakio"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  voit kiertää tämän poistamalla alustimen"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "muuttuvakokoinen yhdysliteraali"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D on vaillinaista tyyppiä"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalaariobjekti %qD vaatii yhden alkion alustimeensa"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "taulukko %qD alustettu sulkujen sisällä olevalla merkkijonoliteraalilla %qE"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, fuzzy, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "%q+D:n edellinen esittely"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr "parametrilla %P on vaillinainen tyyppi %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -43273,7 +43398,7 @@
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -43280,7 +43405,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -43287,889 +43412,899 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
+#, fuzzy, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "paluutyyppi on vaillinainen tyyppi"
+
+#: cp/decl.c:7774
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%qD:n poistettu määrittely"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %q#D declared with type qualifiers"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %q#D declared with type qualifiers"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, fuzzy, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "keskeytysfunktiolla on oltava void-paluutyyppi"
 
 # semi-fuzzy
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taulukon %qD koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "taulukon %qD koko on negatiivinen"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "taulukon koko on negatiivinen"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon %qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "taulukon koon ylivuoto"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD:n esittely void-taulukkona"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD:n esittely funktioiden taulukkona"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "luodaan funktioiden taulukko"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "luodaan viitteiden taulukko"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD:n esittely funktiojäsenten taulukkona"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "luodaan funktiojäsenten taulukkoa"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "nimetön muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ kieltää muuttujan %qs esittelyn ilman tyyppiä"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> tai %<unsigned%> virheellinen %qs:lle"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "sekä %<signed%> että %<unsigned%> määritelty %qs:lle"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> virheellinen %qs:lle"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> tai %<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> tai %<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> tai %<long%> virheellinen %qs:lle"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, fuzzy, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "tallennusluokka annettu malliparametrille %qs"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, fuzzy, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
+#| msgid "type qualifiers ignored on function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
+
+#: cp/decl.c:11156
+#, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:11099
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
-msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
-
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -44176,59 +44311,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -44235,252 +44370,252 @@
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -44487,164 +44622,164 @@
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -44651,77 +44786,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -44741,176 +44876,176 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, fuzzy, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "lueteltu tyyppi määritelty täällä"
@@ -44922,94 +45057,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%q+D on yleensä funktio"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%q+D on yleensä funktio"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
@@ -45018,77 +45153,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "virheellinen jäsenfunktioesittely"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -45128,7 +45263,7 @@
 msgid "deleting %qT is undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malliesittelylle %q+D"
@@ -45141,7 +45276,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
@@ -45255,44 +45390,44 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
 # semi-fuzzy
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "private member %q#D in anonymous union"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
@@ -45301,67 +45436,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%>:n ensimmäisen parametrin tyypin on oltava %<size_t%> (%qT)"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>:n ensimmäisen parametrin tyypin on oltava %qT"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
@@ -45370,62 +45505,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
@@ -45432,17 +45567,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "poistettu funktio %q+D"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -45452,113 +45587,113 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "ei argumentteja"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%E%> on esittelemättä"
@@ -45704,363 +45839,363 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr ""
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "union määritelty täällä"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "initializer for flexible array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD tulee alustaa jäsenten alustuslistassa"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "parametri %qD on alustettu"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, fuzzy, gcc-internal-format
 msgid "  base %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  tässä alustuksessa"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, fuzzy, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, fuzzy, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "muotoilu %s päättyy %%:iin"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, fuzzy, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -46072,7 +46207,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -46156,67 +46291,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, fuzzy, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, fuzzy, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "Tyyppi"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "kolmoismerkki ??%c muunnettu merkiksi %c"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -46337,44 +46472,44 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -46383,59 +46518,59 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-esittely %qD paikallisessa luokassa ilman edeltävää esittelyä"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, fuzzy, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "Konenimen hakuvirhe"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr ""
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "%qT is not a namespace or unscoped enum"
@@ -46443,12 +46578,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr ""
@@ -46455,105 +46590,105 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT ei ole nimiavaruus"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, fuzzy, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD on esittelemättä tällä näkyvyysalueella"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, fuzzy, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD esitelty täällä"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%<fast_interrupt%>-attribuuttidirektiivi jätetty huomiotta"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -46560,12 +46695,12 @@
 msgstr[0] "ehdotettu vaihtoehto:"
 msgstr[1] "ehdotetut vaihtoehdot:"
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%qE on vanhentunut"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -46572,71 +46707,77 @@
 msgid "suggested alternative: %qs"
 msgstr "ehdotettu vaihtoehto:"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%<this%> is unavailable for static member functions"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "struct määritelty täällä"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -46656,7 +46797,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -46681,7 +46822,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> on esittelemättä"
@@ -46761,7 +46902,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -46985,7 +47126,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -47065,7 +47206,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qT ei ole luokka tai nimiavaruus"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -47080,870 +47221,860 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
-#, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ID"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ kieltää yhdysliteraalit"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, fuzzy, gcc-internal-format
 msgid "non-scalar type"
 msgstr "pyydetty muuntoa ei-skalaarityypiksi"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "vanhanmallisen tyyppimuunnoksen käyttö"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "suosittellaan sulkumerkkejä %<>>%>-lausekkeen ympärille"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
+#, fuzzy, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
+
+#: cp/parser.c:10119
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D esitelty täällä"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> ei ole lohkon alussa"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "%s: virheellinen kenttämääritys %s"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "odotettiin %<operator%>"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Avainsana %s on tuntematon tai sillä ei vielä ole toteutusta"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, fuzzy, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "anonyymit variadiset makrot esiteltiin C99:ssä"
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(G++ hyväksyy koodin -fpermissive-valitsimella)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "odotettiin %<template%>"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, fuzzy, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "Odotettu nimi"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, fuzzy, gcc-internal-format
 msgid "namespace name required"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot be inline"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
@@ -47952,17 +48083,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -47969,388 +48100,388 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "id="
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "odotettiin %<,%> tai %<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C90 ei tue joustavia taulukkojäseniä"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ei löydetä luokkaa %qE"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-tarkenne funktiomäärittelyssä"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "vakio tai tunniste odotettu"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -48359,414 +48490,414 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "[Tyhjä]"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "    Ei ilmaistuja epäjäseniä\n"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %<const%>"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "nimiö "
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "Taso 2 ei ole synkronoitu"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "odotettiin %<:%> tai %<...%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # XXX
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, fuzzy, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "%qE ei ole Objective-C-luokkanimi eikä -alias"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "mahdollisia ikisilmukoita ei voi optimoida"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%qD does not refer to a namespace scope function"
@@ -48773,115 +48904,115 @@
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, fuzzy, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "_Peru"
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, fuzzy, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, fuzzy, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
@@ -48888,89 +49019,89 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %d"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "ensiö"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "ensiö"
@@ -48977,57 +49108,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, fuzzy, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ei ole mallifunktio"
@@ -49040,138 +49171,138 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "explicit specialization of function concept %qD"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <nimetön>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "ensiö"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "ensiö"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -49178,17 +49309,17 @@
 msgstr[0] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 msgstr[1] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -49196,47 +49327,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -49246,57 +49377,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "Vaaditaan todennus.\n"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -49303,7 +49434,7 @@
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -49310,12 +49441,12 @@
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
@@ -49324,117 +49455,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "edellinen määrittely oli täällä"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "varjostunut esittely on täällä"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -49443,292 +49574,298 @@
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "provided for %qD"
 msgstr "nimellä %qD"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "use of invalid variable template %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "joustava taulukkojäsen unionissa"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q+D määritelty uudelleen"
@@ -49746,208 +49883,208 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 msgid "%s %#qS"
 msgstr ""
@@ -49955,72 +50092,72 @@
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "%q+D:n edellinen esittely oli täällä"
@@ -50032,108 +50169,113 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
+
 #: cp/repo.c:113
 #, fuzzy, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -50342,7 +50484,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, fuzzy, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
@@ -50392,7 +50534,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
@@ -50465,307 +50607,308 @@
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
-msgstr ""
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
+msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "%s:n arvon on oltava kokonaisluku"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -50892,12 +51035,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "nolla nollaosoitinvakiona"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
@@ -50959,667 +51102,668 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen bittikenttään"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "%<__alignof%>-avainsanaa sovellettu bittikenttään"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "nimikkeen osoitteen ottaminen ei ole standardia"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "vanhentunut tyyppimuunnos merkkijonovakiosta tyyppiin %qT"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "vanhentunut tyyppimuunnos merkkijonovakiosta tyyppiin %qT"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr ""
 
 # semi-fuzzy
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, fuzzy, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ kieltää %<::main%>-funktion kutsumisen ohjelmasta"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "liikaa argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "liian vähän argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "liikaa argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "liikaa argumentteja metodille %q#D"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "liikaa argumentteja funktiolle"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "liian vähän argumentteja funktiolle"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL-arvon käyttö laskutoimituksessa"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "vasemmalle kierron laskuri on negatiivinen"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "oikealle kierron laskuri on negatiivinen"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, fuzzy, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, fuzzy, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ kieltää osoittimen ja kokonaisluvun vertailun"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ kieltää %<void *%>-tyyppisen osoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ kieltää funktio-osoittimen käytön vähennyslaskussa"
 
 # semi-fuzzy; onko metodi tässä luokan jäsenfunktio ja yllä muu funktio?
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "muodostimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, fuzzy, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "id="
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "väliaikaismuuttujan osoitteen ottaminen"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ kieltää %<::main%>-funktion osoitteen ottamisen"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ kieltää enumin vähentämisen"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen kasvattamisen"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen vähentämisen"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, fuzzy, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "halutaan globaalin rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "tyyppimuunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 #| msgid "useless cast to type %qT"
 msgid "useless cast to type %q#T"
 msgstr "tarpeeton tyyppimuunnos tyyppiin %qT"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "muunnos tyypistä %qT tyyppiin %qT kasvattaa kohdetyypin vaadittua kohdistusta"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ kieltää tyyppimuunnoksen funktio-osoittimen ja olio-osoittimen välillä"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ kieltää tyyppimuunnoksen taulukkotyyppiin %qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, fuzzy, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "ei-vakio taulukon indeksi alustimessa"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "taulukkoa käytetty alustimena"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "virheellinen taulukkosijoitus"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8786
+# XXX
+# %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
+msgid "cannot convert %qH to %qI"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -51626,7 +51770,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -51633,21 +51777,14 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-msgid "cannot convert %qH to %qI"
-msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
-
-# XXX
-# %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8804
-#, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
@@ -51654,77 +51791,77 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of %qD"
 msgid "in passing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, fuzzy, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "arvon palautus hajottimesta"
@@ -51731,56 +51868,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "arvon palautus muodostimesta"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "taulukon palauttava funktio"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> ei saa palauttaa NULLia ellei esittely ole %<throw()%> (tai -fcheck-new ole voimassa)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -52006,148 +52143,148 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "muodostinsyntaksia on käytetty, mutta %qT-tyypin muodostinta ei ole esitelty"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "%qE:n kaventava muunnos tyypistä %qT tyyppiin %qT { }:n sisällä"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int-taulukko alustettu epäleveästä merkkijonosta"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int-taulukko alustettu yhteensopimattomasta leveästä merkkijonosta"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "merkkitaulukon alustusmerkkijono on liian pitkä"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member %qD"
 msgid "member %qD with uninitialized reference fields"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -52579,27 +52716,27 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Taulukkoviite rajojen ulkopuolella"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 msgid "Simplification error"
@@ -52607,22 +52744,22 @@
 " EPÄONNISTUI\n"
 "\n"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -53685,7 +53822,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -53869,7 +54006,7 @@
 msgid "deferred type parameter at %C"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -54131,458 +54268,458 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Ei-vakio tyyppiesittely %s*%d kohdassa %C"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "loppumerkki %c puuttuu"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Kaksoiskappele %s attribuutti kohdassa %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribuutti kohdassa %L ei ole sallittu moduulin spesifikaatio-osan ulkopuolella"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "yhtenäistä dataa"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Useita tunnisteita tarjottu yhdellä NAME= tarkenteella kohdassa %C"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -54590,988 +54727,988 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "symboli ”%s”"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Odotettiin vaihtoehtoista paluunimiötä kohdassa %C"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Kaksoiskappalesymboli ”%s” muodollisessa argumenttiluettelossa paikassa %C"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-muuttujan paikassa %C on oltava erilainen kuin funktionimen"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaksivirhe proseduuriosoitinkomponentissa kohdassa %C"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Odotettiin ”%s”-lohkonimeä %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Odotettiin päättävää nimeä kohdassa %C"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Odottamaton merkki muuttujaluettelossa kohdassa %C"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-osoittimen kohdassa %C on oltava kokonaisluku"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-osoittimella kohdassa %C on %d-tavun tarkkuus; muistiosoitteet vaativat %d tavua"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Odotettiin ”)” kohdassa %C"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Odotettiin muuttujanimeä kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Odotettiin lauseketta kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Alustetaan jo alustettu muuttuja kohdassa %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Odottamattomia merkkejä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "abstrakti metodi ei-abstraktissa luokassa"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "%s: Tulostetiedoston %s sulkeminen epäonnistui\n"
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumeraattori ylittää C-kokonaislukutyypin kohdassa %C"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaksivirhe ENUMERATOR-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Roskaa CALL-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Tuntematon attribuutti !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
@@ -55917,29 +56054,29 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettien alivuoto muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettinen ylivuoto muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -56271,7 +56408,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
@@ -56281,63 +56418,63 @@
 msgid "Removing call to function %qs at %L"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "odotettiin lauseketta"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "Siirrä alas"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "epäkelpo totuusarvolauseke"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "continue-lause silmukan ulkopuolella"
@@ -56463,12 +56600,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -57692,7 +57829,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -59158,12 +59295,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -59415,8 +59552,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -59461,7 +59598,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -59813,184 +59950,184 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja ei saa olla THREADPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "Objekti ”%s” ei ole muuttuja kohdassa %L"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -61388,7 +61525,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
@@ -61502,7 +61639,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -61883,229 +62020,229 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -62114,234 +62251,234 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
@@ -62348,12 +62485,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -62361,108 +62498,108 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -62469,69 +62606,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -62538,7 +62675,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -62546,59 +62683,59 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -62605,63 +62742,63 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
@@ -62669,868 +62806,868 @@
 "  tai:  %s -l [SIGNAALI]...\n"
 "  tai:  %s -t [SIGNAALI]...\n"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -63969,7 +64106,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -64628,18 +64765,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei ole kelvollinen ulottuvuusindeksi"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
@@ -64823,179 +64960,179 @@
 msgid "previously defined here as %s"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD on jo määritelty"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "määritelty aiemmin täällä"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "edellinen määrittely täällä"
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "funktio %qD esitelty uudelleen muuttujana"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "esitelty aiemmin täällä"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "ei voitu jäsentää heksadesimaalinumeroa"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "ei voitu jäsentää tiedostosiirrosta"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "odottamaton siirros"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "tiedoston ”%s” otsaketta ei voi lukea"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "tiedostoa %s ei voi avata"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "arkiston otsaketta ei voi kartoittaa"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "tietokantaa %s ei voi lukea"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid epäonnistui"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "  -time                    Mittaa kunkin aliprosessin suoritusaika\n"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, fuzzy, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "kirjoitettaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "avattaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "kirjoitettaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "suljettaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -67054,6 +67191,9 @@
 #~ msgid "invalid use of Boolean expression as operand to %<operator--%>"
 #~ msgstr "virheellinen loogisen lausekkeen käyttö operandina %<operator--%>:lle"
 
+#~ msgid "cannot convert %qT to %qT for argument %qP to %qD"
+#~ msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
+
 #~ msgid "return-statement with a value, in function returning 'void'"
 #~ msgstr "arvo return-lauseelle funktiossa, jonka paluutyyppi on ”void”"
 
Index: gcc/po/el.po
===================================================================
--- gcc/po/el.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/el.po	(.../branches/gcc-8-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -144,42 +144,42 @@
 msgid "negative insn length"
 msgstr ""
 
-#: final.c:3139
+#: final.c:3142
 #, fuzzy
 msgid "could not split insn"
 msgstr "αδυναμία εύρεσης βρόχου"
 
-#: final.c:3615
+#: final.c:3618
 #, fuzzy
 msgid "invalid 'asm': "
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr ""
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, fuzzy, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "μη τερματιζόμενο συμβολικό όνομα"
 
-#: final.c:3930
+#: final.c:3933
 #, fuzzy, c-format
 msgid "operand number missing after %%-letter"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, fuzzy, c-format
 msgid "operand number out of range"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: final.c:3991
+#: final.c:3994
 #, fuzzy, c-format
 msgid "invalid %%-code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr ""
@@ -190,13 +190,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, fuzzy, c-format
 msgid "invalid expression as operand"
@@ -1239,26 +1239,26 @@
 msgid "At top level:"
 msgstr ""
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, fuzzy, c-format
 msgid "In member function %qs"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In function %qs"
 msgstr "Στη συνάρτηση %qs:"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr ""
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr ""
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, fuzzy, c-format
 msgid "    inlined from %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
@@ -3026,9 +3026,9 @@
 msgid "invalid address mode"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3044,7 +3044,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, fuzzy, c-format
 msgid "invalid %%R value"
@@ -3051,13 +3051,13 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
@@ -3088,7 +3088,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
@@ -3099,7 +3099,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
@@ -3110,7 +3110,7 @@
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, fuzzy, c-format
 msgid "invalid %%xn code"
@@ -3121,57 +3121,57 @@
 msgid "invalid operand address"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, fuzzy, c-format
 msgid "invalid operand to %%Z code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, fuzzy, c-format
 msgid "invalid operand to %%z code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 msgid "invalid operands to %%c code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, fuzzy, c-format
 msgid "invalid operand to %%M code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, fuzzy, c-format
 msgid "invalid operand to %%p code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, fuzzy, c-format
 msgid "invalid operand to %%s code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, fuzzy, c-format
 msgid "invalid operand to %%R code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, fuzzy, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, fuzzy, c-format
 msgid "invalid operand to %%U code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, fuzzy, c-format
 msgid "invalid operand to %%V code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, fuzzy, c-format
 msgid "invalid operand to %%O code"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -3178,18 +3178,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "Μη έγκυρος κώδικας αίτησης"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 #, fuzzy
 msgid "unrecognized supposed constant"
 msgstr "άγνωστο πρόθεμα: %s"
@@ -3225,7 +3225,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, fuzzy, c-format
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -3355,8 +3355,8 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3607,98 +3607,98 @@
 msgid "bad output_condmove_single operand"
 msgstr "αρχείο εξόδου"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 msgid "invalid use of register '%s'"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "μη έγκυρο δικαίωμα"
 
 # src/grep.c:1133
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "άγνωστη μέθοδος καταλόγων"
@@ -3740,7 +3740,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -3796,7 +3796,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -3966,145 +3966,145 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4231,43 +4231,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, fuzzy, c-format
 msgid "invalid %%Y operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, fuzzy, c-format
 msgid "invalid %%A operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, fuzzy, c-format
 msgid "invalid %%B operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, fuzzy, c-format
 msgid "invalid %%f operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, fuzzy, c-format
 msgid "invalid %%s operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4490,14 +4490,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4512,7 +4512,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4520,7 +4520,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4534,7 +4534,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4541,7 +4541,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4551,13 +4551,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4567,18 +4567,18 @@
 msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4586,23 +4586,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4612,7 +4612,7 @@
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4623,41 +4623,41 @@
 msgid "expected label"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr ""
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 #, fuzzy
 msgid "jump to label %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 msgid "enters try block"
 msgstr ""
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 msgid "enters catch block"
 msgstr ""
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 msgid "enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 msgid "enters synchronized or atomic statement"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 msgid "enters constexpr if statement"
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
@@ -4758,7 +4758,7 @@
 msgid "<statement>"
 msgstr ""
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr ""
@@ -4777,120 +4777,120 @@
 msgid "<unparsed>"
 msgstr ""
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 msgid "<lambda>"
 msgstr ""
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr ""
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 #, fuzzy
 #| msgid "parse error"
 msgid "<expression error>"
 msgstr "σφάλμα επεξεργασίας"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr ""
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr ""
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, fuzzy, c-format
 msgid "In static member function %qs"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr ""
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, fuzzy, c-format
 msgid "In constructor %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, fuzzy, c-format
 #| msgid "In function %qs:"
 msgid "In destructor %qs"
 msgstr "Στη συνάρτηση %qs:"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 #, fuzzy
 #| msgid "In function"
 msgid "In lambda function"
 msgstr "Στη συνάρτηση"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr ""
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr ""
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, c-format
 msgid "required by substitution of %qS\n"
 msgstr ""
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 msgid "recursively required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 msgid "required from %q#D\n"
 msgstr ""
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 msgid "recursively required from here\n"
 msgstr ""
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 msgid "required from here\n"
 msgstr ""
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr ""
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4943,49 +4943,49 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -5285,12 +5285,12 @@
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -5470,48 +5470,48 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5554,12 +5554,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5821,6 +5821,7 @@
 msgstr ""
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr ""
 
@@ -8589,7 +8590,7 @@
 msgstr ""
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 msgid "Specify the name of the target architecture."
 msgstr ""
 
@@ -9056,7 +9057,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 msgid "Specify bit size of immediate TLS offsets."
 msgstr ""
 
@@ -9755,7 +9756,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr ""
 
@@ -10168,7 +10169,7 @@
 msgstr ""
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
 msgstr ""
 
@@ -10177,12 +10178,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr ""
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr ""
 
@@ -10195,41 +10196,41 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
 msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 msgid "Make all function calls indirect."
 msgstr ""
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 msgid "Convert function return to call and return thunk."
 msgstr ""
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr ""
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1057
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr ""
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr ""
@@ -10636,7 +10637,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr ""
 
@@ -10644,7 +10645,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -10733,7 +10734,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
 msgstr ""
 
@@ -10763,7 +10764,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
 msgstr ""
 
@@ -10843,24 +10844,24 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -10880,19 +10881,19 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 msgid "Use vector instructions added in ISA 3.0."
 msgstr ""
 
@@ -10908,15 +10909,15 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 msgid "Generate the integer modulo instructions."
 msgstr "Ακατάλληλη εντολή"
@@ -10925,16 +10926,16 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -10942,7 +10943,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 msgid "Valid arguments to -mstack-protector-guard=:"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
@@ -10972,13 +10973,12 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr ""
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 msgid "Select ABI calling convention."
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 msgid "Select method for sdata handling."
 msgstr ""
 
@@ -11657,7 +11657,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr ""
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr ""
 
@@ -11857,14 +11857,22 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+msgid "Max number of bytes to compare without loops."
 msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
+msgid "Max number of bytes to compare with loops."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:346
+msgid "Max number of pairs of load insns for compare."
+msgstr ""
+
 #: config/rs6000/rs6000.opt:353
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
 msgstr ""
@@ -11873,10 +11881,39 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr ""
 
+#: config/rs6000/rs6000.opt:410
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:438
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+msgid "%qs is deprecated"
+msgstr "το `%s' δεν είναι κανονικό αρχείο"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
+
+#: config/rs6000/sysv4.opt:28
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 msgid "Use fp registers."
@@ -13064,96 +13101,155 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 #, fuzzy
 msgid "Generate code in big-endian mode."
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 #, fuzzy
 msgid "Generate code in little-endian mode."
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 msgid "Use reduced-set registers for register allocation."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 msgid "Use full-set registers for register allocation."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:91
 #, fuzzy
 msgid "Generate conditional move instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 msgid "Generate performance extension instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 msgid "Generate performance extension version 2 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 msgid "Generate string extension instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 msgid "Generate v3 push25/pop25 instructions."
 msgstr ""
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 #, fuzzy
 msgid "Generate 16-bit instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 msgid "Enable Virtual Hosting support."
 msgstr ""
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 msgid "Known arch types (for use with the -march= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 msgid "Specify the cpu for pipeline model."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr ""
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
 msgid "Enable constructor/destructor feature."
 msgstr ""
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 msgid "Guide linker to relax instructions."
 msgstr "Ακατάλληλη εντολή"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "Ακατάλληλη εντολή"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+msgid "Generate single-precision floating-point instructions."
+msgstr "Ακατάλληλη εντολή"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+msgid "Generate double-precision floating-point instructions."
+msgstr "Ακατάλληλη εντολή"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 msgid "Specify CPU for code generation purposes."
 msgstr ""
@@ -14030,13 +14126,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-msgid "%qs is deprecated"
-msgstr "το `%s' δεν είναι κανονικό αρχείο"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 msgid "Do not generate mpy instructions for ARC700."
@@ -16312,8 +16401,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr ""
@@ -16343,7 +16432,7 @@
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "Μη ορισμένο όνομα %s"
@@ -16818,7 +16907,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -16844,12 +16933,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
@@ -16898,9 +16987,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -16913,8 +17002,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -17045,82 +17134,76 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
@@ -17127,72 +17210,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, fuzzy, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr ""
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr ""
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr ""
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -17199,7 +17282,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -17206,12 +17289,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -17218,62 +17301,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr ""
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -18447,37 +18530,37 @@
 msgid "conversion to incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr ""
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr ""
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: convert.c:1129
+#: convert.c:1131
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "αδύνατη η μετατροπή του U+%04X στο τοπικό σύνολο χαρακτήρων"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr ""
@@ -18632,12 +18715,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18747,12 +18830,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18767,12 +18850,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
@@ -18782,42 +18865,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -19360,28 +19443,28 @@
 msgid "can%'t write PCH file"
 msgstr "αδυναμία εγγραφής αρχείων εξόδου στο `%s'"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr ""
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -19395,12 +19478,13 @@
 msgid "null pointer dereference"
 msgstr "Μη έγκυρη πισω-παραπομπή"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -19918,10 +20002,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -19950,7 +20034,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 msgid "%G%qD source argument is the same as destination"
 msgstr ""
 
@@ -20291,252 +20375,257 @@
 msgid "function cannot be instrumented"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr ""
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr ""
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr ""
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, fuzzy, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr ""
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, gcc-internal-format
 msgid "array types have different bounds"
 msgstr ""
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "Κακοσυνταίριασμα τύπων καταχώρησης/πίνακα"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, fuzzy, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr "Κακοσυνταίριασμα τύπων καταχώρησης/πίνακα"
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr ""
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr ""
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -20557,7 +20646,7 @@
 msgid "the extra base is defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
@@ -20564,7 +20653,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20571,7 +20660,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
@@ -20578,7 +20667,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
@@ -20585,7 +20674,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20592,7 +20681,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -20873,29 +20962,34 @@
 
 #: multiple_target.c:91
 #, gcc-internal-format
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr ""
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr ""
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr ""
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 msgid "default target was not set"
 msgstr "Δεν είναι δυνατόν να βρεθεί η προτεραιότητα."
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -21207,12 +21301,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -21804,22 +21898,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21863,7 +21957,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -22103,157 +22197,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr ""
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -23414,12 +23508,12 @@
 msgid "control reaches end of non-void function"
 msgstr "ο έλεγχος φθάνει στο τέλος μη-κενής συνάρτησης"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23925,7 +24019,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -23965,92 +24059,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9508
+#: tree.c:9513
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -24075,242 +24169,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13529
+#: tree.c:13534
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr ""
@@ -24335,12 +24429,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
@@ -25228,7 +25322,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -25479,7 +25573,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
@@ -26088,7 +26182,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -26103,22 +26197,22 @@
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -26669,8 +26763,8 @@
 msgid "wrong type argument to %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -27301,7 +27395,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
@@ -27377,7 +27471,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -27506,47 +27600,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr ""
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr ""
@@ -27573,31 +27667,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "άγνωστο σετ `%s'"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
 msgstr ""
@@ -28083,8 +28177,8 @@
 msgstr ""
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -28164,8 +28258,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28276,11 +28370,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -28290,145 +28384,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: config/arc/arc.c:6556
+#: config/arc/arc.c:6596
 #, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
-#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr ""
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr ""
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
@@ -28454,153 +28538,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -29410,12 +29494,12 @@
 msgid "invalid IACC argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, fuzzy, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
@@ -29515,566 +29599,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%s: η υποστήριξη εκσφαλμάτωσης δεν έχει συμπεριληφθεί στη μεταγλώττιση.\n"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, fuzzy, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -30081,311 +30150,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30610,7 +30679,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -31138,8 +31207,33 @@
 msgid "constant argument out of range for %s"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, gcc-internal-format
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:702
+#, gcc-internal-format
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:748
+#, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.c:760
+#, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr ""
 
@@ -31159,42 +31253,59 @@
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "position-independent code not supported"
@@ -31407,37 +31518,37 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -31531,12 +31642,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -31586,7 +31697,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
@@ -31888,7 +31999,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31898,7 +32009,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31908,12 +32019,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31923,28 +32034,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
@@ -31964,12 +32075,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
@@ -31991,53 +32102,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -32163,7 +32274,7 @@
 msgstr ""
 
 # src/shred.c:1134
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
@@ -32173,12 +32284,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -32188,22 +32299,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -32213,7 +32324,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -32678,22 +32789,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgstr ""
@@ -32756,30 +32867,35 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
+#, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.c:7058
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
@@ -32902,169 +33018,169 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "πάρα πολλά ορίσματα"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "Δεν είναι δυνατή η καταχώρηση της υπηρεσίας"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33864,7 +33980,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -34116,7 +34232,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -34126,7 +34242,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -34187,7 +34303,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -34218,7 +34334,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "διπλό κλειδί"
@@ -34336,7 +34452,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -34593,7 +34709,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -34752,7 +34868,7 @@
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -34879,7 +34995,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -35059,7 +35175,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -35110,7 +35226,7 @@
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -35147,7 +35263,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
@@ -35177,7 +35293,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -35207,7 +35323,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -35322,12 +35438,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -35390,7 +35506,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
@@ -35535,37 +35651,37 @@
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -35595,7 +35711,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -35636,7 +35752,7 @@
 msgstr "άγνωστος χαρακτήρας `%s'"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -35651,7 +35767,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -35666,8 +35782,8 @@
 msgid "unexpected attribute"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -35705,7 +35821,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -35733,7 +35849,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, fuzzy, gcc-internal-format
 msgid "expected string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
@@ -35797,13 +35913,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, fuzzy, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "σκουπίδια στο τέλος του αριθμού"
@@ -35933,7 +36049,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -35967,22 +36083,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -36002,12 +36118,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -36034,12 +36150,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -36316,7 +36432,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -36376,76 +36492,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -36460,53 +36576,53 @@
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -36528,82 +36644,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr ""
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr ""
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -36613,12 +36729,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -36638,17 +36754,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -36658,67 +36774,67 @@
 msgid "invalid proc_bind kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -36733,7 +36849,7 @@
 msgid "expected function name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -36743,42 +36859,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -36788,22 +36904,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -36813,72 +36929,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36898,32 +37014,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36978,47 +37094,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -37033,7 +37149,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, fuzzy, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -37158,7 +37274,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -37183,7 +37299,7 @@
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -37286,17 +37402,17 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -37321,7 +37437,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -37554,7 +37670,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -37713,7 +37829,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -37780,7 +37896,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -37850,12 +37966,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
@@ -37901,7 +38017,7 @@
 msgid "invalid initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -37916,7 +38032,7 @@
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -38046,7 +38162,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -38086,7 +38202,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -38096,17 +38212,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -38131,22 +38247,22 @@
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
@@ -38197,7 +38313,7 @@
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
@@ -38227,12 +38343,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -38242,25 +38358,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -38271,70 +38387,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -38354,7 +38470,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
@@ -38364,17 +38480,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -38389,18 +38505,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -38412,32 +38528,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -38457,55 +38573,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -38515,32 +38631,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -38671,7 +38787,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38749,21 +38865,21 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr ""
@@ -38770,7 +38886,7 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
@@ -38777,12 +38893,12 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr ""
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr ""
@@ -38789,522 +38905,522 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, fuzzy, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
 # src/main.c:785
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "Ασαφής μορφή `%s'"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, gcc-internal-format
 msgid "no match for "
 msgstr ""
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "σφάλμα στην ανάγνωση εισόδου: %s"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr ""
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr ""
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr ""
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr ""
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr ""
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 #| msgid "%s"
 msgid "%qs"
 msgstr "%s"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr ""
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr ""
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr ""
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr ""
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr ""
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr ""
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr ""
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr ""
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, fuzzy, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "Σφάλμα στο ταίριασμα στην κανονική έκφραση `%s'"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr ""
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%s(%A)%>"
@@ -39312,86 +39428,86 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "η κλήση της υπερφορτωμένης %<%s(%A)%> είναι διφορούμενη"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
@@ -39431,8 +39547,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -39473,7 +39589,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -39553,7 +39669,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -39830,7 +39946,7 @@
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
@@ -39900,7 +40016,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "εμφάνιση πληροφοριών προόδου"
@@ -39995,335 +40111,335 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40368,7 +40484,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -40378,308 +40494,308 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, fuzzy, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr ""
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr ""
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr ""
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr ""
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 msgid "in call to %qD, declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, fuzzy, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr ""
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr ""
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr ""
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr ""
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr ""
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr ""
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr ""
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr ""
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr ""
 
 # src/request.c:37
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, fuzzy, gcc-internal-format
 msgid "statement has no effect"
 msgstr "%s σε %s"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr ""
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr ""
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr ""
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr ""
@@ -40720,198 +40836,198 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr ""
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qF has a different exception specifier"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 msgid "from previous declaration %qF"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr ""
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr ""
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD was here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD was here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, fuzzy, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, fuzzy, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr ""
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 msgid "ignoring the %q#D declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr ""
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration %q+#D"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, fuzzy, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "%s: Μη έγκυρη ρύθμιση `%s'.\n"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
@@ -40924,39 +41040,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
@@ -40964,633 +41080,633 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr ""
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
 msgstr ""
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr ""
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr ""
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
-#, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr ""
+#: cp/decl.c:7339
+#, fuzzy, gcc-internal-format
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -41597,7 +41713,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -41604,7 +41720,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -41611,1151 +41727,1161 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
+#, fuzzy, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "μη πλήρης εγγραφή"
+
+#: cp/decl.c:7774
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.c:8996
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> πρέπει να επιστρέψει %<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
+#, fuzzy, gcc-internal-format
+msgid "deduced class type %qD in function return type"
+msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
+
+#: cp/decl.c:11156
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11099
+#: cp/decl.c:11169
 #, gcc-internal-format
-msgid "deduced class type %qT in function return type"
-msgstr ""
-
-#: cp/decl.c:11111
-#, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -42762,178 +42888,178 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -42940,77 +43066,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -43030,169 +43156,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -43204,23 +43330,23 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
@@ -43227,73 +43353,73 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -43302,77 +43428,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43412,7 +43538,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -43425,7 +43551,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -43536,42 +43662,42 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -43580,67 +43706,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -43649,62 +43775,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -43711,17 +43837,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -43731,93 +43857,93 @@
 msgid "with"
 msgstr ""
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "χωρίς ορίσματα"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr ""
@@ -43824,22 +43950,22 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, fuzzy, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, fuzzy, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -43985,275 +44111,275 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr ""
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/request.c:263
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, fuzzy, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ακατάλληλος τύπος δικτύου :`%s'\n"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -44260,87 +44386,87 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44352,7 +44478,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -44435,67 +44561,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr ""
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
@@ -44616,42 +44742,42 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 msgid "local external declaration %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 msgid "does not match previous declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -44659,59 +44785,59 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, fuzzy, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "η ομάδα του %s άλλαξε σε %s\n"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
 msgstr ""
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, gcc-internal-format
 msgid "  matches this %qD under old rules"
 msgstr ""
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, fuzzy, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "η ομάδα του %s άλλαξε σε %s\n"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr ""
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, gcc-internal-format
 msgid "using obsolete binding %qD"
 msgstr ""
 
 # src/request.c:37
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s: %s: "
 
 # src/request.c:37
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -44718,12 +44844,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr ""
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr ""
@@ -44730,103 +44856,103 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr ""
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, fuzzy, gcc-internal-format
 msgid "%qD not declared"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -44833,78 +44959,83 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -44924,7 +45055,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44949,7 +45080,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -45029,7 +45160,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45251,7 +45382,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "κενό αλφαριθμητικό"
@@ -45331,7 +45462,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
@@ -45346,611 +45477,601 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr ""
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast to %q#T"
 msgstr "παλαιού είδους θέση"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
 #, gcc-internal-format
+msgid "types may not be defined within __builtin_offsetof"
+msgstr ""
+
+#: cp/parser.c:10119
+#, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr ""
-
-#: cp/parser.c:12063
-#, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr ""
-
-#: cp/parser.c:12115
-#, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "πολλαπλός αριθμός επιλογών την εντολή `s'"
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "Μη ορισμένο όνομα %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
@@ -45957,253 +46078,253 @@
 
 # src/dfa.c:962
 # src/dfa.c:970
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Δεν ορίστηκε συντακτικό"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -46212,17 +46333,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -46229,382 +46350,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -46613,262 +46734,262 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
@@ -46875,258 +46996,258 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr ""
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, fuzzy, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr ""
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr ""
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 msgid "  from definition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr ""
@@ -47133,89 +47254,89 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
 # src/request.c:37
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s: %s"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
@@ -47222,57 +47343,57 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr ""
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -47285,137 +47406,137 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, fuzzy, gcc-internal-format
 msgid "        %qD"
 msgstr "        `%D'"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "((ανώνυμο))"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47422,17 +47543,17 @@
 msgstr[0] "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgstr[1] "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -47440,47 +47561,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -47490,57 +47611,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -47547,7 +47668,7 @@
 msgstr[0] "διπλό όνομα χαρακτήρα `%s'"
 msgstr[1] "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -47554,12 +47675,12 @@
 msgstr[0] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 msgstr[1] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -47568,117 +47689,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -47685,287 +47806,292 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr "μη έγκυρη ώρα της μέρας"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -47983,278 +48109,278 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
 # src/request.c:37
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -48266,106 +48392,113 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
+# src/grep.c:785 src/grep.c:792
+# src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -48569,7 +48702,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
@@ -48619,7 +48752,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -48691,39 +48824,39 @@
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4063
-#, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
+#: cp/semantics.c:4052
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
+#, fuzzy, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
+
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4089
+#: cp/semantics.c:4072
 #, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -48730,257 +48863,257 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "αποτυχία κατά την εγγραφή δεδομένων για την κατηγορία `%s'"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -49105,12 +49238,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -49170,735 +49303,730 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr ""
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, fuzzy, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
 # src/main.c:697 src/main.c:751
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "Άγνωστη γλώσσα `%s'"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 msgid "cannot call function %qD"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, fuzzy, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr ""
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr ""
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr ""
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr ""
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
 msgstr ""
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, fuzzy, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, fuzzy, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, fuzzy, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
+msgid "cannot convert %qH to %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-msgid "cannot convert %qH to %qI"
-msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
-
-#: cp/typeck.c:8804
-#, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -49905,55 +50033,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -50174,142 +50302,142 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr ""
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, fuzzy, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr ""
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -50733,48 +50861,48 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -51769,7 +51897,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -51940,7 +52068,7 @@
 msgid "deferred type parameter at %C"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -52192,173 +52320,173 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
 # src/request.c:263
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
@@ -52365,38 +52493,38 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
@@ -52403,243 +52531,243 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -52646,952 +52774,952 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "έχει παραληφθεί το όνομα της παραμέτρου"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Αγνωστος δυαδικός χειριστής."
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων κατηγοριών"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected"
 msgid "%<)%> expected at %C"
 msgstr "αναμενόταν '('"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -53928,27 +54056,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -54273,7 +54401,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -54284,62 +54412,62 @@
 msgid "Removing call to function %qs at %L"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 msgid "bad expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "μη έγκυρος χρήστης"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -54459,12 +54587,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -55657,7 +55785,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -57094,12 +57222,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -57339,8 +57467,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -57382,7 +57510,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
@@ -57723,182 +57851,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -59251,7 +59379,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -59363,7 +59491,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -59737,228 +59865,228 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -59967,232 +60095,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60199,12 +60327,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60212,107 +60340,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60319,67 +60447,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -60386,7 +60514,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -60394,57 +60522,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -60451,889 +60579,889 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
 # src/request.c:37
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -61769,7 +61897,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -62413,18 +62541,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -62609,177 +62737,177 @@
 msgid "previously defined here as %s"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, fuzzy, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, fuzzy, gcc-internal-format
 msgid "previously defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr ""
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, fuzzy, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
 msgstr ""
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, fuzzy, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, fuzzy, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, fuzzy, gcc-internal-format
 msgid "previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr ""
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr ""
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr ""
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, fuzzy, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, fuzzy, gcc-internal-format
 msgid "unexpected offset"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr ""
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr ""
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, fuzzy, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, fuzzy, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "σφάλμα εγγραφής %s"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, fuzzy, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/zh_CN.po
===================================================================
--- gcc/po/zh_CN.po	(.../tags/gcc_8_1_0_release)
+++ gcc/po/zh_CN.po	(.../branches/gcc-8-branch)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-03-29 23:05+0000\n"
+"POT-Creation-Date: 2018-05-01 20:30+0000\n"
 "PO-Revision-Date: 2016-04-30 17:13-0400\n"
 "Last-Translator: Mingye Wang (Arthur2e5) <arthur200126@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -174,40 +174,40 @@
 msgid "negative insn length"
 msgstr "指令长度为负"
 
-#: final.c:3139
+#: final.c:3142
 msgid "could not split insn"
 msgstr "无法分离指令"
 
-#: final.c:3615
+#: final.c:3618
 msgid "invalid 'asm': "
 msgstr "无效的‘asm’："
 
-#: final.c:3748
+#: final.c:3751
 #, c-format
 msgid "nested assembly dialect alternatives"
 msgstr "嵌套的汇编风格指示"
 
-#: final.c:3776 final.c:3788
+#: final.c:3779 final.c:3791
 #, c-format
 msgid "unterminated assembly dialect alternative"
 msgstr "未结束的汇编风格指示"
 
-#: final.c:3930
+#: final.c:3933
 #, c-format
 msgid "operand number missing after %%-letter"
 msgstr "%% 字母后缺少操作数号"
 
-#: final.c:3933 final.c:3974
+#: final.c:3936 final.c:3977
 #, c-format
 msgid "operand number out of range"
 msgstr "操作数号超出范围"
 
-#: final.c:3991
+#: final.c:3994
 #, c-format
 msgid "invalid %%-code"
 msgstr "无效的 %%-code"
 
-#: final.c:4025
+#: final.c:4028
 #, c-format
 msgid "'%%l' operand isn't a label"
 msgstr "‘%%l’操作数不是一个标号"
@@ -218,13 +218,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4161 config/arc/arc.c:5780 config/i386/i386.c:17308
+#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "错误地使用了浮点常量"
 
-#: final.c:4219 config/arc/arc.c:5877 config/i386/i386.c:17399
+#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1186,25 +1186,25 @@
 msgid "At top level:"
 msgstr "在文件作用域："
 
-#: langhooks.c:399 cp/error.c:3442
+#: langhooks.c:399 cp/error.c:3443
 #, c-format
 msgid "In member function %qs"
 msgstr "在成员函数%qs中"
 
-#: langhooks.c:403 cp/error.c:3445
+#: langhooks.c:403 cp/error.c:3446
 #, c-format
 msgid "In function %qs"
 msgstr "在函数%qs中"
 
-#: langhooks.c:454 cp/error.c:3395
+#: langhooks.c:454 cp/error.c:3396
 msgid "    inlined from %qs at %r%s:%d:%d%R"
 msgstr "    内联自%qs于 %r%s:%d:%d%R"
 
-#: langhooks.c:459 cp/error.c:3400
+#: langhooks.c:459 cp/error.c:3401
 msgid "    inlined from %qs at %r%s:%d%R"
 msgstr "    内联自%qs于 %r%s:%d%R"
 
-#: langhooks.c:465 cp/error.c:3406
+#: langhooks.c:465 cp/error.c:3407
 #, c-format
 msgid "    inlined from %qs"
 msgstr "    内联自%qs"
@@ -3066,9 +3066,9 @@
 msgid "invalid address mode"
 msgstr "无效寻址模式"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18564
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21764
-#: config/sparc/sparc.c:9282
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
@@ -3084,7 +3084,7 @@
 msgstr "无效 %%r 值"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21472
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3091,13 +3091,13 @@
 msgstr "无效 %%R 值"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21392 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21420
+#: config/rs6000/rs6000.c:21454
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
@@ -3128,7 +3128,7 @@
 msgstr "无效 %%U 值"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21480
+#: config/rs6000/rs6000.c:21514
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
@@ -3139,7 +3139,7 @@
 msgstr "无效 %%C 值"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21256
+#: config/rs6000/rs6000.c:21290
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
@@ -3150,7 +3150,7 @@
 msgstr "未指定未知的重定位方式"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21769
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3161,58 +3161,58 @@
 msgid "invalid operand address"
 msgstr "fr30_print_operand：未处理的指针"
 
-#: config/arc/arc.c:3806
+#: config/arc/arc.c:3810
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "%%Z 代码的操作数无效"
 
-#: config/arc/arc.c:3814
+#: config/arc/arc.c:3818
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "%%z 代码的操作数无效"
 
-#: config/arc/arc.c:3822
+#: config/arc/arc.c:3826
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "%%Z 代码的操作数无效"
 
-#: config/arc/arc.c:3830
+#: config/arc/arc.c:3834
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "%%M 代码的操作数无效"
 
-#: config/arc/arc.c:3838 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p 代码的操作数无效"
 
-#: config/arc/arc.c:3849 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s 代码的操作数无效"
 
-#: config/arc/arc.c:3997 config/m32r/m32r.c:2126
+#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R 代码的操作数无效"
 
-#: config/arc/arc.c:4073 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L 代码的操作数无效"
 
-#: config/arc/arc.c:4141 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U 代码的操作数无效"
 
-#: config/arc/arc.c:4153
+#: config/arc/arc.c:4157
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V 代码的操作数无效"
 
-#: config/arc/arc.c:4210
+#: config/arc/arc.c:4214
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "%%O 代码的操作数无效"
@@ -3219,18 +3219,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4236 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:2359 config/sparc/sparc.c:9561
+#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "无效的操作数输出代码"
 
-#: config/arc/arc.c:5865
+#: config/arc/arc.c:5869
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/arc/arc.c:6154 config/cris/cris.c:2568
+#: config/arc/arc.c:6158 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "预期的常量无法识别"
 
@@ -3265,7 +3265,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
@@ -3402,8 +3402,8 @@
 msgstr "无效的双精度常量操作数"
 
 #: config/cris/cris.c:622 config/ft32/ft32.c:110 config/moxie/moxie.c:108
-#: final.c:3620 final.c:3622 fold-const.c:267 gcc.c:5297 gcc.c:5311
-#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6348
+#: final.c:3623 final.c:3625 fold-const.c:267 gcc.c:5297 gcc.c:5311
+#: rtl-error.c:101 toplev.c:325 vr-values.c:2414 cp/typeck.c:6354
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
 #, gcc-internal-format, gfc-internal-format
@@ -3620,103 +3620,103 @@
 msgid "bad output_condmove_single operand"
 msgstr "错误的 output_condmove_single 操作数"
 
-#: config/i386/i386.c:17393
+#: config/i386/i386.c:17387
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/i386/i386.c:17931
+#: config/i386/i386.c:17925
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "错误地使用了%<restrict%>"
 
-#: config/i386/i386.c:17936
+#: config/i386/i386.c:17930
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.c:18166
+#: config/i386/i386.c:18160
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand：%%A 代码操作数无效"
 
-#: config/i386/i386.c:18201
+#: config/i386/i386.c:18195
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.c:18270
+#: config/i386/i386.c:18264
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "操作数代码‘%c’的操作数类型无效"
 
-#: config/i386/i386.c:18275
+#: config/i386/i386.c:18269
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.c:18352
+#: config/i386/i386.c:18346
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18431
+#: config/i386/i386.c:18425
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18449
+#: config/i386/i386.c:18443
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18462
+#: config/i386/i386.c:18456
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18477
+#: config/i386/i386.c:18471
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18505
+#: config/i386/i386.c:18499
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18523
+#: config/i386/i386.c:18517
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18546
+#: config/i386/i386.c:18540
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18632
+#: config/i386/i386.c:18626
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/i386/i386.c:18694
+#: config/i386/i386.c:18688
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "操作数的约束无效"
 
-#: config/i386/i386.c:18744
+#: config/i386/i386.c:18738
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "无效的控制谓词"
 
-#: config/i386/i386.c:29614
+#: config/i386/i386.c:29572
 msgid "unknown insn mode"
 msgstr "未知的指令模式"
 
@@ -3755,7 +3755,7 @@
 msgstr "无效的 %%P 操作数"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21410
+#: config/rs6000/rs6000.c:21444
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -3809,7 +3809,7 @@
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33258
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
 msgid "bad address"
 msgstr "错误地址"
 
@@ -3975,144 +3975,144 @@
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10907
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21053
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21244
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21265
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21274
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21283
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21318
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21328
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21338
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21353
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21400
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21447
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21500
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21512
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21526
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21593
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效的 %%x 值"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21713
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22248
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22254
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "对声明中的过时用法给出警告"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22260
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36538
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38705
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38775
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38874
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39092
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39138
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39141
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39179
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39225
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39228
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4243,43 +4243,43 @@
 msgid "created and used with different endianness"
 msgstr "创建和使用时使用了不同的大小端设定"
 
-#: config/sparc/sparc.c:9291 config/sparc/sparc.c:9297
+#: config/sparc/sparc.c:9299 config/sparc/sparc.c:9305
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "无效的 %%Y 操作数"
 
-#: config/sparc/sparc.c:9384
+#: config/sparc/sparc.c:9392
 #, c-format
 msgid "invalid %%A operand"
 msgstr "无效的 %%A 操作数"
 
-#: config/sparc/sparc.c:9404
+#: config/sparc/sparc.c:9412
 #, c-format
 msgid "invalid %%B operand"
 msgstr "无效的 %%B 操作数"
 
-#: config/sparc/sparc.c:9484 config/tilegx/tilegx.c:5105
+#: config/sparc/sparc.c:9492 config/tilegx/tilegx.c:5105
 #: config/tilepro/tilepro.c:4514
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "无效的 %%c 操作数"
 
-#: config/sparc/sparc.c:9516 config/tilegx/tilegx.c:5138
+#: config/sparc/sparc.c:9524 config/tilegx/tilegx.c:5138
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "无效的 %%d 操作数"
 
-#: config/sparc/sparc.c:9535
+#: config/sparc/sparc.c:9543
 #, c-format
 msgid "invalid %%f operand"
 msgstr "无效的 %%f 操作数"
 
-#: config/sparc/sparc.c:9547
+#: config/sparc/sparc.c:9555
 #, c-format
 msgid "invalid %%s operand"
 msgstr "无效的 %%s 操作数"
 
-#: config/sparc/sparc.c:9592
+#: config/sparc/sparc.c:9600
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4500,14 +4500,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27820
-#: cp/parser.c:28409
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27818 cp/parser.c:28427
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -4522,7 +4522,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28457
+#: c/gimple-parser.c:1441 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -4530,7 +4530,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28421
+#: cp/parser.c:28442
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -4544,7 +4544,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28412
+#: cp/parser.c:28433
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
@@ -4551,7 +4551,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18145 cp/parser.c:28418
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -4561,13 +4561,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28451 cp/parser.c:29576
-#: cp/parser.c:32258
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
+#: cp/parser.c:32279
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28344
+#: c/c-parser.c:5974 cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
@@ -4576,18 +4576,18 @@
 msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30151
-#: cp/parser.c:30225
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
+#: cp/parser.c:30246
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28436
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28460
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
@@ -4595,23 +4595,23 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28439
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28415
-#: cp/parser.c:30368
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
+#: cp/parser.c:30389
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35653
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28424 cp/parser.c:31514
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
@@ -4620,7 +4620,7 @@
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15790 cp/parser.c:28433
+#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -4632,46 +4632,46 @@
 msgid "expected label"
 msgstr "需要通道"
 
-#: cp/call.c:10472
+#: cp/call.c:10487
 msgid "candidate 1:"
 msgstr "备选 1："
 
-#: cp/call.c:10473
+#: cp/call.c:10488
 msgid "candidate 2:"
 msgstr "备选 2："
 
-#: cp/decl.c:3163
+#: cp/decl.c:3166
 msgid "jump to label %qD"
 msgstr "跳转至标号%qD"
 
-#: cp/decl.c:3164
+#: cp/decl.c:3167
 msgid "jump to case label"
 msgstr "跳转至 case 标号"
 
-#: cp/decl.c:3233
+#: cp/decl.c:3236
 #, fuzzy
 #| msgid "  enters try block"
 msgid "enters try block"
 msgstr "进入了 try 块"
 
-#: cp/decl.c:3239
+#: cp/decl.c:3242
 #, fuzzy
 #| msgid "  enters catch block"
 msgid "enters catch block"
 msgstr "进入了 catch 块"
 
-#: cp/decl.c:3245
+#: cp/decl.c:3248
 #, fuzzy
 #| msgid "  enters OpenMP structured block"
 msgid "enters OpenMP structured block"
 msgstr "进入了 OpenMP 结构块"
 
-#: cp/decl.c:3251
+#: cp/decl.c:3254
 #, fuzzy
 msgid "enters synchronized or atomic statement"
 msgstr "删除死存储"
 
-#: cp/decl.c:3258
+#: cp/decl.c:3261
 #, fuzzy
 #| msgid "expected statement"
 msgid "enters constexpr if statement"
@@ -4765,7 +4765,7 @@
 msgid "<statement>"
 msgstr "<语句>"
 
-#: cp/error.c:2078 cp/error.c:3122 c-family/c-pretty-print.c:2181
+#: cp/error.c:2078 cp/error.c:3123 c-family/c-pretty-print.c:2181
 #, gcc-internal-format
 msgid "<unknown>"
 msgstr "<未知>"
@@ -4784,124 +4784,124 @@
 msgid "<unparsed>"
 msgstr "<未解析>"
 
-#: cp/error.c:2799
+#: cp/error.c:2800
 #, fuzzy
 msgid "<lambda>"
 msgstr "<lambda"
 
-#: cp/error.c:2842
+#: cp/error.c:2843
 msgid "*this"
 msgstr "*this"
 
-#: cp/error.c:2856
+#: cp/error.c:2857
 msgid "<expression error>"
 msgstr "<表达式错误>"
 
-#: cp/error.c:2871
+#: cp/error.c:2872
 msgid "<unknown operator>"
 msgstr "<未知的运算符>"
 
-#: cp/error.c:3326
+#: cp/error.c:3327
 msgid "At global scope:"
 msgstr "在全局域："
 
-#: cp/error.c:3432
+#: cp/error.c:3433
 #, c-format
 msgid "In static member function %qs"
 msgstr "在静态成员函数%qs中"
 
-#: cp/error.c:3434
+#: cp/error.c:3435
 #, c-format
 msgid "In copy constructor %qs"
 msgstr "在复制构造函数%qs"
 
-#: cp/error.c:3436
+#: cp/error.c:3437
 #, c-format
 msgid "In constructor %qs"
 msgstr "在构造函数%qs中"
 
-#: cp/error.c:3438
+#: cp/error.c:3439
 #, c-format
 msgid "In destructor %qs"
 msgstr "在析构函数%qs中"
 
-#: cp/error.c:3440
+#: cp/error.c:3441
 msgid "In lambda function"
 msgstr "在 lambda 函数中"
 
-#: cp/error.c:3460
+#: cp/error.c:3461
 #, fuzzy, c-format
 msgid "%s: In substitution of %qS:\n"
 msgstr "空动态字符串替换"
 
-#: cp/error.c:3461
+#: cp/error.c:3462
 #, fuzzy
 msgid "%s: In instantiation of %q#D:\n"
 msgstr "对%q#D的显式实例化"
 
-#: cp/error.c:3486
+#: cp/error.c:3487
 msgid "%r%s:%d:%d:%R   "
 msgstr "%r%s:%d:%d:%R   "
 
-#: cp/error.c:3489
+#: cp/error.c:3490
 msgid "%r%s:%d:%R   "
 msgstr "%r%s:%d:%R   "
 
-#: cp/error.c:3497
+#: cp/error.c:3498
 #, fuzzy, c-format
 msgid "recursively required by substitution of %qS\n"
 msgstr "递归必要项由替代的 %qS\n"
 
-#: cp/error.c:3498
+#: cp/error.c:3499
 #, fuzzy, c-format
 msgid "required by substitution of %qS\n"
 msgstr "空动态字符串替换"
 
-#: cp/error.c:3503
+#: cp/error.c:3504
 #, fuzzy
 msgid "recursively required from %q#D\n"
 msgstr "与先前的声明%q+D不同"
 
-#: cp/error.c:3504
+#: cp/error.c:3505
 #, fuzzy
 msgid "required from %q#D\n"
 msgstr "与先前的声明%q+D不同"
 
-#: cp/error.c:3511
+#: cp/error.c:3512
 #, fuzzy
 msgid "recursively required from here\n"
 msgstr "从此处调用"
 
-#: cp/error.c:3512
+#: cp/error.c:3513
 #, fuzzy
 msgid "required from here\n"
 msgstr "从此处调用"
 
-#: cp/error.c:3564
+#: cp/error.c:3565
 #, fuzzy
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%s:%d:%d：[ 跳过 %d 个实例化上下文 ]\n"
 
-#: cp/error.c:3570
+#: cp/error.c:3571
 #, fuzzy
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
 msgstr "%s:%d:%d：[ 跳过 %d 个实例化上下文 ]\n"
 
-#: cp/error.c:3624
+#: cp/error.c:3625
 #, fuzzy
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d:%d：在%qs的广义常表达式扩展中"
 
-#: cp/error.c:3628
+#: cp/error.c:3629
 #, fuzzy
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d：在%qs的广义常表达式扩展中"
 
-#: cp/pt.c:1948 cp/semantics.c:5284
+#: cp/pt.c:1949 cp/semantics.c:5268
 msgid "candidates are:"
 msgstr "备选为："
 
-#: cp/pt.c:1950 cp/pt.c:22627
+#: cp/pt.c:1951 cp/pt.c:22975
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
@@ -4946,48 +4946,48 @@
 msgid "source type is not polymorphic"
 msgstr "源类型不是多态的"
 
-#: cp/typeck.c:6077 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4261
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "单目减的操作数类型错误"
 
-#: cp/typeck.c:6078 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4248
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "单目加的操作数类型错误"
 
-#: cp/typeck.c:6105 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4302
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的参数类型错误"
 
-#: cp/typeck.c:6122 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4310
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能对该类型的参数求绝对值"
 
-#: cp/typeck.c:6134 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4322
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能对该类型的参数求共轭"
 
-#: cp/typeck.c:6152
+#: cp/typeck.c:6158
 msgid "in argument to unary !"
 msgstr "单目 ! 的参数中"
 
-#: cp/typeck.c:6198
+#: cp/typeck.c:6204
 msgid "no pre-increment operator for type"
 msgstr "类型没有前自增运算符"
 
-#: cp/typeck.c:6200
+#: cp/typeck.c:6206
 msgid "no post-increment operator for type"
 msgstr "类型没有后自增运算符"
 
-#: cp/typeck.c:6202
+#: cp/typeck.c:6208
 msgid "no pre-decrement operator for type"
 msgstr "类型没有前自减运算符"
 
-#: cp/typeck.c:6204
+#: cp/typeck.c:6210
 msgid "no post-decrement operator for type"
 msgstr "类型没有后自减运算符"
 
@@ -5270,11 +5270,11 @@
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11189
+#: fortran/parse.c:2050 fortran/resolve.c:11199
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11240 fortran/resolve.c:11243
+#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
 msgid "pointer assignment"
 msgstr "指针赋值"
 
@@ -5452,53 +5452,53 @@
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%%L和%%L处的操作数的秩不一致"
 
-#: fortran/resolve.c:6839
+#: fortran/resolve.c:6849
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.c:6843
+#: fortran/resolve.c:6853
 #, fuzzy
 msgid "iterator variable"
 msgstr "变量"
 
-#: fortran/resolve.c:6847
+#: fortran/resolve.c:6857
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.c:6851
+#: fortran/resolve.c:6861
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.c:6855
+#: fortran/resolve.c:6865
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.c:7140 fortran/resolve.c:7143
+#: fortran/resolve.c:7150 fortran/resolve.c:7153
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/resolve.c:7515 fortran/resolve.c:7518
+#: fortran/resolve.c:7525 fortran/resolve.c:7528
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:7710 fortran/resolve.c:9407
+#: fortran/resolve.c:7720 fortran/resolve.c:9417
 #, fuzzy
 msgid "STAT variable"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7754 fortran/resolve.c:9419
+#: fortran/resolve.c:7764 fortran/resolve.c:9429
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:9209
+#: fortran/resolve.c:9219
 #, fuzzy
 msgid "item in READ"
 msgstr "读取概要："
 
-#: fortran/resolve.c:9431
+#: fortran/resolve.c:9441
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "无法锁定新归档文件"
@@ -5542,12 +5542,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "%3$s 中字符长度不相等 (%1$ld/%2$ld)"
 
-#: fortran/trans-intrinsic.c:7998
+#: fortran/trans-intrinsic.c:8088
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "内建函数 REPEAT 的 NCOPIES 参数为负(其值是 %lld)"
 
-#: fortran/trans-intrinsic.c:8030
+#: fortran/trans-intrinsic.c:8120
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "内建函数 REPEAT 的 NCOPIES 参数太大"
 
@@ -5797,6 +5797,7 @@
 msgstr "-Xbind-now 与 -Xbind-lazy 不兼容"
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
 #, fuzzy
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
 msgstr "与 gprof(1) 一起使用时请考虑使用‘-pg’以代替‘-p’"
@@ -9358,7 +9359,7 @@
 msgstr "在 32 位边界上对齐变量"
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
-#: config/nds32/nds32.opt:94 config/c6x/c6x.opt:67
+#: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
 #, fuzzy
 msgid "Specify the name of the target architecture."
 msgstr "指定目标架构的名称"
@@ -9956,7 +9957,7 @@
 msgstr "指定不使用的寄存器范围"
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
-#: config/rs6000/sysv4.opt:36 config/alpha/alpha.opt:130
+#: config/alpha/alpha.opt:130
 #, fuzzy
 #| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
@@ -10824,7 +10825,7 @@
 msgid "Generate code that conforms to the given ABI."
 msgstr "生成遵循给定 ABI 的代码"
 
-#: config/i386/i386.opt:537
+#: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
 msgstr "已知 ABI (用于 -mabi= 选项)："
 
@@ -11266,7 +11267,7 @@
 msgstr "支持 PKU 内建函数及代码生成。"
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
-#: config/rs6000/rs6000.opt:598
+#: config/rs6000/rs6000.opt:597
 #, fuzzy
 msgid "Use given stack-protector guard."
 msgstr "使用 propolice 来保护堆栈"
@@ -11277,13 +11278,13 @@
 msgstr "已知堆栈保护方式 (stack protector guard, 用于 -mstack-protector-guard= 选项)："
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
-#: config/rs6000/rs6000.opt:612
+#: config/rs6000/rs6000.opt:611
 #, fuzzy
 msgid "Use the given base register for addressing the stack-protector guard."
 msgstr "使用 propolice 来保护堆栈"
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
-#: config/rs6000/rs6000.opt:619
+#: config/rs6000/rs6000.opt:618
 #, fuzzy
 msgid "Use the given offset for addressing the stack-protector guard."
 msgstr "使用 propolice 来保护堆栈"
@@ -11298,47 +11299,49 @@
 msgstr ""
 
 #: config/i386/i386.opt:1011
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation."
-msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
-msgstr "支持 MMX 和 SSE 内建函数及代码生成。"
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
 
 #: config/i386/i386.opt:1016
-msgid "Specifically enables an indirect branch tracking feature from Control-flow Enforcement Technology (CET)."
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
 msgstr ""
 
 #: config/i386/i386.opt:1021
-msgid "Specifically enables an shadow stack support feature from Control-flow Enforcement Technology (CET)."
-msgstr ""
-
-#: config/i386/i386.opt:1026
-msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
-msgstr ""
-
-#: config/i386/i386.opt:1031
 #, fuzzy
 msgid "Make all function calls indirect."
 msgstr "当在算术表达式中使用函数指针时给出警告"
 
-#: config/i386/i386.opt:1035
+#: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
 msgstr ""
 
-#: config/i386/i386.opt:1039
+#: config/i386/i386.opt:1029
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
 msgstr "函数不能返回函数"
 
-#: config/i386/i386.opt:1043 config/s390/s390.opt:274
+#: config/i386/i386.opt:1033 config/s390/s390.opt:274
 #, fuzzy
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
 msgstr "无效的 __fp16 浮点选项：-mfp16-format=%s"
 
-#: config/i386/i386.opt:1059
+#: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
 msgstr ""
 
+#: config/i386/i386.opt:1053
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr "支持 BMI 内建函数及代码生成"
+
+#: config/i386/i386.opt:1057
+#, fuzzy
+#| msgid "Support BMI built-in functions and code generation."
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr "支持 BMI 内建函数及代码生成"
+
 #: config/pa/pa64-hpux.opt:23
 msgid "Assume code will be linked by GNU ld."
 msgstr "假定代码将由 GNU ld 链接。"
@@ -11826,7 +11829,7 @@
 msgid "Deprecated option.  Use -mvrsave instead."
 msgstr "已弃用。请改用 -mvrsave"
 
-#: config/powerpcspe/powerpcspe.opt:334 config/rs6000/rs6000.opt:334
+#: config/powerpcspe/powerpcspe.opt:334
 #, fuzzy
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
 msgstr "指定有多少字节应该被移动内联之前调用出到 memcpy/memmove"
@@ -11835,7 +11838,7 @@
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:342 config/rs6000/rs6000.opt:346
+#: config/powerpcspe/powerpcspe.opt:342
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to strncmp will be generated instead."
 msgstr ""
 
@@ -11945,7 +11948,7 @@
 msgid "-mtune=\tSchedule code for given CPU."
 msgstr "-mtune=\t为指定的 CPU 调度代码"
 
-#: config/powerpcspe/powerpcspe.opt:426 config/rs6000/rs6000.opt:410
+#: config/powerpcspe/powerpcspe.opt:426
 #, fuzzy
 #| msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
@@ -11985,7 +11988,7 @@
 msgid "Valid arguments to -mfloat-gprs=:"
 msgstr "-mfloat-gprs 的有效参数为："
 
-#: config/powerpcspe/powerpcspe.opt:478 config/rs6000/rs6000.opt:438
+#: config/powerpcspe/powerpcspe.opt:478
 #, fuzzy
 #| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
@@ -12087,25 +12090,25 @@
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
 msgstr "使用向量/标量(VSX)指令"
 
-#: config/powerpcspe/powerpcspe.opt:578 config/rs6000/rs6000.opt:538
+#: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:542
+#: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
 #, fuzzy
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
 msgstr "使用向量/标量(VSX)指令"
 
-#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:546
+#: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
 #, fuzzy
 msgid "Generate the quad word memory instructions (lq/stq)."
 msgstr "生成加载/存储乘法指令"
 
-#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:550
+#: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:554
+#: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
 msgstr ""
 
@@ -12125,20 +12128,20 @@
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:558
+#: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:562
+#: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:566
+#: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
 #, fuzzy
 msgid "Use certain scalar instructions added in ISA 3.0."
 msgstr "使用浮点双精度指令"
 
-#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:570
+#: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
 #, fuzzy
 #| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector instructions added in ISA 3.0."
@@ -12156,17 +12159,17 @@
 msgid "Use register+offset memory instructions added in ISA 3.0."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:574
+#: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
 #, fuzzy
 #| msgid "Enable min/max instructions"
 msgid "Use the new min/max instructions defined in ISA 3.0."
 msgstr "启用最小/最大值指令"
 
-#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:578
+#: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:582
+#: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
@@ -12176,19 +12179,19 @@
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:586
+#: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
 msgstr "使用十进制浮点指令"
 
-#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:590
+#: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
 msgstr "使用十进制浮点指令"
 
-#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:594
+#: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
 msgstr ""
 
@@ -12198,7 +12201,7 @@
 msgid "Enable small integers to be in VSX registers."
 msgstr "在寄存器中返回小聚合"
 
-#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:602
+#: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
 #, fuzzy
 #| msgid "Valid arguments to -mfloat-gprs=:"
 msgid "Valid arguments to -mstack-protector-guard=:"
@@ -12240,14 +12243,13 @@
 msgid "Call mcount for profiling before a function prologue."
 msgstr "为取样在函数前言中调用 mcount"
 
-#: config/powerpcspe/sysv4.opt:24 config/rs6000/sysv4.opt:24
+#: config/powerpcspe/sysv4.opt:24
 #, fuzzy
 #| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
 msgstr "选择 ABI 调用约定"
 
-#: config/powerpcspe/sysv4.opt:28 config/rs6000/sysv4.opt:28
-#: config/c6x/c6x.opt:42
+#: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
 #, fuzzy
 #| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
@@ -13116,7 +13118,7 @@
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
 msgstr "在 LDRD 指令中避免重叠的目标和地址寄存器"
 
-#: config/arm/arm.opt:276 config/arc/arc.opt:496
+#: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 #, fuzzy
 msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "启用 unaligned 字词和 halfword 访问到包装的数据。"
@@ -13366,14 +13368,28 @@
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
 msgstr "已弃用%<-mfused-madd%>；请改用%<-ffp-contract=%>"
 
-#: config/rs6000/rs6000.opt:338
-msgid "Specify the maximum number of bytes to compare inline with non-looping code. If this is set to 0, all inline expansion (non-loop and loop) of memcmp is disabled."
+#: config/rs6000/rs6000.opt:334
+msgid "Max number of bytes to move inline."
 msgstr ""
 
+#: config/rs6000/rs6000.opt:338
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare without loops."
+msgstr "去开关后的循环所能有的最大指令数"
+
 #: config/rs6000/rs6000.opt:342
-msgid "Specify the maximum number of bytes to compare inline with loop code generation.  If the length is not known at compile time, memcmp will be called after this many bytes are compared. By default, a length will be picked depending on the tuning target."
-msgstr ""
+#, fuzzy
+#| msgid "The maximum number of insns of an unswitched loop"
+msgid "Max number of bytes to compare with loops."
+msgstr "去开关后的循环所能有的最大指令数"
 
+#: config/rs6000/rs6000.opt:346
+#, fuzzy
+#| msgid "The maximum number of peelings of a single loop"
+msgid "Max number of pairs of load insns for compare."
+msgstr "单个循环最大的剥离数"
+
 #: config/rs6000/rs6000.opt:353
 #, fuzzy
 #| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
@@ -13386,10 +13402,48 @@
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
 msgstr "已弃用%<-mcpu=%>；请改用%<-mtune=%>或%<-march=%>"
 
+#: config/rs6000/rs6000.opt:410
+#, fuzzy
+#| msgid "-mtraceback=\tSelect full, part, or no traceback table"
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr "-mtraceback=\t选择全部、部分或不需要回溯表"
+
+#: config/rs6000/rs6000.opt:438
+#, fuzzy
+#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
+msgid "-mlong-double-[64,128]\tSpecify size of long double."
+msgstr "-mlong-double-<n>\t指定 long double 的大小(64 或 128 位)"
+
+#: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
+#: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
+#: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
+#: config/arc/arc.opt:381
+#, fuzzy, c-format
+msgid "%qs is deprecated"
+msgstr "已弃用%qE"
+
+#: config/rs6000/sysv4.opt:24
+#, fuzzy
+#| msgid "Select ABI calling convention"
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr "选择 ABI 调用约定"
+
+#: config/rs6000/sysv4.opt:28
+#, fuzzy
+#| msgid "Select method for sdata handling"
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr "为处理 sdata 选择方法"
+
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
 msgstr ""
 
+#: config/rs6000/sysv4.opt:36
+#, fuzzy
+#| msgid "Specify bit size of immediate TLS offsets"
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr "指定线程局部存储偏移量立即数的位大小"
+
 #: config/alpha/alpha.opt:27
 #, fuzzy
 #| msgid "Use fp registers"
@@ -14886,101 +14940,167 @@
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
 msgstr "允许 gcc 生成 LIW 指令"
 
-#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:49
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
 msgid "Generate code in big-endian mode."
 msgstr "生成大端序模式的代码。"
 
-#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:53
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
 msgid "Generate code in little-endian mode."
 msgstr "生成小端序模式的代码。"
 
-#: config/nds32/nds32.opt:39
+#: config/nds32/nds32.opt:40
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:54
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:58
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:64
 #, fuzzy
 msgid "Use reduced-set registers for register allocation."
 msgstr "分配寄存器前重新调度指令"
 
-#: config/nds32/nds32.opt:43
+#: config/nds32/nds32.opt:68
 #, fuzzy
 msgid "Use full-set registers for register allocation."
 msgstr "分配寄存器前重新调度指令"
 
-#: config/nds32/nds32.opt:58
+#: config/nds32/nds32.opt:74
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:78
 #, fuzzy
+#| msgid "Align code and data to 32 bits"
+msgid "Align function entry to 4 byte."
+msgstr "将代码和数据对齐到 32 位边界上"
+
+#: config/nds32/nds32.opt:91
+#, fuzzy
 msgid "Generate conditional move instructions."
 msgstr "将数据传输周围的跳转认为是条件转移。"
 
-#: config/nds32/nds32.opt:62
+#: config/nds32/nds32.opt:95
 #, fuzzy
 msgid "Generate performance extension instructions."
 msgstr "生成加载/存储乘法指令"
 
-#: config/nds32/nds32.opt:66
+#: config/nds32/nds32.opt:99
 #, fuzzy
 msgid "Generate performance extension version 2 instructions."
 msgstr "生成加载/存储乘法指令"
 
-#: config/nds32/nds32.opt:70
+#: config/nds32/nds32.opt:103
 #, fuzzy
 msgid "Generate string extension instructions."
 msgstr "生成加载/存储乘法指令"
 
-#: config/nds32/nds32.opt:74
+#: config/nds32/nds32.opt:107
 #, fuzzy
 msgid "Generate v3 push25/pop25 instructions."
 msgstr "生成加载/存储乘法指令"
 
-#: config/nds32/nds32.opt:78
+#: config/nds32/nds32.opt:111
 msgid "Generate 16-bit instructions."
 msgstr "生成 16 位指令。"
 
-#: config/nds32/nds32.opt:82
+#: config/nds32/nds32.opt:115
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:119
 #, fuzzy
 #| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
 msgstr "启用多核支持"
 
-#: config/nds32/nds32.opt:86
+#: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
 msgstr ""
 
-#: config/nds32/nds32.opt:90
+#: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
 msgstr ""
 
-#: config/nds32/nds32.opt:98
+#: config/nds32/nds32.opt:135
 #, fuzzy
 msgid "Known arch types (for use with the -march= option):"
 msgstr "无效的 __fp16 浮点选项：-mfp16-format=%s"
 
-#: config/nds32/nds32.opt:111
+#: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
 msgstr ""
 
-#: config/nds32/nds32.opt:115
+#: config/nds32/nds32.opt:158
 #, fuzzy
 msgid "Known cmodel types (for use with the -mcmodel= option):"
 msgstr "无效的 __fp16 浮点选项：-mfp16-format=%s"
 
-#: config/nds32/nds32.opt:128
+#: config/nds32/nds32.opt:171
 #, fuzzy
 msgid "Specify the cpu for pipeline model."
 msgstr "使用给定的 x86-64 代码模式"
 
-#: config/nds32/nds32.opt:132
+#: config/nds32/nds32.opt:175
 #, fuzzy
 msgid "Known cpu types (for use with the -mcpu= option):"
 msgstr "无效的 __fp16 浮点选项：-mfp16-format=%s"
 
-#: config/nds32/nds32.opt:139
+#: config/nds32/nds32.opt:242
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:246
 #, fuzzy
+#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr "已知浮点 ABI (用于 -mfloat-abi= 选项)："
+
+#: config/nds32/nds32.opt:274
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:293
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:306
+#, fuzzy
 msgid "Enable constructor/destructor feature."
 msgstr "生成全局构造/析构函数表"
 
-#: config/nds32/nds32.opt:143
+#: config/nds32/nds32.opt:310
 #, fuzzy
 msgid "Guide linker to relax instructions."
 msgstr "在汇编器和链接器中优化尾调用指令"
 
+#: config/nds32/nds32.opt:314
+#, fuzzy
+#| msgid "Generate floating point mathematics using given instruction set"
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr "为指定的指令集生成浮点数学代码"
+
+#: config/nds32/nds32.opt:318
+#, fuzzy
+#| msgid "Use paired-single floating-point instructions"
+msgid "Generate single-precision floating-point instructions."
+msgstr "使用配对的单精度浮点指令"
+
+#: config/nds32/nds32.opt:322
+#, fuzzy
+#| msgid "Generate code that uses 68881 floating-point instructions"
+msgid "Generate double-precision floating-point instructions."
+msgstr "生成使用 68881 浮点指令的代码"
+
+#: config/nds32/nds32.opt:326
+msgid "Always save $lp in the stack."
+msgstr ""
+
 #: config/iq2000/iq2000.opt:31
 #, fuzzy
 #| msgid "Specify CPU for code generation purposes"
@@ -16115,13 +16235,6 @@
 msgid "Generate mul64 and mulu64 instructions."
 msgstr "生成加载/存储乘法指令"
 
-#: config/arc/arc.opt:173 config/arc/arc.opt:339 config/arc/arc.opt:346
-#: config/arc/arc.opt:350 config/arc/arc.opt:354 config/arc/arc.opt:358
-#: config/arc/arc.opt:361 config/arc/arc.opt:364 config/arc/arc.opt:381
-#, fuzzy, c-format
-msgid "%qs is deprecated"
-msgstr "已弃用%qE"
-
 #: config/arc/arc.opt:174
 #, fuzzy
 msgid "Do not generate mpy instructions for ARC700."
@@ -19102,8 +19215,8 @@
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1304
-#: cp/cvt.c:1557
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
 msgstr "计算出的值未被使用"
@@ -19131,7 +19244,7 @@
 msgstr "需要整数或布尔类型"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33243 cp/parser.c:33250
+#: cp/parser.c:33264 cp/parser.c:33271
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19605,7 +19718,7 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13631 cp/friend.c:302
+#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
 #: cp/tree.c:4559
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
@@ -19631,12 +19744,12 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10950
+#: attribs.c:590 cp/decl.c:10999
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "忽略%qs属性"
 
-#: attribs.c:592 cp/decl.c:10951
+#: attribs.c:592 cp/decl.c:11000
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
@@ -19685,9 +19798,9 @@
 #: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
 #: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6512
-#: config/i386/i386.c:41522 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33022
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
+#: config/i386/i386.c:41520 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
 #: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
 #: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
 #: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
@@ -19701,8 +19814,8 @@
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2007 cp/decl.c:2017 cp/decl.c:2589
-#: cp/decl.c:3009
+#: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
+#: cp/decl.c:3012
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD先前没有声明"
@@ -19833,82 +19946,74 @@
 msgid "%K%qD specified size between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3170 builtins.c:3186
+#: builtins.c:3170 builtins.c:3185
 #, gcc-internal-format
 msgid "%K%qD writing %E or more bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3177
+#: builtins.c:3176
 #, gcc-internal-format
 msgid "%K%qD writing %E byte into a region of size %E overflows the destination"
-msgstr ""
+msgid_plural "%K%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr[0] ""
 
-#: builtins.c:3179
+#: builtins.c:3191
 #, gcc-internal-format
-msgid "%K%qD writing %E bytes into a region of size %E overflows the destination"
-msgstr ""
-
-#: builtins.c:3192
-#, gcc-internal-format
 msgid "%K%qD writing between %E and %E bytes into a region of size %E overflows the destination"
 msgstr ""
 
-#: builtins.c:3228
+#: builtins.c:3227
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3234
+#: builtins.c:3233
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds maximum object size %E"
 msgstr ""
 
-#: builtins.c:3249
+#: builtins.c:3248
 #, gcc-internal-format
 msgid "%K%qD specified bound %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3255
+#: builtins.c:3254
 #, gcc-internal-format
 msgid "%K%qD specified bound between %E and %E exceeds destination size %E"
 msgstr ""
 
-#: builtins.c:3278
+#: builtins.c:3276
 #, gcc-internal-format
 msgid "%K%qD reading %E byte from a region of size %E"
-msgstr ""
+msgid_plural "%K%qD reading %E bytes from a region of size %E"
+msgstr[0] ""
 
-#: builtins.c:3279
+#: builtins.c:3283
 #, gcc-internal-format
-msgid "%K%qD reading %E bytes from a region of size %E"
-msgstr ""
-
-#: builtins.c:3285
-#, gcc-internal-format
 msgid "%K%qD reading %E or more bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3291
+#: builtins.c:3289
 #, gcc-internal-format
 msgid "%K%qD reading between %E and %E bytes from a region of size %E"
 msgstr ""
 
-#: builtins.c:3965 builtins.c:4031
+#: builtins.c:3967 builtins.c:4033
 #, gcc-internal-format
 msgid "%K%qD specified bound %E equals destination size"
 msgstr ""
 
-#: builtins.c:4879 gimplify.c:3269
+#: builtins.c:4881 gimplify.c:3269
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数太少"
 
-#: builtins.c:4979
+#: builtins.c:4981
 #, fuzzy, gcc-internal-format
 msgid "invalid argument to %qD"
 msgstr "%<...%>作为实参。)"
 
-#: builtins.c:4992
+#: builtins.c:4994
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument to %qD"
 msgstr "需要类型%qT，但实参的类型为%qT"
@@ -19915,72 +20020,72 @@
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
-#: builtins.c:5000
+#: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
 msgstr ""
 
-#: builtins.c:5294
+#: builtins.c:5302
 #, gcc-internal-format
 msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgstr "%<__builtin___clear_cache%>的两个参数必须都是指针"
 
-#: builtins.c:5393
+#: builtins.c:5401
 #, fuzzy, gcc-internal-format
 msgid "trampoline generated for nested function %qD"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: builtins.c:5737 builtins.c:5750
+#: builtins.c:5745 builtins.c:5758
 #, gcc-internal-format
 msgid "%qD changed semantics in GCC 4.4"
 msgstr "%qD在 GCC 4.4 中语义已经改变"
 
-#: builtins.c:5856
+#: builtins.c:5864
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
 msgstr "未知的架构‘%s’"
 
-#: builtins.c:5864
+#: builtins.c:5872
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument to builtin"
 msgstr "%<__builtin_frame_address%>的实参无效"
 
-#: builtins.c:5925 builtins.c:6052
+#: builtins.c:5933 builtins.c:6060
 #, fuzzy, gcc-internal-format
 msgid "failure memory model cannot be stronger than success memory model for %<__atomic_compare_exchange%>"
 msgstr "失败内存式样无法 stronger 比成功内存式样用于 %<__atomic_compare_exchange%>"
 
-#: builtins.c:5933 builtins.c:6060
+#: builtins.c:5941 builtins.c:6068
 #, fuzzy, gcc-internal-format
 msgid "invalid failure memory model for %<__atomic_compare_exchange%>"
 msgstr "无效的失败内存式样用于 %<__atomic_compare_exchange%>"
 
-#: builtins.c:6118
+#: builtins.c:6126
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "错误地使用了%<auto%>"
 
-#: builtins.c:6150 builtins.c:6343
+#: builtins.c:6158 builtins.c:6351
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "gimple 内存存储中右操作数无效"
 
-#: builtins.c:6464
+#: builtins.c:6472
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "non-constant 参数 1 到 __atomic_always_lock_free"
 
-#: builtins.c:6506
+#: builtins.c:6514
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "non-integer 参数 1 到 __atomic_is_lock_free"
 
-#: builtins.c:6570
+#: builtins.c:6578
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_saveregs 不为此目标所支持"
 
-#: builtins.c:6590
+#: builtins.c:6598
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return 在此目标机上不受支持"
@@ -19987,7 +20092,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6850 expr.c:10961
+#: builtins.c:6858 expr.c:10967
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K对%<__builtin_va_arg_pack ()%>的使用无效"
@@ -19994,12 +20099,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6856
+#: builtins.c:6864
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K对%<__builtin_va_arg_pack_len ()%>的使用无效"
 
-#: builtins.c:7111
+#: builtins.c:7119
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>的第二个实参必须是 1"
@@ -20006,65 +20111,65 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7745
+#: builtins.c:7753
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "目标平台不支持 -fcheck-pointer-bounds"
 
-#: builtins.c:8080
+#: builtins.c:8089
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "目标格式不支持无限大浮点数"
 
-#: builtins.c:9703
+#: builtins.c:9712
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "在定参数的函数中使用了%<va_start%>"
 
-#: builtins.c:9711
+#: builtins.c:9720
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数数目不对"
 
-#: builtins.c:9726
+#: builtins.c:9735
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: builtins.c:9731
+#: builtins.c:9740
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: builtins.c:9763
+#: builtins.c:9772
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>的第二个参数不是最后一个有名参数"
 
-#: builtins.c:9776
+#: builtins.c:9785
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "当%<va_start%>的第二个参数有%<register%>存储时行为未经定义"
 
-#: builtins.c:9805
+#: builtins.c:9814
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: builtins.c:9818
+#: builtins.c:9827
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgstr "%K%D 的最后一个实参不是一个 0 到 3 之间的整常量"
 
-#: builtins.c:10094
+#: builtins.c:10103
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%K试图 free 不在堆上的对象%qD"
 
-#: builtins.c:10097
+#: builtins.c:10106
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K试图 free 一个不在堆上的对象"
@@ -21245,37 +21350,37 @@
 msgid "conversion to incomplete type"
 msgstr "转换为不完全类型"
 
-#: convert.c:990
+#: convert.c:992
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
 msgstr "不能在不同大小的矢量类型间进行转换"
 
-#: convert.c:998
+#: convert.c:1000
 #, gcc-internal-format
 msgid "aggregate value used where an integer was expected"
 msgstr "需要整数时使用了聚合值"
 
-#: convert.c:1083
+#: convert.c:1085
 #, gcc-internal-format
 msgid "pointer value used where a complex was expected"
 msgstr "需要复数时使用了指针值"
 
-#: convert.c:1087
+#: convert.c:1089
 #, gcc-internal-format
 msgid "aggregate value used where a complex was expected"
 msgstr "需要复数时使用了聚合值"
 
-#: convert.c:1121
+#: convert.c:1123
 #, fuzzy, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
 msgstr "不能在不同大小的矢量类型间进行转换"
 
-#: convert.c:1129
+#: convert.c:1131
 #, gcc-internal-format
 msgid "can%'t convert value to a vector"
 msgstr "不能将值转换为向量"
 
-#: convert.c:1168
+#: convert.c:1170
 #, gcc-internal-format
 msgid "aggregate value used where a fixed-point was expected"
 msgstr "需要定点数时使用了聚合值"
@@ -21431,12 +21536,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多个 EH 个性需要汇编器支持 .cfi.personality 指示。"
 
-#: dwarf2out.c:10891
+#: dwarf2out.c:10901
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14405
+#: dwarf2out.c:14415
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "变量位置处发现未被非法化的 UNSPEC %d"
@@ -21547,12 +21652,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10973
+#: expr.c:10979
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%K调用%qs，声明有错误属性：%s"
 
-#: expr.c:10986
+#: expr.c:10992
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K调用%qs，声明有警告属性：%s"
@@ -21567,12 +21672,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "栈帧有 %wd 字节，超过了 %wd 字节"
 
-#: final.c:4818 toplev.c:1453 tree-cfgcleanup.c:1300
+#: final.c:4821 toplev.c:1453 tree-cfgcleanup.c:1300
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "无法打开最终指令转储文件%qs：%s"
 
-#: final.c:4887 tree-cfgcleanup.c:1317
+#: final.c:4890 tree-cfgcleanup.c:1317
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "无法关闭最终指令转储文件%qs：%s"
@@ -21582,42 +21687,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大定点常量隐式截断为定点类型"
 
-#: fold-const.c:4168 fold-const.c:4178
+#: fold-const.c:4151 fold-const.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.c:5495 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3159
+#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
 
-#: fold-const.c:5945 fold-const.c:5959
+#: fold-const.c:5928 fold-const.c:5942
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比较结果始终为 %d"
 
-#: fold-const.c:6102
+#: fold-const.c:6085
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "对两个不匹配的不等比较取%<or%>的结果总为 1"
 
-#: fold-const.c:6107
+#: fold-const.c:6090
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "对两个互斥的相等比较取%<and%>的结果永远是 0"
 
-#: fold-const.c:8327
+#: fold-const.c:8310
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "在比较中归约常量时假定有符号数从不溢出"
 
-#: fold-const.c:8727
+#: fold-const.c:8710
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "在比较周围组合变量时假定有符号数从不溢出"
 
-#: fold-const.c:12082
+#: fold-const.c:12063
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折叠检查: 原始树因折叠而改变 "
@@ -22157,28 +22262,28 @@
 msgid "can%'t write PCH file"
 msgstr "无法写入 PCH 文件"
 
-#: gimple-fold.c:1620 gimple-fold.c:2601
+#: gimple-fold.c:1624 gimple-fold.c:2609
 #, fuzzy, gcc-internal-format
 msgid "%qD source argument is the same as destination"
 msgstr "属性%qE的参数无效"
 
-#: gimple-fold.c:1675
+#: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
 msgstr ""
 
-#: gimple-fold.c:1680
+#: gimple-fold.c:1684
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2048 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
-#: gimple-fold.c:2050
+#: gimple-fold.c:2054
 msgid "%G%qD specified bound %E exceeds destination size %wu"
 msgstr ""
 
-#: gimple-fold.c:2066
+#: gimple-fold.c:2070
 msgid "%G%qD specified bound %E equals source length"
 msgstr ""
 
@@ -22194,12 +22299,13 @@
 msgid "null pointer dereference"
 msgstr "空指针"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12446
-#: tree.c:12483 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
+#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
 #: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
-#: cp/call.c:6487 cp/call.c:8084 cp/constexpr.c:820 cp/constexpr.c:2298
-#: cp/cvt.c:1011 cp/cvt.c:1038 cp/decl.c:7316 cp/decl2.c:5249 cp/pt.c:8333
-#: cp/semantics.c:1836 cp/typeck.c:1695 cp/typeck.c:1890 cp/typeck.c:3821
+#: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
+#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
 msgstr "在此声明"
@@ -22710,10 +22816,10 @@
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3976
-#: cp/decl.c:10704 cp/decl.c:11103 cp/friend.c:384 cp/friend.c:393
-#: cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422 cp/parser.c:6337
-#: cp/parser.c:21016
+#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
+#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
+#: cp/parser.c:6327 cp/parser.c:21027
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -22746,7 +22852,7 @@
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wu"
 msgstr ""
 
-#: gimple-ssa-warn-restrict.c:1884
+#: gimple-ssa-warn-restrict.c:1890
 #, fuzzy
 msgid "%G%qD source argument is the same as destination"
 msgstr "属性%qE的参数无效"
@@ -23095,252 +23201,257 @@
 msgid "function cannot be instrumented"
 msgstr "不能内联%<main%>函数"
 
-#: ipa-devirt.c:762 ipa-devirt.c:913
+#: ipa-devirt.c:755 ipa-devirt.c:906
 #, fuzzy, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
 msgstr "先前的定义在这里"
 
-#: ipa-devirt.c:765
+#: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:804
+#: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:810
+#: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
 msgstr ""
 
-#: ipa-devirt.c:814
+#: ipa-devirt.c:807
 #, fuzzy, gcc-internal-format
 msgid "RTTI will not work on this type"
 msgstr "在指定 -fno-rtti 的情况下不能使用 typeid"
 
-#: ipa-devirt.c:844 ipa-devirt.c:872 ipa-devirt.c:943
+#: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, fuzzy, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
 msgstr "先前的定义在这里"
 
-#: ipa-devirt.c:850
+#: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
 msgstr ""
 
-#: ipa-devirt.c:878
+#: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
 msgstr ""
 
-#: ipa-devirt.c:921 ipa-devirt.c:951
+#: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:925
+#: ipa-devirt.c:918
 #, fuzzy, gcc-internal-format
 msgid "contains additional virtual method %qD"
 msgstr "为非虚方法%q+D指定了初始值设定项"
 
-#: ipa-devirt.c:932
+#: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
 msgstr ""
 
-#: ipa-devirt.c:957
+#: ipa-devirt.c:950
 #, fuzzy, gcc-internal-format
 msgid "virtual method %qD"
 msgstr "C++ 静态虚拟方法"
 
-#: ipa-devirt.c:961
+#: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
 msgstr ""
 
-#: ipa-devirt.c:967
+#: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
 msgstr ""
 
-#: ipa-devirt.c:997
+#: ipa-devirt.c:990
 #, fuzzy, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
 msgstr "先前的定义在这里"
 
-#: ipa-devirt.c:1008 ipa-devirt.c:1023 ipa-devirt.c:1273 ipa-devirt.c:1365
-#: ipa-devirt.c:1404 ipa-devirt.c:1422
+#: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
+#: ipa-devirt.c:1397 ipa-devirt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "a different type is defined in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: ipa-devirt.c:1015
+#: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
 msgstr ""
 
-#: ipa-devirt.c:1025
+#: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
 msgstr ""
 
-#: ipa-devirt.c:1119
+#: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1124
+#: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
 msgstr ""
 
-#: ipa-devirt.c:1129
+#: ipa-devirt.c:1122
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: ipa-devirt.c:1152
+#: ipa-devirt.c:1145
 #, fuzzy, gcc-internal-format
 msgid "type name %qs should match type name %qs"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: ipa-devirt.c:1156 ipa-devirt.c:1248
+#: ipa-devirt.c:1149 ipa-devirt.c:1241
 #, fuzzy, gcc-internal-format
 msgid "the incompatible type is defined here"
 msgstr "枚举类型在此定义"
 
-#: ipa-devirt.c:1184
+#: ipa-devirt.c:1177
 #, fuzzy, gcc-internal-format
 msgid "array types have different bounds"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: ipa-devirt.c:1199
+#: ipa-devirt.c:1192
 #, fuzzy, gcc-internal-format
 msgid "return value type mismatch"
 msgstr "<返回值>"
 
-#: ipa-devirt.c:1214
+#: ipa-devirt.c:1207
 #, gcc-internal-format
 msgid "implicit this pointer type mismatch"
 msgstr ""
 
-#: ipa-devirt.c:1217
+#: ipa-devirt.c:1210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
 msgstr "非类型参数包中类型不匹配"
 
-#: ipa-devirt.c:1228
+#: ipa-devirt.c:1221
 #, fuzzy, gcc-internal-format
 msgid "types have different parameter counts"
 msgstr "形参类型不同"
 
-#: ipa-devirt.c:1239
+#: ipa-devirt.c:1232
 #, fuzzy, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "先前的定义在这里"
 
-#: ipa-devirt.c:1245
+#: ipa-devirt.c:1238
 #, fuzzy, gcc-internal-format
 msgid "type %qT should match type %qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: ipa-devirt.c:1280
+#: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1298
+#: ipa-devirt.c:1291
 #, fuzzy, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: ipa-devirt.c:1313
+#: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1322
+#: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1330
+#: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1348
+#: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1355
+#: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1380
+#: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1389
+#: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1449
+#: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1464
+#: ipa-devirt.c:1457
 #, fuzzy, gcc-internal-format
 msgid "has different return value in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: ipa-devirt.c:1487 ipa-devirt.c:1499
+#: ipa-devirt.c:1480 ipa-devirt.c:1492
 #, fuzzy, gcc-internal-format
 msgid "has different parameters in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: ipa-devirt.c:1522
+#: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1526
+#: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
 msgstr ""
 
-#: ipa-devirt.c:1544 ipa-devirt.c:1600
+#: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1551 ipa-devirt.c:1605
+#: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1559
+#: ipa-devirt.c:1552
 #, fuzzy, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: ipa-devirt.c:1573
+#: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
 msgstr ""
 
-#: ipa-devirt.c:1586
+#: ipa-devirt.c:1579
 #, fuzzy, gcc-internal-format
 msgid "fields have different layout in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
+#: ipa-devirt.c:1586
+#, gcc-internal-format
+msgid "one field is bitfield while other is not"
+msgstr ""
+
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
@@ -23361,37 +23472,37 @@
 msgid "the extra base is defined here"
 msgstr "未定义 C++ 基类"
 
-#: ipa-devirt.c:3780
+#: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3789
+#: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3819
+#: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3827
+#: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
 msgstr[0] ""
 
-#: ipa-devirt.c:3835
+#: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
 msgstr[0] ""
 
-#: ipa-devirt.c:3846
+#: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
@@ -23673,32 +23784,37 @@
 #: multiple_target.c:91
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
-msgid "default target_clones attribute was not set"
+msgid "default %<target_clones%> attribute was not set"
 msgstr "版本属性不是一个字符串"
 
-#: multiple_target.c:324
+#: multiple_target.c:343
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
-msgid "single target_clones attribute is ignored"
+msgid "single %<target_clones%> attribute is ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: multiple_target.c:332
+#: multiple_target.c:351
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "clones for %<target_clones%> attribute cannot be created"
 msgstr "版本属性不是一个字符串"
 
-#: multiple_target.c:335
+#: multiple_target.c:354
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be copied because it receives a non-local goto"
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
 msgstr "函数%q+F无法被复制，因为它接受了非局部的 goto"
 
-#: multiple_target.c:352
+#: multiple_target.c:371
 #, fuzzy, gcc-internal-format
 msgid "default target was not set"
 msgstr "默认实参%qE使用了局部变量%qD"
 
+#: multiple_target.c:379
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
@@ -24022,12 +24138,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "memusage：无法识别的选项“$1”"
 
-#: opts-common.c:1198 config/i386/i386.c:3203
+#: opts-common.c:1198 config/i386/i386.c:3206
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: opts-common.c:1201 config/i386/i386.c:3206
+#: opts-common.c:1201 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs对%qs而言无效"
@@ -24643,22 +24759,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "输出操作数 %d 必须使用%<&%>约束"
 
-#: regcprop.c:1195
+#: regcprop.c:1187
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data：[%u]  空链(%u) 的 next_regno 错误"
 
-#: regcprop.c:1207
+#: regcprop.c:1199
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data：在 regno 链(%u)中的循环"
 
-#: regcprop.c:1210
+#: regcprop.c:1202
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data：[%u] 错误的 oldest_regno (%u)"
 
-#: regcprop.c:1222
+#: regcprop.c:1214
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data：[%u] 链(%s %u %i)中的非空 reg"
@@ -24702,7 +24818,7 @@
 msgstr "嵌套函数中使用了全局寄存器变量%qD"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29419
+#: config/rs6000/rs6000.c:29453
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "%qD与已用的函数冲突"
@@ -24944,157 +25060,157 @@
 msgid "%qD renamed after being referenced in assembly"
 msgstr "%D 在汇编中被引用后又被重命名"
 
-#: symtab.c:992
+#: symtab.c:998
 #, fuzzy, gcc-internal-format
 msgid "function symbol is not function"
 msgstr "函数返回了一个函数"
 
-#: symtab.c:1000
+#: symtab.c:1006
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: symtab.c:1006
+#: symtab.c:1012
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "未知类型的输入行"
 
-#: symtab.c:1015
+#: symtab.c:1021
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1023
+#: symtab.c:1029
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1032
+#: symtab.c:1038
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1045
+#: symtab.c:1051
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "cgraph_hash 中找不到节点"
 
-#: symtab.c:1052
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: symtab.c:1057
+#: symtab.c:1063
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.c:1062
+#: symtab.c:1068
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.c:1067
+#: symtab.c:1073
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.c:1072
+#: symtab.c:1078
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "-fmit-class-file 的别名"
 
-#: symtab.c:1077
+#: symtab.c:1083
 #, fuzzy, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.c:1082
+#: symtab.c:1088
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.c:1091
+#: symtab.c:1097
 #, fuzzy, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.c:1096
+#: symtab.c:1102
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group 并非环状清单"
 
-#: symtab.c:1101
+#: symtab.c:1107
 #, fuzzy, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "不支持组合有不同取样信息的单元。"
 
-#: symtab.c:1106
+#: symtab.c:1112
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "节点是单独在中 comdat 群组"
 
-#: symtab.c:1113
+#: symtab.c:1119
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group 并非环状清单"
 
-#: symtab.c:1128
+#: symtab.c:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1138
+#: symtab.c:1144
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1145
+#: symtab.c:1151
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "节点是单独在中 comdat 群组"
 
-#: symtab.c:1157
+#: symtab.c:1163
 #, fuzzy, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "--help=target 的别名"
 
-#: symtab.c:1164
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1179
+#: symtab.c:1185
 #, fuzzy, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "--help=target 的别名"
 
-#: symtab.c:1187
+#: symtab.c:1193
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1210 symtab.c:1247
+#: symtab.c:1216 symtab.c:1253
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify 失败"
 
-#: symtab.c:1243
+#: symtab.c:1249
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1652
+#: symtab.c:1658
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "函数%q+D重声明为内联的"
 
-#: symtab.c:1654
+#: symtab.c:1660
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "变量%qD被设定但未被使用"
 
-#: symtab.c:1682
+#: symtab.c:1688
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -26265,12 +26381,12 @@
 msgid "control reaches end of non-void function"
 msgstr "在有返回值的函数中，控制流程到达函数尾"
 
-#: tree-cfg.c:9498 cp/cvt.c:1035
+#: tree-cfg.c:9498 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: tree-cfg.c:9503 cp/cvt.c:1042
+#: tree-cfg.c:9503 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "忽略声明有 warn_unused_result 属性的函数的返回值"
@@ -26773,7 +26889,7 @@
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "矢量随机播放作业将被展开 piecewise"
 
-#: tree-vect-loop.c:4037
+#: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -26818,92 +26934,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7847
+#: tree.c:7852
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "函数数组是没有意义的"
 
-#: tree.c:8014
+#: tree.c:8019
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "函数不能返回函数"
 
-#: tree.c:9322 tree.c:9407 tree.c:9468
+#: tree.c:9327 tree.c:9412 tree.c:9473
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "树检查：%s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.c:9359
+#: tree.c:9364
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "树检查：不需要 %s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.c:9372
+#: tree.c:9377
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "树检查：需要类%qs，得到%qs(%s) 在 %s，于 %s:%d"
 
-#: tree.c:9421
+#: tree.c:9426
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "树检查：不需要类%qs，得到%qs(%s) 在 %s，于 %s:%d"
 
-#: tree.c:9434
+#: tree.c:9439
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "树检查：需要 omp_clause %s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.c:9494
+#: tree.c:9499
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "树检查：需要包含%qs结构的树，得到%qs在 %s，于 %s:%d"
 
-#: tree.c:9508
+#: tree.c:9513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "树检查：访问了 %3$s 中有 %2$d 个 elt  的 tree_vec 的 elt %1$d，于 %4$s:%5$d"
 
-#: tree.c:9520
+#: tree.c:9525
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "树检查：访问了 %3$s 中有 %2$d 个 elt  的 tree_vec 的 elt %1$d，于 %4$s:%5$d"
 
-#: tree.c:9533
+#: tree.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.c:9546
+#: tree.c:9551
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 omp_clause %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.c:12441
+#: tree.c:12446
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.c:12444
+#: tree.c:12449
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.c:12468 tree.c:12490
+#: tree.c:12473 tree.c:12495
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.c:12471 tree.c:12493
+#: tree.c:12476 tree.c:12498
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.c:12477 tree.c:12498
+#: tree.c:12482 tree.c:12503
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "已弃用类型：%s"
 
-#: tree.c:12480 tree.c:12501
+#: tree.c:12485 tree.c:12506
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "已弃用此类型"
@@ -26928,247 +27044,247 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13038
-#, gcc-internal-format
-msgid "type variant differs by "
+#: tree.c:13043
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13079
+#: tree.c:13084
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13081
+#: tree.c:13086
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13083
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13103
+#: tree.c:13108
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13116
+#: tree.c:13121
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13152
+#: tree.c:13157
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13154
+#: tree.c:13159
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13156
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13194
+#: tree.c:13199
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13196
+#: tree.c:13201
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with notes file\n"
 msgid "first mismatch is field"
 msgstr "%s:时间戳与说明文件不匹配\n"
 
-#: tree.c:13198
+#: tree.c:13203
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13215
+#: tree.c:13220
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13217 tree.c:13228
+#: tree.c:13222 tree.c:13233
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13219 tree.c:13230
+#: tree.c:13224 tree.c:13235
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13226
+#: tree.c:13231
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: tree.c:13529
+#: tree.c:13534
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "Main variant is not defined"
 msgstr "环境变量%qs未定义"
 
-#: tree.c:13534
+#: tree.c:13539
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13546
+#: tree.c:13551
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13564
+#: tree.c:13569
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13572
+#: tree.c:13577
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13578
+#: tree.c:13583
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13594
+#: tree.c:13599
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13604
+#: tree.c:13609
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13614
+#: tree.c:13619
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13635
+#: tree.c:13640
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13641
+#: tree.c:13646
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13652
+#: tree.c:13657
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13663
+#: tree.c:13668
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13681
+#: tree.c:13686
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13688
+#: tree.c:13693
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13695
+#: tree.c:13700
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13711
+#: tree.c:13716
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13719
+#: tree.c:13724
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13726
+#: tree.c:13731
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13736
+#: tree.c:13741
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: tree.c:13745
+#: tree.c:13750
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: tree.c:13767
+#: tree.c:13772
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13782
+#: tree.c:13787
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13788
+#: tree.c:13793
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13801
+#: tree.c:13806
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13814
+#: tree.c:13819
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13820
+#: tree.c:13825
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13827
+#: tree.c:13832
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13839
+#: tree.c:13844
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13845
+#: tree.c:13850
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13855
+#: tree.c:13860
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13862
+#: tree.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -27194,12 +27310,12 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "损坏的值取样：%s 取样总数(%d)与基本块数(%d)不匹配"
 
-#: var-tracking.c:7164
+#: var-tracking.c:7166
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "变量跟踪大小越限，请不带 -fvar-tracking-assignments 重试"
 
-#: var-tracking.c:7168
+#: var-tracking.c:7170
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "变量跟踪大小越限"
@@ -28097,7 +28213,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8887
+#: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建议在用作真值的赋值语句前后加上括号"
@@ -28352,7 +28468,7 @@
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "索引 %E 指定了一个大于%qT大小的偏移量"
 
-#: c-family/c-common.c:6427 cp/init.c:3002 cp/init.c:3021
+#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "数组太大"
@@ -28969,7 +29085,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8198
+#: c-family/c-omp.c:557 cp/semantics.c:8186
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -28985,22 +29101,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8088
+#: c-family/c-omp.c:599 cp/semantics.c:8076
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7744
+#: c-family/c-omp.c:704 cp/semantics.c:7732
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8094
+#: c-family/c-omp.c:711 cp/semantics.c:8082
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7859
+#: c-family/c-omp.c:775 cp/semantics.c:7847
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -29549,8 +29665,8 @@
 msgid "wrong type argument to %s"
 msgstr "不能对该类型的参数求绝对值"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1836
-#: cp/constexpr.c:4088
+#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常量表达式溢出"
@@ -30204,7 +30320,7 @@
 msgstr ""
 
 #: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
-#: cp/typeck.c:5032
+#: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
@@ -30284,7 +30400,7 @@
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5359
+#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
@@ -30416,47 +30532,47 @@
 msgid "-mcpu=%s has invalid silicon revision"
 msgstr "-mcpu=%s 芯片版本不正确"
 
-#: common/config/i386/i386-common.c:1273
+#: common/config/i386/i386-common.c:1285
 #, fuzzy, gcc-internal-format
 msgid "-malign-loops is obsolete, use -falign-loops"
 msgstr "%salign-loops%s 已经过时，请使用 -falign-loops%s"
 
-#: common/config/i386/i386-common.c:1275
+#: common/config/i386/i386-common.c:1287
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-loops=%d is not between 0 and %d"
 msgstr "-malign-loops=%d 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.c:1282
+#: common/config/i386/i386-common.c:1294
 #, fuzzy, gcc-internal-format
 msgid "-malign-jumps is obsolete, use -falign-jumps"
 msgstr "%salign-jumps%s 已经过时，请使用 -falign-jumps%s"
 
-#: common/config/i386/i386-common.c:1284
+#: common/config/i386/i386-common.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-jumps=%d is not between 0 and %d"
 msgstr "-malign-jumps=%d 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.c:1292
+#: common/config/i386/i386-common.c:1304
 #, fuzzy, gcc-internal-format
 msgid "-malign-functions is obsolete, use -falign-functions"
 msgstr "%salign-functions%s 已过时，请使用 -falign-functions%s"
 
-#: common/config/i386/i386-common.c:1294
+#: common/config/i386/i386-common.c:1306
 #, gcc-internal-format, gfc-internal-format
 msgid "-malign-functions=%d is not between 0 and %d"
 msgstr "-malign-functions=%d 不在 0 和 %d 之间"
 
-#: common/config/i386/i386-common.c:1303
+#: common/config/i386/i386-common.c:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mbranch-cost=%d is not between 0 and 5"
 msgstr "%sbranch-cost=%d%s不在 0 和 5 之间"
 
-#: common/config/i386/i386-common.c:1357
+#: common/config/i386/i386-common.c:1369
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgstr "%<-fsplit-stack%>只在 GNU/Linux 下被支持"
 
-#: common/config/i386/i386-common.c:1363
+#: common/config/i386/i386-common.c:1375
 #, gcc-internal-format
 msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
@@ -30482,31 +30598,31 @@
 msgstr ""
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
-#: common/config/rs6000/rs6000-common.c:173 config/sparc/sparc.c:1734
+#: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "未知的 -mdebug-%s 开关"
 
 #: common/config/powerpcspe/powerpcspe-common.c:221
-#: common/config/rs6000/rs6000-common.c:212
+#: common/config/rs6000/rs6000-common.c:221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown switch -mlong-double-%s"
 msgstr "未知的 -mdebug-%s 开关"
 
 #: common/config/powerpcspe/powerpcspe-common.c:231
-#: common/config/rs6000/rs6000-common.c:222
+#: common/config/rs6000/rs6000-common.c:231
 #, gcc-internal-format
 msgid "-msingle-float option equivalent to -mhard-float"
 msgstr "-msingle-float 选项等同于 -mhard-float"
 
 #: common/config/powerpcspe/powerpcspe-common.c:247
-#: common/config/rs6000/rs6000-common.c:238
+#: common/config/rs6000/rs6000-common.c:247
 #, gcc-internal-format
 msgid "-msimple-fpu option ignored"
 msgstr "-msimple-fpu 选项被忽略"
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
-#: common/config/rs6000/rs6000-common.c:304
+#: common/config/rs6000/rs6000-common.c:313
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
@@ -30993,8 +31109,8 @@
 msgstr "attribute(target(\"%s\"))未知"
 
 #: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5476 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36870 config/s390/s390.c:15746
+#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
@@ -31075,8 +31191,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 开关的值%qs错误"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6522
-#: config/arc/arc.c:6801 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
+#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31188,11 +31304,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6467 config/i386/i386.c:12494 config/i386/i386.c:41426
-#: config/i386/i386.c:41476 config/i386/i386.c:41546 config/m68k/m68k.c:780
-#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4562
+#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
+#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32948
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31202,153 +31318,143 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE属性只能用于函数"
 
-#: config/arc/arc.c:6421
+#: config/arc/arc.c:6425
 #, fuzzy, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: config/arc/arc.c:6429
+#: config/arc/arc.c:6433
 #, fuzzy, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%>的实参无效"
 
-#: config/arc/arc.c:6556
-#, gcc-internal-format
-msgid "builtin operand should be an unsigned 6-bit value"
-msgstr ""
-
-#: config/arc/arc.c:6597
+#: config/arc/arc.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea 必须与 -mmulticore 一起使用"
 
-#: config/arc/arc.c:6638 config/arc/arc.c:6735
+#: config/arc/arc.c:6637 config/arc/arc.c:6734
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6671 config/arc/arc.c:6703
+#: config/arc/arc.c:6670 config/arc/arc.c:6702
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6675 config/arc/arc.c:6707
+#: config/arc/arc.c:6674 config/arc/arc.c:6706
 #, fuzzy, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6739
+#: config/arc/arc.c:6738
 #, fuzzy, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6772
+#: config/arc/arc.c:6771
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6776
+#: config/arc/arc.c:6775
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6783
+#: config/arc/arc.c:6782
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6786
+#: config/arc/arc.c:6785
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6833
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "symbol used as immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "符号被用作立即操作数"
 
-#: config/arc/arc.c:6838
+#: config/arc/arc.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6842
+#: config/arc/arc.c:6841
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6846
+#: config/arc/arc.c:6845
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6849
+#: config/arc/arc.c:6848
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6900
+#: config/arc/arc.c:6899
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:6921
+#: config/arc/arc.c:7685
 #, gcc-internal-format
-msgid "operand for sleep instruction must be an unsigned 6 bit compile-time constant"
-msgstr ""
-
-#: config/arc/arc.c:7707
-#, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7916
+#: config/arc/arc.c:7894
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "在 %2$s 缓存中 %1$zu 字节可用"
 
-#: config/arc/arc.c:10704
+#: config/arc/arc.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/arc/arc.c:10712 config/arc/arc.c:10751
+#: config/arc/arc.c:10690 config/arc/arc.c:10729
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute is missing"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.c:10723 config/arc/arc.c:10762 config/arc/arc.c:10864
+#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/arc/arc.c:10743
+#: config/arc/arc.c:10721
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arc/arc.c:10798
+#: config/arc/arc.c:10776
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arc/arc.c:10804
+#: config/arc/arc.c:10782
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute ignored"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.c:10854 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
-#: config/nvptx/nvptx.c:4585
+#: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "属性%qE只能用于变量"
@@ -31374,153 +31480,153 @@
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2631 config/arm/arm-builtins.c:2735
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "选择子必须是立即数"
 
-#: config/arm/arm-builtins.c:2639 config/arm/arm-builtins.c:2684
-#: config/arm/arm-builtins.c:2742 config/arm/arm-builtins.c:2751
+#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
+#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2644 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2649 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2821
+#: config/arm/arm-builtins.c:2823
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "掩码必须是一个立即数"
 
-#: config/arm/arm-builtins.c:2826
+#: config/arm/arm-builtins.c:2828
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE属性的参数应当在 0 和 255 之间"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3016
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3018
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3020
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3022
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3033
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32336,12 +32442,12 @@
 msgid "invalid IACC argument"
 msgstr "无效的 IACC 实参"
 
-#: config/frv/frv.c:8629 config/sparc/sparc.c:10832
+#: config/frv/frv.c:8629 config/sparc/sparc.c:10840
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs需要一个常量实参"
 
-#: config/frv/frv.c:8634 config/sparc/sparc.c:10838
+#: config/frv/frv.c:8634 config/sparc/sparc.c:10846
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "常量实参超过%qs的范围"
@@ -32443,60 +32549,60 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "不能在 PCH 文件中找到位置：%m"
 
-#: config/i386/i386.c:3174
+#: config/i386/i386.c:3177
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "错误的选项于环境变量 MINICOM=“%s”\n"
 
-#: config/i386/i386.c:3180
+#: config/i386/i386.c:3183
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3190
+#: config/i386/i386.c:3193
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D的寄存器名无效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3216
+#: config/i386/i386.c:3219
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D的寄存器名无效"
 
-#: config/i386/i386.c:3229
+#: config/i386/i386.c:3232
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%s：未知选项 -%c\n"
 
-#: config/i386/i386.c:3239
+#: config/i386/i386.c:3242
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3246
+#: config/i386/i386.c:3249
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs没有指定类名"
 
-#: config/i386/i386.c:3299
+#: config/i386/i386.c:3302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "%L处参数列表函数未知"
 
-#: config/i386/i386.c:3723
+#: config/i386/i386.c:3726
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386.c:3772
+#: config/i386/i386.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
-#: config/i386/i386.c:3774
+#: config/i386/i386.c:3777
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -32503,529 +32609,514 @@
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3801
+#: config/i386/i386.c:3804
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386.c:3818
+#: config/i386/i386.c:3821
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3830
+#: config/i386/i386.c:3833
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "%<-Wabi=1%> 不受支持，将使用 =2"
 
-#: config/i386/i386.c:3848 config/i386/i386.c:3857 config/i386/i386.c:3869
-#: config/i386/i386.c:3880 config/i386/i386.c:3891
+#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3883 config/i386/i386.c:3894
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3860 config/i386/i386.c:3872
+#: config/i386/i386.c:3863 config/i386/i386.c:3875
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3878 config/i386/i386.c:3887 config/i386/i386.c:5250
+#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
 
-#: config/i386/i386.c:3915
+#: config/i386/i386.c:3918
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel 在此配置下不受支持"
 
-#: config/i386/i386.c:3920
+#: config/i386/i386.c:3923
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未编译入对 %i 位模式的支持"
 
-#: config/i386/i386.c:3929
+#: config/i386/i386.c:3932
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3931
+#: config/i386/i386.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3938
+#: config/i386/i386.c:3941
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3940
+#: config/i386/i386.c:3943
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3948 config/i386/i386.c:4262
+#: config/i386/i386.c:3951 config/i386/i386.c:4265
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您选择的 CPU 不支持 x86-64 指令集"
 
-#: config/i386/i386.c:4194 config/i386/i386.c:4197
+#: config/i386/i386.c:4197 config/i386/i386.c:4200
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX 不支持 x32"
 
-#: config/i386/i386.c:4202
+#: config/i386/i386.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= 的值(%s)不正确"
 
-#: config/i386/i386.c:4203
+#: config/i386/i386.c:4206
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "%2$sarch=%3$s %4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386.c:4225
+#: config/i386/i386.c:4228
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4227
+#: config/i386/i386.c:4230
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4232
+#: config/i386/i386.c:4235
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4233
+#: config/i386/i386.c:4236
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4281
+#: config/i386/i386.c:4284
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= 开关的值 (%s) 错误"
 
-#: config/i386/i386.c:4282
+#: config/i386/i386.c:4285
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "%2$stune=%3$s%4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386.c:4302
+#: config/i386/i386.c:4305
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4304
+#: config/i386/i386.c:4307
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4309
+#: config/i386/i386.c:4312
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4310
+#: config/i386/i386.c:4313
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4376
+#: config/i386/i386.c:4379
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386.c:4378
+#: config/i386/i386.c:4381
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之间"
 
-#: config/i386/i386.c:4414
+#: config/i386/i386.c:4417
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:4415
+#: config/i386/i386.c:4418
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:4494
+#: config/i386/i386.c:4497
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/i386/i386.c:4520
+#: config/i386/i386.c:4523
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386.c:4533
+#: config/i386/i386.c:4536
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386.c:4542
+#: config/i386/i386.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:4543
+#: config/i386/i386.c:4546
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:4553
+#: config/i386/i386.c:4556
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386.c:4560
+#: config/i386/i386.c:4563
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386.c:4610
+#: config/i386/i386.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4612
+#: config/i386/i386.c:4615
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4626
+#: config/i386/i386.c:4629
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4628
+#: config/i386/i386.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4738
+#: config/i386/i386.c:4741
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386.c:4745
+#: config/i386/i386.c:4748
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4810 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "未知的选项：%s %s %s"
 
-#: config/i386/i386.c:4867 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4872 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4904 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:4942
-#, gcc-internal-format
-msgid "%<-fcf-protection=branch%> requires Intel CET support. Use -mcet or -mibt option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4951
-#, gcc-internal-format
-msgid "%<-fcf-protection=return%> requires Intel CET support. Use -mcet or -mshstk option to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:4961
-#, gcc-internal-format
-msgid "%<-fcf-protection=full%> requires Intel CET support. Use -mcet or both of -mibt and -mshstk options to enable CET"
-msgstr ""
-
-#: config/i386/i386.c:5542 config/i386/i386.c:5589 config/s390/s390.c:15812
+#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/i386/i386.c:5570
+#: config/i386/i386.c:5534
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\")已经被指定"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5837
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:5867
+#: config/i386/i386.c:5852
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5916
+#: config/i386/i386.c:5901
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386.c:5928
+#: config/i386/i386.c:5913
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5949
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386.c:6062
+#: config/i386/i386.c:6047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386.c:6066
+#: config/i386/i386.c:6051
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386.c:6480 config/i386/i386.c:6531
+#: config/i386/i386.c:6465 config/i386/i386.c:6516
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386.c:6485
+#: config/i386/i386.c:6470
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6492 config/i386/i386.c:41446
+#: config/i386/i386.c:6477 config/i386/i386.c:41444
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386.c:6498
+#: config/i386/i386.c:6483
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386.c:6523 config/i386/i386.c:6566
+#: config/i386/i386.c:6508 config/i386/i386.c:6551
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:6527
+#: config/i386/i386.c:6512
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386.c:6535 config/i386/i386.c:6584
+#: config/i386/i386.c:6520 config/i386/i386.c:6569
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6545 config/i386/i386.c:6562
+#: config/i386/i386.c:6530 config/i386/i386.c:6547
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:6549
+#: config/i386/i386.c:6534
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386.c:6553 config/i386/i386.c:6580
+#: config/i386/i386.c:6538 config/i386/i386.c:6565
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6570 config/i386/i386.c:6588
+#: config/i386/i386.c:6555 config/i386/i386.c:6573
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6576
+#: config/i386/i386.c:6561
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386.c:6820
+#: config/i386/i386.c:6805
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:6823
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qT却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:7141
+#: config/i386/i386.c:7126
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 不支持 ms_abi 属性"
 
-#: config/i386/i386.c:7175
+#: config/i386/i386.c:7160
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:7517
+#: config/i386/i386.c:7502
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7523
+#: config/i386/i386.c:7508
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:7537
+#: config/i386/i386.c:7522
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7543
+#: config/i386/i386.c:7528
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7559
+#: config/i386/i386.c:7544
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却出现了 SSE 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7565
+#: config/i386/i386.c:7550
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:7581
+#: config/i386/i386.c:7566
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7587
+#: config/i386/i386.c:7572
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "没有启用 MMX却返回 MMX 向量，这改变了 ABI"
 
-#: config/i386/i386.c:7769
+#: config/i386/i386.c:7754
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有一个可变数组成员的结构的 ABI 有了改变"
 
-#: config/i386/i386.c:7886
+#: config/i386/i386.c:7871
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:8004
+#: config/i386/i386.c:7989
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/i386/i386.c:8167
+#: config/i386/i386.c:8152
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中返回"
 
-#: config/i386/i386.c:8173
+#: config/i386/i386.c:8158
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中传递参数"
 
-#: config/i386/i386.c:8189
+#: config/i386/i386.c:8174
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "已禁用 x87 却在 x87 寄存器中返回"
 
-#: config/i386/i386.c:8486 config/i386/i386.c:8765 config/i386/i386.c:9291
+#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:8488 config/i386/i386.c:8767 config/i386/i386.c:9293
+#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9193
+#: config/i386/i386.c:9178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:11616
+#: config/i386/i386.c:11601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert：%s 与 %s 赋值兼容"
 
-#: config/i386/i386.c:13608
+#: config/i386/i386.c:13593
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:13698
+#: config/i386/i386.c:13683
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14985
+#: config/i386/i386.c:14970
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支持对嵌套函数使用 fastcall"
 
-#: config/i386/i386.c:15005
+#: config/i386/i386.c:14990
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支持在嵌套函数中使用 2 个寄存器参数"
@@ -33032,85 +33123,85 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15016
+#: config/i386/i386.c:15001
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支持 3 个寄存器参数"
 
-#: config/i386/i386.c:17945
+#: config/i386/i386.c:17939
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17956 config/i386/i386.c:17970
+#: config/i386/i386.c:17950 config/i386/i386.c:17964
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:18002
+#: config/i386/i386.c:17996
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "扩展的寄存器没有高半部分"
 
-#: config/i386/i386.c:18017
+#: config/i386/i386.c:18011
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:18208
+#: config/i386/i386.c:18202
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: config/i386/i386.c:28509
+#: config/i386/i386.c:28467
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.c:30037
+#: config/i386/i386.c:29995
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32465
+#: config/i386/i386.c:32435
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32515
+#: config/i386/i386.c:32485
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "找不到任何查看器用于 %s/%s\n"
 
-#: config/i386/i386.c:32525
+#: config/i386/i386.c:32495
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32687
+#: config/i386/i386.c:32657
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32692 config/i386/i386.c:32968
-#: config/rs6000/rs6000.c:37816
+#: config/i386/i386.c:32662 config/i386/i386.c:32938
+#: config/rs6000/rs6000.c:37850
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/i386/i386.c:32825 config/rs6000/rs6000.c:37573
+#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386.c:33237
+#: config/i386/i386.c:33207
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/i386/i386.c:33262 config/i386/i386.c:33312
+#: config/i386/i386.c:33232 config/i386/i386.c:33282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
@@ -33117,233 +33208,233 @@
 "\n"
 "错误：“%s”并非有效新闻群组！\n"
 
-#: config/i386/i386.c:34005 config/i386/i386.c:35445
+#: config/i386/i386.c:33975 config/i386/i386.c:35415
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最后一个实参必须是一个 2 位立即数"
 
-#: config/i386/i386.c:34400
+#: config/i386/i386.c:34370
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:34495
+#: config/i386/i386.c:34465
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35376
+#: config/i386/i386.c:35346
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:35391
+#: config/i386/i386.c:35361
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最后一个实参必须是一个 3 位立即数"
 
-#: config/i386/i386.c:35424
+#: config/i386/i386.c:35394
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:35464
+#: config/i386/i386.c:35434
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:35477
+#: config/i386/i386.c:35447
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:35487
+#: config/i386/i386.c:35457
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "倒数第二个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35492 config/i386/i386.c:36272
+#: config/i386/i386.c:35462 config/i386/i386.c:36249
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35626
+#: config/i386/i386.c:35596
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: config/i386/i386.c:35631
+#: config/i386/i386.c:35601
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "不正确的格式：%s\n"
 
-#: config/i386/i386.c:35637 config/i386/i386.c:35844
+#: config/i386/i386.c:35607 config/i386/i386.c:35814
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "控制生成的浮点舍入模式"
 
-#: config/i386/i386.c:35826
+#: config/i386/i386.c:35796
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:35832
+#: config/i386/i386.c:35802
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:35835
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:36270
+#: config/i386/i386.c:36247
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386.c:36352 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15296
+#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15304
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/i386/i386.c:36562
+#: config/i386/i386.c:36539
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE需要未知的 ISA 选项"
 
-#: config/i386/i386.c:36566
+#: config/i386/i386.c:36543
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE需要 ISA 选项 %s"
 
-#: config/i386/i386.c:37383
+#: config/i386/i386.c:37381
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最后一个实参必须是一个立即数"
 
-#: config/i386/i386.c:38110 config/i386/i386.c:38292
+#: config/i386/i386.c:38108 config/i386/i386.c:38290
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:38345
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "左实参必须是一个切片"
 
-#: config/i386/i386.c:38351
+#: config/i386/i386.c:38349
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "(提示略过)"
 
-#: config/i386/i386.c:38370
+#: config/i386/i386.c:38368
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:41433
+#: config/i386/i386.c:41431
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386.c:41454
+#: config/i386/i386.c:41452
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386.c:41487 config/i386/i386.c:41496
+#: config/i386/i386.c:41485 config/i386/i386.c:41494
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386.c:41532 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33031
+#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33065
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386.c:41557 config/i386/i386.c:41579 config/ia64/ia64.c:815
+#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386.c:41567 config/i386/i386.c:41589 config/s390/s390.c:1182
+#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/i386/i386.c:41621
+#: config/i386/i386.c:41619
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41628
+#: config/i386/i386.c:41626
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41638
+#: config/i386/i386.c:41636
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41641
+#: config/i386/i386.c:41639
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.c:44628
+#: config/i386/i386.c:44676
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: config/i386/i386.c:44692
+#: config/i386/i386.c:44740
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/i386/i386.c:44721
+#: config/i386/i386.c:44769
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.c:50585
+#: config/i386/i386.c:50634
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "未知的架构‘%s’"
 
-#: config/i386/i386.c:50592
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50598
+#: config/i386/i386.c:50647
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50622 config/i386/i386.c:50738
+#: config/i386/i386.c:50671 config/i386/i386.c:50787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "不支持的真理哈希类型 %d。\n"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50690
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/i386/i386.c:50663
+#: config/i386/i386.c:50712
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/i386/i386.c:50984
+#: config/i386/i386.c:51033
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33567,7 +33658,7 @@
 msgstr "interrupt_thread 只在 fido 中可用"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25757
+#: config/rs6000/rs6000.c:25791
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支持堆栈限制表达式"
@@ -34103,8 +34194,36 @@
 msgid "constant argument out of range for %s"
 msgstr "常量实参超过%qs的范围"
 
-#: config/nds32/nds32-intrinsic.c:291
+#: config/nds32/nds32-intrinsic.c:690
 #, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3s or v3f toolchain"
+msgstr "此内建函数只在 fr450 上可用"
+
+#: config/nds32/nds32-intrinsic.c:702
+#, fuzzy, gcc-internal-format
+#| msgid "this builtin function is only available on the fr450"
+msgid "this builtin function is only available on the v3f toolchain"
+msgstr "此内建函数只在 fr450 上可用"
+
+#: config/nds32/nds32-intrinsic.c:717
+#, fuzzy, gcc-internal-format
+#| msgid "nested functions not supported on this target"
+msgid "this builtin function not support on the v3m toolchain"
+msgstr "嵌套函数在此目标机上不受支持"
+
+#: config/nds32/nds32-intrinsic.c:736
+#, fuzzy, gcc-internal-format
+msgid "don't support performance extension instructions"
+msgstr "生成加载/存储乘法指令"
+
+#: config/nds32/nds32-intrinsic.c:748
+#, fuzzy, gcc-internal-format
+msgid "don't support performance extension version 2 instructions"
+msgstr "生成加载/存储乘法指令"
+
+#: config/nds32/nds32-intrinsic.c:760
+#, fuzzy, gcc-internal-format
 msgid "don't support string extension instructions"
 msgstr "启用符号扩展指令"
 
@@ -34124,42 +34243,59 @@
 msgstr "不允许多个中断属性"
 
 #. Trampoline is not supported on reduced-set registers yet.
-#: config/nds32/nds32.c:1804 config/nds32/nds32.c:1858
-#: config/nds32/nds32.c:2375 config/nds32/nds32.c:2422
-#: config/nds32/nds32.c:2437 config/nds32/nds32.c:2443
-#: config/nds32/nds32.c:2503 config/nds32/nds32.c:2509
-#: config/nds32/nds32.c:2541
+#: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
+#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
+#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
+#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
+#: config/nds32/nds32.c:3322
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "嵌套函数蹦床在此目标机上不受支持"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:2344
+#: config/nds32/nds32.c:3025
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "类型索引编号 %d 超出范围\n"
 
-#: config/nds32/nds32.c:2649
+#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
+#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
+#: config/nds32/nds32.c:3069
 #, fuzzy, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range!"
+msgstr "类型索引编号 %d 超出范围\n"
+
+#: config/nds32/nds32.c:3508
+#, fuzzy, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "迭代变量%qE类型无效"
 
-#: config/nds32/nds32.c:2677
+#: config/nds32/nds32.c:3536
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "重置属性为默认值"
 
-#: config/nds32/nds32.c:2693
+#: config/nds32/nds32.c:3552
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "属性%qs的参数无效"
 
-#: config/nds32/nds32.c:2706
+#: config/nds32/nds32.c:3565
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "属性%qs的参数无效"
 
-#: config/nds32/nds32.c:2778
+#: config/nds32/nds32.c:3638
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
+msgstr ""
+
+#: config/nds32/nds32.c:3641
+#, gcc-internal-format
+msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
+msgstr ""
+
+#: config/nds32/nds32.c:3647
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "尽可能生成与位置无关的代码(大模式)"
@@ -34376,38 +34512,38 @@
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
 msgstr ""
 
-#: config/nvptx/nvptx.c:1972
+#: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
 msgstr ""
 
-#: config/nvptx/nvptx.c:2167
+#: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4567
+#: config/nvptx/nvptx.c:4616
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: config/nvptx/nvptx.c:4590
+#: config/nvptx/nvptx.c:4639
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 属性不允许用于自动存储类"
 
-#: config/nvptx/nvptx.c:4960
+#: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4961
+#: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4971
+#: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34501,12 +34637,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall 末尾有垃圾字符"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6108
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6112
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -34560,7 +34696,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert 只接受三个参数"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6813
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -34874,7 +35010,7 @@
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11229
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 返回向量引用：非标准的 ABI 扩展，不保证兼容性"
@@ -34884,7 +35020,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11587
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
@@ -34894,12 +35030,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12596
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12771
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 传递向量引用：非标准的 ABI 扩展，不保证兼容性"
@@ -34909,28 +35045,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13963
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14007
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14093
+#: config/rs6000/rs6000.c:14101
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14111
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14127
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -34951,12 +35087,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14783
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14785
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
@@ -34979,53 +35115,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "属性%qs的参数无效"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15057
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "实参 3 必须是一个 4 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15082
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "实参 2 必须是一个 2 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15102
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15114
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "数字必须是 0 或 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15126
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15140
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15152
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "数字必须是 0 或 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15229
-#: config/rs6000/rs6000.c:15561
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
+#: config/rs6000/rs6000.c:15569
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15386
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "无法解析的重载 Altivec 内建函数%qF"
@@ -35151,7 +35287,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部错误：内建函数 %s 的第 %d 个参数有非预期的参数类型 %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25724
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "栈帧太大"
@@ -35161,13 +35297,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29425
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target 在此目标机上不受支持"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30413
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
@@ -35177,22 +35313,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32796
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32798
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32800
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32802
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
@@ -35202,7 +35338,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32811
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
@@ -35667,22 +35803,22 @@
 msgid "unknown cpu %qs for -mtune"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/riscv/riscv.c:4094
+#: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4134
+#: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.c:4139
+#: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
 msgstr ""
 
-#: config/riscv/riscv.c:4149
+#: config/riscv/riscv.c:4152
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
@@ -35750,33 +35886,38 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6122 config/rs6000/rs6000-c.c:6173
-#: config/rs6000/rs6000-c.c:6443 config/rs6000/rs6000-c.c:6509
-#: config/rs6000/rs6000-c.c:6860 config/rs6000/rs6000-c.c:6901
+#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
+#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
+#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:6246 config/rs6000/rs6000-c.c:6329
-#: config/rs6000/rs6000-c.c:6681
+#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
+#: config/rs6000/rs6000-c.c:6736
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:6438
+#: config/rs6000/rs6000-c.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:6965
+#: config/rs6000/rs6000-c.c:7054
 #, fuzzy, gcc-internal-format
+msgid "builtin %qs requires builtin %qs"
+msgstr "内建函数%q+D未被声明为函数"
+
+#: config/rs6000/rs6000-c.c:7058
+#, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000-c.c:6973
+#: config/rs6000/rs6000-c.c:7068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
@@ -35910,46 +36051,46 @@
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/rs6000/rs6000.c:11393
+#: config/rs6000/rs6000.c:11401
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:11854
+#: config/rs6000/rs6000.c:11862
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:13564
+#: config/rs6000/rs6000.c:13572
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/rs6000/rs6000.c:14142
+#: config/rs6000/rs6000.c:14150
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000.c:14181
+#: config/rs6000/rs6000.c:14189
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: config/rs6000/rs6000.c:14239 config/rs6000/rs6000.c:15890
+#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:14734
+#: config/rs6000/rs6000.c:14742
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/rs6000/rs6000.c:14931
+#: config/rs6000/rs6000.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -35956,133 +36097,133 @@
 msgstr "%s 只接受 1 个参数"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14950
+#: config/rs6000/rs6000.c:14958
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "属性%qs的参数无效"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14978
+#: config/rs6000/rs6000.c:14986
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "属性%qs的参数无效"
 
-#: config/rs6000/rs6000.c:15004
+#: config/rs6000/rs6000.c:15012
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15608
+#: config/rs6000/rs6000.c:15616
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:15623
+#: config/rs6000/rs6000.c:15631
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:15842
+#: config/rs6000/rs6000.c:15850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: config/rs6000/rs6000.c:15912
+#: config/rs6000/rs6000.c:15932
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "此内建函数只在 fr450 上可用"
 
-#: config/rs6000/rs6000.c:15914 config/rs6000/rs6000.c:15916
-#: config/rs6000/rs6000.c:15918 config/rs6000/rs6000.c:15920
-#: config/rs6000/rs6000.c:15926 config/rs6000/rs6000.c:15928
-#: config/rs6000/rs6000.c:15935 config/rs6000/rs6000.c:15942
-#: config/rs6000/rs6000.c:15949 config/rs6000/rs6000.c:15955
+#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
+#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
+#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
+#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15923 config/rs6000/rs6000.c:15932
-#: config/rs6000/rs6000.c:15939 config/rs6000/rs6000.c:15946
+#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15952
+#: config/rs6000/rs6000.c:15972
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15958
+#: config/rs6000/rs6000.c:15978
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15962
+#: config/rs6000/rs6000.c:15982
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000.c:18185
+#: config/rs6000/rs6000.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部错误：内建函数 %s 有非预期的返回类型 %s"
 
-#: config/rs6000/rs6000.c:18202
+#: config/rs6000/rs6000.c:18235
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "内部错误：内建函数 %s 的第 %d 个参数有非预期的参数类型 %s"
 
-#: config/rs6000/rs6000.c:29417
+#: config/rs6000/rs6000.c:29451
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/rs6000/rs6000.c:32714
+#: config/rs6000/rs6000.c:32748
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.c:32808
+#: config/rs6000/rs6000.c:32842
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.c:32816
+#: config/rs6000/rs6000.c:32850
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.c:32819
+#: config/rs6000/rs6000.c:32853
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.c:36842
+#: config/rs6000/rs6000.c:36876
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.c:36845
+#: config/rs6000/rs6000.c:36879
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.c:36847
+#: config/rs6000/rs6000.c:36881
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/rs6000/rs6000.c:37382
+#: config/rs6000/rs6000.c:37416
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/rs6000/rs6000.c:37541
+#: config/rs6000/rs6000.c:37575
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -36896,7 +37037,7 @@
 #. making it a constraint in that case was rejected in
 #. DR#252.
 #: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
-#: cp/typeck.c:2022 cp/typeck.c:7955 cp/typeck.c:8717
+#: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如预期地被忽略"
@@ -37149,7 +37290,7 @@
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: c/c-decl.c:2806 cp/name-lookup.c:2801
+#: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD的声明隐藏了一个全局声明"
@@ -37159,7 +37300,7 @@
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD的声明隐藏了先前的一个局部变量"
 
-#: c/c-decl.c:2838 cp/name-lookup.c:2813
+#: c/c-decl.c:2838 cp/name-lookup.c:2818
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "被隐藏的声明在这里"
@@ -37222,7 +37363,7 @@
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每个未声明的标识符在其出现的函数内只报告一次"
 
-#: c/c-decl.c:3562 cp/decl.c:3052
+#: c/c-decl.c:3562 cp/decl.c:3055
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "标号%qE在所有函数外被引用"
@@ -37252,7 +37393,7 @@
 msgid "duplicate label declaration %qE"
 msgstr "重复的标号定义%qE"
 
-#: c/c-decl.c:3776 cp/decl.c:3457
+#: c/c-decl.c:3776 cp/decl.c:3460
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重复的标号%qD"
@@ -37370,7 +37511,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不能用于函数原型以外"
 
-#: c/c-decl.c:4635 cp/decl2.c:1519
+#: c/c-decl.c:4635 cp/decl2.c:1520
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -37626,7 +37767,7 @@
 msgid "storage class specified for unnamed parameter"
 msgstr "为无名形参指定了存储类"
 
-#: c/c-decl.c:5874 cp/decl.c:10886
+#: c/c-decl.c:5874 cp/decl.c:10935
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "为类型名指定了存储类"
@@ -37789,7 +37930,7 @@
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.c:6421 cp/decl.c:11143
+#: c/c-decl.c:6421 cp/decl.c:11201
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
@@ -37916,7 +38057,7 @@
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "结构或联合成员不能具有可变类型"
 
-#: c/c-decl.c:6755 cp/decl.c:9940
+#: c/c-decl.c:6755 cp/decl.c:9989
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "变量或字段%qE声明为 void"
@@ -38096,7 +38237,7 @@
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: c/c-decl.c:7680 cp/decl.c:4799
+#: c/c-decl.c:7680 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
@@ -38146,7 +38287,7 @@
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.c:8064 cp/decl.c:12010
+#: c/c-decl.c:8064 cp/decl.c:12069
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
@@ -38183,7 +38324,7 @@
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>重声明"
 
-#: c/c-decl.c:8458 cp/decl.c:14364
+#: c/c-decl.c:8458 cp/decl.c:14423
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定的模式对枚举值来说太小"
@@ -38213,7 +38354,7 @@
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.c:8715 cp/decl.c:5101 cp/decl.c:14896
+#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "内联函数%qD给定了非内联属性"
@@ -38243,7 +38384,7 @@
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.c:8847 cp/decl.c:15031
+#: c/c-decl.c:8847 cp/decl.c:15090
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
@@ -38358,12 +38499,12 @@
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.c:9470 cp/decl.c:15814
+#: c/c-decl.c:9470 cp/decl.c:15873
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.c:9490 cp/decl.c:15846
+#: c/c-decl.c:9490 cp/decl.c:15905
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
@@ -38427,7 +38568,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.c:10004 cp/parser.c:28240
+#: c/c-decl.c:10004 cp/parser.c:28261
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
@@ -38573,38 +38714,38 @@
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.c:11514 cp/semantics.c:5364
+#: c/c-decl.c:11514 cp/semantics.c:5348
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5368
+#: c/c-decl.c:11518 cp/semantics.c:5352
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4664
+#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4672
+#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4617
+#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次数为负"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4680
+#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4625
+#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次数大于或等于类型宽度"
@@ -38636,7 +38777,7 @@
 msgid "to match this %qs"
 msgstr "没有匹配"
 
-#: c/c-parser.c:1216 cp/parser.c:28463
+#: c/c-parser.c:1216 cp/parser.c:28484
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -38678,7 +38819,7 @@
 msgstr "未知的类型名%qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:35986 cp/parser.c:38972
+#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -38693,7 +38834,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30140 cp/parser.c:30214
+#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "属性在未初始化类型上被忽略"
@@ -38708,8 +38849,8 @@
 msgid "unexpected attribute"
 msgstr "非预期的属性"
 
-#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10953
-#: cp/parser.c:11152
+#: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
+#: cp/parser.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -38748,7 +38889,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用于变量或函数声明"
 
-#: c/c-parser.c:2220 cp/parser.c:13006 cp/parser.c:13163
+#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要%<,%>或%<;%>"
@@ -38776,7 +38917,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38613
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字符串"
@@ -38841,13 +38982,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28466 cp/parser.c:30992
-#: cp/parser.c:31022 cp/parser.c:31092 cp/parser.c:33209 cp/parser.c:38329
+#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
+#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
 
-#: c/c-parser.c:2995 cp/parser.c:18374
+#: c/c-parser.c:2995 cp/parser.c:18384
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "枚举表以逗号结尾"
@@ -38977,7 +39118,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<else%>前需要%<}%>"
 
-#: c/c-parser.c:5067 cp/parser.c:11271
+#: c/c-parser.c:5067 cp/parser.c:11270
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%>之前没有%<if%>"
@@ -39011,22 +39152,22 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10905
+#: c/c-parser.c:5532 c/gimple-parser.c:1451 cp/parser.c:10904
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要语句"
 
-#: c/c-parser.c:5639 cp/parser.c:12526
+#: c/c-parser.c:5639 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建议在空的%<if%>语句体周围加上花括号"
 
-#: c/c-parser.c:5681 cp/parser.c:12529
+#: c/c-parser.c:5681 cp/parser.c:12519
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建议在空的%<else%>语句体周围加上花括号"
 
-#: c/c-parser.c:5815 cp/parser.c:11507
+#: c/c-parser.c:5815 cp/parser.c:11506
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建议显式地使用花括号以避免出现有歧义的%<else%>"
@@ -39046,12 +39187,12 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "此指令中寄存器无效"
 
-#: c/c-parser.c:6172 cp/parser.c:11709
+#: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
 
-#: c/c-parser.c:6178 cp/parser.c:11715
+#: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC unroll%> pragma"
 msgstr ""
@@ -39079,12 +39220,12 @@
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.c:6868 cp/typeck.c:4457
+#: c/c-parser.c:6868 cp/typeck.c:4473
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.c:6873 cp/typeck.c:4462
+#: c/c-parser.c:6873 cp/typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -39374,7 +39515,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: c/c-parser.c:8891 cp/parser.c:6928
+#: c/c-parser.c:8891 cp/parser.c:6918
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -39434,77 +39575,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31052
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:10682 cp/parser.c:31012
+#: c/c-parser.c:10682 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%qs后断言"
 
-#: c/c-parser.c:10685 cp/parser.c:31015
+#: c/c-parser.c:10685 cp/parser.c:31036
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<readonly%>属性与%<setter%>属性冲突"
 
-#: c/c-parser.c:10699 cp/parser.c:31030
+#: c/c-parser.c:10699 cp/parser.c:31051
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:10704 cp/parser.c:31036
+#: c/c-parser.c:10704 cp/parser.c:31057
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.c:10711 cp/parser.c:31044
+#: c/c-parser.c:10711 cp/parser.c:31065
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:10905 cp/parser.c:38653
+#: c/c-parser.c:10905 cp/parser.c:38674
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:35983 cp/parser.c:36277 cp/parser.c:36365
-#: cp/parser.c:36436 cp/parser.c:38700 cp/parser.c:38715 cp/parser.c:38731
-#: cp/parser.c:38747 cp/parser.c:38763 cp/parser.c:38790 cp/parser.c:38803
-#: cp/parser.c:38826 cp/parser.c:38839
+#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
+#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
+#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
+#: cp/parser.c:38847 cp/parser.c:38860
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.c:10972 cp/parser.c:38816
+#: c/c-parser.c:10972 cp/parser.c:38837
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.c:11050 cp/parser.c:38897
+#: c/c-parser.c:11050 cp/parser.c:38918
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38926 cp/parser.c:38959
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要语句"
 
-#: c/c-parser.c:11111 cp/parser.c:38690
+#: c/c-parser.c:11111 cp/parser.c:38711
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
 
-#: c/c-parser.c:11421 cp/parser.c:31436
+#: c/c-parser.c:11421 cp/parser.c:31457
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:11443 cp/parser.c:31973
+#: c/c-parser.c:11443 cp/parser.c:31994
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "需要整数表达式"
@@ -39519,58 +39660,58 @@
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:11746 cp/semantics.c:6820
+#: c/c-parser.c:11746 cp/semantics.c:6808
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:11788 cp/parser.c:32052
+#: c/c-parser.c:11788 cp/parser.c:32073
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:11865 cp/parser.c:32116
+#: c/c-parser.c:11865 cp/parser.c:32137
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32118
+#: c/c-parser.c:11867 cp/parser.c:32139
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32221
+#: c/c-parser.c:11968 cp/parser.c:32242
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32239
-#: cp/parser.c:36269 cp/parser.c:36357
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
+#: cp/parser.c:36290 cp/parser.c:36378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32292
+#: c/c-parser.c:12035 cp/parser.c:32313
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32299
+#: c/c-parser.c:12042 cp/parser.c:32320
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:12044 cp/parser.c:32301
+#: c/c-parser.c:12044 cp/parser.c:32322
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:12050 cp/parser.c:32307
+#: c/c-parser.c:12050 cp/parser.c:32328
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -39592,85 +39733,85 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12229 cp/semantics.c:7004
+#: c/c-parser.c:12229 cp/semantics.c:6992
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12276 cp/semantics.c:7033
+#: c/c-parser.c:12276 cp/semantics.c:7021
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32524 cp/parser.c:32531
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "需要%<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32540 cp/parser.c:32547
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6311
+#: c/c-parser.c:12425 cp/semantics.c:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6343
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12499 cp/parser.c:31832
+#: c/c-parser.c:12499 cp/parser.c:31853
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多 %<static%> 参数"
 
-#: c/c-parser.c:12533 cp/parser.c:31865
+#: c/c-parser.c:12533 cp/parser.c:31886
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "非预期的参数"
 
-#: c/c-parser.c:12699 cp/semantics.c:7132
+#: c/c-parser.c:12699 cp/semantics.c:7120
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: c/c-parser.c:12765 cp/parser.c:32605
+#: c/c-parser.c:12765 cp/parser.c:32626
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37622
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32819
+#: c/c-parser.c:12967 cp/parser.c:32840
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32835
+#: c/c-parser.c:13021 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:13025 cp/parser.c:32838
+#: c/c-parser.c:13025 cp/parser.c:32859
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:13037 cp/semantics.c:6401
+#: c/c-parser.c:13037 cp/semantics.c:6389
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13060 cp/parser.c:32858
+#: c/c-parser.c:13060 cp/parser.c:32879
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -39680,12 +39821,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13226 cp/semantics.c:6491
+#: c/c-parser.c:13226 cp/semantics.c:6479
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13271 cp/semantics.c:6601
+#: c/c-parser.c:13271 cp/semantics.c:6589
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
@@ -39705,17 +39846,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:13584 cp/parser.c:33353 cp/parser.c:33578
+#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:13669 cp/parser.c:33426
+#: c/c-parser.c:13669 cp/parser.c:33447
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.c:13767 cp/parser.c:33525
+#: c/c-parser.c:13767 cp/parser.c:33546
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -39725,69 +39866,69 @@
 msgid "invalid proc_bind kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:14059 cp/parser.c:33804
+#: c/c-parser.c:14059 cp/parser.c:33825
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33815 cp/parser.c:34122
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.c:14214 cp/parser.c:33989
+#: c/c-parser.c:14214 cp/parser.c:34010
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-parser.c:14334 cp/parser.c:34111
+#: c/c-parser.c:14334 cp/parser.c:34132
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:14472 cp/parser.c:36782
+#: c/c-parser.c:14472 cp/parser.c:36803
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36792
+#: c/c-parser.c:14482 cp/parser.c:36813
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-parser.c:14502 cp/parser.c:36812
+#: c/c-parser.c:14502 cp/parser.c:36833
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:14513 cp/parser.c:36823
+#: c/c-parser.c:14513 cp/parser.c:36844
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-parser.c:14520 cp/parser.c:36830
+#: c/c-parser.c:14520 cp/parser.c:36851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-parser.c:14528 cp/parser.c:36838
+#: c/c-parser.c:14528 cp/parser.c:36859
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:14540 cp/parser.c:36850
+#: c/c-parser.c:14540 cp/parser.c:36871
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36936
+#: c/c-parser.c:14632 cp/parser.c:36957
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.c:14648 cp/parser.c:36953
+#: c/c-parser.c:14648 cp/parser.c:36974
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -39803,7 +39944,7 @@
 msgid "expected function name"
 msgstr "需要函数"
 
-#: c/c-parser.c:14893 cp/parser.c:38043
+#: c/c-parser.c:14893 cp/parser.c:38064
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -39814,42 +39955,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14953 cp/parser.c:38097 cp/parser.c:38139
+#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14970 cp/parser.c:38153
+#: c/c-parser.c:14970 cp/parser.c:38174
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14979 cp/parser.c:38162
+#: c/c-parser.c:14979 cp/parser.c:38183
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14980 cp/parser.c:38163
+#: c/c-parser.c:14980 cp/parser.c:38184
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:15023 cp/parser.c:37131
+#: c/c-parser.c:15023 cp/parser.c:37152
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:15435 cp/parser.c:34490 cp/parser.c:34516
+#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:15439 cp/parser.c:34547 cp/parser.c:34563
+#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:15488 cp/semantics.c:8413 cp/semantics.c:8423
+#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
@@ -39859,22 +40000,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:15619 cp/parser.c:35082
+#: c/c-parser.c:15619 cp/parser.c:35103
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35093
+#: c/c-parser.c:15630 cp/parser.c:35114
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35120
+#: c/c-parser.c:15648 cp/parser.c:35141
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:15718 cp/semantics.c:8078 cp/semantics.c:8165
+#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
@@ -39884,74 +40025,74 @@
 msgid "not enough perfectly nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.c:15862 cp/parser.c:35343
+#: c/c-parser.c:15862 cp/parser.c:35364
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.c:15909 cp/parser.c:35163 cp/parser.c:35205 cp/pt.c:16039
+#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35416
+#: c/c-parser.c:16000 cp/parser.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-parser.c:16166 cp/parser.c:35579
+#: c/c-parser.c:16166 cp/parser.c:35600
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:16374 cp/parser.c:35778
+#: c/c-parser.c:16374 cp/parser.c:35799
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-parser.c:16573 cp/parser.c:35974
+#: c/c-parser.c:16573 cp/parser.c:35995
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36211
+#: c/c-parser.c:16793 cp/parser.c:36232
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16806 cp/parser.c:36224
+#: c/c-parser.c:16806 cp/parser.c:36245
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16853 cp/parser.c:36449
+#: c/c-parser.c:16853 cp/parser.c:36470
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16925 cp/parser.c:36304
+#: c/c-parser.c:16925 cp/parser.c:36325
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16937 cp/parser.c:36316
+#: c/c-parser.c:16937 cp/parser.c:36337
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17011 cp/parser.c:36393
+#: c/c-parser.c:17011 cp/parser.c:36414
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17024 cp/parser.c:36406
+#: c/c-parser.c:17024 cp/parser.c:36427
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17238 cp/parser.c:36659
+#: c/c-parser.c:17238 cp/parser.c:36680
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -39971,32 +40112,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37252
+#: c/c-parser.c:17395 cp/parser.c:37273
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37322
+#: c/c-parser.c:17474 cp/parser.c:37343
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37341
+#: c/c-parser.c:17493 cp/parser.c:37362
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37388
+#: c/c-parser.c:17534 cp/parser.c:37409
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37395
+#: c/c-parser.c:17541 cp/parser.c:37416
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37402
+#: c/c-parser.c:17547 cp/parser.c:37423
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
@@ -40051,47 +40192,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37847
+#: c/c-parser.c:17947 cp/parser.c:37868
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7543
+#: c/c-parser.c:18162 cp/semantics.c:7531
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.c:18164 cp/semantics.c:7545
+#: c/c-parser.c:18164 cp/semantics.c:7533
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7547
+#: c/c-parser.c:18168 cp/semantics.c:7535
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
 
-#: c/c-parser.c:18368 cp/parser.c:38544
+#: c/c-parser.c:18368 cp/parser.c:38565
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而无需 transactional 内存支持已启用"
 
-#: c/c-parser.c:18374 cp/parser.c:38550
+#: c/c-parser.c:18374 cp/parser.c:38571
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38559
+#: c/c-parser.c:18383 cp/parser.c:38580
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>无法在之内外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38562
+#: c/c-parser.c:18385 cp/parser.c:38583
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函数"
 
-#: c/c-parser.c:18391 cp/parser.c:38568
+#: c/c-parser.c:18391 cp/parser.c:38589
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>无法在之内 %<__transaction_atomic%>"
@@ -40107,7 +40248,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4141
+#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "对 void 表达式的使用无效"
@@ -40231,7 +40372,7 @@
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: c/c-typeck.c:2622 cp/typeck.c:3303 cp/typeck.c:3390
+#: c/c-typeck.c:2622 cp/typeck.c:3319 cp/typeck.c:3406
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "数组下标不是一个整数"
@@ -40256,7 +40397,7 @@
 msgid "enum constant defined here"
 msgstr "枚举常量在此定义"
 
-#: c/c-typeck.c:2905 cp/typeck.c:1693
+#: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -40359,18 +40500,18 @@
 msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4733 cp/typeck.c:4987
+#: c/c-typeck.c:3730 c/c-typeck.c:3750 cp/typeck.c:4749 cp/typeck.c:5003
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4756 cp/typeck.c:4776
+#: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比较指针和整数"
 
-#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4759 cp/typeck.c:4779
+#: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -40396,7 +40537,7 @@
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5546
+#: c/c-typeck.c:3852 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在指向不完全类型的指针上执行算术运算"
@@ -40636,7 +40777,7 @@
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "从类型为%qT的函数调用转换到不匹配的类型%qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7789
+#: c/c-typeck.c:5695 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "将一个整数转换为大小不同的指针"
@@ -40800,7 +40941,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8862
+#: c/c-typeck.c:6808 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
@@ -40872,7 +41013,7 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2058
+#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "对非左值数组的使用无效"
@@ -40948,12 +41089,12 @@
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "传统 C 不接受自动的聚合初始化"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1042
+#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "对可变数组成员的初始化"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1056
+#: c/c-typeck.c:7398 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "用宽字符串初始化 char 数组"
@@ -40999,7 +41140,7 @@
 msgid "invalid initializer"
 msgstr "无效的初始值设定"
 
-#: c/c-typeck.c:7912 cp/decl.c:6386
+#: c/c-typeck.c:7912 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
@@ -41014,7 +41155,7 @@
 msgid "braces around scalar initializer"
 msgstr "标量初始化带花括号"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1081 cp/typeck2.c:1294
+#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在嵌套的上下文中初始化可变数组成员"
@@ -41144,7 +41285,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允许%<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9084
+#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
@@ -41184,7 +41325,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: c/c-typeck.c:10404 cp/parser.c:11068
+#: c/c-typeck.c:10404 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 标号出现在开关语句外"
@@ -41194,17 +41335,17 @@
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>标号未出现在 switch 语句内"
 
-#: c/c-typeck.c:10578 cp/parser.c:12366
+#: c/c-typeck.c:10578 cp/parser.c:12356
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:10580 cp/parser.c:12389
+#: c/c-typeck.c:10580 cp/parser.c:12379
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:10585 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12369
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP for 循环中使用了 break 语句"
@@ -41229,22 +41370,22 @@
 msgid "expression statement has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5001
+#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5014
+#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "形参数量不同"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5042
+#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4727
+#: c/c-typeck.c:11523 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "使用 == 或 != 比较浮点数是不安全的"
@@ -41295,7 +41436,7 @@
 msgstr "指针与整数 0 比较大小"
 
 #: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
-#: cp/typeck.c:5065 cp/typeck.c:5072
+#: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指针与整数 0 比较大小"
@@ -41325,12 +41466,12 @@
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8520
+#: c/c-typeck.c:12340 cp/semantics.c:8508
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8557
+#: c/c-typeck.c:12379 cp/semantics.c:8545
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -41340,26 +41481,26 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4562
-#: cp/semantics.c:6729
+#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
+#: cp/semantics.c:6717
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4572
-#: cp/semantics.c:6747
+#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
+#: cp/semantics.c:6735
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD不是一个成员模板函数"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4586 cp/semantics.c:6772
+#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4590
-#: cp/semantics.c:6775
+#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
+#: cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -41370,70 +41511,70 @@
 msgstr "字段%qE的类型不完全"
 
 #: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4607 cp/semantics.c:6781 cp/semantics.c:6943
+#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4639
+#: c/c-typeck.c:12511 cp/semantics.c:4623
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4646
+#: c/c-typeck.c:12518 cp/semantics.c:4630
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
 #: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4682 cp/semantics.c:4746
+#: cp/semantics.c:4666 cp/semantics.c:4730
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4701
+#: c/c-typeck.c:12564 cp/semantics.c:4685
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4709
+#: c/c-typeck.c:12572 cp/semantics.c:4693
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4718
-#: cp/semantics.c:4828
+#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
+#: cp/semantics.c:4812
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4735
+#: c/c-typeck.c:12598 cp/semantics.c:4719
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4772
+#: c/c-typeck.c:12635 cp/semantics.c:4756
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4787
+#: c/c-typeck.c:12650 cp/semantics.c:4771
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4820
+#: c/c-typeck.c:12683 cp/semantics.c:4804
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4838
-#: cp/semantics.c:4950
+#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
+#: cp/semantics.c:4934
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4846
+#: c/c-typeck.c:12709 cp/semantics.c:4830
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE不是一个类"
@@ -41453,7 +41594,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE的类型对%<reduction(%s)%>无效"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5767
+#: c/c-typeck.c:13187 cp/semantics.c:5755
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "用户定义的%qD总是计算所有两个参数"
@@ -41463,17 +41604,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7261
+#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7301
+#: c/c-typeck.c:13305 cp/semantics.c:7289
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5941
+#: c/c-typeck.c:13319 cp/semantics.c:5929
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -41488,18 +41629,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:6011
+#: c/c-typeck.c:13354 cp/semantics.c:5999
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6095
-#: cp/semantics.c:6936
+#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
+#: cp/semantics.c:6924
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6104
+#: c/c-typeck.c:13393 cp/semantics.c:6092
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD在数据子句中多次出现"
@@ -41511,32 +41652,32 @@
 
 #: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
 #: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6114 cp/semantics.c:6121 cp/semantics.c:6172
-#: cp/semantics.c:6178 cp/semantics.c:6215 cp/semantics.c:6692
-#: cp/semantics.c:6829 cp/semantics.c:6835 cp/semantics.c:6848
-#: cp/semantics.c:6857
+#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
+#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
+#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
+#: cp/semantics.c:6845
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
 #: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6123 cp/semantics.c:6180 cp/semantics.c:6837
-#: cp/semantics.c:6859
+#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
+#: cp/semantics.c:6847
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6166
+#: c/c-typeck.c:13427 cp/semantics.c:6154
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6209
+#: c/c-typeck.c:13456 cp/semantics.c:6197
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6557
+#: c/c-typeck.c:13475 cp/semantics.c:6545
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
@@ -41556,56 +41697,56 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6639
+#: c/c-typeck.c:13551 cp/semantics.c:6627
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6670
+#: c/c-typeck.c:13573 cp/semantics.c:6658
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6689
-#: cp/semantics.c:6846
+#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
+#: cp/semantics.c:6834
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6695
-#: cp/semantics.c:6850
+#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
+#: cp/semantics.c:6838
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6736
+#: c/c-typeck.c:13635 cp/semantics.c:6724
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6811
-#: cp/semantics.c:6950
+#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
+#: cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6930
+#: c/c-typeck.c:13766 cp/semantics.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6959
+#: c/c-typeck.c:13794 cp/semantics.c:6947
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6974
+#: c/c-typeck.c:13808 cp/semantics.c:6962
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6976
+#: c/c-typeck.c:13811 cp/semantics.c:6964
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
@@ -41615,32 +41756,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6371
+#: c/c-typeck.c:13900 cp/semantics.c:6359
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7153
+#: c/c-typeck.c:13931 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7344
+#: c/c-typeck.c:13981 cp/semantics.c:7332
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7235
+#: c/c-typeck.c:14001 cp/semantics.c:7223
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7248
+#: c/c-typeck.c:14013 cp/semantics.c:7236
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7215
+#: c/c-typeck.c:14031 cp/semantics.c:7203
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -41783,7 +41924,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3441 cp/pt.c:6494
+#: cp/call.c:3441 cp/pt.c:6495
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -41868,27 +42009,27 @@
 msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
 msgstr ""
 
-#: cp/call.c:3928
+#: cp/call.c:3934
 #, fuzzy
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: cp/call.c:4074
+#: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
 msgstr ""
 
-#: cp/call.c:4095
+#: cp/call.c:4101
 #, fuzzy
 msgid "conversion from %qH to %qI in a converted constant expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:4232
+#: cp/call.c:4238
 #, gcc-internal-format
 msgid "no matching function for call to %<%D(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:4235
+#: cp/call.c:4241
 #, gcc-internal-format
 msgid "call of overloaded %<%D(%A)%> is ambiguous"
 msgstr "调用重载的%<%D(%A)%>有歧义"
@@ -41895,640 +42036,640 @@
 
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
-#: cp/call.c:4470
+#: cp/call.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
 msgstr "没有对象不能调用成员函数指针 %E，考虑使用 .* 或 ->*"
 
-#: cp/call.c:4541
+#: cp/call.c:4547
 #, gcc-internal-format
 msgid "no match for call to %<(%T) (%A)%>"
 msgstr "对%<(%T) (%A)%>的调用没有匹配"
 
-#: cp/call.c:4554
+#: cp/call.c:4560
 #, gcc-internal-format
 msgid "call of %<(%T) (%A)%> is ambiguous"
 msgstr "对%<(%T) (%A)%>的调用有歧义"
 
-#: cp/call.c:4606
+#: cp/call.c:4612
 #, fuzzy, gcc-internal-format
 msgid "ambiguous overload for "
 msgstr "调用重载的%<%D(%A)%>有歧义"
 
-#: cp/call.c:4607
+#: cp/call.c:4613
 #, fuzzy, gcc-internal-format
 msgid "no match for "
 msgstr "没有匹配"
 
-#: cp/call.c:4610
+#: cp/call.c:4616
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/call.c:4612
+#: cp/call.c:4618
 #, fuzzy, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/call.c:4614
+#: cp/call.c:4620
 #, gcc-internal-format
 msgid " (operand type is %qT)"
 msgstr ""
 
-#: cp/call.c:4630
+#: cp/call.c:4636
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%>"
 msgstr "需要%<operator%>"
 
-#: cp/call.c:4634
+#: cp/call.c:4640
 #, fuzzy, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
 msgstr "%<%E::%E%>既不是类也不是命名空间"
 
-#: cp/call.c:4643 cp/call.c:4674 cp/call.c:4683
+#: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%>"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: cp/call.c:4646
+#: cp/call.c:4652
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:4653
+#: cp/call.c:4659
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%>"
 msgstr "错误的运算符"
 
-#: cp/call.c:4656
+#: cp/call.c:4662
 #, fuzzy, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
 msgstr "%<%E::%E%>不是一个类型"
 
-#: cp/call.c:4664
+#: cp/call.c:4670
 #, fuzzy, gcc-internal-format
 msgid "%qs"
 msgstr "重复的%qs"
 
-#: cp/call.c:4667
+#: cp/call.c:4673
 #, fuzzy, gcc-internal-format
 msgid "%qs in %<%s %E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:4677
+#: cp/call.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
 msgstr "在协议中找到%<-%E%>而非%<+%E%>"
 
-#: cp/call.c:4686
+#: cp/call.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
 msgstr "%Xbfd_openr %s: %E\n"
 
-#: cp/call.c:4795
+#: cp/call.c:4801
 #, gcc-internal-format
 msgid "ISO C++ forbids omitting the middle term of a ?: expression"
 msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
-#: cp/call.c:4857
+#: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
 msgstr ""
 
-#: cp/call.c:4874 cp/call.c:4881
+#: cp/call.c:4880 cp/call.c:4887
 #, fuzzy
 msgid "conversion of scalar %qH to vector %qI involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: cp/call.c:4934
+#: cp/call.c:4940
 #, fuzzy, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/call.c:5024
+#: cp/call.c:5030
 #, gcc-internal-format
 msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第二个操作数类型为%<void%>，但第三个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:5029
+#: cp/call.c:5035
 #, gcc-internal-format
 msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
 msgstr "条件运算符的第三个操作数类型为%<void%>，但第二个操作数既不是异常表达式，也不拥有%<void%>类型"
 
-#: cp/call.c:5079 cp/call.c:5199 cp/call.c:5342
+#: cp/call.c:5085 cp/call.c:5205 cp/call.c:5348
 #, gcc-internal-format
 msgid "operands to ?: have different types %qT and %qT"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: cp/call.c:5082
+#: cp/call.c:5088
 #, gcc-internal-format
 msgid "  and each type can be converted to the other"
 msgstr ""
 
-#: cp/call.c:5274
+#: cp/call.c:5280
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:5287
+#: cp/call.c:5293
 #, gcc-internal-format
 msgid "enumeral mismatch in conditional expression: %qT vs %qT"
 msgstr "条件表达式中枚举不匹配：%qT对%qT"
 
-#: cp/call.c:5299
+#: cp/call.c:5305
 #, gcc-internal-format
 msgid "enumeral and non-enumeral type in conditional expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/call.c:5792
+#: cp/call.c:5798
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%>没有出现在后缀%qs中，尝试使用前缀运算符"
 
-#: cp/call.c:5794
+#: cp/call.c:5800
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "没有为后缀%2$qs声明%<%1$D(int)%>"
 
-#: cp/call.c:5916
+#: cp/call.c:5922
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/call.c:6259
+#: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgstr ""
 
-#: cp/call.c:6262
+#: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgstr ""
 
-#: cp/call.c:6297
+#: cp/call.c:6303
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.c:6429
+#: cp/call.c:6435
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD没有相应的释放函数"
 
-#: cp/call.c:6435
+#: cp/call.c:6441
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "没有合适的%<operator %s%>给%qT"
 
-#: cp/call.c:6470
+#: cp/call.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6472 cp/decl.c:7325
+#: cp/call.c:6478 cp/decl.c:7343
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "在此声明"
 
-#: cp/call.c:6478
+#: cp/call.c:6484
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6480 cp/decl.c:7326
+#: cp/call.c:6486 cp/decl.c:7344
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "在此声明"
 
-#: cp/call.c:6486
+#: cp/call.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D无法访问"
 
-#: cp/call.c:6550
+#: cp/call.c:6556
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
-#: cp/call.c:6554
+#: cp/call.c:6560
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "将 NULL 转换到非指针类型%qT"
 
-#: cp/call.c:6563
+#: cp/call.c:6569
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:6567
+#: cp/call.c:6573
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.c:6654
+#: cp/call.c:6660
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT的初始值设定周围花括号太多"
 
-#: cp/call.c:6665
+#: cp/call.c:6671
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/call.c:6673
+#: cp/call.c:6679
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/call.c:6690 cp/call.c:6714 cp/call.c:6837 cp/call.c:6928 cp/call.c:6980
-#: cp/call.c:7008
+#: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
+#: cp/call.c:7018 cp/typeck.c:8815
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: cp/call.c:6710 cp/cvt.c:226
+#: cp/call.c:6716 cp/cvt.c:226
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/call.c:6751 cp/call.c:6758
+#: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "从初始化列表转换为%qT将使用显式构造函数%qD"
 
-#: cp/call.c:6754
+#: cp/call.c:6760
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.c:6994
+#: cp/call.c:7004
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.c:6998
+#: cp/call.c:7008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:7001
+#: cp/call.c:7011
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.c:7037
+#: cp/call.c:7047
 #, gcc-internal-format
 msgid "cannot bind bitfield %qE to %qT"
 msgstr "无法将位段%qE绑定到%qT"
 
-#: cp/call.c:7040 cp/call.c:7057
+#: cp/call.c:7050 cp/call.c:7067
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能将紧实的字段%qE绑定到%qT"
 
-#: cp/call.c:7043
+#: cp/call.c:7053
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "无法将右值%qE绑定到%qT"
 
-#: cp/call.c:7153
+#: cp/call.c:7163
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.c:7170 cp/cvt.c:1886
+#: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgstr ""
 
-#: cp/call.c:7207
+#: cp/call.c:7217
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "不能通过%<...%>传递有不能平凡复制的类型%q#T"
 
-#: cp/call.c:7243
+#: cp/call.c:7253
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/call.c:7253
+#: cp/call.c:7263
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:7321
+#: cp/call.c:7331
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "递归计算%q#D的默认参数"
 
-#: cp/call.c:7330
+#: cp/call.c:7340
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD的第 %1$d 个形参的默认实参尚未被解析到"
 
-#: cp/call.c:7433
+#: cp/call.c:7444
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/call.c:7488
+#: cp/call.c:7499
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/call.c:7850
+#: cp/call.c:7864
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/call.c:7853 cp/call.c:7969 cp/call.c:10132
+#: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "在调用%qD时"
 
-#: cp/call.c:7883
+#: cp/call.c:7897
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT是%qT的一个不可访问的基类"
 
-#: cp/call.c:7965
+#: cp/call.c:7979
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "演绎 %qT 为 %qT"
 
-#: cp/call.c:7971
+#: cp/call.c:7985
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "(您可以用 -fno-deduce-init-lis 禁用它)"
 
-#: cp/call.c:8082
+#: cp/call.c:8096
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/call.c:8565
+#: cp/call.c:8579
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.c:8568
+#: cp/call.c:8582
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.c:8573
+#: cp/call.c:8587
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.c:8578
+#: cp/call.c:8592
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.c:8593
+#: cp/call.c:8607
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.c:8595
+#: cp/call.c:8609
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:8597
+#: cp/call.c:8611
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/call.c:8600
+#: cp/call.c:8614
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8603
+#: cp/call.c:8617
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/call.c:8605
+#: cp/call.c:8619
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.c:8626
+#: cp/call.c:8640
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.c:8628
+#: cp/call.c:8642
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.c:8630
+#: cp/call.c:8644
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "(在%qs的初始化附近)"
 
-#: cp/call.c:8633
+#: cp/call.c:8647
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.c:8636
+#: cp/call.c:8650
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.c:8639
+#: cp/call.c:8653
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.c:8650
+#: cp/call.c:8664
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.c:8662
+#: cp/call.c:8676
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.c:8679
+#: cp/call.c:8693
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.c:8682
+#: cp/call.c:8696
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.c:8692
+#: cp/call.c:8706
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.c:8695
+#: cp/call.c:8709
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.c:8698
+#: cp/call.c:8712
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.c:8707
+#: cp/call.c:8721
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.c:8729
+#: cp/call.c:8743
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "在此声明"
 
-#: cp/call.c:8825
+#: cp/call.c:8839
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cp/call.c:9065
+#: cp/call.c:9079
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.c:9113 cp/pt.c:14720 cp/typeck.c:2896
+#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
 
-#: cp/call.c:9115
+#: cp/call.c:9121
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "对于函数类型的类型转换，移除冗余的%<::%D%>"
 
-#: cp/call.c:9244
+#: cp/call.c:9259
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:9261
+#: cp/call.c:9276
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:9285
+#: cp/call.c:9300
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:9288
+#: cp/call.c:9303
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "对重载的%<%s(%A)%>的调用有歧义"
 
-#: cp/call.c:9309
+#: cp/call.c:9324
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:9314
+#: cp/call.c:9329
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:9315
+#: cp/call.c:9330
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:9338
+#: cp/call.c:9353
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "没有对象无法调用成员函数%qD"
 
-#: cp/call.c:10130
+#: cp/call.c:10145
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "传递%qT时选择%qT而不是%qT"
 
-#: cp/call.c:10190
+#: cp/call.c:10205
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "选择%qD而不是%qD"
 
-#: cp/call.c:10191
+#: cp/call.c:10206
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:10194
+#: cp/call.c:10209
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "因为前者的实参类型转换序列更好"
 
-#: cp/call.c:10418
+#: cp/call.c:10433
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "重载解决时默认参数不匹配"
 
-#: cp/call.c:10422
+#: cp/call.c:10437
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr "备选 1: %q+#F"
 
-#: cp/call.c:10424
+#: cp/call.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr "备选 2: %q+#F"
 
-#: cp/call.c:10469
+#: cp/call.c:10484
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换"
 
-#: cp/call.c:10652
+#: cp/call.c:10667
 #, fuzzy
 msgid "could not convert %qE from %qH to %qI"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/call.c:10854
+#: cp/call.c:10869
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暂时的约束到 %qD 只有持续直到建构子离开"
 
-#: cp/call.c:10977
+#: cp/call.c:10994
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:10981
+#: cp/call.c:10998
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
@@ -42571,8 +42712,8 @@
 msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D无法被重载"
 
-#: cp/class.c:1135 cp/decl.c:1703 cp/decl.c:1724 cp/decl.c:1756
-#: cp/name-lookup.c:2284 cp/name-lookup.c:2559
+#: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
+#: cp/name-lookup.c:2285 cp/name-lookup.c:2564
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "先前的声明%q+D"
@@ -42615,7 +42756,7 @@
 msgstr ""
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
-#: cp/cvt.c:1024
+#: cp/cvt.c:1028
 #, fuzzy, gcc-internal-format
 msgid "%qT declared here"
 msgstr "在此声明"
@@ -42698,7 +42839,7 @@
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:2906 cp/name-lookup.c:3288 cp/parser.c:19709
+#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
@@ -42989,7 +43130,7 @@
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:6760 cp/parser.c:23225
+#: cp/class.c:6760 cp/parser.c:23239
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
@@ -43059,7 +43200,7 @@
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
-#: cp/class.c:7948 cp/class.c:7985
+#: cp/class.c:7948 cp/class.c:7990
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "类型信息不充分"
@@ -43158,338 +43299,338 @@
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/constexpr.c:1211 cp/constexpr.c:1719
+#: cp/constexpr.c:1220 cp/constexpr.c:1728
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
 msgstr "调用这些函数时给出警告"
 
-#: cp/constexpr.c:1216 cp/constexpr.c:1226 cp/constexpr.c:1829
+#: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:1405 cp/constexpr.c:5352
+#: cp/constexpr.c:1414 cp/constexpr.c:5368
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "内部函数"
 
-#: cp/constexpr.c:1483
+#: cp/constexpr.c:1492
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/constexpr.c:1502 cp/constexpr.c:5370
+#: cp/constexpr.c:1511 cp/constexpr.c:5386
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/constexpr.c:1574
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:1581
+#: cp/constexpr.c:1590
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:1585
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: cp/constexpr.c:1625
+#: cp/constexpr.c:1634
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "调用存在循环依赖"
 
-#: cp/constexpr.c:1636
+#: cp/constexpr.c:1645
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:1869
+#: cp/constexpr.c:1880
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:1876
+#: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1894
+#: cp/constexpr.c:1905
 #, fuzzy, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:1913
+#: cp/constexpr.c:1924
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:2057
+#: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2293
+#: cp/constexpr.c:2304
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:2296
+#: cp/constexpr.c:2307
 #, fuzzy, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:2301
+#: cp/constexpr.c:2312
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:2304
+#: cp/constexpr.c:2315
 #, fuzzy, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:2469
+#: cp/constexpr.c:2480
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:2500
+#: cp/constexpr.c:2511
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:2514 cp/constexpr.c:2604 cp/constexpr.c:4120
-#: cp/constexpr.c:4193 cp/constexpr.c:5306
+#: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
+#: cp/constexpr.c:4204 cp/constexpr.c:5322
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:2520
+#: cp/constexpr.c:2531
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:2545
+#: cp/constexpr.c:2556
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: cp/constexpr.c:2564
+#: cp/constexpr.c:2575
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:3301 cp/constexpr.c:4611
+#: cp/constexpr.c:3312 cp/constexpr.c:4624
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:3320
+#: cp/constexpr.c:3331
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:3359
+#: cp/constexpr.c:3370
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:3366
+#: cp/constexpr.c:3377
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.c:3371
+#: cp/constexpr.c:3382
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D不是 const"
 
-#: cp/constexpr.c:3374
+#: cp/constexpr.c:3385
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D是 volatile"
 
-#: cp/constexpr.c:3379 cp/constexpr.c:3386
+#: cp/constexpr.c:3390 cp/constexpr.c:3397
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:3392
+#: cp/constexpr.c:3403
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/constexpr.c:3395
+#: cp/constexpr.c:3406
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/constexpr.c:3583
+#: cp/constexpr.c:3594
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:3959
+#: cp/constexpr.c:3970
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:4098
+#: cp/constexpr.c:4109
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:4239 cp/constexpr.c:5829
+#: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.c:4597
+#: cp/constexpr.c:4587
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:4623
+#: cp/constexpr.c:4636
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:4638
+#: cp/constexpr.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:4700 cp/constexpr.c:5693 cp/constexpr.c:6000
+#: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:4782
+#: cp/constexpr.c:4798
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:4785
+#: cp/constexpr.c:4801
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: cp/constexpr.c:4857
+#: cp/constexpr.c:4873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:4866
+#: cp/constexpr.c:4882
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:4880
+#: cp/constexpr.c:4896
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.c:5261
+#: cp/constexpr.c:5277
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "表达式%qE有副作用"
 
-#: cp/constexpr.c:5453
+#: cp/constexpr.c:5469
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:5456
+#: cp/constexpr.c:5472
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.c:5491
+#: cp/constexpr.c:5507
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: cp/constexpr.c:5523
+#: cp/constexpr.c:5539
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 对象 %qE 与线程本地或自动贮藏体并非常数运算式"
 
-#: cp/constexpr.c:5556
+#: cp/constexpr.c:5572
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:5641
+#: cp/constexpr.c:5657
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.c:5705
+#: cp/constexpr.c:5721
 #, fuzzy, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5783
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:5799
+#: cp/constexpr.c:5834
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/constexpr.c:5806
+#: cp/constexpr.c:5841
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/constexpr.c:5878
+#: cp/constexpr.c:5913
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%L处被零除"
 
-#: cp/constexpr.c:5977
+#: cp/constexpr.c:6012
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:6008
+#: cp/constexpr.c:6043
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处非常量初始化表达式"
 
-#: cp/constexpr.c:6030
+#: cp/constexpr.c:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:6041
+#: cp/constexpr.c:6076
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: cp/cp-gimplify.c:1411
+#: cp/cp-gimplify.c:1415
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1414
+#: cp/cp-gimplify.c:1418
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1425
+#: cp/cp-gimplify.c:1429
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -43538,7 +43679,7 @@
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/cvt.c:496 cp/typeck.c:7338
+#: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "从%qT转换到%qT并未提领指针"
@@ -43549,311 +43690,311 @@
 msgid "cannot convert type %qH to type %qI"
 msgstr "不能将类型%qT转换为类型%qT"
 
-#: cp/cvt.c:765
+#: cp/cvt.c:769
 #, gcc-internal-format
 msgid "conversion from %q#T to %q#T"
 msgstr "从%q#T到%q#T的转换"
 
-#: cp/cvt.c:782
+#: cp/cvt.c:786
 #, gcc-internal-format
 msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
 msgstr "转换的结果不能确定，因为%qE已经超过了类型%qT的范围"
 
-#: cp/cvt.c:793 cp/cvt.c:845
+#: cp/cvt.c:797 cp/cvt.c:849
 #, gcc-internal-format
 msgid "%q#T used where a %qT was expected"
 msgstr "不应使用%q#T而应使用%qT"
 
-#: cp/cvt.c:802
+#: cp/cvt.c:806
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
 msgstr "不能将%qE转换为%qT"
 
-#: cp/cvt.c:861
+#: cp/cvt.c:865
 #, gcc-internal-format
 msgid "%q#T used where a floating point value was expected"
 msgstr "需要浮点数值时使用了%q#T"
 
-#: cp/cvt.c:920
+#: cp/cvt.c:924
 #, fuzzy
 #| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
 msgstr "请求从%qT转换到非标量类型%qT"
 
-#: cp/cvt.c:1009
+#: cp/cvt.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1017
+#: cp/cvt.c:1021
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: cp/cvt.c:1022
+#: cp/cvt.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "in call to %qD, declared here"
 msgstr "%qD在此声明"
 
-#: cp/cvt.c:1089
+#: cp/cvt.c:1093
 #, gcc-internal-format
 msgid "pseudo-destructor is not called"
 msgstr "伪析构函数未被调用"
 
-#: cp/cvt.c:1167
+#: cp/cvt.c:1171
 #, gcc-internal-format
 msgid "conversion to void will not access object of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1171
+#: cp/cvt.c:1175
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第二个操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1176
+#: cp/cvt.c:1180
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第三个操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1181
+#: cp/cvt.c:1185
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
 msgstr "提领不会访问作为逗号操作符右操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1186
+#: cp/cvt.c:1190
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
 msgstr "提领不会访问作为逗号操作符左操作数的具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1191
+#: cp/cvt.c:1195
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in statement"
 msgstr "提领不会访问语句中具有不完全类型的对象%qT"
 
-#: cp/cvt.c:1195
+#: cp/cvt.c:1199
 #, gcc-internal-format
 msgid "indirection will not access object of incomplete type %qT in for increment expression"
 msgstr "提领不会访问 for 循环增量表达式中具有不完全类型%qT的对象"
 
-#: cp/cvt.c:1211
+#: cp/cvt.c:1215
 #, gcc-internal-format
 msgid "conversion to void will not access object of type %qT"
 msgstr "向 void 的转换不会访问具有类型%qT的对象"
 
-#: cp/cvt.c:1215
+#: cp/cvt.c:1219
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
 msgstr "隐式提领不会访问作为条件表达式第二个操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1220
+#: cp/cvt.c:1224
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
 msgstr "隐式提领不会访问作为条件表达式第三个操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1225
+#: cp/cvt.c:1229
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
 msgstr "隐式提领不会访问作为逗号操作符右操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1230
+#: cp/cvt.c:1234
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
 msgstr "隐式提领不会访问作为逗号操作符左操作数的具有类型%qT的对象"
 
-#: cp/cvt.c:1235
+#: cp/cvt.c:1239
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in statement"
 msgstr "隐式提领不会访问语句中类型为%qT的对象"
 
-#: cp/cvt.c:1239
+#: cp/cvt.c:1243
 #, gcc-internal-format
 msgid "implicit dereference will not access object of type %qT in for increment expression"
 msgstr "隐式提领不会访问 for 循环增量表达式中具有类型%qT的对象"
 
-#: cp/cvt.c:1253
+#: cp/cvt.c:1257
 #, gcc-internal-format
 msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1258
+#: cp/cvt.c:1262
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第二个操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1263
+#: cp/cvt.c:1267
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
 msgstr "提领不会访问作为条件表达式第三个操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1268
+#: cp/cvt.c:1272
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
 msgstr "提领不会访问作为逗号操作符右操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1273
+#: cp/cvt.c:1277
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
 msgstr "提领不会访问作为逗号操作符左操作数的具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1278
+#: cp/cvt.c:1282
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
 msgstr "提领不会访问语句中具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1283
+#: cp/cvt.c:1287
 #, gcc-internal-format
 msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
 msgstr "提领不会访问 for 循环增量表达式中具有不能平凡复制类型%qT的对象"
 
-#: cp/cvt.c:1323
+#: cp/cvt.c:1327
 #, gcc-internal-format
 msgid "conversion to void will not access object %qE of incomplete type %qT"
 msgstr "向 void 的转换不会访问具有不完全类型%2$qT的对象%1$qE"
 
-#: cp/cvt.c:1327
+#: cp/cvt.c:1331
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
 msgstr "条件表达式第二个操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1332
+#: cp/cvt.c:1336
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
 msgstr "条件表达式第三个操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1337
+#: cp/cvt.c:1341
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
 msgstr "逗号操作符的右操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1342
+#: cp/cvt.c:1346
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
 msgstr "逗号操作符的左操作数中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1347
+#: cp/cvt.c:1351
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in statement"
 msgstr "语句中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1351
+#: cp/cvt.c:1355
 #, gcc-internal-format
 msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
 msgstr "for 循环增量表达式中的对象%qE具有不完全的类型%qT，不会被访问"
 
-#: cp/cvt.c:1403
+#: cp/cvt.c:1407
 #, fuzzy, gcc-internal-format
 msgid "conversion to void cannot resolve address of overloaded function"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/cvt.c:1407
+#: cp/cvt.c:1411
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1411
+#: cp/cvt.c:1415
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1415
+#: cp/cvt.c:1419
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1419
+#: cp/cvt.c:1423
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1423
+#: cp/cvt.c:1427
 #, fuzzy, gcc-internal-format
 msgid "statement cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1427
+#: cp/cvt.c:1431
 #, fuzzy, gcc-internal-format
 msgid "for increment expression cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/cvt.c:1443
+#: cp/cvt.c:1447
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1448
+#: cp/cvt.c:1452
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1453
+#: cp/cvt.c:1457
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1458
+#: cp/cvt.c:1462
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1463
+#: cp/cvt.c:1467
 #, fuzzy, gcc-internal-format
 msgid "statement is a reference, not call, to function %qE"
 msgstr "给予函数%qE的参数不是浮点数"
 
-#: cp/cvt.c:1468
+#: cp/cvt.c:1472
 #, fuzzy, gcc-internal-format
 msgid "for increment expression is a reference, not call, to function %qE"
 msgstr "%s 是对函数%qE的一个引用而不是调用"
 
-#: cp/cvt.c:1495
+#: cp/cvt.c:1499
 #, fuzzy, gcc-internal-format
 msgid "second operand of conditional expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1500
+#: cp/cvt.c:1504
 #, fuzzy, gcc-internal-format
 msgid "third operand of conditional expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1505
+#: cp/cvt.c:1509
 #, fuzzy, gcc-internal-format
 msgid "right operand of comma operator has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1509
+#: cp/cvt.c:1513
 #, fuzzy, gcc-internal-format
 msgid "left operand of comma operator has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/cvt.c:1513
+#: cp/cvt.c:1517
 #, gcc-internal-format
 msgid "statement has no effect"
 msgstr "语句不起作用"
 
-#: cp/cvt.c:1517
+#: cp/cvt.c:1521
 #, gcc-internal-format
 msgid "for increment expression has no effect"
 msgstr "for 循环増量表达式不起作用"
 
-#: cp/cvt.c:1672
+#: cp/cvt.c:1676
 #, gcc-internal-format
 msgid "converting NULL to non-pointer type"
 msgstr "将 NULL 转换为非指针类型"
 
-#: cp/cvt.c:1787
+#: cp/cvt.c:1791
 #, fuzzy, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/cvt.c:1802
+#: cp/cvt.c:1806
 #, gcc-internal-format
 msgid "ambiguous default type conversion from %qT"
 msgstr "%qT的默认类型转换有歧义"
 
-#: cp/cvt.c:1805
+#: cp/cvt.c:1809
 #, gcc-internal-format
 msgid "  candidate conversions include %qD and %qD"
 msgstr "  备选转换包括%qD和%qD"
@@ -43897,207 +44038,207 @@
 msgid "%qD was declared %<extern%> and later %<static%>"
 msgstr "%qD先被声明为%<extern%>后又被声明为%<static%>"
 
-#: cp/decl.c:1250
+#: cp/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as array of function members"
 msgid "declaration of %qF has a different exception specifier"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.c:1263
+#: cp/decl.c:1266
 #, fuzzy, gcc-internal-format
 #| msgid "from previous declaration %q+F"
 msgid "from previous declaration %qF"
 msgstr "从先前的声明%q+F"
 
-#: cp/decl.c:1298
+#: cp/decl.c:1301
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl.c:1301 cp/decl.c:13784
+#: cp/decl.c:1304 cp/decl.c:13843
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "先前的声明%q+D"
 
-#: cp/decl.c:1330
+#: cp/decl.c:1333
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "cannot specialize concept %q#D"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.c:1352
+#: cp/decl.c:1355
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/decl.c:1421
+#: cp/decl.c:1424
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %q+D conflicts with raw literal operator %qD"
 msgstr "实字运算符模板 %q+D 冲突与原始实字运算符 %qD"
 
-#: cp/decl.c:1426
+#: cp/decl.c:1429
 #, fuzzy, gcc-internal-format
 msgid "raw literal operator %q+D conflicts with literal operator template %qD"
 msgstr "原始实字运算符 %q+D 冲突与实字运算符模板 %qD"
 
-#: cp/decl.c:1446
+#: cp/decl.c:1449
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD was here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.c:1449
+#: cp/decl.c:1452
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD was here"
 msgstr "%q+D的上一个声明在此"
 
-#: cp/decl.c:1467
+#: cp/decl.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qD declared as non-function"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: cp/decl.c:1479 cp/decl.c:1613
+#: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
 msgid "shadowing built-in function %q#D"
 msgstr "隐藏了内建函数%q#D"
 
-#: cp/decl.c:1480 cp/decl.c:1614
+#: cp/decl.c:1483 cp/decl.c:1617
 #, gcc-internal-format
 msgid "shadowing library function %q#D"
 msgstr "隐藏了库函数%q#D"
 
-#: cp/decl.c:1488
+#: cp/decl.c:1491
 #, gcc-internal-format
 msgid "library function %q#D redeclared as non-function %q#D"
 msgstr "库函数%q#D重声明为非函数%q#D"
 
-#: cp/decl.c:1491
+#: cp/decl.c:1494
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl.c:1499
+#: cp/decl.c:1502
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: cp/decl.c:1501
+#: cp/decl.c:1504
 #, fuzzy, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
 msgstr "先前对于%q+#D的非函数声明"
 
-#: cp/decl.c:1561
+#: cp/decl.c:1564
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl.c:1589
+#: cp/decl.c:1592
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
 msgstr "使内建声明%q#D出现歧义"
 
-#: cp/decl.c:1594 cp/decl.c:1608
+#: cp/decl.c:1597 cp/decl.c:1611
 #, fuzzy, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
 msgstr "使内建声明%q#D出现歧义"
 
-#: cp/decl.c:1598
+#: cp/decl.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "derived type declaration"
 msgid "ignoring the %q#D declaration"
 msgstr "派生的类型声明"
 
-#: cp/decl.c:1699
+#: cp/decl.c:1702
 #, gcc-internal-format
 msgid "%q#D redeclared as different kind of symbol"
 msgstr "%q#D被重新声明为不同意义的符号"
 
-#: cp/decl.c:1722
+#: cp/decl.c:1725
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/decl.c:1741
+#: cp/decl.c:1744
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
 msgstr "%q+D先前没有声明过"
 
-#: cp/decl.c:1743 cp/decl.c:1771
+#: cp/decl.c:1746 cp/decl.c:1774
 #, fuzzy, gcc-internal-format
 msgid "old declaration %q#D"
 msgstr "%q#D的声明"
 
-#: cp/decl.c:1753
+#: cp/decl.c:1756
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/decl.c:1769
+#: cp/decl.c:1772
 #, fuzzy, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
 msgstr "%q+D先前没有声明过"
 
-#: cp/decl.c:1779
+#: cp/decl.c:1782
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting declaration %q+#D"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/decl.c:1781
+#: cp/decl.c:1784
 #, fuzzy, gcc-internal-format
 msgid "previous declaration as %q#D"
 msgstr "先前的声明%q+D"
 
-#: cp/decl.c:1839 cp/decl2.c:921
+#: cp/decl.c:1842 cp/decl2.c:921
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously defined here"
 msgstr "%q+#D已在此定义过"
 
-#: cp/decl.c:1840 cp/name-lookup.c:2689 cp/name-lookup.c:2711
+#: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q+#D已在此定义过"
 
-#: cp/decl.c:1850
+#: cp/decl.c:1853
 #, fuzzy, gcc-internal-format
 msgid "prototype specified for %q#D"
 msgstr "%q+D的寄存器名无效"
 
-#: cp/decl.c:1852
+#: cp/decl.c:1855
 #, fuzzy, gcc-internal-format
 msgid "previous non-prototype definition here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.c:1890
+#: cp/decl.c:1893
 #, fuzzy, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
 msgstr "%q+D声明为没有外部链接的，之前却有外部声明"
 
-#: cp/decl.c:1893
+#: cp/decl.c:1896
 #, fuzzy, gcc-internal-format
 msgid "previous declaration with %qL linkage"
 msgstr "%qD先前没有声明"
 
-#: cp/decl.c:1927 cp/decl.c:1935
+#: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
 msgid "default argument given for parameter %d of %q#D"
 msgstr "为%2$q#D的第 %1$d 个形参指定了默认实参"
 
-#: cp/decl.c:1930 cp/decl.c:1938
+#: cp/decl.c:1933 cp/decl.c:1941
 #, fuzzy, gcc-internal-format
 msgid "previous specification in %q#D here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.c:2004
+#: cp/decl.c:2007
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.c:2015
+#: cp/decl.c:2018
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %q+D"
@@ -44111,39 +44252,39 @@
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.c:2448
+#: cp/decl.c:2451
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/decl.c:2586
+#: cp/decl.c:2589
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D的数据区域与先前的声明冲突"
 
 #. Reject two definitions.
-#: cp/decl.c:2840 cp/decl.c:2869 cp/decl.c:2902 cp/decl.c:2919 cp/decl.c:3014
+#: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
 #: cp/decl2.c:919
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q#D 重定义"
 
-#: cp/decl.c:2856
+#: cp/decl.c:2859
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD与已用的函数冲突"
 
-#: cp/decl.c:2866
+#: cp/decl.c:2869
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D未在类中声明"
 
-#: cp/decl.c:2880 cp/decl.c:2929
+#: cp/decl.c:2883 cp/decl.c:2932
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D重声明内联并有%<gnu_inline%>属性"
 
-#: cp/decl.c:2883 cp/decl.c:2932
+#: cp/decl.c:2886 cp/decl.c:2935
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D重声明为内联而没有%<gnu_inline%>属性"
@@ -44151,649 +44292,650 @@
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.c:2949
+#: cp/decl.c:2952
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/decl.c:2963
+#: cp/decl.c:2966
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q#D的线程局部声明出现在其非线程局部声明之后"
 
-#: cp/decl.c:2966
+#: cp/decl.c:2969
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q#D的非线程局部声明出现在其线程局部声明之后"
 
-#: cp/decl.c:2981 cp/decl.c:3022 cp/name-lookup.c:2280 cp/name-lookup.c:2687
-#: cp/name-lookup.c:2709
+#: cp/decl.c:2984 cp/decl.c:3025 cp/name-lookup.c:2281 cp/name-lookup.c:2692
+#: cp/name-lookup.c:2714
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q#D重声明"
 
-#: cp/decl.c:3006
+#: cp/decl.c:3009
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.c:3071
+#: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.c:3072
+#: cp/decl.c:3075
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "上一个声明"
 
-#: cp/decl.c:3166
+#: cp/decl.c:3169
 #, gcc-internal-format
 msgid "  from here"
 msgstr "从这里"
 
-#: cp/decl.c:3189 cp/decl.c:3416
+#: cp/decl.c:3192 cp/decl.c:3419
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "退出了 OpenMP 结构块"
 
-#: cp/decl.c:3216
+#: cp/decl.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3219
+#: cp/decl.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D, which has non-trivial destructor"
 msgstr "进入了有不平凡析构函数的%q+#D的作用域"
 
-#: cp/decl.c:3274
+#: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
 msgstr ""
 
-#: cp/decl.c:3369 cp/decl.c:3389
+#: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
 msgid "  enters catch block"
 msgstr "进入了 catch 块"
 
-#: cp/decl.c:3376
+#: cp/decl.c:3379
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3379
+#: cp/decl.c:3382
 #, fuzzy, gcc-internal-format
 #| msgid "  enters scope of %q+#D which has non-trivial destructor"
 msgid "  enters scope of %q#D which has non-trivial destructor"
 msgstr "进入了有不平凡析构函数的%q+#D的作用域"
 
-#: cp/decl.c:3387
+#: cp/decl.c:3390
 #, gcc-internal-format
 msgid "  enters try block"
 msgstr "进入了 try 块"
 
-#: cp/decl.c:3391
+#: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.c:3393
+#: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
 msgstr ""
 
-#: cp/decl.c:3399
+#: cp/decl.c:3402
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "进入了 OpenMP 结构块"
 
-#: cp/decl.c:3431 cp/parser.c:12376 cp/parser.c:12397
+#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "OpenMP 结构块出口无效"
 
-#: cp/decl.c:3828
+#: cp/decl.c:3831
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD不是一个类型"
 
-#: cp/decl.c:3835 cp/parser.c:6376
+#: cp/decl.c:3838 cp/parser.c:6366
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD使用时未带模板参数"
 
-#: cp/decl.c:3844
+#: cp/decl.c:3847
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T不是一个类"
 
-#: cp/decl.c:3872 cp/decl.c:3965
+#: cp/decl.c:3875 cp/decl.c:3968
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.c:3873
+#: cp/decl.c:3876
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.c:3886
+#: cp/decl.c:3889
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "在%2$qT中查询%1$qT有歧义"
 
-#: cp/decl.c:3895
+#: cp/decl.c:3898
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类模板"
 
-#: cp/decl.c:3902
+#: cp/decl.c:3905
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类型"
 
-#: cp/decl.c:3974
+#: cp/decl.c:3977
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/decl.c:4174
+#: cp/decl.c:4177
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qE is deprecated"
 msgid "%<-fno-for-scope%> is deprecated"
 msgstr "已弃用协议%qE"
 
-#: cp/decl.c:4177
+#: cp/decl.c:4180
 #, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
 msgstr ""
 
-#: cp/decl.c:4273
+#: cp/decl.c:4276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "-faligned-new=%d is not a power of two"
 msgstr "不支持 -falign-labels=%d"
 
-#: cp/decl.c:4730
+#: cp/decl.c:4733
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有构造函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:4733
+#: cp/decl.c:4736
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有构构函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.c:4736
+#: cp/decl.c:4739
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/decl.c:4754
+#: cp/decl.c:4757
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:4757
+#: cp/decl.c:4760
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T的属性必须跟在%qs关键字后面"
 
-#: cp/decl.c:4780
+#: cp/decl.c:4783
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一个声明指定了多个类型"
 
-#: cp/decl.c:4785
+#: cp/decl.c:4788
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "对 C++ 内建类型%qT的重声明"
 
-#: cp/decl.c:4803
+#: cp/decl.c:4806
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:4829
+#: cp/decl.c:4832
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 声明中缺少类型名"
 
-#: cp/decl.c:4837
+#: cp/decl.c:4840
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允许匿名结构"
 
-#: cp/decl.c:4844
+#: cp/decl.c:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:4847
+#: cp/decl.c:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.c:4852
+#: cp/decl.c:4855
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%>只能在类中指定"
 
-#: cp/decl.c:4855
+#: cp/decl.c:4858
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能为构造函数指定%<explicit%>"
 
-#: cp/decl.c:4858
+#: cp/decl.c:4861
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:4862
+#: cp/decl.c:4865
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:4866
+#: cp/decl.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:4870
+#: cp/decl.c:4873
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.c:4874
+#: cp/decl.c:4877
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.c:4878
+#: cp/decl.c:4881
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "此声明中的%<typedef%>被忽略"
 
-#: cp/decl.c:4881
+#: cp/decl.c:4884
 #, gcc-internal-format
 msgid "%<constexpr%> cannot be used for type declarations"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: cp/decl.c:4903
+#: cp/decl.c:4906
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/decl.c:4906
+#: cp/decl.c:4909
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/decl.c:4978
+#: cp/decl.c:4981
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略在定义之外为类类型%qT应用的属性"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.c:4982
+#: cp/decl.c:4985
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略在关联定义之外为依赖类类型%qT应用的属性"
 
-#: cp/decl.c:5051 cp/decl2.c:841
+#: cp/decl.c:5054 cp/decl2.c:841
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use decltype instead)"
 msgstr "typedef%qD被初始化(改用 decltype)"
 
-#: cp/decl.c:5059
+#: cp/decl.c:5062
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D声明有%<extern%>并被初始化"
 
-#: cp/decl.c:5088
+#: cp/decl.c:5091
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/decl.c:5112
+#: cp/decl.c:5115
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/decl.c:5120
+#: cp/decl.c:5123
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:5121
+#: cp/decl.c:5124
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.c:5133
+#: cp/decl.c:5136
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允许将%<%T::%D%>定义为%<%T::%D%>"
 
-#: cp/decl.c:5145
+#: cp/decl.c:5148
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允许成员%qD的初始化"
 
-#: cp/decl.c:5194
+#: cp/decl.c:5197
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.c:5227
+#: cp/decl.c:5230
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:5230
+#: cp/decl.c:5233
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:5295
+#: cp/decl.c:5298
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "变量%q#D有初始值设定，但是类型不完全"
 
-#: cp/decl.c:5301 cp/decl.c:6249
+#: cp/decl.c:5304 cp/decl.c:6259
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "数组%q#D的元素类型不完全"
 
-#: cp/decl.c:5311
+#: cp/decl.c:5314
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/decl.c:5346
+#: cp/decl.c:5349
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:5403
+#: cp/decl.c:5406
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名字被用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5409
+#: cp/decl.c:5412
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5425
+#: cp/decl.c:5431
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值设定不受支持"
 
-#: cp/decl.c:5428
+#: cp/decl.c:5434
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/decl.c:5480
+#: cp/decl.c:5490
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:5487
+#: cp/decl.c:5497
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:5499
+#: cp/decl.c:5509
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:5539
+#: cp/decl.c:5549
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD的存储大小未知"
 
-#: cp/decl.c:5563
+#: cp/decl.c:5573
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD的存储大小不是常量"
 
-#: cp/decl.c:5611
+#: cp/decl.c:5621
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:5615
+#: cp/decl.c:5625
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.c:5621
+#: cp/decl.c:5631
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr " 变通的作法是删除初始值设定"
 
-#: cp/decl.c:5657
+#: cp/decl.c:5667
 #, gcc-internal-format
 msgid "uninitialized const %qD"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.c:5664
+#: cp/decl.c:5674
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:5671
+#: cp/decl.c:5681
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:5679
+#: cp/decl.c:5689
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T没有用户提供的默认构造函数"
 
-#: cp/decl.c:5683
+#: cp/decl.c:5693
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建构子未被 user-provided 因为它是明确的缺席在中类别本体"
 
-#: cp/decl.c:5686
+#: cp/decl.c:5696
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建构子不初始化 %q+#D"
 
-#: cp/decl.c:5830
+#: cp/decl.c:5840
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: cp/decl.c:5871
+#: cp/decl.c:5881
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/decl.c:5906
+#: cp/decl.c:5916
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.c:5914
+#: cp/decl.c:5924
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT没有名为%qD的非静态数据成员"
 
-#: cp/decl.c:5934
+#: cp/decl.c:5944
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: cp/decl.c:5964
+#: cp/decl.c:5974
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示项 %qE 外侧汇总初始设置式"
 
-#: cp/decl.c:6001 cp/decl.c:6224 cp/typeck2.c:1307 cp/typeck2.c:1584
-#: cp/typeck2.c:1632 cp/typeck2.c:1679
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
+#: cp/typeck2.c:1638 cp/typeck2.c:1685
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
 
-#: cp/decl.c:6040
+#: cp/decl.c:6050
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.c:6149
+#: cp/decl.c:6159
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: cp/decl.c:6251
+#: cp/decl.c:6261
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "数组%q#T的元素类型不完全"
 
-#: cp/decl.c:6259
+#: cp/decl.c:6269
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "变长复合字面量"
 
-#: cp/decl.c:6314
+#: cp/decl.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q+D类型不完全"
 
-#: cp/decl.c:6335
+#: cp/decl.c:6345
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "标量对象%qD在初始值设定中需要一个元素"
 
-#: cp/decl.c:6380
+#: cp/decl.c:6390
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在 C++98 中%qD必须由构造函数而不是%<{...}%>初始化"
 
-#: cp/decl.c:6477
+#: cp/decl.c:6487
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "数组%qD被有括号的字面字符串%qE所初始化"
 
-#: cp/decl.c:6511
+#: cp/decl.c:6523
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "构造函数中对静态成员的初始化无效"
 
-#: cp/decl.c:6513
+#: cp/decl.c:6525
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:6516
+#: cp/decl.c:6528
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:6521
+#: cp/decl.c:6533
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一个类外的初始化)"
 
-#: cp/decl.c:6700
+#: cp/decl.c:6712
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.c:6843
+#: cp/decl.c:6855
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.c:6861 cp/decl.c:12546
+#: cp/decl.c:6873 cp/decl.c:12605
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/decl.c:6865 cp/decl.c:12550
+#: cp/decl.c:6877 cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:6918
+#: cp/decl.c:6930
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/decl.c:7010
+#: cp/decl.c:7026
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.c:7063
+#: cp/decl.c:7081
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隐藏了早先的类型声明%q#D"
 
-#: cp/decl.c:7249
+#: cp/decl.c:7267
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.c:7311
+#: cp/decl.c:7329
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/decl.c:7314
+#: cp/decl.c:7332
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7321
+#: cp/decl.c:7339
 #, fuzzy, gcc-internal-format
-msgid "cannot decompose non-public member %qD of %qT"
-msgstr "生成非类类型%qT的成员指针"
+#| msgid "%qT is an inaccessible base of %qT"
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr "%qT是%qT不可访问的基类"
 
-#: cp/decl.c:7347
+#: cp/decl.c:7365
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7356
+#: cp/decl.c:7374
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7553
+#: cp/decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.c:7569
+#: cp/decl.c:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: cp/decl.c:7578 cp/decl.c:7663
+#: cp/decl.c:7617 cp/decl.c:7702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -44800,914 +44942,925 @@
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "为结构字段指定了%qs"
 
-#: cp/decl.c:7582
+#: cp/decl.c:7621
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7585
+#: cp/decl.c:7624
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7630
+#: cp/decl.c:7669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:7656
+#: cp/decl.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:7665
+#: cp/decl.c:7704
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7686
+#: cp/decl.c:7725
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/decl.c:7712
+#: cp/decl.c:7751
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:7717
+#: cp/decl.c:7756
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/decl.c:7722
+#: cp/decl.c:7761
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "无法分解地址"
 
-#: cp/decl.c:7732
+#: cp/decl.c:7765
 #, fuzzy, gcc-internal-format
+#| msgid "source is of incomplete class type"
+msgid "structured binding refers to incomplete class type %qT"
+msgstr "源有不完全的类类型"
+
+#: cp/decl.c:7774
+#, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: cp/decl.c:8171
+#: cp/decl.c:8213
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8174
+#: cp/decl.c:8216
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解构式"
 
-#: cp/decl.c:8180
+#: cp/decl.c:8222
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8408
+#: cp/decl.c:8450
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:8412
+#: cp/decl.c:8454
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:8415
+#: cp/decl.c:8457
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:8431
+#: cp/decl.c:8473
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.c:8433
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8499
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.c:8459
+#: cp/decl.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8464
+#: cp/decl.c:8506
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.c:8466
+#: cp/decl.c:8508
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.c:8468
+#: cp/decl.c:8510
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8515
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8517
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.c:8477
+#: cp/decl.c:8519
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8482
+#: cp/decl.c:8524
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.c:8484
+#: cp/decl.c:8526
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.c:8486
+#: cp/decl.c:8528
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8493
+#: cp/decl.c:8535
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.c:8500
+#: cp/decl.c:8542
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.c:8532
+#: cp/decl.c:8574
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.c:8572
+#: cp/decl.c:8614
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.c:8582
+#: cp/decl.c:8624
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD没有声明为一个参数"
 
-#: cp/decl.c:8588
+#: cp/decl.c:8630
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: cp/decl.c:8590
+#: cp/decl.c:8632
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法%qD返回非 Java 类型%qT"
 
-#: cp/decl.c:8661
+#: cp/decl.c:8703
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "-fmit-class-file 的别名"
 
-#: cp/decl.c:8730
+#: cp/decl.c:8772
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在友元声明中定义显式特例化%qD"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8740
+#: cp/decl.c:8782
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本模板的声明中对模板标识符%qD的使用无效"
 
-#: cp/decl.c:8758
+#: cp/decl.c:8800
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/decl.c:8766
+#: cp/decl.c:8808
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.c:8815
+#: cp/decl.c:8857
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:8817
+#: cp/decl.c:8859
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.c:8819
+#: cp/decl.c:8861
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:8821
+#: cp/decl.c:8863
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.c:8878
+#: cp/decl.c:8920
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8879
+#: cp/decl.c:8921
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8887
+#: cp/decl.c:8929
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8888
+#: cp/decl.c:8930
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8898
+#: cp/decl.c:8940
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.c:8904
+#: cp/decl.c:8946
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:8917
+#: cp/decl.c:8959
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/decl.c:8927
+#: cp/decl.c:8969
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 带有无效参数列表"
 
-#: cp/decl.c:8935
+#: cp/decl.c:8977
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.c:8941
+#: cp/decl.c:8983
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "浮点数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.c:8947
+#: cp/decl.c:8991
 #, fuzzy, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
+
+#: cp/decl.c:8996
+#, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:9027
+#: cp/decl.c:9076
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%>必须返回%<int%>"
 
-#: cp/decl.c:9067
+#: cp/decl.c:9116
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.c:9072
+#: cp/decl.c:9121
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.c:9074
+#: cp/decl.c:9123
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.c:9091
+#: cp/decl.c:9140
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成员函数%q#D未在类%qT中声明"
 
-#: cp/decl.c:9280
+#: cp/decl.c:9329
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:9288
+#: cp/decl.c:9337
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: cp/decl.c:9295
+#: cp/decl.c:9344
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9415
+#: cp/decl.c:9464
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9419
+#: cp/decl.c:9468
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9423
+#: cp/decl.c:9472
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9437
+#: cp/decl.c:9486
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9444
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.c:9449
+#: cp/decl.c:9498
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允许初始化成员常量%qD，因为它有非整数的类型%qT"
 
-#: cp/decl.c:9549
+#: cp/decl.c:9598
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "数组%qD的大小具有非整数类型%qT"
 
-#: cp/decl.c:9551
+#: cp/decl.c:9600
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/decl.c:9581 cp/decl.c:9631
+#: cp/decl.c:9630 cp/decl.c:9680
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:9597
+#: cp/decl.c:9646
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "数组%qD的大小为负"
 
-#: cp/decl.c:9599 cp/init.c:3649
+#: cp/decl.c:9648 cp/init.c:3651
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "数组大小为负数"
 
-#: cp/decl.c:9613
+#: cp/decl.c:9662
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:9615
+#: cp/decl.c:9664
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允许大小为 0 的数组"
 
-#: cp/decl.c:9628
+#: cp/decl.c:9677
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.c:9637
+#: cp/decl.c:9686
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ 不允许变长数组%qD"
 
-#: cp/decl.c:9639
+#: cp/decl.c:9688
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ 不允许变长数组"
 
-#: cp/decl.c:9645
+#: cp/decl.c:9694
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "使用了变长数组%qD"
 
-#: cp/decl.c:9648
+#: cp/decl.c:9697
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "使用了变长数组"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9746
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "数组维数溢出"
 
-#: cp/decl.c:9750
+#: cp/decl.c:9799
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/decl.c:9760
+#: cp/decl.c:9809
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD声明为 void 的数组"
 
-#: cp/decl.c:9762
+#: cp/decl.c:9811
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "创建 void 数组"
 
-#: cp/decl.c:9767
+#: cp/decl.c:9816
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD声明为函数的数组"
 
-#: cp/decl.c:9769
+#: cp/decl.c:9818
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "创建函数的数组"
 
-#: cp/decl.c:9774
+#: cp/decl.c:9823
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD声明为引用的数组"
 
-#: cp/decl.c:9776
+#: cp/decl.c:9825
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "创建引用的数组"
 
-#: cp/decl.c:9781
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.c:9783
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "创建函数成员的组织"
 
-#: cp/decl.c:9797
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:9801
+#: cp/decl.c:9850
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "声明多维数组必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:9860
+#: cp/decl.c:9909
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "为构造函数指定返回值无效"
 
-#: cp/decl.c:9863
+#: cp/decl.c:9912
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9873
+#: cp/decl.c:9922
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:9876
+#: cp/decl.c:9925
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9888
+#: cp/decl.c:9937
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "为%<operator %T%>指定了返回值"
 
-#: cp/decl.c:9891
+#: cp/decl.c:9940
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9899
+#: cp/decl.c:9948
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:9902
+#: cp/decl.c:9951
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9906
+#: cp/decl.c:9955
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/decl.c:9915
+#: cp/decl.c:9964
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:9936
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "无名变量或字段声明为 void"
 
-#: cp/decl.c:9943
+#: cp/decl.c:9992
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "变量或字段声明为 void"
 
-#: cp/decl.c:9958
+#: cp/decl.c:10007
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:9964
+#: cp/decl.c:10013
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:10219
+#: cp/decl.c:10268
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "对限定名%<::%D%>的使用无效"
 
-#: cp/decl.c:10222 cp/decl.c:10242
+#: cp/decl.c:10271 cp/decl.c:10291
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "对限定名%<%T::%D%>的使用无效"
 
-#: cp/decl.c:10225
+#: cp/decl.c:10274
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "对限定名%<%D::%D%>的使用无效"
 
-#: cp/decl.c:10234
+#: cp/decl.c:10283
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T 不是一个类或命名空间"
 
-#: cp/decl.c:10256 cp/decl.c:10349 cp/decl.c:10358 cp/decl.c:11911
+#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:10262
+#: cp/decl.c:10311
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD未声明为成员"
 
-#: cp/decl.c:10290
+#: cp/decl.c:10339
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少声明标识符：使用了保留字%qD"
 
-#: cp/decl.c:10341
+#: cp/decl.c:10390
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.c:10366
+#: cp/decl.c:10415
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:10371
+#: cp/decl.c:10420
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "声明的形参%qD不存在"
 
-#: cp/decl.c:10405
+#: cp/decl.c:10454
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.c:10411
+#: cp/decl.c:10460
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.c:10419
+#: cp/decl.c:10468
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs的声明指定了两个以上的数据类型"
 
-#: cp/decl.c:10425
+#: cp/decl.c:10474
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:10466
+#: cp/decl.c:10515
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ 不支持单独以 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:10515 cp/decl.c:10518 cp/decl.c:10521
+#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允许声明无类型的%qs"
 
-#: cp/decl.c:10537
+#: cp/decl.c:10586
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/decl.c:10543
+#: cp/decl.c:10592
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 对 %2$qs 不支持 %<__int%1$d%>"
 
-#: cp/decl.c:10565 cp/decl.c:10585
+#: cp/decl.c:10614 cp/decl.c:10634
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "为%qs使用%<signed%>或%<unsigned%>无效"
 
-#: cp/decl.c:10567
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "为%qs同时给定了%<signed%>和%<unsigned%>"
 
-#: cp/decl.c:10569
+#: cp/decl.c:10618
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%>对%qs无效"
 
-#: cp/decl.c:10571
+#: cp/decl.c:10620
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%>对%qs无效"
 
-#: cp/decl.c:10573
+#: cp/decl.c:10622
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%>对%qs无效"
 
-#: cp/decl.c:10575
+#: cp/decl.c:10624
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%>或%<short%>对%qs无效"
 
-#: cp/decl.c:10577
+#: cp/decl.c:10626
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>、%<int%>、%<short%>或%<char%>对%qs无效"
 
-#: cp/decl.c:10579
+#: cp/decl.c:10628
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "为 char%qs给定了%<long%>或%<short%>"
 
-#: cp/decl.c:10581
+#: cp/decl.c:10630
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "为%qs同时给定了%<long%>和%<short%>"
 
-#: cp/decl.c:10587
+#: cp/decl.c:10636
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%>或%<short%>对%qs无效"
 
-#: cp/decl.c:10595
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "为%qs使用 long、short、signed 或 unsigned 无效"
 
-#: cp/decl.c:10663
+#: cp/decl.c:10712
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "对%qs而言无效的复数"
 
-#: cp/decl.c:10702
+#: cp/decl.c:10751
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10720
+#: cp/decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:10726
+#: cp/decl.c:10775
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:10736
+#: cp/decl.c:10785
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:10741
+#: cp/decl.c:10790
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "为模板参数%qs指定了存储类"
 
-#: cp/decl.c:10747
+#: cp/decl.c:10796
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10800
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:10756
+#: cp/decl.c:10805
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:10766
+#: cp/decl.c:10815
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:10776
+#: cp/decl.c:10825
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/decl.c:10779
+#: cp/decl.c:10828
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/decl.c:10781
+#: cp/decl.c:10830
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10834
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10845
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10804
+#: cp/decl.c:10853
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qE declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "嵌套函数%qE被声明为%<extern%>"
 
-#: cp/decl.c:10808
+#: cp/decl.c:10857
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10812
+#: cp/decl.c:10861
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10823
+#: cp/decl.c:10872
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:10826
+#: cp/decl.c:10875
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10906
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:10880
+#: cp/decl.c:10929
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:10884
+#: cp/decl.c:10933
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "为形参%qs指定了存储类"
 
-#: cp/decl.c:10897
+#: cp/decl.c:10946
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: cp/decl.c:10901
+#: cp/decl.c:10950
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在文件层将%qs声明为%<auto%>"
 
-#: cp/decl.c:10908
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 
-#: cp/decl.c:10920
+#: cp/decl.c:10969
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "为友元函数声明指定了无效的存储类"
 
-#: cp/decl.c:11001
+#: cp/decl.c:11050
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:11049
+#: cp/decl.c:11098
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/decl.c:11069
+#: cp/decl.c:11118
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.c:11072
+#: cp/decl.c:11121
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:11078
+#: cp/decl.c:11127
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11085
+#: cp/decl.c:11134
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.c:11095
+#: cp/decl.c:11147
 #, fuzzy, gcc-internal-format
+#| msgid "type qualifiers ignored on function return type"
+msgid "deduced class type %qD in function return type"
+msgstr "忽略函数返回类型的类型限定"
+
+#: cp/decl.c:11156
+#, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11099
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
-msgid "deduced class type %qT in function return type"
-msgstr "忽略函数返回类型的类型限定"
-
-#: cp/decl.c:11111
+#: cp/decl.c:11169
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -45714,57 +45867,57 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11122
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:11125
+#: cp/decl.c:11183
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.c:11154
+#: cp/decl.c:11212
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.c:11160
+#: cp/decl.c:11218
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.c:11189
+#: cp/decl.c:11247
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:11190
+#: cp/decl.c:11248
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:11194
+#: cp/decl.c:11252
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11195
+#: cp/decl.c:11253
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11203
+#: cp/decl.c:11261
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11204
+#: cp/decl.c:11262
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11222
+#: cp/decl.c:11280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -45771,249 +45924,249 @@
 msgstr "构造函数不能被声明为虚函数"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11237
+#: cp/decl.c:11295
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11241
+#: cp/decl.c:11299
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.c:11243
+#: cp/decl.c:11301
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.c:11255
+#: cp/decl.c:11313
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11281
+#: cp/decl.c:11339
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.c:11321
+#: cp/decl.c:11379
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:11334 cp/decl.c:11341
+#: cp/decl.c:11392 cp/decl.c:11399
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.c:11343
+#: cp/decl.c:11401
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.c:11372
+#: cp/decl.c:11430
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.c:11373
+#: cp/decl.c:11431
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:11446
+#: cp/decl.c:11504
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.c:11516
+#: cp/decl.c:11574
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.c:11541
+#: cp/decl.c:11599
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.c:11547
+#: cp/decl.c:11605
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.c:11577
+#: cp/decl.c:11635
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.c:11579
+#: cp/decl.c:11637
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:11587
+#: cp/decl.c:11645
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:11627
+#: cp/decl.c:11685
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11693
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11695
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.c:11648
+#: cp/decl.c:11706
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:11651
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.c:11654
+#: cp/decl.c:11712
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.c:11663
+#: cp/decl.c:11721
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11668
+#: cp/decl.c:11726
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11674
+#: cp/decl.c:11732
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11679
+#: cp/decl.c:11737
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11684
+#: cp/decl.c:11742
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11689
+#: cp/decl.c:11747
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11720
+#: cp/decl.c:11778
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: cp/decl.c:11725
+#: cp/decl.c:11783
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11733
+#: cp/decl.c:11787
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.c:11754
+#: cp/decl.c:11813
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.c:11841
+#: cp/decl.c:11900
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.c:11849
+#: cp/decl.c:11908
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.c:11851
+#: cp/decl.c:11910
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.c:11855
+#: cp/decl.c:11914
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.c:11868
+#: cp/decl.c:11927
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.c:11888
+#: cp/decl.c:11947
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.c:11892
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11902
+#: cp/decl.c:11961
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.c:11917
+#: cp/decl.c:11976
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:11936
+#: cp/decl.c:11995
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.c:11942
+#: cp/decl.c:12001
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:11944
+#: cp/decl.c:12003
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:11993 cp/parser.c:3270
+#: cp/decl.c:12052 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: cp/decl.c:11997
+#: cp/decl.c:12056
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12021
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:12024
+#: cp/decl.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -46020,164 +46173,164 @@
 msgstr "ISO C90 不允许可变数组成员"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12040
+#: cp/decl.c:12099
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.c:12062
+#: cp/decl.c:12121
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD模板声明无效"
 
-#: cp/decl.c:12071
+#: cp/decl.c:12130
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.c:12094
+#: cp/decl.c:12153
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:12101
+#: cp/decl.c:12160
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.c:12107
+#: cp/decl.c:12166
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:12112
+#: cp/decl.c:12171
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:12118
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:12126
+#: cp/decl.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:12131
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:12140
+#: cp/decl.c:12199
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.c:12143
+#: cp/decl.c:12202
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/decl.c:12198
+#: cp/decl.c:12257
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: cp/decl.c:12203
+#: cp/decl.c:12262
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.c:12213
+#: cp/decl.c:12272
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:12259
+#: cp/decl.c:12318
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12263
+#: cp/decl.c:12322
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.c:12291
+#: cp/decl.c:12350
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12295
+#: cp/decl.c:12354
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12409
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.c:12352
+#: cp/decl.c:12411
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.c:12356
+#: cp/decl.c:12415
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:12359
+#: cp/decl.c:12418
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:12364
+#: cp/decl.c:12423
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.c:12375
+#: cp/decl.c:12434
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.c:12379
+#: cp/decl.c:12438
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:12387
+#: cp/decl.c:12446
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.c:12394
+#: cp/decl.c:12453
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:12395
+#: cp/decl.c:12454
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:12430
+#: cp/decl.c:12489
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
@@ -46184,78 +46337,78 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12438
+#: cp/decl.c:12497
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.c:12474
+#: cp/decl.c:12533
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.c:12481
+#: cp/decl.c:12540
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.c:12487
+#: cp/decl.c:12546
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.c:12494
+#: cp/decl.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:12515
+#: cp/decl.c:12574
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.c:12526
+#: cp/decl.c:12585
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.c:12530
+#: cp/decl.c:12589
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.c:12695
+#: cp/decl.c:12754
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:12698
+#: cp/decl.c:12757
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:12782
+#: cp/decl.c:12841
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.c:12786
+#: cp/decl.c:12845
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/decl.c:12809
+#: cp/decl.c:12868
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.c:12836
+#: cp/decl.c:12895
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.c:12838
+#: cp/decl.c:12897
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
@@ -46275,177 +46428,177 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13091
+#: cp/decl.c:13150
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.c:13169
+#: cp/decl.c:13228
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.c:13175
+#: cp/decl.c:13234
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.c:13202
+#: cp/decl.c:13261
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:13208
+#: cp/decl.c:13267
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.c:13218
+#: cp/decl.c:13277
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
 #. 13.4.0.3
-#: cp/decl.c:13244
+#: cp/decl.c:13303
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
 #. Variadic.
-#: cp/decl.c:13255
+#: cp/decl.c:13314
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.c:13279
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.c:13280
+#: cp/decl.c:13339
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.c:13291
+#: cp/decl.c:13350
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.c:13292
+#: cp/decl.c:13351
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.c:13302
+#: cp/decl.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:13303 cp/decl.c:13312
+#: cp/decl.c:13362 cp/decl.c:13371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.c:13313
+#: cp/decl.c:13372
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:13330 cp/decl.c:13333
+#: cp/decl.c:13389 cp/decl.c:13392
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.c:13360
+#: cp/decl.c:13419
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "向指向 void 的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13362
+#: cp/decl.c:13421
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13369
+#: cp/decl.c:13428
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13371
+#: cp/decl.c:13430
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13379
+#: cp/decl.c:13438
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13381
+#: cp/decl.c:13440
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13396
+#: cp/decl.c:13455
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.c:13415
+#: cp/decl.c:13474
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13480
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.c:13433
+#: cp/decl.c:13492
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.c:13488
+#: cp/decl.c:13547
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:13511
+#: cp/decl.c:13570
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:13514
+#: cp/decl.c:13573
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.c:13516
+#: cp/decl.c:13575
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:13524
+#: cp/decl.c:13583
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.c:13525 cp/decl.c:13532
+#: cp/decl.c:13584 cp/decl.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:13531
+#: cp/decl.c:13590
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -46457,95 +46610,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13546
+#: cp/decl.c:13605
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.c:13600 cp/name-lookup.c:4647
+#: cp/decl.c:13659 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.c:13630 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6435
-#: cp/pt.c:8942
+#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
+#: cp/pt.c:9209
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.c:13635
+#: cp/decl.c:13694
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13644 cp/name-lookup.c:4074 cp/name-lookup.c:4081
-#: cp/name-lookup.c:4934 cp/parser.c:6386 cp/parser.c:26286
+#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.c:13747
+#: cp/decl.c:13806
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.c:13783
+#: cp/decl.c:13842
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.c:13923
+#: cp/decl.c:13982
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.c:13930
+#: cp/decl.c:13989
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.c:13941
+#: cp/decl.c:14000
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/decl.c:13966
+#: cp/decl.c:14025
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.c:13996
+#: cp/decl.c:14055
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.c:13998
+#: cp/decl.c:14057
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.c:14143
+#: cp/decl.c:14202
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:14146 cp/decl.c:14154 cp/decl.c:14166 cp/parser.c:18274
+#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.c:14151
+#: cp/decl.c:14210
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.c:14163
+#: cp/decl.c:14222
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下层的输入 enum %q#T"
 
-#: cp/decl.c:14241
+#: cp/decl.c:14300
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -46555,78 +46708,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14388
+#: cp/decl.c:14447
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.c:14560
+#: cp/decl.c:14619
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:14570
+#: cp/decl.c:14629
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14678
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:14620
+#: cp/decl.c:14679
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:14631
+#: cp/decl.c:14690
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.c:14651
+#: cp/decl.c:14710
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.c:14762
+#: cp/decl.c:14821
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.c:14940 cp/typeck.c:9257
+#: cp/decl.c:14999 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.c:15285
+#: cp/decl.c:15344
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "无效的函数声明"
 
-#: cp/decl.c:15727
+#: cp/decl.c:15786
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:15729 cp/typeck.c:9137
+#: cp/decl.c:15788 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.c:15937
+#: cp/decl.c:15996
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "无效的成员函数声明"
 
-#: cp/decl.c:15951
+#: cp/decl.c:16010
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.c:16327
+#: cp/decl.c:16386
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -46666,7 +46819,7 @@
 msgid "deleting %qT is undefined"
 msgstr "删除%qT未定义"
 
-#: cp/decl2.c:585 cp/pt.c:5551
+#: cp/decl2.c:585 cp/pt.c:5552
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D声明为模板"
@@ -46679,7 +46832,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5510
+#: cp/decl2.c:640 cp/pt.c:5511
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "析构函数%qD被声明为一个成员模板"
@@ -46792,45 +46945,45 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "位段%qD非整型"
 
-#: cp/decl2.c:1514
+#: cp/decl2.c:1515
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/decl2.c:1581
+#: cp/decl2.c:1582
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "匿名结构不在有名类型内"
 
-#: cp/decl2.c:1597
+#: cp/decl2.c:1598
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/decl2.c:1604
+#: cp/decl2.c:1605
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "匿名联合中出现私有成员%q+#D"
 
-#: cp/decl2.c:1607
+#: cp/decl2.c:1608
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/decl2.c:1672
+#: cp/decl2.c:1673
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "命名空间域的匿名聚合必须是静态的"
 
-#: cp/decl2.c:1681
+#: cp/decl2.c:1682
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "匿名联合没有成员"
 
-#: cp/decl2.c:1714
+#: cp/decl2.c:1715
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%>必须返回%qT"
@@ -46839,71 +46992,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1725
+#: cp/decl2.c:1726
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%>的第一个形参不能有默认参数"
 
-#: cp/decl2.c:1741
+#: cp/decl2.c:1742
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%>的第一个形参类型为%<size_t%>(%qT)"
 
-#: cp/decl2.c:1770
+#: cp/decl2.c:1771
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%>必须返回%qT"
 
-#: cp/decl2.c:1779
+#: cp/decl2.c:1780
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>的第一个形参类型为%qT"
 
-#: cp/decl2.c:2659
+#: cp/decl2.c:2660
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2663
+#: cp/decl2.c:2664
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2668
+#: cp/decl2.c:2669
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2676
+#: cp/decl2.c:2677
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT被声明为比其字段%qD的类型有更高的可见性"
 
-#: cp/decl2.c:2694
+#: cp/decl2.c:2695
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2698
+#: cp/decl2.c:2699
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2703
+#: cp/decl2.c:2704
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2710
+#: cp/decl2.c:2711
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/decl2.c:4308
+#: cp/decl2.c:4309
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q+#D声明为具有匿名类型，在使用前未被定义"
@@ -46912,63 +47065,63 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4317
+#: cp/decl2.c:4318
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明变量 %q#D 与链结"
 
-#: cp/decl2.c:4321
+#: cp/decl2.c:4322
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明函数 %q#D 与链结"
 
-#: cp/decl2.c:4325
+#: cp/decl2.c:4326
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D未指明非限定类型，所以它不被用作外部链接"
 
-#: cp/decl2.c:4333
+#: cp/decl2.c:4334
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D声明为具有局部类型%qT，在使用前未被定义"
 
-#: cp/decl2.c:4337
+#: cp/decl2.c:4338
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "constexpr 变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/decl2.c:4340
+#: cp/decl2.c:4341
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%q+#D的早先声明有%qL链接"
 
-#: cp/decl2.c:4528
+#: cp/decl2.c:4529
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl2.c:4531
+#: cp/decl2.c:4532
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "先前的声明%q+D"
 
-#: cp/decl2.c:4533
+#: cp/decl2.c:4534
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=4 (or =0) 可以改变向量修饰来避免这个错误"
 
-#: cp/decl2.c:4605 cp/decl2.c:4608
+#: cp/decl2.c:4606 cp/decl2.c:4609
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4955
+#: cp/decl2.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了内联函数%q+D但从未定义过"
 
-#: cp/decl2.c:5142
+#: cp/decl2.c:5143
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D的第 %1$P 个形参缺少默认实参"
@@ -46975,18 +47128,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5244
+#: cp/decl2.c:5251
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.c:5247
+#: cp/decl2.c:5254
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
 
-#: cp/decl2.c:5300
+#: cp/decl2.c:5307
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -46996,113 +47149,113 @@
 msgid "with"
 msgstr "with"
 
-#: cp/error.c:3688
+#: cp/error.c:3689
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "(no argument)"
 msgstr "没有参数"
 
-#: cp/error.c:3780
+#: cp/error.c:3781
 #, gcc-internal-format
 msgid "[...]"
 msgstr ""
 
-#: cp/error.c:4140
+#: cp/error.c:4141
 #, fuzzy, gcc-internal-format
 msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4145
+#: cp/error.c:4146
 #, fuzzy, gcc-internal-format
 msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4150
+#: cp/error.c:4151
 #, fuzzy, gcc-internal-format
 msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4155
+#: cp/error.c:4156
 #, fuzzy, gcc-internal-format
 msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4160
+#: cp/error.c:4161
 #, fuzzy, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4164
+#: cp/error.c:4165
 #, fuzzy, gcc-internal-format
 msgid "scoped enums only available with -std=c++11 or -std=gnu++11"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4168
+#: cp/error.c:4169
 #, fuzzy, gcc-internal-format
 msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4173
+#: cp/error.c:4174
 #, fuzzy, gcc-internal-format
 msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4178
+#: cp/error.c:4179
 #, fuzzy, gcc-internal-format
 msgid "override controls (override/final) only available with -std=c++11 or -std=gnu++11"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4183
+#: cp/error.c:4184
 #, fuzzy, gcc-internal-format
 msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4188
+#: cp/error.c:4189
 #, fuzzy, gcc-internal-format
 msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4193
+#: cp/error.c:4194
 #, fuzzy, gcc-internal-format
 msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4198
+#: cp/error.c:4199
 #, fuzzy, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4203
+#: cp/error.c:4204
 #, fuzzy, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4208
+#: cp/error.c:4209
 #, fuzzy, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/error.c:4258
+#: cp/error.c:4259
 #, gcc-internal-format
 msgid "incomplete type %qT used in nested name specifier"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/error.c:4262
+#: cp/error.c:4263
 #, gcc-internal-format
 msgid "reference to %<%T::%D%> is ambiguous"
 msgstr "对%<%T::%D%>的引用有歧义"
 
-#: cp/error.c:4267 cp/typeck.c:2408
+#: cp/error.c:4268 cp/typeck.c:2413
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/error.c:4271 cp/typeck.c:2880
+#: cp/error.c:4272 cp/typeck.c:2885
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD不是%qD的成员"
 
-#: cp/error.c:4277
+#: cp/error.c:4278
 #, gcc-internal-format
 msgid "%<::%D%> has not been declared"
 msgstr "%<::%D%>未被声明"
@@ -47248,363 +47401,363 @@
 msgid "(if this is not what you intended, make sure the function template has already been declared and add <> after the function name here) "
 msgstr "(如果这不是您原来的想法，请确定此函数模板已经声明过，并在这里的函数名后面添加 <>)"
 
-#: cp/init.c:392
+#: cp/init.c:394
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/init.c:461
+#: cp/init.c:463
 #, fuzzy, gcc-internal-format
 msgid "cannot value-initialize array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/init.c:500
+#: cp/init.c:502
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/init.c:506
+#: cp/init.c:508
 #, fuzzy, gcc-internal-format
 msgid "value-initialization of reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/init.c:564
+#: cp/init.c:566
 #, fuzzy, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/init.c:611
+#: cp/init.c:613
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:615
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "联合在此定义"
 
-#: cp/init.c:671
+#: cp/init.c:673
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:697
+#: cp/init.c:699
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD应该在成员初始化列表中被初始化"
 
-#: cp/init.c:718
+#: cp/init.c:720
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "形参%qD已初始化"
 
-#: cp/init.c:829
+#: cp/init.c:831
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:843 cp/init.c:867 cp/init.c:2408 cp/method.c:1368
+#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:845 cp/init.c:862 cp/init.c:869 cp/init.c:2393 cp/init.c:2421
+#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D将在"
 
-#: cp/init.c:860 cp/init.c:2380 cp/method.c:1379
+#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:1039
+#: cp/init.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D将在"
 
-#: cp/init.c:1042
+#: cp/init.c:1044
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基类%qT将在"
 
-#: cp/init.c:1046
+#: cp/init.c:1048
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "%q+#D"
 
-#: cp/init.c:1048
+#: cp/init.c:1050
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "基类%qT"
 
-#: cp/init.c:1050
+#: cp/init.c:1052
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "在此处初始化后被初始化"
 
-#: cp/init.c:1067
+#: cp/init.c:1069
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "为%qD给定了多个初始值设定"
 
-#: cp/init.c:1071
+#: cp/init.c:1073
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "为基类%qT给定了多个初始值设定"
 
-#: cp/init.c:1156
+#: cp/init.c:1158
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化%qT的多个成员"
 
-#: cp/init.c:1253
+#: cp/init.c:1255
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基类%q#T应该在复制构造函数中显式地初始化"
 
-#: cp/init.c:1480 cp/init.c:1499
+#: cp/init.c:1482 cp/init.c:1501
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:1486
+#: cp/init.c:1488
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D是一个静态数据成员；它只能在定义时被初始化"
 
-#: cp/init.c:1493
+#: cp/init.c:1495
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/init.c:1532
+#: cp/init.c:1534
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "对没有基类的%qT的无名初始化"
 
-#: cp/init.c:1540
+#: cp/init.c:1542
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "对使用了多继承的%qT的无名初始化"
 
-#: cp/init.c:1587
+#: cp/init.c:1589
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD既是一个直接基类又是一个间接虚基类"
 
-#: cp/init.c:1595
+#: cp/init.c:1597
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/init.c:1598
+#: cp/init.c:1600
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/init.c:1708 cp/init.c:4384 cp/typeck2.c:1172
+#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/init.c:2017 cp/semantics.c:3268
+#: cp/init.c:2019 cp/semantics.c:3268
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/init.c:2073
+#: cp/init.c:2075
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全类型%qT没有成员%qD"
 
-#: cp/init.c:2087
+#: cp/init.c:2089
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "指向位段%qD指针无效"
 
-#: cp/init.c:2173 cp/typeck.c:1888
+#: cp/init.c:2175 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/init.c:2180 cp/semantics.c:1835
+#: cp/init.c:2182 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "对非静态数据成员%qD的无效使用"
 
-#: cp/init.c:2377
+#: cp/init.c:2379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2385
+#: cp/init.c:2387
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2389
+#: cp/init.c:2391
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2405
+#: cp/init.c:2407
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2413
+#: cp/init.c:2415
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2417
+#: cp/init.c:2419
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2708
+#: cp/init.c:2710
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2719
+#: cp/init.c:2721
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2730
+#: cp/init.c:2732
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2878
+#: cp/init.c:2880
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "表达式中整复数溢出"
 
-#: cp/init.c:2888
+#: cp/init.c:2890
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:2902
+#: cp/init.c:2904
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "文件域中的动态可变字段"
 
-#: cp/init.c:2918
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2922
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/init.c:2930
+#: cp/init.c:2932
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "对 new 而言类型%<void%>无效"
 
-#: cp/init.c:2973
+#: cp/init.c:2975
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:3099
+#: cp/init.c:3101
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合适的%qD，在类%qT中"
 
-#: cp/init.c:3106 cp/search.c:1023
+#: cp/init.c:3108 cp/search.c:1023
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "对成员%qD的请求有歧义"
 
-#: cp/init.c:3179
+#: cp/init.c:3181
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3182
+#: cp/init.c:3184
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:3185
+#: cp/init.c:3187
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3368
+#: cp/init.c:3370
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/init.c:3631
+#: cp/init.c:3633
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:3663
+#: cp/init.c:3665
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用于引用类型"
 
-#: cp/init.c:3672
+#: cp/init.c:3674
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用于函数类型"
 
-#: cp/init.c:3741
+#: cp/init.c:3743
 #, fuzzy, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:3745
+#: cp/init.c:3747
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4293
+#: cp/init.c:4295
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值设定在完成之前结束"
 
-#: cp/init.c:4597
+#: cp/init.c:4599
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 时数组大小未知"
 
-#: cp/init.c:4621
+#: cp/init.c:4623
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:4626
+#: cp/init.c:4628
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4640
+#: cp/init.c:4642
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "删除对象的抽象类别类型 %qT 该项有 non-virtual 解构式将造成未定义的行为"
 
-#: cp/init.c:4645
+#: cp/init.c:4647
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "删除对象的 polymorphic 类别类型 %qT 该项有 non-virtual 解构式也许造成未定义的行为"
 
-#: cp/init.c:4952
+#: cp/init.c:4954
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的实参类型既非指针也非数组"
@@ -47616,7 +47769,7 @@
 
 #: cp/lambda.c:557
 #, gcc-internal-format
-msgid "capture of variable-size type %qT that is not an N3639 array of runtime bound"
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
 #: cp/lambda.c:561
@@ -47699,67 +47852,67 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(如果您使用%<-fpermissive%>，G++ 会接受您的代码，但是允许使用未定义的名称是已弃用的风格)"
 
-#: cp/mangle.c:2363
+#: cp/mangle.c:2366
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "修饰 typeof，请改用 decltype"
 
-#: cp/mangle.c:2367
+#: cp/mangle.c:2370
 #, fuzzy, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "修饰未知的定点类型"
 
-#: cp/mangle.c:2650
+#: cp/mangle.c:2653
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "修饰未知的定点类型"
 
-#: cp/mangle.c:3261
+#: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3266
+#: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "修饰 %C"
 
-#: cp/mangle.c:3343
+#: cp/mangle.c:3346
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "省略的%<?:%>中操作数不能被修饰"
 
-#: cp/mangle.c:3430
+#: cp/mangle.c:3433
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "函数模板签名里有字面字符串"
 
-#: cp/mangle.c:3859
+#: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3906
+#: cp/mangle.c:3909
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:3912
+#: cp/mangle.c:3915
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4184
+#: cp/mangle.c:4187
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4189
+#: cp/mangle.c:4192
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4194
+#: cp/mangle.c:4197
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
@@ -47882,45 +48035,45 @@
 msgid "defaulted function %q+D with default argument"
 msgstr "默认化函数%q+D有默认参数"
 
-#: cp/name-lookup.c:2282
+#: cp/name-lookup.c:2283
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/name-lookup.c:2434
+#: cp/name-lookup.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D隐藏了%q#T的构造函数"
 
-#: cp/name-lookup.c:2557
+#: cp/name-lookup.c:2562
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/name-lookup.c:2562
+#: cp/name-lookup.c:2567
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/name-lookup.c:2662
+#: cp/name-lookup.c:2667
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D的声明隐藏了一个形参"
 
-#: cp/name-lookup.c:2779
+#: cp/name-lookup.c:2784
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/name-lookup.c:2940
+#: cp/name-lookup.c:2945
 #, fuzzy, gcc-internal-format
 #| msgid "global declaration %q+#D"
 msgid "local external declaration %q#D"
 msgstr "全局声明%q+#D"
 
-#: cp/name-lookup.c:2942
+#: cp/name-lookup.c:2947
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration %q+#D"
 msgid "does not match previous declaration %q#D"
@@ -47929,63 +48082,63 @@
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
-#: cp/name-lookup.c:3065
+#: cp/name-lookup.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "本地类中的友元声明%qD没有先前声明"
 
-#: cp/name-lookup.c:3127
+#: cp/name-lookup.c:3132
 #, gcc-internal-format
 msgid "injected friend %qD is visible due to %<-ffriend-injection%>"
 msgstr ""
 
-#: cp/name-lookup.c:3247
+#: cp/name-lookup.c:3252
 #, gcc-internal-format
 msgid "name lookup of %qD changed"
 msgstr "%qD的名称查阅已改变"
 
-#: cp/name-lookup.c:3250
+#: cp/name-lookup.c:3255
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under ISO standard rules"
 msgid "matches this %qD under ISO standard rules"
 msgstr "在 ISO 标准规则下匹配此%q+D"
 
-#: cp/name-lookup.c:3252
+#: cp/name-lookup.c:3257
 #, fuzzy, gcc-internal-format
 #| msgid "  matches this %q+D under old rules"
 msgid "  matches this %qD under old rules"
 msgstr "在旧规则下匹配此%q+D"
 
-#: cp/name-lookup.c:3270 cp/name-lookup.c:3280
+#: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
 msgid "name lookup of %qD changed for ISO %<for%> scoping"
 msgstr "在 ISO%<for%>作用域中，%qD的名称查找有变化"
 
-#: cp/name-lookup.c:3273
+#: cp/name-lookup.c:3278
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot use obsolete binding %qD because it has a destructor"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/name-lookup.c:3284
+#: cp/name-lookup.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "  using obsolete binding at %q+D"
 msgid "using obsolete binding %qD"
 msgstr "在%q+D使用过时的绑定"
 
-#: cp/name-lookup.c:3342
+#: cp/name-lookup.c:3347
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d\n"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.c:3345
+#: cp/name-lookup.c:3350
 #, gcc-internal-format
 msgid "%s %s %p %d\n"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.c:4014
+#: cp/name-lookup.c:4019
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
 msgstr "%qT作为枚举被引用"
@@ -47992,12 +48145,12 @@
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
-#: cp/name-lookup.c:4024
+#: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
 msgstr "using 声明不能指定一个模板标识符。请尝试%<using %D%>"
 
-#: cp/name-lookup.c:4031
+#: cp/name-lookup.c:4036
 #, gcc-internal-format
 msgid "namespace %qD not allowed in using-declaration"
 msgstr "不允许在 using 声明中使用命名空间%qD"
@@ -48004,116 +48157,116 @@
 
 #. It's a nested name with template parameter dependent scope.
 #. This can only be using-declaration for class member.
-#: cp/name-lookup.c:4039
+#: cp/name-lookup.c:4044
 #, gcc-internal-format
 msgid "%qT is not a namespace"
 msgstr "%qT不是一个命名空间"
 
 #. C++11 7.3.3/10.
-#: cp/name-lookup.c:4052
+#: cp/name-lookup.c:4057
 #, gcc-internal-format
 msgid "%qD is already declared in this scope"
 msgstr "%qD已在此作用域中声明过"
 
-#: cp/name-lookup.c:4069
+#: cp/name-lookup.c:4074
 #, gcc-internal-format
 msgid "%qD not declared"
 msgstr "%qD未声明"
 
-#: cp/name-lookup.c:4780
+#: cp/name-lookup.c:4785
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.c:4787
+#: cp/name-lookup.c:4792
 #, gcc-internal-format
 msgid "%<%T::%D%> names destructor"
 msgstr "%<%T::%D%>指定了析构函数"
 
-#: cp/name-lookup.c:4804
+#: cp/name-lookup.c:4809
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%>在%qT内指定了构造函数"
 
-#: cp/name-lookup.c:4838
+#: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:4847
+#: cp/name-lookup.c:4852
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "没有与%<%T::%D%>匹配的成员，在%q#T中"
 
-#: cp/name-lookup.c:4914
+#: cp/name-lookup.c:4919
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD的声明不在包含%qD的命名空间中"
 
-#: cp/name-lookup.c:4953
+#: cp/name-lookup.c:4958
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD的声明中有显式的限定"
 
-#: cp/name-lookup.c:5005
+#: cp/name-lookup.c:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.c:5007
+#: cp/name-lookup.c:5012
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D声明为友元"
 
-#: cp/name-lookup.c:5016
+#: cp/name-lookup.c:5021
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD应当先在%qD内声明"
 
-#: cp/name-lookup.c:5061
+#: cp/name-lookup.c:5069
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD属性需要一个 NTBS 作为实参"
 
-#: cp/name-lookup.c:5068
+#: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD属性无意义，因为匿名命名空间的成员拥有局部符号"
 
-#: cp/name-lookup.c:5078
+#: cp/name-lookup.c:5086
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:5084
+#: cp/name-lookup.c:5092
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:5103 cp/name-lookup.c:6854
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定%qD属性被忽略"
 
-#: cp/name-lookup.c:5376
+#: cp/name-lookup.c:5426
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空间搜索的用于 %qE"
 
-#: cp/name-lookup.c:5391
+#: cp/name-lookup.c:5441
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建议的替代："
 
-#: cp/name-lookup.c:5397
+#: cp/name-lookup.c:5447
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5410 cp/name-lookup.c:5572
+#: cp/name-lookup.c:5472 cp/name-lookup.c:5764
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -48120,73 +48273,79 @@
 msgid "suggested alternative: %qs"
 msgstr "建议的替代："
 
-#: cp/name-lookup.c:5536
+#: cp/name-lookup.c:5704
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgstr ""
 
-#: cp/name-lookup.c:5719
+#: cp/name-lookup.c:5711
 #, fuzzy, gcc-internal-format
+#| msgid "%<this%> is unavailable for static member functions"
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr "静态成员函数中不能使用%<this%>"
+
+#: cp/name-lookup.c:5929
+#, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/name-lookup.c:5721
+#: cp/name-lookup.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "结构在此定义"
 
-#: cp/name-lookup.c:6476
+#: cp/name-lookup.c:6687
 #, fuzzy, gcc-internal-format
-msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/name-lookup.c:6848
+#: cp/name-lookup.c:7059
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: cp/name-lookup.c:6851
+#: cp/name-lookup.c:7062
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:6868
+#: cp/name-lookup.c:7079
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/name-lookup.c:6952
+#: cp/name-lookup.c:7163
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "这里不允许命名空间别名%qD，假定为%qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:6972
+#: cp/name-lookup.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/name-lookup.c:7007
+#: cp/name-lookup.c:7218
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法属性必须被指定的于结束只有"
 
-#: cp/name-lookup.c:7008
+#: cp/name-lookup.c:7219
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "标号%qD在此定义"
 
-#: cp/name-lookup.c:7081
+#: cp/name-lookup.c:7292
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX 进入 pop_everything ()\n"
 
-#: cp/name-lookup.c:7090
+#: cp/name-lookup.c:7301
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX 离开 pop_everything ()\n"
@@ -48206,7 +48365,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37233
+#: cp/parser.c:1352 cp/parser.c:37254
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -48231,7 +48390,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "在非类类型%2$qT中请求成员%1$qE"
 
-#: cp/parser.c:2949 cp/parser.c:18211
+#: cp/parser.c:2949 cp/parser.c:18221
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>尚未声明"
@@ -48312,7 +48471,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮点字面量不能出现在常量表达式中"
 
-#: cp/parser.c:3143 cp/pt.c:17482
+#: cp/parser.c:3143 cp/pt.c:17853
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "常量表达式中不能出现目标不是整型或枚举型的类型转换"
@@ -48536,7 +48695,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "无法找到字串实字运算符 %qD 与 %qT，%qT 参数"
 
-#: cp/parser.c:4587 cp/parser.c:12950
+#: cp/parser.c:4587 cp/parser.c:12940
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "需要声明"
@@ -48619,7 +48778,7 @@
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%<~%>前的作用域%qT不是一个类名"
 
-#: cp/parser.c:5948 cp/parser.c:7870
+#: cp/parser.c:5948 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -48634,877 +48793,868 @@
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名%qD用于析构函数声明"
 
-#: cp/parser.c:6110
+#: cp/parser.c:6111 cp/parser.c:20249
 #, fuzzy, gcc-internal-format
-msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
-msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
-
-#: cp/parser.c:6121 cp/parser.c:20238
-#, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:6230
+#: cp/parser.c:6220
 #, fuzzy, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/parser.c:6298
+#: cp/parser.c:6288
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/parser.c:6324
+#: cp/parser.c:6314
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/parser.c:6332
+#: cp/parser.c:6322
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "%C 期待访问指定符"
 
-#: cp/parser.c:6436 cp/typeck.c:2679 cp/typeck.c:2682 cp/typeck.c:2699
+#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD不是一个模板"
 
-#: cp/parser.c:6514
+#: cp/parser.c:6504
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:6721 cp/parser.c:8957
+#: cp/parser.c:6711 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "类型不能定义在类型转换中"
 
-#: cp/parser.c:6807
+#: cp/parser.c:6797
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "类型不能定义在%<typeid%>表达式中"
 
-#: cp/parser.c:6899
+#: cp/parser.c:6889
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:6911 cp/pt.c:18043
+#: cp/parser.c:6901 cp/pt.c:18416
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:7005
+#: cp/parser.c:6995
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ 不允许复合字面量"
 
-#: cp/parser.c:7064
+#: cp/parser.c:7054
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7606 cp/typeck.c:2567
+#: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "错误地使用了%qD"
 
-#: cp/parser.c:7615
+#: cp/parser.c:7605
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/parser.c:7922
+#: cp/parser.c:7912
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "非标准类型"
 
-#: cp/parser.c:8020
+#: cp/parser.c:8013
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 
-#: cp/parser.c:8121
+#: cp/parser.c:8114
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:8411
+#: cp/parser.c:8404
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:8427
+#: cp/parser.c:8420
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的类型标识符后面不能出现数组边界"
 
-#: cp/parser.c:8429
+#: cp/parser.c:8422
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/parser.c:8461
+#: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8509
+#: cp/parser.c:8502
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要表达式类型"
 
-#: cp/parser.c:8538
+#: cp/parser.c:8531
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:8666
+#: cp/parser.c:8659
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:9062
+#: cp/parser.c:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of old-style cast"
 msgid "use of old-style cast to %q#T"
 msgstr "使用旧式的类型转换"
 
-#: cp/parser.c:9210
+#: cp/parser.c:9203
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>运算符在 C++0x 中将被认为是两个右尖括号"
 
-#: cp/parser.c:9213
+#: cp/parser.c:9206
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建议%<>>%>表达式周围加上括号"
 
-#: cp/parser.c:9417
+#: cp/parser.c:9410
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ 不允许省略 ?: 的中间操作数"
 
-#: cp/parser.c:10120
+#: cp/parser.c:9832
 #, fuzzy, gcc-internal-format
+#| msgid "types may not be defined in conditions"
+msgid "types may not be defined within __builtin_offsetof"
+msgstr "类型不能定义在条件表达式中"
+
+#: cp/parser.c:10119
+#, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "已经在 Lambda 表达式中捕获了%<this%>"
 
-#: cp/parser.c:10129
+#: cp/parser.c:10128
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10281
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "捕获列表应在此结束"
 
-#: cp/parser.c:10297
+#: cp/parser.c:10296
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %<this%> 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:10314
+#: cp/parser.c:10313
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10359
+#: cp/parser.c:10358
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10366
+#: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10388
+#: cp/parser.c:10387
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qE"
 msgstr "%qD不是一个变量"
 
-#: cp/parser.c:10392 cp/parser.c:10402 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/parser.c:10398
+#: cp/parser.c:10397
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "截取的变量 %qD 与 non-automatic 贮藏体持续时间"
 
-#: cp/parser.c:10434
+#: cp/parser.c:10433
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %qD 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:10439
+#: cp/parser.c:10438
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明确的 by-reference 截取的 %qD 冗余与 by-reference 截取缺省"
 
-#: cp/parser.c:10495
+#: cp/parser.c:10494
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10499
+#: cp/parser.c:10498
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10531
+#: cp/parser.c:10530
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:10549
+#: cp/parser.c:10548
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重复的%<volatile%>"
 
-#: cp/parser.c:10596
+#: cp/parser.c:10595
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10966 cp/parser.c:11159
+#: cp/parser.c:10965 cp/parser.c:11158
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:11006
+#: cp/parser.c:11005
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "需要标号语句"
 
-#: cp/parser.c:11052
+#: cp/parser.c:11051
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 标号%qE未出现在 switch 语句中"
 
-#: cp/parser.c:11166
+#: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%qE之前需要%<typename%>，因为%qT是一个有依赖的作用域"
 
-#: cp/parser.c:11175
+#: cp/parser.c:11174
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>命名了一个构造函数而非类型"
 
-#: cp/parser.c:11223
+#: cp/parser.c:11222
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
 msgstr "标号位于复合语句末尾"
 
-#: cp/parser.c:11350
+#: cp/parser.c:11349
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11377
+#: cp/parser.c:11376
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11547 cp/parser.c:28469
+#: cp/parser.c:11546 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
 
-#: cp/parser.c:11580
+#: cp/parser.c:11579
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/parser.c:12019
+#: cp/parser.c:12018
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: cp/parser.c:12057
+#: cp/parser.c:12105
 #, fuzzy, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
-msgstr "range-based %<for%> 运算式的类型 %qT 有 %<end%>成员并不是 %<begin%>"
-
-#: cp/parser.c:12063
-#, fuzzy, gcc-internal-format
-msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
-msgstr "range-based %<for%> 运算式的类型 %qT 有 %<begin%>成员并不是 %<end%>"
-
-#: cp/parser.c:12115
-#, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:12260 cp/parser.c:28472
+#: cp/parser.c:12250 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
 
-#: cp/parser.c:12308
+#: cp/parser.c:12298
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12436
+#: cp/parser.c:12426
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "前往目录:"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12444
+#: cp/parser.c:12434
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.c:12457 cp/parser.c:28475
+#: cp/parser.c:12447 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
 
-#: cp/parser.c:12630 cp/parser.c:23570
+#: cp/parser.c:12620 cp/parser.c:23584
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多余的%<;%>"
 
-#: cp/parser.c:12873
+#: cp/parser.c:12863
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>未出现在块起始"
 
-#: cp/parser.c:13087
+#: cp/parser.c:13083
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13107
+#: cp/parser.c:13103
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:13128
+#: cp/parser.c:13124
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合声明和函数定义"
 
-#: cp/parser.c:13152
+#: cp/parser.c:13148
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:13207
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "初始值设定项中索引范围为空"
 
-#: cp/parser.c:13210
+#: cp/parser.c:13206
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13261
+#: cp/parser.c:13257
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13310
+#: cp/parser.c:13306
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration"
 msgid "empty structured binding declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:13328
+#: cp/parser.c:13324
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "成员函数%qD的初始值设定无效"
 
-#: cp/parser.c:13495
+#: cp/parser.c:13491
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%>用在类外"
 
-#: cp/parser.c:13562
+#: cp/parser.c:13558
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%>的语义在 C++0x 中将被改变；请考虑删除它"
 
-#: cp/parser.c:13598
+#: cp/parser.c:13594
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:13604
+#: cp/parser.c:13600
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D无效，在%q#T中"
 
-#: cp/parser.c:13697
+#: cp/parser.c:13693
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "类定义不能被声明为友元"
 
-#: cp/parser.c:13767 cp/parser.c:24050
+#: cp/parser.c:13763 cp/parser.c:24064
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:13809
+#: cp/parser.c:13805
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:13913
+#: cp/parser.c:13909
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14115
+#: cp/parser.c:14111
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:14268
+#: cp/parser.c:14264
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14291
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:14299
+#: cp/parser.c:14295
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:14383
+#: cp/parser.c:14379
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有构造函数才能有基类初始值设定"
 
-#: cp/parser.c:14405
+#: cp/parser.c:14406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.c:14417 cp/pt.c:23900
+#: cp/parser.c:14418 cp/pt.c:24255
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.c:14429 cp/pt.c:23912
+#: cp/parser.c:14430 cp/pt.c:24267
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
 
-#: cp/parser.c:14481
+#: cp/parser.c:14482
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代错误的旧式基类初始值设定"
 
-#: cp/parser.c:14551
+#: cp/parser.c:14552
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(限定的初始值设定隐式地是一个类型)"
 
-#: cp/parser.c:14926
+#: cp/parser.c:14927
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介于 %<“”%>和后缀识别码"
 
-#: cp/parser.c:14932
+#: cp/parser.c:14933
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "需要标识符或%<(%>"
 
-#: cp/parser.c:14941
+#: cp/parser.c:14942
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: cp/parser.c:14947
+#: cp/parser.c:14948
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "二元操作中中操作数无效"
 
-#: cp/parser.c:14974
+#: cp/parser.c:14975
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "需要操作符"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15019
+#: cp/parser.c:15020
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:15189
+#: cp/parser.c:15190
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:15197
+#: cp/parser.c:15198
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:15282
+#: cp/parser.c:15283
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15346
+#: cp/parser.c:15347
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:15581 cp/parser.c:15667 cp/parser.c:21681
+#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:15585 cp/parser.c:15671
+#: cp/parser.c:15586 cp/parser.c:15672
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:15737
+#: cp/parser.c:15738
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:15797
+#: cp/parser.c:15798
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以%<<::%>开始一个模板实参列表"
 
-#: cp/parser.c:15801
+#: cp/parser.c:15802
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%>是%<[%>的另一种拼法。请在%<<%>和%<::%>间加上空格"
 
-#: cp/parser.c:15805
+#: cp/parser.c:15806
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用%<-fpermissive%>G++ 会接受您的代码)"
 
-#: cp/parser.c:15915
+#: cp/parser.c:15924
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "模板实参表语法错误"
 
 #. The name does not name a template.
-#: cp/parser.c:15983 cp/parser.c:16113 cp/parser.c:16328
+#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "需要模板名"
 
 #. Explain what went wrong.
-#: cp/parser.c:16029
+#: cp/parser.c:16038
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非模板%qD用作模板"
 
-#: cp/parser.c:16031
+#: cp/parser.c:16040
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用%<%T::template %D%>来表示这是一个模板"
 
-#: cp/parser.c:16180
+#: cp/parser.c:16189
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:16289 cp/parser.c:16307 cp/parser.c:16474
+#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "需要模板实参"
 
-#: cp/parser.c:16449
+#: cp/parser.c:16458
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:16576
+#: cp/parser.c:16585
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "显式实例化不应当使用%<inline%>限定符"
 
-#: cp/parser.c:16580
+#: cp/parser.c:16589
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:16639
+#: cp/parser.c:16648
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/parser.c:16860
+#: cp/parser.c:16869
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:17044
+#: cp/parser.c:17053
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17050
+#: cp/parser.c:17059
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17055
+#: cp/parser.c:17064
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17200
+#: cp/parser.c:17209
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:17269
+#: cp/parser.c:17278
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "需要类型名"
 
-#: cp/parser.c:17622
+#: cp/parser.c:17631
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用于范围的 enum 必须不使用 %<%D%>关键字"
 
-#: cp/parser.c:17845
+#: cp/parser.c:17854
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "声明%qD没有声明任何东西"
 
-#: cp/parser.c:17932
+#: cp/parser.c:17942
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/parser.c:17936
+#: cp/parser.c:17946
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:17941
+#: cp/parser.c:17951
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/parser.c:18075
+#: cp/parser.c:18085
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD不是一个枚举模板"
 
-#: cp/parser.c:18086
+#: cp/parser.c:18096
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:18101
+#: cp/parser.c:18111
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18156
+#: cp/parser.c:18166
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: cp/parser.c:18205
+#: cp/parser.c:18215
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "启用模板自动实例化"
 
-#: cp/parser.c:18219
+#: cp/parser.c:18229
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:18231 cp/parser.c:23057
+#: cp/parser.c:18241 cp/parser.c:23070
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qD声明出现在命名空间%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:18236 cp/parser.c:23062
+#: cp/parser.c:18246 cp/parser.c:23075
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD声明出现在%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:18248 cp/parser.c:23076
+#: cp/parser.c:18258 cp/parser.c:23089
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "不允许有多余的限定"
 
-#: cp/parser.c:18272
+#: cp/parser.c:18282
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/parser.c:18285
+#: cp/parser.c:18295
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/parser.c:18305
+#: cp/parser.c:18315
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而无需名称"
 
-#: cp/parser.c:18308
+#: cp/parser.c:18318
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必须使用简单的识别码"
 
-#: cp/parser.c:18487
+#: cp/parser.c:18497
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:18493
+#: cp/parser.c:18503
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:18560
+#: cp/parser.c:18570
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18568
+#: cp/parser.c:18578
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:18573
+#: cp/parser.c:18583
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace name required"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:18577
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18580
+#: cp/parser.c:18590
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18597
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:18642
+#: cp/parser.c:18652
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18793
+#: cp/parser.c:18803
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18808
+#: cp/parser.c:18818
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "模板标识符不允许出现在 using 声明中"
 
-#: cp/parser.c:18855
+#: cp/parser.c:18865
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18875
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "访问声明被不宜用在中 favour 的 using-declarations；建议：加入 %<using%> 关键字"
 
-#: cp/parser.c:18930
+#: cp/parser.c:18940
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:19095
+#: cp/parser.c:19106
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "函数%qD用作%<asm%>的输出"
 
-#: cp/parser.c:19482
+#: cp/parser.c:19493
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19504
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/parser.c:19497
+#: cp/parser.c:19508
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:19548
+#: cp/parser.c:19559
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "预期的建构子、解构式，或类型转换"
 
 #. Anything else is an error.
-#: cp/parser.c:19587 cp/parser.c:21893
+#: cp/parser.c:19598 cp/parser.c:21906
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "需要初始值设定"
 
-#: cp/parser.c:19668
+#: cp/parser.c:19679
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "为函数提供了初始值设定"
 
-#: cp/parser.c:19702
+#: cp/parser.c:19713
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:19716
+#: cp/parser.c:19727
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "函数%q+D重声明为内联的"
 
-#: cp/parser.c:20158
+#: cp/parser.c:20169
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/parser.c:20284
+#: cp/parser.c:20295
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/parser.c:20288
+#: cp/parser.c:20299
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>不是一个类型"
@@ -49513,17 +49663,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20317
+#: cp/parser.c:20328
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "无效的声明"
 
-#: cp/parser.c:20325
+#: cp/parser.c:20336
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "将构造函数用作模板无效"
 
-#: cp/parser.c:20327
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
@@ -49530,392 +49680,392 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20399
+#: cp/parser.c:20410
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "需要一个限定的标识符"
 
-#: cp/parser.c:20424
+#: cp/parser.c:20435
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "需要声明"
 
-#: cp/parser.c:20543
+#: cp/parser.c:20554
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD是一个命名空间"
 
-#: cp/parser.c:20545
+#: cp/parser.c:20556
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/parser.c:20566
+#: cp/parser.c:20577
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:20627
+#: cp/parser.c:20638
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:20681
+#: cp/parser.c:20692
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "%q+D的类型限定冲突"
 
-#: cp/parser.c:20718
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: cp/parser.c:20776
+#: cp/parser.c:20787
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "%C处重复访问限定符"
 
-#: cp/parser.c:21014
+#: cp/parser.c:21025
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/parser.c:21020 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2083
+#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "对%qT的使用非法"
 
-#: cp/parser.c:21041
+#: cp/parser.c:21052
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "不能在模板实参中定义类型"
 
-#: cp/parser.c:21046
+#: cp/parser.c:21057
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:21134
+#: cp/parser.c:21145
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:21437
+#: cp/parser.c:21429
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "需要%<,%>或%<...%>"
 
-#: cp/parser.c:21512
+#: cp/parser.c:21504
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:21665
+#: cp/parser.c:21678
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "默认参数只允许出现在函数参数中"
 
-#: cp/parser.c:21683
+#: cp/parser.c:21696
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:21689
+#: cp/parser.c:21702
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:21691
+#: cp/parser.c:21704
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:22118
+#: cp/parser.c:22131
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:22138
+#: cp/parser.c:22151
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:22176
+#: cp/parser.c:22189
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:22190
+#: cp/parser.c:22203
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22215
+#: cp/parser.c:22228
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:22253
+#: cp/parser.c:22266
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22309 cp/parser.c:22435
+#: cp/parser.c:22322 cp/parser.c:22448
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "需要类名"
 
-#: cp/parser.c:22637
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:22640
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "结构定义后需要%<;%>"
 
-#: cp/parser.c:22643
+#: cp/parser.c:22656
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "联合定义后需要%<;%>"
 
-#: cp/parser.c:22999
+#: cp/parser.c:23012
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "需要%<{%>或%<:%>"
 
-#: cp/parser.c:23010
+#: cp/parser.c:23023
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "不能为类指定 %<override%>"
 
-#: cp/parser.c:23018
+#: cp/parser.c:23031
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:23025
+#: cp/parser.c:23038
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:23037
+#: cp/parser.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:23043
+#: cp/parser.c:23056
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:23101
+#: cp/parser.c:23114
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:23132
+#: cp/parser.c:23146
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/parser.c:23168
+#: cp/parser.c:23182
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/parser.c:23227
+#: cp/parser.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T的前一个定义"
 
-#: cp/parser.c:23317 cp/parser.c:28478
+#: cp/parser.c:23331 cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:23341
+#: cp/parser.c:23355
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23345
+#: cp/parser.c:23359
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:23591
+#: cp/parser.c:23605
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "声明友元时必须使用 class 关键字"
 
-#: cp/parser.c:23609
+#: cp/parser.c:23623
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:23627
+#: cp/parser.c:23641
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23738
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:23731
+#: cp/parser.c:23745
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: cp/parser.c:23744
+#: cp/parser.c:23758
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23889
+#: cp/parser.c:23903
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函数定义上有 pure 指定"
 
-#: cp/parser.c:23909
+#: cp/parser.c:23923
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:23956
+#: cp/parser.c:23970
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23984
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:24044
+#: cp/parser.c:24058
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "指定了无效的 AE 类型(%s)\n"
 
-#: cp/parser.c:24079
+#: cp/parser.c:24093
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/parser.c:24209
+#: cp/parser.c:24223
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "在基类限定中指定了多于一次的%<virtual%>"
 
-#: cp/parser.c:24229
+#: cp/parser.c:24243
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超过一个访问说明符在中 base-specified"
 
-#: cp/parser.c:24253
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:24256
+#: cp/parser.c:24270
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(基类隐式地是一个类型)"
 
-#: cp/parser.c:24350 cp/parser.c:24428
+#: cp/parser.c:24364 cp/parser.c:24442
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:24436
+#: cp/parser.c:24450
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/parser.c:24442
+#: cp/parser.c:24456
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "动态异常规格被不宜用在中 C++0x; 使用 %<noexcept%> 作为替代"
 
-#: cp/parser.c:24486
+#: cp/parser.c:24500
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:24525
+#: cp/parser.c:24539
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/parser.c:24636
+#: cp/parser.c:24650
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:25189
+#: cp/parser.c:25203
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25217
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要标识符"
 
-#: cp/parser.c:25287
+#: cp/parser.c:25301
 #, fuzzy, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:25291
+#: cp/parser.c:25305
 #, fuzzy, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:25328
+#: cp/parser.c:25342
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:25389
+#: cp/parser.c:25403
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25707
+#: cp/parser.c:25721
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25739
+#: cp/parser.c:25753
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:26446
+#: cp/parser.c:26467
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.c:26451
+#: cp/parser.c:26472
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.c:26455
+#: cp/parser.c:26476
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -49924,522 +50074,522 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26462
+#: cp/parser.c:26483
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.c:26811
+#: cp/parser.c:26832
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.c:26970
+#: cp/parser.c:26991
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:26975
+#: cp/parser.c:26996
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27066
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "启用乘法指令"
 
-#: cp/parser.c:27069
+#: cp/parser.c:27090
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/parser.c:27091
+#: cp/parser.c:27112
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.c:27100
+#: cp/parser.c:27121
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.c:27120
+#: cp/parser.c:27141
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:27224
+#: cp/parser.c:27245
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.c:27275
+#: cp/parser.c:27296
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "没有声明任何东西"
 
-#: cp/parser.c:27321
+#: cp/parser.c:27342
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.c:27629
+#: cp/parser.c:27650
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.c:27642
+#: cp/parser.c:27663
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.c:27937
+#: cp/parser.c:27958
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28097
+#: cp/parser.c:28118
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:28112
+#: cp/parser.c:28133
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.c:28246
+#: cp/parser.c:28267
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.c:28254
+#: cp/parser.c:28275
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: cp/parser.c:28259
+#: cp/parser.c:28280
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的标号%qD"
 
-#: cp/parser.c:28283
+#: cp/parser.c:28304
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.c:28335
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.c:28338
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.c:28341
+#: cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.c:28347
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.c:28350
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:28353
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.c:28365
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28419
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "于 %s 等待异动作业锁定\n"
 
-#: cp/parser.c:28430
+#: cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.c:28442
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.c:28445
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.c:28448
+#: cp/parser.c:28469
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.c:28454
+#: cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.c:28481
+#: cp/parser.c:28502
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:28751
+#: cp/parser.c:28772
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.c:28756
+#: cp/parser.c:28777
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28798
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28819
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.c:29041
+#: cp/parser.c:29062
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.c:29282 cp/parser.c:30599 cp/parser.c:30787
+#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.c:29351
+#: cp/parser.c:29372
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:29421
+#: cp/parser.c:29442
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 消息参数被预期"
 
-#: cp/parser.c:29452
+#: cp/parser.c:29473
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.c:29862
+#: cp/parser.c:29883
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.c:29937 cp/parser.c:29955
+#: cp/parser.c:29958 cp/parser.c:29976
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "%C处数组声明需要另外一维"
 
-#: cp/parser.c:29949 cp/parser.c:30014
+#: cp/parser.c:29970 cp/parser.c:30035
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:30057
+#: cp/parser.c:30078
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介于 Objective-C++ 方法"
 
-#: cp/parser.c:30263 cp/parser.c:30270 cp/parser.c:30277
+#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "不一致的实例变量指定"
 
-#: cp/parser.c:30392
+#: cp/parser.c:30413
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.c:30564
+#: cp/parser.c:30585
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "属性可能无法被指定的之前 %<@%D%>Objective-C++ 关键字"
 
-#: cp/parser.c:30571
+#: cp/parser.c:30592
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.c:30846 cp/parser.c:30853 cp/parser.c:30860
+#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "不能设置只读属性"
 
-#: cp/parser.c:31990
+#: cp/parser.c:32011
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.c:32703
+#: cp/parser.c:32724
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效还原标识符"
 
-#: cp/parser.c:34890
+#: cp/parser.c:34911
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:35210 cp/pt.c:16046
+#: cp/parser.c:35231 cp/pt.c:16392
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.c:35295
+#: cp/parser.c:35316
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: cp/parser.c:37500
+#: cp/parser.c:37521
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:37528
+#: cp/parser.c:37549
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:37540
+#: cp/parser.c:37561
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37641
+#: cp/parser.c:37662
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:37661 cp/semantics.c:5421
+#: cp/parser.c:37682 cp/semantics.c:5405
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37666 cp/semantics.c:5430
+#: cp/parser.c:37687 cp/semantics.c:5414
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37669 cp/pt.c:12611 cp/semantics.c:5436
+#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37672 cp/semantics.c:5442
+#: cp/parser.c:37693 cp/semantics.c:5426
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38026
+#: cp/parser.c:38047
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38036
+#: cp/parser.c:38057
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38371
+#: cp/parser.c:38392
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38414 cp/semantics.c:8587
+#: cp/parser.c:38435 cp/semantics.c:8575
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:38416 cp/semantics.c:8589
+#: cp/parser.c:38437 cp/semantics.c:8577
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:38610
+#: cp/parser.c:38631
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%>末尾有垃圾字符"
 
-#: cp/parser.c:38906
+#: cp/parser.c:38927
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:38938
+#: cp/parser.c:38959
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:39018
+#: cp/parser.c:39039
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.c:39274
+#: cp/parser.c:39295
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:39330
+#: cp/parser.c:39351
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
 
-#: cp/pt.c:302
+#: cp/pt.c:303
 #, gcc-internal-format
 msgid "data member %qD cannot be a member template"
 msgstr "数据成员%qD不能是成员模板"
 
-#: cp/pt.c:314
+#: cp/pt.c:315
 #, gcc-internal-format
 msgid "invalid member template declaration %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/pt.c:693
+#: cp/pt.c:694
 #, gcc-internal-format
 msgid "explicit specialization in non-namespace scope %qD"
 msgstr "显式特例化出现在非命名空间作用域%qD中"
 
-#: cp/pt.c:707
+#: cp/pt.c:708
 #, gcc-internal-format
 msgid "enclosing class templates are not explicitly specialized"
 msgstr "所包含的类模板并未被显式特例化"
 
-#: cp/pt.c:791
+#: cp/pt.c:792
 #, gcc-internal-format
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/pt.c:801
+#: cp/pt.c:802
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空间内对%qD的特例化"
 
-#: cp/pt.c:803 cp/pt.c:1030
+#: cp/pt.c:804 cp/pt.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "  from definition of %q#D"
 msgstr "  从%q+#D的定义"
 
-#: cp/pt.c:820
+#: cp/pt.c:821
 #, gcc-internal-format
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.c:940
+#: cp/pt.c:941
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "类名隐藏了模板的模板形参%qD"
 
-#: cp/pt.c:952
+#: cp/pt.c:953
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:955 cp/pt.c:1092
+#: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:987
+#: cp/pt.c:988
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT的实例化在特例化之后"
 
-#: cp/pt.c:1028
+#: cp/pt.c:1029
 #, gcc-internal-format
 msgid "specializing %q#T in different namespace"
 msgstr "在不同命名空间中特例化%q#T"
@@ -50446,67 +50596,67 @@
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.c:1070
+#: cp/pt.c:1071
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT的实例化在%qT的特例化之后"
 
-#: cp/pt.c:1088
+#: cp/pt.c:1089
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/pt.c:1551
+#: cp/pt.c:1552
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:1953 cp/semantics.c:5290
+#: cp/pt.c:1954 cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s%#D"
 
-#: cp/pt.c:2088
+#: cp/pt.c:2089
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/pt.c:2093
+#: cp/pt.c:2094
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:2364
+#: cp/pt.c:2365
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "%2$q+D的模板标识符%1$qD不匹配任何模板声明"
 
-#: cp/pt.c:2367
+#: cp/pt.c:2368
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "发现 %d 个%<template<>%>，需要 %d 来特例化一个成员函数模板"
 
-#: cp/pt.c:2378
+#: cp/pt.c:2379
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:2588
+#: cp/pt.c:2589
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.c:2597
+#: cp/pt.c:2598
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:2603
+#: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.c:2627
+#: cp/pt.c:2628
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
@@ -50513,24 +50663,24 @@
 msgstr "在初次使用后显式特例化%qD"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.c:2632
+#: cp/pt.c:2633
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.c:2729
+#: cp/pt.c:2730
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/pt.c:2733
+#: cp/pt.c:2734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:2734
+#: cp/pt.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "以前在此声明过"
@@ -50537,58 +50687,58 @@
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
-#: cp/pt.c:2823 cp/pt.c:2882
+#: cp/pt.c:2824 cp/pt.c:2883
 #, gcc-internal-format
 msgid "template-id %qD in declaration of primary template"
 msgstr "模板标识符%qD出现在基本模板的声明中"
 
-#: cp/pt.c:2836
+#: cp/pt.c:2837
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "显式初始化中出现了模板参数列表"
 
-#: cp/pt.c:2842
+#: cp/pt.c:2843
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "为显式实例化提供的定义"
 
-#: cp/pt.c:2850
+#: cp/pt.c:2851
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:2853
+#: cp/pt.c:2854
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太少"
 
-#: cp/pt.c:2855
+#: cp/pt.c:2856
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD的显式特例化必须由%<template <>%>引入"
 
-#: cp/pt.c:2861
+#: cp/pt.c:2862
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:2892
+#: cp/pt.c:2893
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:2895
+#: cp/pt.c:2896
 #, fuzzy, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.c:2928
+#: cp/pt.c:2929
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "显式特例化时指定了默认参数"
 
-#: cp/pt.c:2966
+#: cp/pt.c:2967
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD不是一个模板函数"
@@ -50601,161 +50751,161 @@
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.c:3028
+#: cp/pt.c:3029
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隐式声明的特殊成员函数"
 
-#: cp/pt.c:3044
+#: cp/pt.c:3045
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/pt.c:3075
+#: cp/pt.c:3076
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/pt.c:3078
+#: cp/pt.c:3079
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/pt.c:3186
+#: cp/pt.c:3187
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.c:3620
+#: cp/pt.c:3621
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: cp/pt.c:3941
+#: cp/pt.c:3942
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基类初始值设定展开%<%T%>不包括参数包"
 
-#: cp/pt.c:4009
+#: cp/pt.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "展开样式%<%T%>不包括参数包"
 
-#: cp/pt.c:4011
+#: cp/pt.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "展开样式%<%E%>不包括参数包"
 
-#: cp/pt.c:4062
+#: cp/pt.c:4063
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "参数包未能在%<...%>中被展开："
 
-#: cp/pt.c:4079 cp/pt.c:4834
+#: cp/pt.c:4080 cp/pt.c:4835
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "       %qD"
 
-#: cp/pt.c:4081
+#: cp/pt.c:4082
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <匿名>"
 
-#: cp/pt.c:4207
+#: cp/pt.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.c:4210
+#: cp/pt.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.c:4212
+#: cp/pt.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/pt.c:4770
+#: cp/pt.c:4771
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:4829
+#: cp/pt.c:4830
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到模板参数："
 
-#: cp/pt.c:4853
+#: cp/pt.c:4854
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4857
+#: cp/pt.c:4858
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4861 cp/pt.c:4872
+#: cp/pt.c:4862 cp/pt.c:4873
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:4869
+#: cp/pt.c:4870
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4884
+#: cp/pt.c:4885
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4886
+#: cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:4933
+#: cp/pt.c:4934
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:4936
+#: cp/pt.c:4937
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "参数包实参%qT必须出现在模板实参表末尾"
 
-#: cp/pt.c:4957
+#: cp/pt.c:4958
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/pt.c:5003
+#: cp/pt.c:5004
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "模板实参%2$qE的类型%1$qT取决于模板参数"
 
-#: cp/pt.c:5065
+#: cp/pt.c:5066
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:5069
+#: cp/pt.c:5070
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:5246
+#: cp/pt.c:5247
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD没有默认参数"
@@ -50763,49 +50913,49 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5268
+#: cp/pt.c:5269
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:5304
+#: cp/pt.c:5305
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5307
+#: cp/pt.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5310
+#: cp/pt.c:5311
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "只有指定了 -std=c++0x 或 -std=gnu++0x 时才能在函数模板中使用默认参数"
 
-#: cp/pt.c:5313
+#: cp/pt.c:5314
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "默认参数不能用在部分特例化中"
 
-#: cp/pt.c:5316 cp/pt.c:5374
+#: cp/pt.c:5317 cp/pt.c:5375
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:5488
+#: cp/pt.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "形参%qD被声明为 void"
 
-#: cp/pt.c:5495
+#: cp/pt.c:5496
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "模板类没有名字"
 
-#: cp/pt.c:5503
+#: cp/pt.c:5504
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
@@ -50815,64 +50965,64 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5525
+#: cp/pt.c:5526
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD模板声明无效"
 
-#: cp/pt.c:5668
+#: cp/pt.c:5669
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "对非模板%q#D的模板定义"
 
-#: cp/pt.c:5711
+#: cp/pt.c:5712
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 级的%q#D模板参数，却给出了 %d 级"
 
-#: cp/pt.c:5725
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.c:5728
+#: cp/pt.c:5729
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%2$q#T得到了 %1$d 个模板参数"
 
-#: cp/pt.c:5730
+#: cp/pt.c:5731
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "但实际需要 %d 个"
 
-#: cp/pt.c:5751
+#: cp/pt.c:5752
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:5754
+#: cp/pt.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用 template<> 来显式特例化"
 
-#: cp/pt.c:5881
+#: cp/pt.c:5882
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT不是一个模板类型"
 
-#: cp/pt.c:5894
+#: cp/pt.c:5895
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD的声明中没有 template 限定"
 
-#: cp/pt.c:5905
+#: cp/pt.c:5906
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "重声明为具有 %d 个模板参数"
 
-#: cp/pt.c:5909
+#: cp/pt.c:5910
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -50880,12 +51030,12 @@
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "先前的声明%q+D使用了 %d 个模板参数"
 
-#: cp/pt.c:5946
+#: cp/pt.c:5947
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "模板形参%q+#D"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5948
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
@@ -50894,416 +51044,422 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5957
+#: cp/pt.c:5958
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:5959
+#: cp/pt.c:5960
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:5987
+#: cp/pt.c:5988
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.c:5990
+#: cp/pt.c:5991
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:6249 cp/pt.c:6317
+#: cp/pt.c:6250 cp/pt.c:6318
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.c:6252
+#: cp/pt.c:6253
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6255
+#: cp/pt.c:6256
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6267
+#: cp/pt.c:6268
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6271
+#: cp/pt.c:6272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6320
+#: cp/pt.c:6321
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必须是格式为‘&X::Y’的成员指针"
 
-#: cp/pt.c:6322
+#: cp/pt.c:6323
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/pt.c:6382
+#: cp/pt.c:6383
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:6391
+#: cp/pt.c:6392
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  类型 %qT 和 %qT 有不兼容的 cv-qualifiers"
 
-#: cp/pt.c:6400
+#: cp/pt.c:6401
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/pt.c:6409
+#: cp/pt.c:6410
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/pt.c:6420
+#: cp/pt.c:6421
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6430
+#: cp/pt.c:6431
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/pt.c:6439
+#: cp/pt.c:6440
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/pt.c:6451
+#: cp/pt.c:6452
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/pt.c:6455
+#: cp/pt.c:6456
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 冲突值用于 non-type 参数 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6466
+#: cp/pt.c:6467
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6477
+#: cp/pt.c:6478
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:6489
+#: cp/pt.c:6490
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/pt.c:6520
+#: cp/pt.c:6521
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/pt.c:6533
+#: cp/pt.c:6534
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/pt.c:6537
+#: cp/pt.c:6538
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "派生联合%qT无效"
 
-#: cp/pt.c:6548
+#: cp/pt.c:6549
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板参数的模板模板参数是不一致与其他 deduced 模板参数"
 
-#: cp/pt.c:6558
+#: cp/pt.c:6559
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/pt.c:6568
+#: cp/pt.c:6569
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6608
+#: cp/pt.c:6609
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE不是类型%qT的有效模板实参，因为字面字符串不能用在此上下文中"
 
-#: cp/pt.c:6757
+#: cp/pt.c:6758
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6771
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6832
+#: cp/pt.c:6833
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.c:6840
+#: cp/pt.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6856
+#: cp/pt.c:6857
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6863
+#: cp/pt.c:6864
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6872
+#: cp/pt.c:6873
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6887
+#: cp/pt.c:6888
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6896
+#: cp/pt.c:6897
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6903
+#: cp/pt.c:6904
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6932
+#: cp/pt.c:6933
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.c:6940
+#: cp/pt.c:6941
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.c:6958
+#: cp/pt.c:6959
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.c:6974
+#: cp/pt.c:6975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为它没有外部链接"
 
-#: cp/pt.c:6985
+#: cp/pt.c:6986
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:7035
+#: cp/pt.c:7036
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.c:7037
+#: cp/pt.c:7038
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.c:7091
+#: cp/pt.c:7092
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:7653
+#: cp/pt.c:7654
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:7669
+#: cp/pt.c:7670
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:7804
+#: cp/pt.c:7805
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.c:7833
+#: cp/pt.c:7834
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.c:7838
+#: cp/pt.c:7839
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.c:7854 cp/pt.c:7876 cp/pt.c:7930
+#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:7859
+#: cp/pt.c:7860
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.c:7864
+#: cp/pt.c:7865
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.c:7867
+#: cp/pt.c:7868
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:7881
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.c:7884
+#: cp/pt.c:7885
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.c:7934
+#: cp/pt.c:7935
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
 
-#: cp/pt.c:7948
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:7951
+#: cp/pt.c:7952
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:8011
+#: cp/pt.c:8012
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.c:8148 cp/pt.c:8464
+#: cp/pt.c:8149 cp/pt.c:8465
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:8163 cp/pt.c:8297
+#: cp/pt.c:8164 cp/pt.c:8298
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8293
+#: cp/pt.c:8294
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8302
+#: cp/pt.c:8303
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:8327
+#: cp/pt.c:8328
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8331
+#: cp/pt.c:8332
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8430
+#: cp/pt.c:8431
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8787
+#: cp/pt.c:9054
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D声明为模板"
 
-#: cp/pt.c:8954
+#: cp/pt.c:9221
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.c:8956
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.c:9079
+#: cp/pt.c:9346
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "内部一致性错误"
 
-#: cp/pt.c:9428
+#: cp/pt.c:9697
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:9865
+#: cp/pt.c:10125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:11393
+#: cp/pt.c:11202
+#, fuzzy, gcc-internal-format
+#| msgid "flexible array member in union"
+msgid "flexible array member %qD in union"
+msgstr "联合和可变数组成员"
+
+#: cp/pt.c:11691
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11824
+#: cp/pt.c:12160
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.c:11827
+#: cp/pt.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.c:12414
+#: cp/pt.c:12747
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定义%q#D的默认参数"
@@ -51321,278 +51477,278 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13375
+#: cp/pt.c:13708
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.c:13548
+#: cp/pt.c:13881
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.c:13550
+#: cp/pt.c:13883
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.c:13668
+#: cp/pt.c:14001
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.c:13670
+#: cp/pt.c:14003
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.c:13710
+#: cp/pt.c:14043
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/pt.c:14304
+#: cp/pt.c:14637
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.c:14306
+#: cp/pt.c:14639
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.c:14308
+#: cp/pt.c:14641
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.c:14321
+#: cp/pt.c:14654
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.c:14324
+#: cp/pt.c:14657
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.c:14372
+#: cp/pt.c:14705
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.c:14378
+#: cp/pt.c:14711
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.c:14384
+#: cp/pt.c:14717
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.c:14450
+#: cp/pt.c:14783
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/pt.c:14483
+#: cp/pt.c:14816
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.c:14520
+#: cp/pt.c:14853
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.c:14528
+#: cp/pt.c:14861
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.c:14592
+#: cp/pt.c:14925
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14667
+#: cp/pt.c:15000
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.c:14845
+#: cp/pt.c:15178
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.c:14860
+#: cp/pt.c:15193
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.c:14862
+#: cp/pt.c:15195
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.c:15052
+#: cp/pt.c:15394
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.c:15537 cp/pt.c:17017
+#: cp/pt.c:15883 cp/pt.c:17386
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.c:15541 cp/pt.c:17021
+#: cp/pt.c:15887 cp/pt.c:17390
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.c:17961
+#: cp/pt.c:18334
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.c:17989
+#: cp/pt.c:18362
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.c:17994
+#: cp/pt.c:18367
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:17997
+#: cp/pt.c:18370
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:18002
+#: cp/pt.c:18375
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.c:18339
+#: cp/pt.c:18712
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.c:18342
+#: cp/pt.c:18715
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.c:18653
+#: cp/pt.c:19026
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.c:18655
+#: cp/pt.c:19028
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:18665
+#: cp/pt.c:19038
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.c:18680
+#: cp/pt.c:19053
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.c:18698
+#: cp/pt.c:19071
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.c:22624
+#: cp/pt.c:22972
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:22626
+#: cp/pt.c:22974
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:22632
+#: cp/pt.c:22980
 #, fuzzy
 msgid "%s %#qS"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.c:22656 cp/pt.c:22743
+#: cp/pt.c:23004 cp/pt.c:23091
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:22675
+#: cp/pt.c:23023
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.c:22681 cp/pt.c:22738
+#: cp/pt.c:23029 cp/pt.c:23086
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.c:22686
+#: cp/pt.c:23034
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.c:22694
+#: cp/pt.c:23042
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.c:22730
+#: cp/pt.c:23078
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.c:22753 cp/pt.c:22838
+#: cp/pt.c:23101 cp/pt.c:23187
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.c:22758 cp/pt.c:22855
+#: cp/pt.c:23106 cp/pt.c:23204
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.c:22814
+#: cp/pt.c:23163
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:22816
+#: cp/pt.c:23165
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:22825
+#: cp/pt.c:23174
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:22843
+#: cp/pt.c:23192
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.c:22889
+#: cp/pt.c:23238
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/pt.c:23186
+#: cp/pt.c:23536
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -51605,113 +51761,118 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23492
+#: cp/pt.c:23842
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.c:23693
+#: cp/pt.c:24043
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:24062
+#: cp/pt.c:24418
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.c:24064
+#: cp/pt.c:24420
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:25367
+#: cp/pt.c:25723
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/pt.c:25605
+#: cp/pt.c:25961
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.c:26075
+#: cp/pt.c:26440
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.c:26213
+#: cp/pt.c:26586
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26220
+#: cp/pt.c:26593
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:26234
+#: cp/pt.c:26607
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:26241
+#: cp/pt.c:26614
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
-#: cp/pt.c:26303
+#: cp/pt.c:26676
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26306
+#: cp/pt.c:26679
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26338
+#: cp/pt.c:26711
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26373
+#: cp/pt.c:26746
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:26375
+#: cp/pt.c:26748
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:26408
+#: cp/pt.c:26781
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26412
+#: cp/pt.c:26785
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:26416
+#: cp/pt.c:26789
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:26420
+#: cp/pt.c:26793
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
+#: cp/pt.c:26912
+#, fuzzy, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr "模板第 %d 个参数无效"
+
 #: cp/repo.c:113
 #, gcc-internal-format
 msgid "-frepo must be used with -c"
@@ -51924,7 +52085,7 @@
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "伪析构函数名的限定作用域无效"
 
-#: cp/semantics.c:2656 cp/typeck.c:2599
+#: cp/semantics.c:2656 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的类型%qT不匹配析构函数名 ~%qT"
@@ -51974,7 +52135,7 @@
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.c:3443 cp/semantics.c:9281
+#: cp/semantics.c:3443 cp/semantics.c:9269
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
@@ -52047,299 +52208,300 @@
 msgstr "%qD不是一个枚举名"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4025
+#: cp/semantics.c:4009
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/semantics.c:4054
+#: cp/semantics.c:4038
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "不能为析构函数%<~%T%>使用%<offsetof%>"
 
-#: cp/semantics.c:4063
+#: cp/semantics.c:4052
 #, gcc-internal-format
-msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
-msgstr ""
-
-#: cp/semantics.c:4071
-#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4077
+#: cp/semantics.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
+msgid "cannot apply %<offsetof%> to member function"
+msgstr "不能为成员函数%qD应用%<offsetof%>"
+
+#: cp/semantics.c:4061
+#, fuzzy, gcc-internal-format
+#| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4089
-#, gcc-internal-format
-msgid "offsetof within non-standard-layout type %qT is undefined"
-msgstr ""
+#: cp/semantics.c:4072
+#, fuzzy, gcc-internal-format
+msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
+msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/semantics.c:4599 cp/semantics.c:6081 cp/semantics.c:6152
-#: cp/semantics.c:6195 cp/semantics.c:6545 cp/semantics.c:6644
-#: cp/semantics.c:6787
+#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
+#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
+#: cp/semantics.c:6775
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5287
+#: cp/semantics.c:5271
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/semantics.c:5560
+#: cp/semantics.c:5544
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:5608
+#: cp/semantics.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE的类型对%<reduction%>无效"
 
-#: cp/semantics.c:5719
+#: cp/semantics.c:5707
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5953
+#: cp/semantics.c:5941
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5967
+#: cp/semantics.c:5955
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5989
+#: cp/semantics.c:5977
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6092
+#: cp/semantics.c:6080
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6164
+#: cp/semantics.c:6152
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD在%<firstprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6207
+#: cp/semantics.c:6195
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6252
+#: cp/semantics.c:6240
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6266
+#: cp/semantics.c:6254
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6300
+#: cp/semantics.c:6288
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6303
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6307
+#: cp/semantics.c:6295
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6329
+#: cp/semantics.c:6317
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6333
+#: cp/semantics.c:6321
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6338
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6388
+#: cp/semantics.c:6376
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6418
+#: cp/semantics.c:6406
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6431
+#: cp/semantics.c:6419
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:6450
+#: cp/semantics.c:6438
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6478
+#: cp/semantics.c:6466
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6507
+#: cp/semantics.c:6495
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6528
+#: cp/semantics.c:6516
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6555
+#: cp/semantics.c:6543
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6569
+#: cp/semantics.c:6557
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6575
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:6588
+#: cp/semantics.c:6576
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6637
+#: cp/semantics.c:6625
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6922
+#: cp/semantics.c:6910
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "太多的%qs子句"
 
-#: cp/semantics.c:6926
+#: cp/semantics.c:6914
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6991
+#: cp/semantics.c:6979
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7020
+#: cp/semantics.c:7008
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7049
+#: cp/semantics.c:7037
 #, fuzzy, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7078
+#: cp/semantics.c:7066
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:7117
+#: cp/semantics.c:7105
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7536
+#: cp/semantics.c:7524
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.c:7550
+#: cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.c:7755
+#: cp/semantics.c:7743
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.c:8183
+#: cp/semantics.c:8171
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:8410 cp/semantics.c:8420
+#: cp/semantics.c:8398 cp/semantics.c:8408
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:8714
+#: cp/semantics.c:8702
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:8716
+#: cp/semantics.c:8704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:8721
+#: cp/semantics.c:8709
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.c:8751
+#: cp/semantics.c:8739
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.c:8779
+#: cp/semantics.c:8767
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/semantics.c:9320
+#: cp/semantics.c:9308
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.c:9373
+#: cp/semantics.c:9361
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.c:9375
+#: cp/semantics.c:9363
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9393
+#: cp/semantics.c:9381
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -52466,12 +52628,12 @@
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:5438
+#: cp/tree.c:5440
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "PRINT_OPERAND 空指针"
 
-#: cp/tree.c:5451
+#: cp/tree.c:5453
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失败，于 %s:%d"
@@ -52533,760 +52695,754 @@
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "不同类型 %T 和 %T 有相同的正规类型节点"
 
-#: cp/typeck.c:1617
+#: cp/typeck.c:1620
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs用于成员函数无效"
 
-#: cp/typeck.c:1703
+#: cp/typeck.c:1708
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "对位段使用%<sizeof%>无效"
 
-#: cp/typeck.c:1711
+#: cp/typeck.c:1716
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<sizeof%>应用到函数类型的表达式上"
 
-#: cp/typeck.c:1760
+#: cp/typeck.c:1765
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "对位段使用%<__alignof%>无效"
 
-#: cp/typeck.c:1771
+#: cp/typeck.c:1776
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<__alignof%>应用到函数类型的表达式上"
 
-#: cp/typeck.c:1848
+#: cp/typeck.c:1853
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/typeck.c:1893
+#: cp/typeck.c:1898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/typeck.c:2067
+#: cp/typeck.c:2072
 #, fuzzy, gcc-internal-format
 msgid "taking address of temporary array"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:2233
+#: cp/typeck.c:2238
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.c:2237
+#: cp/typeck.c:2242
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.c:2371 cp/typeck.c:2812
+#: cp/typeck.c:2376 cp/typeck.c:2817
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.c:2375 cp/typeck.c:2816
+#: cp/typeck.c:2380 cp/typeck.c:2821
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.c:2406
+#: cp/typeck.c:2411
 #, gcc-internal-format
 msgid "invalid use of nonstatic data member %qE"
 msgstr "对非静态数据成员%qE的使用无效"
 
-#: cp/typeck.c:2465
+#: cp/typeck.c:2470
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "对 NULL 对象非静态数据成员%qD的访问无效"
 
-#: cp/typeck.c:2614
+#: cp/typeck.c:2619
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "对象类型%qT的析构函数名~%qT不匹配"
 
-#: cp/typeck.c:2623
+#: cp/typeck.c:2628
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被析构的类型是%qT，但析构函数却使用了%qT"
 
-#: cp/typeck.c:2740
+#: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
-#: cp/typeck.c:2846 cp/typeck.c:2872
+#: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/typeck.c:2911
+#: cp/typeck.c:2916
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT不是%qT的基类"
 
-#: cp/typeck.c:2947
+#: cp/typeck.c:2952
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2954
+#: cp/typeck.c:2959
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.c:2983
+#: cp/typeck.c:2988
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD不是一个成员模板函数"
 
-#: cp/typeck.c:3151
+#: cp/typeck.c:3167
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT不是一个指向对象的类型"
 
-#: cp/typeck.c:3182
+#: cp/typeck.c:3198
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "对成员指针数组索引的使用无效"
 
-#: cp/typeck.c:3185
+#: cp/typeck.c:3201
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "对成员指针使用一元%<*%>非法"
 
-#: cp/typeck.c:3188
+#: cp/typeck.c:3204
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "隐式转换成员指针用法无效"
 
-#: cp/typeck.c:3191
+#: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.c:3255
+#: cp/typeck.c:3271
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "数组引用缺少下标"
 
-#: cp/typeck.c:3350
+#: cp/typeck.c:3366
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/typeck.c:3384
+#: cp/typeck.c:3400
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: cp/typeck.c:3457
+#: cp/typeck.c:3473
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用%qE时缺少对象"
 
-#: cp/typeck.c:3688
+#: cp/typeck.c:3704
 #, fuzzy, gcc-internal-format
 #| msgid "cannot disable built-in function %qs"
 msgid "cannot call function %qD"
 msgstr "无法禁用内建函数%qs"
 
-#: cp/typeck.c:3703
+#: cp/typeck.c:3719
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允许在程序里调用%<::main%>"
 
-#: cp/typeck.c:3724
+#: cp/typeck.c:3740
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必须用%<.*%>or%<->*%>调用%<%E (...)%>中的成员函数指针，例如%<(... ->* %E) (...)%>"
 
-#: cp/typeck.c:3741
+#: cp/typeck.c:3757
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3744
+#: cp/typeck.c:3760
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3747
+#: cp/typeck.c:3763
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.c:3804
+#: cp/typeck.c:3820
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:3805
+#: cp/typeck.c:3821
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:3810
+#: cp/typeck.c:3826
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/typeck.c:3811
+#: cp/typeck.c:3827
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太少"
 
-#: cp/typeck.c:3817
+#: cp/typeck.c:3833
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:3818
+#: cp/typeck.c:3834
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:3828
+#: cp/typeck.c:3844
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.c:3829
+#: cp/typeck.c:3845
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.c:3832
+#: cp/typeck.c:3848
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.c:3833
+#: cp/typeck.c:3849
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.c:3912
+#: cp/typeck.c:3928
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: cp/typeck.c:3915
+#: cp/typeck.c:3931
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "形参 %P 的类型%qT不完全"
 
-#: cp/typeck.c:4159
+#: cp/typeck.c:4175
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD的地址永远不会为 NULL"
 
-#: cp/typeck.c:4170
+#: cp/typeck.c:4186
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: cp/typeck.c:4288 cp/typeck.c:4299
+#: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定从重载函数转换到类型%qT"
 
-#: cp/typeck.c:4345
+#: cp/typeck.c:4361
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算术表达式中使用了 NULL"
 
-#: cp/typeck.c:4702
+#: cp/typeck.c:4718
 #, gcc-internal-format
 msgid "left rotate count is negative"
 msgstr "循环左移次数为负"
 
-#: cp/typeck.c:4703
+#: cp/typeck.c:4719
 #, gcc-internal-format
 msgid "right rotate count is negative"
 msgstr "循环右移次数为负"
 
-#: cp/typeck.c:4709
+#: cp/typeck.c:4725
 #, gcc-internal-format
 msgid "left rotate count >= width of type"
 msgstr "循环左移次数大于或等于类型宽度"
 
-#: cp/typeck.c:4710
+#: cp/typeck.c:4726
 #, gcc-internal-format
 msgid "right rotate count >= width of type"
 msgstr "循环右移次数大于或等于类型宽度"
 
-#: cp/typeck.c:4793 cp/typeck.c:4801 cp/typeck.c:5081 cp/typeck.c:5089
+#: cp/typeck.c:4809 cp/typeck.c:4817 cp/typeck.c:5097 cp/typeck.c:5105
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允许比较指针和整数的值"
 
-#: cp/typeck.c:5003 cp/typeck.c:5016
+#: cp/typeck.c:5019 cp/typeck.c:5032
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/typeck.c:5117
+#: cp/typeck.c:5133
 #, gcc-internal-format
 msgid "unordered comparison on non-floating point argument"
 msgstr "非浮点实参间的无效比较"
 
-#: cp/typeck.c:5162
+#: cp/typeck.c:5178
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/typeck.c:5172
+#: cp/typeck.c:5188
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "操作数类型%qT和%qT对双目%qO而言无效"
 
-#: cp/typeck.c:5476
+#: cp/typeck.c:5492
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允许在减法中使用类型为%<void *%>的指针"
 
-#: cp/typeck.c:5484
+#: cp/typeck.c:5500
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允许在减法中使用函数指针"
 
-#: cp/typeck.c:5492
+#: cp/typeck.c:5508
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允许在减法中使用指向方法的指针"
 
-#: cp/typeck.c:5537
+#: cp/typeck.c:5553
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指针算术中使用指向不完全类型的指针无效"
 
-#: cp/typeck.c:5612
+#: cp/typeck.c:5628
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "取构造函数%qE的地址"
 
-#: cp/typeck.c:5613
+#: cp/typeck.c:5629
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.c:5629
+#: cp/typeck.c:5645
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用%qE形成成员函数指针的用法无效"
 
-#: cp/typeck.c:5632
+#: cp/typeck.c:5648
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "需要一个限定的标识符"
 
-#: cp/typeck.c:5639
+#: cp/typeck.c:5655
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "%qE两边的括号不能用来构造一个成员函数指针"
 
 #. An expression like &memfn.
-#: cp/typeck.c:5815
+#: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过提取一个未限定的或带括号的非静态成员函数的地址来形成一个成员函数指针。请使用%<&%T::%D%>"
 
-#: cp/typeck.c:5820
+#: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过取已绑定的成员函数的地址来构造成员函数指针。请改用%<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:5857
+#: cp/typeck.c:5873
 #, gcc-internal-format
 msgid "taking address of temporary"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.c:5859
+#: cp/typeck.c:5875
 #, fuzzy, gcc-internal-format
 msgid "taking address of xvalue (rvalue reference)"
 msgstr "右值的引用用作左值"
 
-#: cp/typeck.c:5876
+#: cp/typeck.c:5892
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允许取函数%<::main%>的地址"
 
-#: cp/typeck.c:5946
+#: cp/typeck.c:5949
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能创建指向引用成员%qD的指针"
 
-#: cp/typeck.c:5966
+#: cp/typeck.c:5969
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "无法取得位段%qD的地址"
 
-#: cp/typeck.c:6112
+#: cp/typeck.c:6118
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type bool"
 msgstr "取一个类型为%<void%>的表达式的地址"
 
-#: cp/typeck.c:6113
+#: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.c:6234
+#: cp/typeck.c:6240
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ 不允许枚举自增"
 
-#: cp/typeck.c:6235
+#: cp/typeck.c:6241
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/typeck.c:6251
+#: cp/typeck.c:6257
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: cp/typeck.c:6252
+#: cp/typeck.c:6258
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/typeck.c:6263
+#: cp/typeck.c:6269
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自增"
 
-#: cp/typeck.c:6264
+#: cp/typeck.c:6270
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自减"
 
-#: cp/typeck.c:6299
+#: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.c:6308
+#: cp/typeck.c:6314
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.c:6315
+#: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.c:6496
+#: cp/typeck.c:6502
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: cp/typeck.c:6518
+#: cp/typeck.c:6524
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求显式寄存器变量%qD的地址。"
 
-#: cp/typeck.c:6523
+#: cp/typeck.c:6529
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "请求声明为%<register%>的%qD的地址"
 
-#: cp/typeck.c:6598
+#: cp/typeck.c:6604
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/typeck.c:6610
+#: cp/typeck.c:6616
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6614
+#: cp/typeck.c:6620
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6618
+#: cp/typeck.c:6624
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6655
+#: cp/typeck.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.c:6741
+#: cp/typeck.c:6747
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/typeck.c:6774
+#: cp/typeck.c:6780
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的类型转换丢失了限定符"
 
-#: cp/typeck.c:6780
+#: cp/typeck.c:6786
 #, gcc-internal-format
 msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 static_cast 丢失了限定符"
 
-#: cp/typeck.c:6786
+#: cp/typeck.c:6792
 #, gcc-internal-format
 msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 reinterpret_cast 丢失了限定符"
 
-#: cp/typeck.c:6807
+#: cp/typeck.c:6813
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:6820
+#: cp/typeck.c:6826
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/typeck.c:7243
+#: cp/typeck.c:7249
 #, gcc-internal-format
 msgid "invalid static_cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 static_cast 无效"
 
-#: cp/typeck.c:7269
+#: cp/typeck.c:7275
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "从%qT转换到%qT"
 
-#: cp/typeck.c:7325
+#: cp/typeck.c:7343
 #, gcc-internal-format
 msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/typeck.c:7395
+#: cp/typeck.c:7413
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "从%qT到%qT的转换损失精度"
 
-#: cp/typeck.c:7420
+#: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.c:7431
+#: cp/typeck.c:7449
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "在不同的成员指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.c:7452 cp/typeck.c:7630
+#: cp/typeck.c:7470 cp/typeck.c:7652
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "从%qT到%qT的转换增大了目标类型的对齐需求"
 
-#: cp/typeck.c:7468
+#: cp/typeck.c:7486
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允许在函数指针和对象指针间进行转换"
 
-#: cp/typeck.c:7482
+#: cp/typeck.c:7500
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck.c:7546
+#: cp/typeck.c:7568
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它既不是指针，也不是引用，也不是数据成员指针"
 
-#: cp/typeck.c:7555
+#: cp/typeck.c:7577
 #, gcc-internal-format
 msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它是一个指针函数类型的指针或引用"
 
-#: cp/typeck.c:7596
+#: cp/typeck.c:7618
 #, gcc-internal-format
 msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:7665
+#: cp/typeck.c:7687
 #, gcc-internal-format
 msgid "invalid const_cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.c:7761 cp/typeck.c:7769
+#: cp/typeck.c:7783 cp/typeck.c:7791
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允许转换为数组类型%qT"
 
-#: cp/typeck.c:7778
+#: cp/typeck.c:7800
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.c:8091
+#: cp/typeck.c:8113
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "在求%<%Q(%#T, %#T)%>值时"
 
-#: cp/typeck.c:8151
+#: cp/typeck.c:8173
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "初始值设定中数组索引不是常数"
 
-#: cp/typeck.c:8177
+#: cp/typeck.c:8199
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/typeck.c:8191
+#: cp/typeck.c:8213
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "数组被用作初始值设定"
 
-#: cp/typeck.c:8193
+#: cp/typeck.c:8215
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "无效的数组赋值"
 
-#: cp/typeck.c:8327
+#: cp/typeck.c:8349
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "在成员函数指针转换中"
 
-#: cp/typeck.c:8341
+#: cp/typeck.c:8363
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成员指针转换经由虚基类%qT"
 
-#: cp/typeck.c:8388 cp/typeck.c:8407
+#: cp/typeck.c:8410 cp/typeck.c:8429
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "在成员指针转换中"
 
-#: cp/typeck.c:8488
+#: cp/typeck.c:8510
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/typeck.c:8786
+#: cp/typeck.c:8812 cp/typeck.c:8829
 #, fuzzy
-#| msgid "cannot convert %qT to %qT for argument %qP to %qD"
-msgid "cannot convert %qH to %qI for argument %qP to %qD"
-msgstr "不能将%4$qD的实参%3$qP从%1$qT转换到%2$qT"
+#| msgid "cannot convert %qT to %qT"
+msgid "cannot convert %qH to %qI"
+msgstr "不能将%qT转换为%qT"
 
-#: cp/typeck.c:8792
+#: cp/typeck.c:8821
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "不能在参数默认时将%qT转换为%qT"
 
-#: cp/typeck.c:8796
+#: cp/typeck.c:8825
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "不能在传参时将%qT转换为%qT"
 
-#: cp/typeck.c:8800
+#: cp/typeck.c:8833
 #, fuzzy
-#| msgid "cannot convert %qT to %qT"
-msgid "cannot convert %qH to %qI"
-msgstr "不能将%qT转换为%qT"
-
-#: cp/typeck.c:8804
-#, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/typeck.c:8808
+#: cp/typeck.c:8837
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "不能在返回时将%qT转换为%qT"
 
-#: cp/typeck.c:8812
+#: cp/typeck.c:8841
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "不能在赋值时将%qT转换为%qT"
 
-#: cp/typeck.c:8825
+#: cp/typeck.c:8854
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "源有不完全的类类型"
 
-#: cp/typeck.c:8843
+#: cp/typeck.c:8872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8847
+#: cp/typeck.c:8876
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: cp/typeck.c:8852
+#: cp/typeck.c:8881
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8857
+#: cp/typeck.c:8886
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8896
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:8962
+#: cp/typeck.c:8991
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在传递%2$q+D的第 %1$P 个实参时"
 
-#: cp/typeck.c:9021
+#: cp/typeck.c:9050
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.c:9028
+#: cp/typeck.c:9057
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "返回了一个非左值的引用"
 
-#: cp/typeck.c:9043
+#: cp/typeck.c:9072
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "返回了对局部变量的%q+D的引用"
 
-#: cp/typeck.c:9047
+#: cp/typeck.c:9076
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:9051
+#: cp/typeck.c:9080
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:9090
+#: cp/typeck.c:9119
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "析构函数返回值"
@@ -53293,57 +53449,57 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:9098
+#: cp/typeck.c:9127
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能从构造函数的异常处理中返回"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:9101
+#: cp/typeck.c:9130
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "构造函数返回值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:9135 cp/typeck.c:9181
+#: cp/typeck.c:9164 cp/typeck.c:9210
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:9143
+#: cp/typeck.c:9172
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck.c:9162
+#: cp/typeck.c:9191
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/typeck.c:9165
+#: cp/typeck.c:9194
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/typeck.c:9201
+#: cp/typeck.c:9230
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:9230
+#: cp/typeck.c:9259
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%>不能返回 NULL，除非它被声明为%<throw()%>(或 -fcheck-new 起作用)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9855
+#: cp/typeck.c:9884
 #, fuzzy, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "右值的引用用作左值"
 
-#: cp/typeck.c:9857
+#: cp/typeck.c:9886
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "右值的引用用作左值"
@@ -53566,144 +53722,144 @@
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "使用了构造函数的语法，但没有为类型%qT声明构造函数"
 
-#: cp/typeck2.c:963
+#: cp/typeck2.c:966
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.c:974 cp/typeck2.c:988
+#: cp/typeck2.c:977 cp/typeck2.c:991
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.c:978
+#: cp/typeck2.c:981
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "位段%qs的宽度不是一个整数常量表达式"
 
-#: cp/typeck2.c:1066
+#: cp/typeck2.c:1069
 #, gcc-internal-format
 msgid "int-array initialized from non-wide string"
 msgstr "int 型数组由非宽字符串初始化"
 
-#: cp/typeck2.c:1072
+#: cp/typeck2.c:1075
 #, gcc-internal-format
 msgid "int-array initialized from incompatible wide string"
 msgstr "int 型数组不兼容的宽字符串初始化"
 
-#: cp/typeck2.c:1102
+#: cp/typeck2.c:1105
 #, gcc-internal-format
 msgid "initializer-string for array of chars is too long"
 msgstr "用以初始化字符数组的字符串太长"
 
-#: cp/typeck2.c:1154
+#: cp/typeck2.c:1157
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.c:1490 cp/typeck2.c:1517
+#: cp/typeck2.c:1496 cp/typeck2.c:1523
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.c:1498
+#: cp/typeck2.c:1504
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1505
+#: cp/typeck2.c:1511
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1581
+#: cp/typeck2.c:1587
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "类型%qD不匹配原先的声明"
 
-#: cp/typeck2.c:1654
+#: cp/typeck2.c:1660
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.c:1665
+#: cp/typeck2.c:1671
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.c:1852
+#: cp/typeck2.c:1858
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.c:1866
+#: cp/typeck2.c:1872
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.c:1892
+#: cp/typeck2.c:1898
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.c:1894
+#: cp/typeck2.c:1900
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.c:1921
+#: cp/typeck2.c:1927
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.c:1930
+#: cp/typeck2.c:1936
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.c:1952
+#: cp/typeck2.c:1958
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.c:2012
+#: cp/typeck2.c:2018
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2023
+#: cp/typeck2.c:2029
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2031
+#: cp/typeck2.c:2037
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2074
+#: cp/typeck2.c:2080
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck2.c:2089
+#: cp/typeck2.c:2096
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/typeck2.c:2107
+#: cp/typeck2.c:2114
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.c:2334
+#: cp/typeck2.c:2341
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.c:2337
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -54130,29 +54286,29 @@
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2041
+#: fortran/array.c:2055
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "%3$L处数组构造函数中不同 CHARACTER 长度(%1$d/%2$d)"
 
-#: fortran/array.c:2160
+#: fortran/array.c:2174
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2219
+#: fortran/array.c:2233
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2223
+#: fortran/array.c:2237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "%L处数组引用错误"
 
-#: fortran/array.c:2250 fortran/data.c:552 fortran/data.c:571
+#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
 #: fortran/data.c:585 fortran/data.c:714
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
@@ -54159,22 +54315,22 @@
 msgid "Simplification error"
 msgstr "gimplification 失败"
 
-#: fortran/array.c:2362
+#: fortran/array.c:2376
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2413
+#: fortran/array.c:2427
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2458
+#: fortran/array.c:2472
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2606
+#: fortran/array.c:2620
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -55171,7 +55327,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3605 fortran/decl.c:10035
+#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "%2$L处类型‘%1$s’达到了最大的扩展级别"
@@ -55351,7 +55507,7 @@
 msgid "deferred type parameter at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11695
+#: fortran/decl.c:1004 fortran/resolve.c:11705
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -55611,454 +55767,454 @@
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2474
+#: fortran/decl.c:2501
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2485
+#: fortran/decl.c:2512
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/decl.c:2511 fortran/decl.c:8338
+#: fortran/decl.c:2538 fortran/decl.c:8369
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:2519
+#: fortran/decl.c:2546
 #, fuzzy, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:2582
+#: fortran/decl.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "创建旧风格表格"
 
-#: fortran/decl.c:2590
+#: fortran/decl.c:2617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "引用类型的非法值初始化"
 
-#: fortran/decl.c:2603
+#: fortran/decl.c:2630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2623 fortran/decl.c:6630
+#: fortran/decl.c:2650 fortran/decl.c:6661
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2636
+#: fortran/decl.c:2663
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2645 fortran/decl.c:10209
+#: fortran/decl.c:2672 fortran/decl.c:10240
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C处需要一个初始化表达式"
 
-#: fortran/decl.c:2652
+#: fortran/decl.c:2679
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C处对变量的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2669
+#: fortran/decl.c:2696
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "不允许在%C处初始化可分配的组件"
 
-#: fortran/decl.c:2683
+#: fortran/decl.c:2710
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2691
+#: fortran/decl.c:2718
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2699
+#: fortran/decl.c:2726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "%3$L处‘%2$s’的指针组件‘%1$s’类型尚未声明"
 
-#: fortran/decl.c:2762 fortran/decl.c:2798
+#: fortran/decl.c:2789 fortran/decl.c:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%3$C处旧式的类型声明 %1$s*%2$d 不受支持"
 
-#: fortran/decl.c:2804
+#: fortran/decl.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%3$C处的 %1$s*%2$d 类型声明不符合标准"
 
-#: fortran/decl.c:2863 fortran/decl.c:2940
+#: fortran/decl.c:2890 fortran/decl.c:2967
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "%C处缺少右括号"
 
-#: fortran/decl.c:2876 fortran/decl.c:3011
+#: fortran/decl.c:2903 fortran/decl.c:3038
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C处需要初始化表达式"
 
-#: fortran/decl.c:2884 fortran/decl.c:3017
+#: fortran/decl.c:2911 fortran/decl.c:3044
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C处需要标量初始化表达式"
 
-#: fortran/decl.c:2914 fortran/decl.c:3626
+#: fortran/decl.c:2941 fortran/decl.c:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "种别 %1$d 不为类型%3$C处 %2$s 所支持"
 
-#: fortran/decl.c:2927
+#: fortran/decl.c:2954
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C 种别类型参数对应类型 %s 但%L处的类型却是 %s"
 
-#: fortran/decl.c:2938
+#: fortran/decl.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C处缺少右括号或逗号"
 
-#: fortran/decl.c:3043
+#: fortran/decl.c:3070
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "种别 %d 在%C处不为 CHARACTER 所支持"
 
-#: fortran/decl.c:3175
+#: fortran/decl.c:3202
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:3260
+#: fortran/decl.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3273
+#: fortran/decl.c:3304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "%C 需要一个无名接口"
 
-#: fortran/decl.c:3386
+#: fortran/decl.c:3417
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3410
+#: fortran/decl.c:3441
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "%L实体的种别类型参数与类型限定中的种别类型参数不同"
 
-#: fortran/decl.c:3434
+#: fortran/decl.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%>的第一个形参不能有默认参数"
 
-#: fortran/decl.c:3466
+#: fortran/decl.c:3497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/decl.c:3494
+#: fortran/decl.c:3525
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3501
+#: fortran/decl.c:3532
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%2$L处数组‘%1$s’是个变量，不能被归约为常量表达式"
 
-#: fortran/decl.c:3516
+#: fortran/decl.c:3547
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/decl.c:3788
+#: fortran/decl.c:3819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "扩展：%C处的 BYTE 类型"
 
-#: fortran/decl.c:3793
+#: fortran/decl.c:3824
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C处使用到的 BYTE 类型在目标机上不可用"
 
-#: fortran/decl.c:3815
+#: fortran/decl.c:3846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C处 TYPE 中的组件必须先于 CONTAINS"
 
-#: fortran/decl.c:3818
+#: fortran/decl.c:3849
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/decl.c:3841 fortran/decl.c:3872 fortran/decl.c:3901
-#: fortran/decl.c:4185
+#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
+#: fortran/decl.c:4216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "%C处类型指定无效"
 
-#: fortran/decl.c:3897
+#: fortran/decl.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "扩展：‘%s’重初始化于 %L"
 
-#: fortran/decl.c:3940 fortran/decl.c:4076 fortran/decl.c:4088
-#: fortran/decl.c:4102 fortran/decl.c:4580 fortran/decl.c:4588
+#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
+#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:4035
+#: fortran/decl.c:4066
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "未定义 C++ 基类"
 
-#: fortran/decl.c:4117
+#: fortran/decl.c:4148
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "类型名称‘%s’于 %C 冲突与在之前声明的实体于 %L, 该项有同名"
 
-#: fortran/decl.c:4256
+#: fortran/decl.c:4287
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C处 IMPLICIT NONE 语句重复"
 
-#: fortran/decl.c:4265
+#: fortran/decl.c:4296
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4324
+#: fortran/decl.c:4355
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C处 IMPLICIT 缺少字符范围"
 
-#: fortran/decl.c:4370
+#: fortran/decl.c:4401
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句中的字母必须按序排列"
 
-#: fortran/decl.c:4423
+#: fortran/decl.c:4454
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:4433
+#: fortran/decl.c:4464
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:4539
+#: fortran/decl.c:4570
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4546
+#: fortran/decl.c:4577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4551
+#: fortran/decl.c:4582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4565
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/decl.c:4594
+#: fortran/decl.c:4625
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "不能从%2$C处主机作用域单元 IMPORT‘%1$s’- 不存在。"
 
-#: fortran/decl.c:4601
+#: fortran/decl.c:4632
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "‘%s’已经从%C处主机作用域单元导入。"
 
-#: fortran/decl.c:4642
+#: fortran/decl.c:4673
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%C处的 IMPORT 语句语法错误"
 
-#: fortran/decl.c:4979
+#: fortran/decl.c:5010
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:4981
+#: fortran/decl.c:5012
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:5076
+#: fortran/decl.c:5107
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重复的 %s 属性，位于 %L"
 
-#: fortran/decl.c:5093
+#: fortran/decl.c:5124
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5110
+#: fortran/decl.c:5141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5119
+#: fortran/decl.c:5150
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5127
+#: fortran/decl.c:5158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/decl.c:5134
+#: fortran/decl.c:5165
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5143
+#: fortran/decl.c:5174
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5151
+#: fortran/decl.c:5182
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5189
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 
-#: fortran/decl.c:5167
+#: fortran/decl.c:5198
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5185
+#: fortran/decl.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5195
+#: fortran/decl.c:5226
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%2$L处的 %1$s 属性不允许出现在模块规格说明以外"
 
-#: fortran/decl.c:5205
+#: fortran/decl.c:5236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5218
+#: fortran/decl.c:5249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:5229
+#: fortran/decl.c:5260
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:5284 fortran/decl.c:8642
+#: fortran/decl.c:5315 fortran/decl.c:8673
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "%C处的 PROTECTED 仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:5290
+#: fortran/decl.c:5321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:5324
+#: fortran/decl.c:5355
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "%L处指定了重复的 VALUE 属性"
 
-#: fortran/decl.c:5331
+#: fortran/decl.c:5362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:5338
+#: fortran/decl.c:5369
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5379
+#: fortran/decl.c:5410
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "%C处为单个 NAME= 指定了多个标识符"
 
-#: fortran/decl.c:5477
+#: fortran/decl.c:5508
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "%2$L处隐式声明的 BIND(C) 函数‘%1$s’不能与 C 互操作"
 
-#: fortran/decl.c:5499
+#: fortran/decl.c:5530
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’可能不是 C 互操作种别，即使公共块‘%4$s’是 BIND(C)"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5539
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "%2$L处的类型声明‘%1$s’不是与 C 可互操作的，但它是个 BIND(C)"
 
-#: fortran/decl.c:5512
+#: fortran/decl.c:5543
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "%2$L处的变量‘%1$s’无法与 C 互操作但被声明为 BIND(C)"
 
-#: fortran/decl.c:5524
+#: fortran/decl.c:5555
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’不能被声明为 BIND(C)，因为它不是全局的"
 
-#: fortran/decl.c:5538
+#: fortran/decl.c:5569
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/decl.c:5546
+#: fortran/decl.c:5577
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/decl.c:5558
+#: fortran/decl.c:5589
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个数组"
 
-#: fortran/decl.c:5566
+#: fortran/decl.c:5597
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个字符串"
@@ -56065,962 +56221,962 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5577
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "%2$L处符号‘%1$s’被标记为 PRIVATE 但是已经给定绑定标号‘%3$s’"
 
-#: fortran/decl.c:5651
+#: fortran/decl.c:5682
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句需要实体或公共块名"
 
-#: fortran/decl.c:5696
+#: fortran/decl.c:5727
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句缺少实体或公共块名"
 
-#: fortran/decl.c:5703
+#: fortran/decl.c:5734
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "%s:%d: 缺少新的符号名称"
 
-#: fortran/decl.c:5732
+#: fortran/decl.c:5763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:5819
+#: fortran/decl.c:5850
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C处的派生类型以前尚未被定义，因此不能出现在派生类型定义中"
 
-#: fortran/decl.c:5861
+#: fortran/decl.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:5870
+#: fortran/decl.c:5901
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:5920
+#: fortran/decl.c:5951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:5965
+#: fortran/decl.c:5996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:5977
+#: fortran/decl.c:6008
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必须不出现两者于 %C"
 
-#: fortran/decl.c:6023
+#: fortran/decl.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6030
+#: fortran/decl.c:6061
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6037
+#: fortran/decl.c:6068
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6103 fortran/primary.c:1820
+#: fortran/decl.c:6134 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%L 不带 * 虚参的替代返回"
 
-#: fortran/decl.c:6109 fortran/decl.c:6117
+#: fortran/decl.c:6140 fortran/decl.c:6148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "缺少前导左括号"
 
-#: fortran/decl.c:6157
+#: fortran/decl.c:6188
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:6170
+#: fortran/decl.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C处数组声明需要另外一维"
 
-#: fortran/decl.c:6173
+#: fortran/decl.c:6204
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C处形参列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:6191
+#: fortran/decl.c:6222
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "重复的汇编操作数名%qs"
 
-#: fortran/decl.c:6194
+#: fortran/decl.c:6225
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符号‘%s’在%C处的形参列表中重复出现"
 
-#: fortran/decl.c:6233
+#: fortran/decl.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6239
+#: fortran/decl.c:6270
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6278
+#: fortran/decl.c:6309
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C处 RESULT 变量不能与函数重名"
 
-#: fortran/decl.c:6355
+#: fortran/decl.c:6386
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:6365 fortran/decl.c:7463
+#: fortran/decl.c:6396 fortran/decl.c:7494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008：%L处的 BIND(C)属性对于内部过程不可以指定"
 
-#: fortran/decl.c:6569
+#: fortran/decl.c:6600
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "%C处的 BIND(C) 属性要求一个具有 BIND(C)的接口"
 
-#: fortran/decl.c:6576
+#: fortran/decl.c:6607
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/decl.c:6582
+#: fortran/decl.c:6613
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "%C处的哑过程不能有带有 NAME 的 BIND(C) 属性"
 
-#: fortran/decl.c:6605
+#: fortran/decl.c:6636
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/decl.c:6651 fortran/decl.c:6839 fortran/decl.c:10692
+#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6700 fortran/decl.c:10592
+#: fortran/decl.c:6731 fortran/decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:6707
+#: fortran/decl.c:6738
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/decl.c:6711
+#: fortran/decl.c:6742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "%C处需要一个类型限定的过程或过程指针组件"
 
-#: fortran/decl.c:6783
+#: fortran/decl.c:6814
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C处过程指针组件语法错误"
 
-#: fortran/decl.c:6801
+#: fortran/decl.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C处的 PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:6810 fortran/decl.c:9361
+#: fortran/decl.c:6841 fortran/decl.c:9392
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6880
+#: fortran/decl.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6952
+#: fortran/decl.c:6983
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "函数定义在%C处需要形参列表"
 
-#: fortran/decl.c:6976 fortran/decl.c:6980 fortran/decl.c:7235
-#: fortran/decl.c:7239 fortran/decl.c:7431 fortran/decl.c:7435
+#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
+#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
 #: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%L处的 BIND(C) 属性只能用于变量或公共块"
 
-#: fortran/decl.c:7133
+#: fortran/decl.c:7164
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:7142
+#: fortran/decl.c:7173
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C处的 ENTRY 语句不能出现在 PROGRAM 中"
 
-#: fortran/decl.c:7145
+#: fortran/decl.c:7176
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:7148
+#: fortran/decl.c:7179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:7151
+#: fortran/decl.c:7182
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:7155 fortran/decl.c:7200
+#: fortran/decl.c:7186 fortran/decl.c:7231
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/decl.c:7159
+#: fortran/decl.c:7190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:7163
+#: fortran/decl.c:7194
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C处的 ENTRY 语句不能出现在 DERIVED TYPE 块中"
 
-#: fortran/decl.c:7167
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C处的 ENTRY 语句不能出现在 IF-THEN 块中"
 
-#: fortran/decl.c:7172
+#: fortran/decl.c:7203
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C处的 ENTRY 语句不能出现在 DO 块中"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7207
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:7180
+#: fortran/decl.c:7211
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C处的 ENTRY 语句不能出现在 FORALL 块中"
 
-#: fortran/decl.c:7184
+#: fortran/decl.c:7215
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C处的 ENTRY 语句不能出现在 WHERE 块中"
 
-#: fortran/decl.c:7188
+#: fortran/decl.c:7219
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C处的 ENTRY 语句不能出现在嵌套的子程序中"
 
-#: fortran/decl.c:7192
+#: fortran/decl.c:7223
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/decl.c:7213
+#: fortran/decl.c:7244
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
 
-#: fortran/decl.c:7264 fortran/decl.c:7470
+#: fortran/decl.c:7295 fortran/decl.c:7501
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "%C 处 BIND(C) 前缺少要求的括号"
 
-#: fortran/decl.c:7532 fortran/decl.c:7539
+#: fortran/decl.c:7563 fortran/decl.c:7570
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%C处的名字中有非法字符"
 
-#: fortran/decl.c:7579
+#: fortran/decl.c:7610
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C绑定标号的 NAME= 限定符语法错误"
 
-#: fortran/decl.c:7595
+#: fortran/decl.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/decl.c:7603
+#: fortran/decl.c:7634
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7622
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C处绑定标号缺少右括号"
 
-#: fortran/decl.c:7628
+#: fortran/decl.c:7659
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7665
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "对于哑过程 %s，%C 处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:7663
+#: fortran/decl.c:7694
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "%C 处的 ABSTRACT INTERFACE 的 BIND(C)上不允许有 NAME"
 
-#: fortran/decl.c:7908
+#: fortran/decl.c:7939
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:7917
+#: fortran/decl.c:7948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "%s 语句在%C处不能跟随 %s 语句在%L处"
 
 #. We would have required END [something].
-#: fortran/decl.c:7926
+#: fortran/decl.c:7957
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:7937
+#: fortran/decl.c:7968
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:7957
+#: fortran/decl.c:7988
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要块名‘%s’在‘%s’表达式中，于 %C"
 
-#: fortran/decl.c:7974
+#: fortran/decl.c:8005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/decl.c:7988 fortran/decl.c:7996
+#: fortran/decl.c:8019 fortran/decl.c:8027
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "%2$C处需要 %1$s 语句"
 
-#: fortran/decl.c:8095
+#: fortran/decl.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:8103
+#: fortran/decl.c:8134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "%2$L处在初始化后为 %1$s 指定了维数"
 
-#: fortran/decl.c:8111
+#: fortran/decl.c:8142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:8120
+#: fortran/decl.c:8151
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L处数组规格必须延迟"
 
-#: fortran/decl.c:8218
+#: fortran/decl.c:8249
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C处变量列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:8255
+#: fortran/decl.c:8286
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8269 fortran/decl.c:8309
+#: fortran/decl.c:8300 fortran/decl.c:8340
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在%C处需要变量名"
 
-#: fortran/decl.c:8285
+#: fortran/decl.c:8316
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/decl.c:8289
+#: fortran/decl.c:8320
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C处的 Cray 指针精度为 %d；内存地址需要 %d 字节"
 
-#: fortran/decl.c:8295
+#: fortran/decl.c:8326
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8334
+#: fortran/decl.c:8365
 #, fuzzy, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:8358
+#: fortran/decl.c:8389
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在%C处需要“)”"
 
-#: fortran/decl.c:8370
+#: fortran/decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:8396
+#: fortran/decl.c:8427
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:8428
+#: fortran/decl.c:8459
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:8447
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "%C处的 Cray 指针声明需要 -fcray-pointer 标记"
 
-#: fortran/decl.c:8486
+#: fortran/decl.c:8517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/decl.c:8592
+#: fortran/decl.c:8623
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%2$C处的 %1$s 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:8609
+#: fortran/decl.c:8640
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "%2$C处的 .%1$s. 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:8648
+#: fortran/decl.c:8679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:8686
+#: fortran/decl.c:8717
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:8710
+#: fortran/decl.c:8741
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PRIVATE 语句仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:8747
+#: fortran/decl.c:8778
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PUBLIC 语句只不允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:8775
+#: fortran/decl.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C处的 PARAMETER 语句需要变量名"
 
-#: fortran/decl.c:8782
+#: fortran/decl.c:8813
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 语句中需要 = 符号"
 
-#: fortran/decl.c:8788
+#: fortran/decl.c:8819
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 语句中需要表达式"
 
-#: fortran/decl.c:8808
+#: fortran/decl.c:8839
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "%C处初始化已经初始化的变量"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8833
+#: fortran/decl.c:8864
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8849
+#: fortran/decl.c:8880
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C处 PARAMETER 语句中有非预期的字符"
 
-#: fortran/decl.c:8868 fortran/decl.c:8924
+#: fortran/decl.c:8899 fortran/decl.c:8955
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8903
+#: fortran/decl.c:8934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/decl.c:8910
+#: fortran/decl.c:8941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:8959
+#: fortran/decl.c:8990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/decl.c:8966
+#: fortran/decl.c:8997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:8985
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C处覆盖 SAVE 语句跟随以前的 SAVE 语句"
 
-#: fortran/decl.c:8996
+#: fortran/decl.c:9027
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:9042
+#: fortran/decl.c:9073
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:9056
+#: fortran/decl.c:9087
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:9060
+#: fortran/decl.c:9091
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:9098
+#: fortran/decl.c:9129
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:9110
+#: fortran/decl.c:9141
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9137
+#: fortran/decl.c:9168
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易变的用于 coarray 变量‘%s’于 %C, 该项是 use-/ host-associated"
 
-#: fortran/decl.c:9162
+#: fortran/decl.c:9193
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9174
+#: fortran/decl.c:9205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:9218
+#: fortran/decl.c:9249
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:9243
+#: fortran/decl.c:9274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/decl.c:9336
+#: fortran/decl.c:9367
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C处的 MODULE PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:9394
+#: fortran/decl.c:9425
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "%L处内建过程不能是 MODULE PROCEDURE"
 
-#: fortran/decl.c:9443
+#: fortran/decl.c:9474
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:9452
+#: fortran/decl.c:9483
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/decl.c:9458
+#: fortran/decl.c:9489
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: fortran/decl.c:9465
+#: fortran/decl.c:9496
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 BIND(C)"
 
-#: fortran/decl.c:9472
+#: fortran/decl.c:9503
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 SEQUENCE 类型"
 
-#: fortran/decl.c:9495
+#: fortran/decl.c:9526
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PRIVATE"
 
-#: fortran/decl.c:9507
+#: fortran/decl.c:9538
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PUBLIC"
 
-#: fortran/decl.c:9528
+#: fortran/decl.c:9559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "%q+D的抽象类型无效"
 
-#: fortran/decl.c:9574
+#: fortran/decl.c:9605
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9580
+#: fortran/decl.c:9611
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:9627
+#: fortran/decl.c:9658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:9660
+#: fortran/decl.c:9691
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:9695
+#: fortran/decl.c:9726
 #, fuzzy, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/decl.c:9709
+#: fortran/decl.c:9740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:9727
+#: fortran/decl.c:9758
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:9734
+#: fortran/decl.c:9765
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:9895
+#: fortran/decl.c:9926
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定义中需要 ::"
 
-#: fortran/decl.c:9923
+#: fortran/decl.c:9954
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:9933
+#: fortran/decl.c:9964
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "%2$C处的派生类型名“%1$s”已经有一个基本类型 %3$s"
 
-#: fortran/decl.c:9950
+#: fortran/decl.c:9981
 #, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:10011
+#: fortran/decl.c:10042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:10095
+#: fortran/decl.c:10126
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C处 Cray 指针不能指向假定外形数组"
 
-#: fortran/decl.c:10115
+#: fortran/decl.c:10146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: fortran/decl.c:10147
+#: fortran/decl.c:10178
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C处：枚举量超过 C 整数类型"
 
-#: fortran/decl.c:10226
+#: fortran/decl.c:10257
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L没有用整数表达式初始化"
 
-#: fortran/decl.c:10274
+#: fortran/decl.c:10305
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C 前需要 ENUM 定义语句"
 
-#: fortran/decl.c:10310
+#: fortran/decl.c:10341
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C处 ENUMERATOR 定义中语法错误"
 
-#: fortran/decl.c:10357 fortran/decl.c:10372
+#: fortran/decl.c:10388 fortran/decl.c:10403
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "%C处重复访问限定符"
 
-#: fortran/decl.c:10392
+#: fortran/decl.c:10423
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "捆绑属性已经指定传递，%C处 NOPASS 非法"
 
-#: fortran/decl.c:10412
+#: fortran/decl.c:10443
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "捆绑属性已经指定传递， %C处 PASS 非法"
 
-#: fortran/decl.c:10439
+#: fortran/decl.c:10470
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%C处 POINTER 属性重复"
 
-#: fortran/decl.c:10457
+#: fortran/decl.c:10488
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C处 NON_OVERRIDABLE 重复"
 
-#: fortran/decl.c:10473
+#: fortran/decl.c:10504
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:10486
+#: fortran/decl.c:10517
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "%C需要访问限定符"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:10496
+#: fortran/decl.c:10527
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE 和 DEFERRED 不能同时出现在%C处"
 
-#: fortran/decl.c:10508
+#: fortran/decl.c:10539
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "%C处的过程指针组件需要 POINTER 属性"
 
-#: fortran/decl.c:10550
+#: fortran/decl.c:10581
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%C 需要一个无名接口"
 
-#: fortran/decl.c:10556
+#: fortran/decl.c:10587
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10576
+#: fortran/decl.c:10607
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10612
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "%C处的 PROCEDURE(接口) 需要声明为 DEFERRED"
 
-#: fortran/decl.c:10604
+#: fortran/decl.c:10635
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/decl.c:10608
+#: fortran/decl.c:10639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/decl.c:10620
+#: fortran/decl.c:10651
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:10626
+#: fortran/decl.c:10657
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%C处与显式目标捆绑的 PROCEDURE 中需要‘::’"
 
-#: fortran/decl.c:10636
+#: fortran/decl.c:10667
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:10653
+#: fortran/decl.c:10684
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "%2$C处包含 DEFERRED 绑定的类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/decl.c:10664
+#: fortran/decl.c:10695
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "在 %3$C 处对于派生类型“%2$s”已经有一个非普通的过程用限定名“%1$s”"
 
-#: fortran/decl.c:10715
+#: fortran/decl.c:10746
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "%C处的 GENERIC 必须是在派生类型 CONTAINS 内"
 
-#: fortran/decl.c:10735
+#: fortran/decl.c:10766
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10747
+#: fortran/decl.c:10778
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C处需要泛型名或运算符描述子"
 
-#: fortran/decl.c:10768
+#: fortran/decl.c:10799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C处的 USE 语句缺少泛型规格"
 
-#: fortran/decl.c:10779
+#: fortran/decl.c:10810
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10815
+#: fortran/decl.c:10846
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "%3$C处派生类型‘%2$s’已经有一个绑定名为‘%1$s’的非泛型过程"
 
-#: fortran/decl.c:10823
+#: fortran/decl.c:10854
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "%C处的绑定必须有与已经定义的绑定‘%s’相同的访问权限"
 
-#: fortran/decl.c:10871
+#: fortran/decl.c:10902
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "%C处需要特定的绑定名"
 
-#: fortran/decl.c:10881
+#: fortran/decl.c:10912
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%3$C处‘%1$s’已经定义为泛型的‘%2$s’特定的限定"
 
-#: fortran/decl.c:10899
+#: fortran/decl.c:10930
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:10934
+#: fortran/decl.c:10965
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "%C处的 FINAL 声明必须在一个派生类型的 CONTAINS 节内"
 
-#: fortran/decl.c:10945
+#: fortran/decl.c:10976
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "%C处带有 FINAL 的派生类型声明必须在 MODULE 的规格说明部分内"
 
-#: fortran/decl.c:10967
+#: fortran/decl.c:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "%C处的 FINAL 为空"
 
-#: fortran/decl.c:10974
+#: fortran/decl.c:11005
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:10984
+#: fortran/decl.c:11015
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10990
+#: fortran/decl.c:11021
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "未知的 C++ 编码名称"
 
-#: fortran/decl.c:11003
+#: fortran/decl.c:11034
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:11073
+#: fortran/decl.c:11104
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中有未知的属性"
 
-#: fortran/decl.c:11119
+#: fortran/decl.c:11150
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中的语法错误"
 
-#: fortran/decl.c:11139
+#: fortran/decl.c:11170
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11153
+#: fortran/decl.c:11184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -57357,27 +57513,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "扩展：%L处 BOZ 字面量被用来初始化非整数变量‘%s’"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10187
+#: fortran/expr.c:3369 fortran/resolve.c:10197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "扩展：在 %L处的 BOZ 字面量在一个 DATA 语句之外并且也在 INT/REAL/DBLE/CMPLX 之外"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10198
+#: fortran/expr.c:3380 fortran/resolve.c:10208
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "%L处 BOZ 字面量按位转换后是非整数符号‘%s’"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10207
+#: fortran/expr.c:3388 fortran/resolve.c:10217
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时算术下溢。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10211
+#: fortran/expr.c:3392 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时算术上溢。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10215
+#: fortran/expr.c:3396 fortran/resolve.c:10225
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时产生算术 NaN。这一检查可用 -fno-range-check 选项禁用"
@@ -57705,7 +57861,7 @@
 
 #: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
-#: fortran/trans-intrinsic.c:7217
+#: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "在%L处建立临时数组"
@@ -57715,64 +57871,64 @@
 msgid "Removing call to function %qs at %L"
 msgstr "%2$L处函数‘%1$s’的返回值没有设置"
 
-#: fortran/frontend-passes.c:1256 fortran/frontend-passes.c:1295
+#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "需要表达式"
 
-#: fortran/frontend-passes.c:1291
+#: fortran/frontend-passes.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "错误的移动"
 
-#: fortran/frontend-passes.c:2144
+#: fortran/frontend-passes.c:2161
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比较中操作数无效"
 
-#: fortran/frontend-passes.c:2390
+#: fortran/frontend-passes.c:2407
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:2397
+#: fortran/frontend-passes.c:2414
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:2620 fortran/frontend-passes.c:2644
+#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/frontend-passes.c:2629 fortran/frontend-passes.c:2653
+#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/frontend-passes.c:2713
+#: fortran/frontend-passes.c:2730
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:2719
+#: fortran/frontend-passes.c:2736
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:3111 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3620
+#: fortran/frontend-passes.c:3637
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4412
+#: fortran/frontend-passes.c:4429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "循环变量"
@@ -57892,12 +58048,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16341
+#: fortran/interface.c:970 fortran/resolve.c:16351
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16359
+#: fortran/interface.c:977 fortran/resolve.c:16369
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -59096,7 +59252,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/io.c:3369 fortran/resolve.c:14253
+#: fortran/io.c:3369 fortran/resolve.c:14263
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -60548,12 +60704,12 @@
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6229
+#: fortran/openmp.c:2942 fortran/openmp.c:6225
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6233
+#: fortran/openmp.c:2946 fortran/openmp.c:6229
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
@@ -60793,8 +60949,8 @@
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10018
-#: fortran/resolve.c:11285
+#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
+#: fortran/resolve.c:11295
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
@@ -60836,7 +60992,7 @@
 
 #: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
 #: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6027
+#: fortran/openmp.c:6023
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "%2$L处符号‘%1$s’出现在多个分句上"
@@ -61179,182 +61335,182 @@
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "%L处 !$OMP DO 折叠的循环不形成矩形迭代空间"
 
-#: fortran/openmp.c:5613
+#: fortran/openmp.c:5611
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: fortran/openmp.c:5622 fortran/openmp.c:5630
+#: fortran/openmp.c:5620 fortran/openmp.c:5628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: fortran/openmp.c:5714 fortran/openmp.c:5727
+#: fortran/openmp.c:5712 fortran/openmp.c:5725
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5746
+#: fortran/openmp.c:5744
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "%L处 !$OMP DO 不能是一个 DO WHILE 或不带循环控制的 DO"
 
-#: fortran/openmp.c:5752
+#: fortran/openmp.c:5750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "%L处 !$OMP DO 迭代变量必须具有整数类型"
 
-#: fortran/openmp.c:5768
+#: fortran/openmp.c:5766
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "%L处 !$OMP DO 折叠的循环不形成矩形迭代空间"
 
-#: fortran/openmp.c:5782
+#: fortran/openmp.c:5778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "折叠的 !$OMP DO 循环没有完美的嵌套于%L处"
 
-#: fortran/openmp.c:5792 fortran/openmp.c:5801
+#: fortran/openmp.c:5788 fortran/openmp.c:5797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: fortran/openmp.c:5816 fortran/openmp.c:5823
+#: fortran/openmp.c:5812 fortran/openmp.c:5819
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845
+#: fortran/openmp.c:5841
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5849 fortran/openmp.c:5853
+#: fortran/openmp.c:5845 fortran/openmp.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5856
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5864
+#: fortran/openmp.c:5860
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5870
+#: fortran/openmp.c:5866
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) 与 INTENT(%s) 在 %L 冲突"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5888
+#: fortran/openmp.c:5884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5890
+#: fortran/openmp.c:5886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/openmp.c:5897
+#: fortran/openmp.c:5893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5903
+#: fortran/openmp.c:5899
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5938
+#: fortran/openmp.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/openmp.c:6003
+#: fortran/openmp.c:5999
 #, fuzzy, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:6010
+#: fortran/openmp.c:6006
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/openmp.c:6137
+#: fortran/openmp.c:6133
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6159
+#: fortran/openmp.c:6155
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6183
+#: fortran/openmp.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6191
+#: fortran/openmp.c:6187
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6220
+#: fortran/openmp.c:6216
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6242
+#: fortran/openmp.c:6238
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6258
+#: fortran/openmp.c:6254
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6273
+#: fortran/openmp.c:6269
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6283
+#: fortran/openmp.c:6279
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6291
+#: fortran/openmp.c:6287
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -62716,7 +62872,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9550 fortran/resolve.c:11215
+#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
@@ -62826,7 +62982,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16273
+#: fortran/resolve.c:2905 fortran/resolve.c:16283
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
@@ -63201,229 +63357,229 @@
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 对象与 polymorphic allocatable subcomponent 于 %L"
 
-#: fortran/resolve.c:5909
+#: fortran/resolve.c:5919
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.c:5916
+#: fortran/resolve.c:5926
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.c:5951
+#: fortran/resolve.c:5961
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
-#: fortran/resolve.c:5960
+#: fortran/resolve.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6148
+#: fortran/resolve.c:6158
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.c:6175
+#: fortran/resolve.c:6185
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.c:6226
+#: fortran/resolve.c:6236
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:6776
+#: fortran/resolve.c:6786
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.c:6802
+#: fortran/resolve.c:6812
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:6816 fortran/resolve.c:6823
+#: fortran/resolve.c:6826 fortran/resolve.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6875
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:6901
+#: fortran/resolve.c:6911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:6918
+#: fortran/resolve.c:6928
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6924
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6985
+#: fortran/resolve.c:6995
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:6990
+#: fortran/resolve.c:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.c:6997
+#: fortran/resolve.c:7007
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7005
+#: fortran/resolve.c:7015
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.c:7010
+#: fortran/resolve.c:7020
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.c:7023
+#: fortran/resolve.c:7033
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.c:7126 fortran/resolve.c:7418
+#: fortran/resolve.c:7136 fortran/resolve.c:7428
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7134 fortran/resolve.c:7383
+#: fortran/resolve.c:7144 fortran/resolve.c:7393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7240
+#: fortran/resolve.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.c:7271
+#: fortran/resolve.c:7281
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:7429
+#: fortran/resolve.c:7439
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.c:7441
+#: fortran/resolve.c:7451
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.c:7455
+#: fortran/resolve.c:7465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7470
+#: fortran/resolve.c:7480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7483
+#: fortran/resolve.c:7493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.c:7501
+#: fortran/resolve.c:7511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 于 %L 与 type-spec 需求相同 character-length 参数作为在中声明"
 
-#: fortran/resolve.c:7582 fortran/resolve.c:7597
+#: fortran/resolve.c:7592 fortran/resolve.c:7607
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7589
+#: fortran/resolve.c:7599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7612
+#: fortran/resolve.c:7622
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7639
+#: fortran/resolve.c:7649
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:7658
+#: fortran/resolve.c:7668
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.c:7673
+#: fortran/resolve.c:7683
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7684
+#: fortran/resolve.c:7694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:7716
+#: fortran/resolve.c:7726
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:7739
+#: fortran/resolve.c:7749
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7750
+#: fortran/resolve.c:7760
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.c:7761
+#: fortran/resolve.c:7771
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:7784
+#: fortran/resolve.c:7794
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7814
+#: fortran/resolve.c:7824
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.c:7820 fortran/resolve.c:7826
+#: fortran/resolve.c:7830 fortran/resolve.c:7836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -63432,233 +63588,233 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8054
+#: fortran/resolve.c:8064
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:8105
+#: fortran/resolve.c:8115
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8116
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.c:8129
+#: fortran/resolve.c:8139
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.c:8175
+#: fortran/resolve.c:8185
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:8194
+#: fortran/resolve.c:8204
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8214
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:8222 fortran/resolve.c:8230
+#: fortran/resolve.c:8232 fortran/resolve.c:8240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8292 fortran/resolve.c:8863
+#: fortran/resolve.c:8302 fortran/resolve.c:8873
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.c:8318
+#: fortran/resolve.c:8328
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.c:8330
+#: fortran/resolve.c:8340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.c:8345
+#: fortran/resolve.c:8355
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.c:8448
+#: fortran/resolve.c:8458
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.c:8508
+#: fortran/resolve.c:8518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8513
+#: fortran/resolve.c:8523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8535
+#: fortran/resolve.c:8545
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:8546
+#: fortran/resolve.c:8556
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8753
+#: fortran/resolve.c:8763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.c:8773 fortran/resolve.c:8785
+#: fortran/resolve.c:8783 fortran/resolve.c:8795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8814
+#: fortran/resolve.c:8824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:8826
+#: fortran/resolve.c:8836
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:8838
+#: fortran/resolve.c:8848
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.c:8841
+#: fortran/resolve.c:8851
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:9098
+#: fortran/resolve.c:9108
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.c:9194
+#: fortran/resolve.c:9204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:9247
+#: fortran/resolve.c:9257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "数据转移组件于 %L 无法 polymorphic 除非它被处理由定义的输入/输出进程"
 
-#: fortran/resolve.c:9270
+#: fortran/resolve.c:9280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9279
+#: fortran/resolve.c:9289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9286
+#: fortran/resolve.c:9296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:9297
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9303
+#: fortran/resolve.c:9313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9318
+#: fortran/resolve.c:9328
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.c:9378
+#: fortran/resolve.c:9388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:9392
+#: fortran/resolve.c:9402
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:9395
+#: fortran/resolve.c:9405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:9402 fortran/resolve.c:9523
+#: fortran/resolve.c:9412 fortran/resolve.c:9533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:9414 fortran/resolve.c:9530
+#: fortran/resolve.c:9424 fortran/resolve.c:9540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:9426
+#: fortran/resolve.c:9436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:9439
+#: fortran/resolve.c:9449
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:9500
+#: fortran/resolve.c:9510
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:9504 fortran/resolve.c:9514
+#: fortran/resolve.c:9514 fortran/resolve.c:9524
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.c:9557
+#: fortran/resolve.c:9567
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9577
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
@@ -63665,12 +63821,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9584 fortran/resolve.c:9607
+#: fortran/resolve.c:9594 fortran/resolve.c:9617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往叙述于 %L 树叶重要建构用于标贴于 %L"
 
-#: fortran/resolve.c:9588 fortran/resolve.c:9613
+#: fortran/resolve.c:9598 fortran/resolve.c:9623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -63678,109 +63834,109 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9628
+#: fortran/resolve.c:9638
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.c:9700
+#: fortran/resolve.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.c:9716
+#: fortran/resolve.c:9726
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.c:9724 fortran/resolve.c:9811
+#: fortran/resolve.c:9734 fortran/resolve.c:9821
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9744 fortran/resolve.c:9831
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.c:9765
+#: fortran/resolve.c:9775
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:9774
+#: fortran/resolve.c:9784
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.c:9939
+#: fortran/resolve.c:9949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9959
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.c:10026
+#: fortran/resolve.c:10036
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.c:10128
+#: fortran/resolve.c:10138
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10241
+#: fortran/resolve.c:10251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.c:10273
+#: fortran/resolve.c:10283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
-#: fortran/resolve.c:10278
+#: fortran/resolve.c:10288
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/resolve.c:10320
+#: fortran/resolve.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10324
+#: fortran/resolve.c:10334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/resolve.c:10329
+#: fortran/resolve.c:10339
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:10336
+#: fortran/resolve.c:10346
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "变量必须不是 polymorphic 在中 intrinsic 指派于 %L - 检查该有匹配特定的副常式用于‘=’运算符"
 
-#: fortran/resolve.c:10347
+#: fortran/resolve.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.c:10653
+#: fortran/resolve.c:10663
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -63787,70 +63943,70 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10895
+#: fortran/resolve.c:10905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.c:10907
+#: fortran/resolve.c:10917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:11147
+#: fortran/resolve.c:11157
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.c:11150
+#: fortran/resolve.c:11160
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.c:11161
+#: fortran/resolve.c:11171
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.c:11223
+#: fortran/resolve.c:11233
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.c:11268
+#: fortran/resolve.c:11278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.c:11272
+#: fortran/resolve.c:11282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.c:11329
+#: fortran/resolve.c:11339
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11334
+#: fortran/resolve.c:11344
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:11418
+#: fortran/resolve.c:11428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:11497
+#: fortran/resolve.c:11507
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.c:11607
+#: fortran/resolve.c:11617
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -63857,7 +64013,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11620
+#: fortran/resolve.c:11630
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -63865,58 +64021,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11637
+#: fortran/resolve.c:11647
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.c:11722
+#: fortran/resolve.c:11732
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.c:11951
+#: fortran/resolve.c:11961
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:11955
+#: fortran/resolve.c:11965
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.c:11963
+#: fortran/resolve.c:11973
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11983
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:11988
+#: fortran/resolve.c:11998
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.c:12000
+#: fortran/resolve.c:12010
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.c:12031
+#: fortran/resolve.c:12041
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.c:12053
+#: fortran/resolve.c:12063
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
 
-#: fortran/resolve.c:12080
+#: fortran/resolve.c:12090
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
@@ -63923,894 +64079,894 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12121
+#: fortran/resolve.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.c:12140
+#: fortran/resolve.c:12150
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.c:12161
+#: fortran/resolve.c:12171
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12168
+#: fortran/resolve.c:12178
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12215
+#: fortran/resolve.c:12225
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12218
+#: fortran/resolve.c:12228
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12222
+#: fortran/resolve.c:12232
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12235
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12238
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12231
+#: fortran/resolve.c:12241
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12273
+#: fortran/resolve.c:12283
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，于 %s:%d"
 
-#: fortran/resolve.c:12300
+#: fortran/resolve.c:12310
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.c:12322
+#: fortran/resolve.c:12332
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.c:12344
+#: fortran/resolve.c:12354
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.c:12362
+#: fortran/resolve.c:12372
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12371
+#: fortran/resolve.c:12381
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12379
+#: fortran/resolve.c:12389
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12399
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:12408
+#: fortran/resolve.c:12418
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.c:12412
+#: fortran/resolve.c:12422
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.c:12416
+#: fortran/resolve.c:12426
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.c:12420
+#: fortran/resolve.c:12430
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.c:12433
+#: fortran/resolve.c:12443
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:12442
+#: fortran/resolve.c:12452
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:12448
+#: fortran/resolve.c:12458
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.c:12460
+#: fortran/resolve.c:12470
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:12517
+#: fortran/resolve.c:12527
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/resolve.c:12523
+#: fortran/resolve.c:12533
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.c:12529
+#: fortran/resolve.c:12539
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.c:12537
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.c:12543
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.c:12586
+#: fortran/resolve.c:12596
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12594
+#: fortran/resolve.c:12604
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12602
+#: fortran/resolve.c:12612
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12611
+#: fortran/resolve.c:12621
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12695
+#: fortran/resolve.c:12705
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:12704
+#: fortran/resolve.c:12714
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.c:12713
+#: fortran/resolve.c:12723
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:12721
+#: fortran/resolve.c:12731
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.c:12727
+#: fortran/resolve.c:12737
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.c:12733
+#: fortran/resolve.c:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:12741
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.c:12750
+#: fortran/resolve.c:12760
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.c:12772
+#: fortran/resolve.c:12782
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.c:12809
+#: fortran/resolve.c:12819
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.c:12849
+#: fortran/resolve.c:12859
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.c:12885
+#: fortran/resolve.c:12895
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "引用%qs有歧义：出现在接口%qs和接口%qs中"
 
-#: fortran/resolve.c:12944
+#: fortran/resolve.c:12954
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.c:12956
+#: fortran/resolve.c:12966
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.c:12984
+#: fortran/resolve.c:12994
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.c:13040
+#: fortran/resolve.c:13050
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.c:13232
+#: fortran/resolve.c:13242
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.c:13274
+#: fortran/resolve.c:13284
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:13288
+#: fortran/resolve.c:13298
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.c:13302 fortran/resolve.c:13768
+#: fortran/resolve.c:13312 fortran/resolve.c:13778
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.c:13310
+#: fortran/resolve.c:13320
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.c:13319
+#: fortran/resolve.c:13329
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.c:13325
+#: fortran/resolve.c:13335
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:13331
+#: fortran/resolve.c:13341
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.c:13360
+#: fortran/resolve.c:13370
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13380
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.c:13462
+#: fortran/resolve.c:13472
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.c:13564
+#: fortran/resolve.c:13574
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:13573
+#: fortran/resolve.c:13583
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13593
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:13592
+#: fortran/resolve.c:13602
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:13603
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L处 ICHAR 的参数长度必须为 1"
 
-#: fortran/resolve.c:13701
+#: fortran/resolve.c:13711
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:13715
+#: fortran/resolve.c:13725
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:13731
+#: fortran/resolve.c:13741
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13751
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.c:13750
+#: fortran/resolve.c:13760
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.c:13759
+#: fortran/resolve.c:13769
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:13801
+#: fortran/resolve.c:13811
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:13814
+#: fortran/resolve.c:13824
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.c:13825
+#: fortran/resolve.c:13835
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字符成分‘%s’的‘%s’于 %L 与已推迟长度必须是指标或 ALLOCATABLE"
 
-#: fortran/resolve.c:13858
+#: fortran/resolve.c:13868
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.c:13866
+#: fortran/resolve.c:13876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 于 %L 在中串行或绑定©类型 %s"
 
-#: fortran/resolve.c:13875
+#: fortran/resolve.c:13885
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.c:13893 fortran/resolve.c:13905
+#: fortran/resolve.c:13903 fortran/resolve.c:13915
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "%3$L处‘%2$s’的指针组件‘%1$s’类型尚未声明"
 
-#: fortran/resolve.c:13979
+#: fortran/resolve.c:13989
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/resolve.c:14024
+#: fortran/resolve.c:14034
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "作为延伸类型‘%s’于 %L 有 coarray 成分，亲代类型‘%s’应该也有一个"
 
-#: fortran/resolve.c:14037
+#: fortran/resolve.c:14047
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.c:14101
+#: fortran/resolve.c:14111
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14134
+#: fortran/resolve.c:14144
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:14206
+#: fortran/resolve.c:14216
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.c:14212
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.c:14218
+#: fortran/resolve.c:14228
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:14226
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:14243
+#: fortran/resolve.c:14253
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:14265
+#: fortran/resolve.c:14275
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.c:14276
+#: fortran/resolve.c:14286
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14313
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.c:14327
+#: fortran/resolve.c:14337
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.c:14343
+#: fortran/resolve.c:14353
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.c:14354
+#: fortran/resolve.c:14364
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:14362
+#: fortran/resolve.c:14372
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14413
+#: fortran/resolve.c:14423
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:14424
+#: fortran/resolve.c:14434
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14431
+#: fortran/resolve.c:14441
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14470
+#: fortran/resolve.c:14480
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:14537
+#: fortran/resolve.c:14547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:14633
+#: fortran/resolve.c:14643
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14654
+#: fortran/resolve.c:14664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/resolve.c:14667
+#: fortran/resolve.c:14677
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:14670
+#: fortran/resolve.c:14680
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:14678
+#: fortran/resolve.c:14688
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14695
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14698
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.c:14704
+#: fortran/resolve.c:14714
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14724
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.c:14723
+#: fortran/resolve.c:14733
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.c:14736 fortran/resolve.c:14913
+#: fortran/resolve.c:14746 fortran/resolve.c:14923
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.c:14750
+#: fortran/resolve.c:14760
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14759
+#: fortran/resolve.c:14769
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14768
+#: fortran/resolve.c:14778
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14776
+#: fortran/resolve.c:14786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14783
+#: fortran/resolve.c:14793
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14803
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.c:14810
+#: fortran/resolve.c:14820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14817
+#: fortran/resolve.c:14827
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14824
+#: fortran/resolve.c:14834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.c:14850
+#: fortran/resolve.c:14860
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14870
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:14939
+#: fortran/resolve.c:14949
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.c:14954
+#: fortran/resolve.c:14964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:14967
+#: fortran/resolve.c:14977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:14985
+#: fortran/resolve.c:14995
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.c:14997
+#: fortran/resolve.c:15007
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15006
+#: fortran/resolve.c:15016
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15018
+#: fortran/resolve.c:15028
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15027
+#: fortran/resolve.c:15037
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:15039
+#: fortran/resolve.c:15049
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:15055
+#: fortran/resolve.c:15065
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.c:15063
+#: fortran/resolve.c:15073
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:15070
+#: fortran/resolve.c:15080
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.c:15082
+#: fortran/resolve.c:15092
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15091
+#: fortran/resolve.c:15101
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15107
+#: fortran/resolve.c:15117
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15113
+#: fortran/resolve.c:15123
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15138
+#: fortran/resolve.c:15148
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.c:15208
+#: fortran/resolve.c:15218
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.c:15219
+#: fortran/resolve.c:15229
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15323
+#: fortran/resolve.c:15333
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15329
+#: fortran/resolve.c:15339
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.c:15335
+#: fortran/resolve.c:15345
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.c:15344
+#: fortran/resolve.c:15354
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:15358
+#: fortran/resolve.c:15368
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.c:15404
+#: fortran/resolve.c:15414
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.c:15417
+#: fortran/resolve.c:15427
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.c:15516
+#: fortran/resolve.c:15526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15524
+#: fortran/resolve.c:15534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15532
+#: fortran/resolve.c:15542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15657
+#: fortran/resolve.c:15667
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.c:15822
+#: fortran/resolve.c:15832
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.c:15828
+#: fortran/resolve.c:15838
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.c:15912
+#: fortran/resolve.c:15922
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15931
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15929
+#: fortran/resolve.c:15939
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.c:15945
+#: fortran/resolve.c:15955
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16048
+#: fortran/resolve.c:16058
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.c:16063
+#: fortran/resolve.c:16073
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.c:16088
+#: fortran/resolve.c:16098
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16097
+#: fortran/resolve.c:16107
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16170
+#: fortran/resolve.c:16180
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16181
+#: fortran/resolve.c:16191
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16192
+#: fortran/resolve.c:16202
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.c:16283
+#: fortran/resolve.c:16293
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.c:16296
+#: fortran/resolve.c:16306
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:16316
+#: fortran/resolve.c:16326
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16336
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.c:16334
+#: fortran/resolve.c:16344
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:16348
+#: fortran/resolve.c:16358
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.c:16366
+#: fortran/resolve.c:16376
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.c:16373
+#: fortran/resolve.c:16383
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.c:16451
+#: fortran/resolve.c:16461
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -65254,7 +65410,7 @@
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree()：无效类型；%s"
 
-#: fortran/simplify.c:8085
+#: fortran/simplify.c:8078
 #, fuzzy, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "%2$L处字符串中的字符‘%1$s’不能被转换到字符种别 %3$d"
@@ -65902,18 +66058,18 @@
 msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "内部函数 %s(%d) 无法识别"
 
-#: fortran/trans-intrinsic.c:2270 fortran/trans-intrinsic.c:2735
-#: fortran/trans-intrinsic.c:2932
+#: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
+#: fortran/trans-intrinsic.c:3022
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%2$L处‘%1$s’内建函数的‘dim’实参不是一个有效的维数索引"
 
-#: fortran/trans-intrinsic.c:10482 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/trans-intrinsic.c:10489
+#: fortran/trans-intrinsic.c:10579
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
@@ -66096,179 +66252,179 @@
 msgid "previously defined here as %s"
 msgstr "%q+#D已在此定义过"
 
-#: lto/lto-symtab.c:475
+#: lto/lto-symtab.c:480
 #, fuzzy, gcc-internal-format
 msgid "multiple prevailing defs for %qE"
 msgstr "%2$qE的第 %1$d 个参数必须是 %3$d 的倍数"
 
-#: lto/lto-symtab.c:493
+#: lto/lto-symtab.c:498
 #, gcc-internal-format
 msgid "%qD has already been defined"
 msgstr "%qD已定义过"
 
-#: lto/lto-symtab.c:495
+#: lto/lto-symtab.c:500
 #, gcc-internal-format
 msgid "previously defined here"
 msgstr "以前在此定义过"
 
-#: lto/lto-symtab.c:703
+#: lto/lto-symtab.c:717
 #, fuzzy, gcc-internal-format
 msgid "%qD violates the C++ One Definition Rule "
 msgstr "先前的定义在这里"
 
-#: lto/lto-symtab.c:708
+#: lto/lto-symtab.c:722
 #, gcc-internal-format
 msgid "type of %qD does not match original declaration"
 msgstr "类型%qD不匹配原先的声明"
 
-#: lto/lto-symtab.c:728
+#: lto/lto-symtab.c:742
 #, gcc-internal-format
 msgid "alignment of %qD is bigger than original declaration"
 msgstr "%qD的对齐"
 
-#: lto/lto-symtab.c:734
+#: lto/lto-symtab.c:748
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "size of %qD differ from the size of original declaration"
 msgstr "类型%qD不匹配原先的声明"
 
-#: lto/lto-symtab.c:739
+#: lto/lto-symtab.c:753
 #, fuzzy, gcc-internal-format
 msgid "%qD was previously declared here"
 msgstr "以前在此声明过"
 
-#: lto/lto-symtab.c:742
+#: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
 msgstr ""
 
-#: lto/lto-symtab.c:828
+#: lto/lto-symtab.c:842
 #, gcc-internal-format
 msgid "variable %qD redeclared as function"
 msgstr "变量%qD重声明为函数"
 
-#: lto/lto-symtab.c:835
+#: lto/lto-symtab.c:849
 #, gcc-internal-format
 msgid "function %qD redeclared as variable"
 msgstr "函数%qD重声明为变量"
 
-#: lto/lto-symtab.c:847
+#: lto/lto-symtab.c:861
 #, gcc-internal-format
 msgid "previously declared here"
 msgstr "以前在此声明过"
 
-#: lto/lto.c:1845
+#: lto/lto.c:1890
 #, gcc-internal-format
 msgid "bytecode stream: garbage at the end of symbols section"
 msgstr "字节码流：符号节结尾有垃圾字符"
 
-#: lto/lto.c:1872
+#: lto/lto.c:1917
 #, gcc-internal-format
 msgid "could not parse hex number"
 msgstr "不能解析 16 进制数"
 
-#: lto/lto.c:1904
+#: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
 msgstr "符号解析文件中有非预期的文件名 %s。需要 %s"
 
-#: lto/lto.c:1913
+#: lto/lto.c:1958
 #, gcc-internal-format
 msgid "could not parse file offset"
 msgstr "不能解析文件偏移量"
 
-#: lto/lto.c:1916
+#: lto/lto.c:1961
 #, gcc-internal-format
 msgid "unexpected offset"
 msgstr "非预期的偏移"
 
-#: lto/lto.c:1938
+#: lto/lto.c:1983
 #, fuzzy, gcc-internal-format
 msgid "invalid line in the resolution file"
 msgstr "符号解析文件"
 
-#: lto/lto.c:1949
+#: lto/lto.c:1994
 #, fuzzy, gcc-internal-format
 msgid "invalid resolution in the resolution file"
 msgstr "符号解析文件"
 
-#: lto/lto.c:1955
+#: lto/lto.c:2000
 #, fuzzy, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
 msgstr "分辨率子识别号 "
 
-#: lto/lto.c:2072
+#: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO decls from %s"
 msgstr "无法从 “%s” 中读取 LTO decls"
 
-#: lto/lto.c:2178
+#: lto/lto.c:2223
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot open %s"
 msgstr "无法打开 %s"
 
-#: lto/lto.c:2199
+#: lto/lto.c:2244
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot map %s"
 msgstr "无法映射 %s"
 
-#: lto/lto.c:2210
+#: lto/lto.c:2255
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot read %s"
 msgstr "无法读取 %s"
 
-#: lto/lto.c:2324
+#: lto/lto.c:2369
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() 失败"
 
-#: lto/lto.c:2349
+#: lto/lto.c:2394
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid 失败"
 
-#: lto/lto.c:2352
+#: lto/lto.c:2397
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "%s 子进程失败"
 
-#: lto/lto.c:2355
+#: lto/lto.c:2400
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "子进程收到致命信号 %d"
 
-#: lto/lto.c:2431
+#: lto/lto.c:2476
 #, fuzzy, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "打开 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2519
+#: lto/lto.c:2564
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "打开 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2525
+#: lto/lto.c:2570
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "写入 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2536
+#: lto/lto.c:2581
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "关闭 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2788
+#: lto/lto.c:2833
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "无法打开符号解析文件：%s"
 
-#: lto/lto.c:2909
+#: lto/lto.c:2954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: lto/lto.c:2941
+#: lto/lto.c:2986
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "错误在的期间合并的转译单位"
@@ -68678,6 +68834,14 @@
 #~ msgstr "%qE不是一个类"
 
 #, fuzzy
+#~ msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
+#~ msgstr "range-based %<for%> 运算式的类型 %qT 有 %<end%>成员并不是 %<begin%>"
+
+#, fuzzy
+#~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
+#~ msgstr "range-based %<for%> 运算式的类型 %qT 有 %<begin%>成员并不是 %<end%>"
+
+#, fuzzy
 #~ msgid "break statement used with Cilk Plus for loop"
 #~ msgstr "OpenMP for 循环中使用了 break 语句"
 
@@ -68786,6 +68950,9 @@
 #~ msgid "invalid use of Boolean expression as operand to %<operator--%>"
 #~ msgstr "布尔表达式不能用作%<运算符--%>的操作数"
 
+#~ msgid "cannot convert %qT to %qT for argument %qP to %qD"
+#~ msgstr "不能将%4$qD的实参%3$qP从%1$qT转换到%2$qT"
+
 #~ msgid "return-statement with a value, in function returning 'void'"
 #~ msgstr "在返回‘void’的函数中，返回语句带返回值"
 
